# NGLui

!!! danger "Breaking Changes in 4.0.0"

    NGLui has undergone a major upgrade to version 4.0.0, which breaks many of the old features of version 3.x.
    In doing so, the API should be easier and more consisstent, with new features by focusing on the modern implementation of Neuroglancer and the bleeding edge Spelunker deployment used in many CAVE projects.
    See the [Changelog](./changelog.md) for more details.

NGLui is a Python library to help interacting with Neuroglancer, a web-based viewer for large-scale 3D data visualization.
Neuroglancer is designed to visualize large, 3d datasets, such as those found in connectomics, and `nglui` is designed to make it easier to generate and parse Neuroglancer states.
It is particularly useful in the context of the [CAVE analysis ecosystem](https://caveconnectome.github.io/CAVEclient/), which provides tools for analyzing, proofreading and visualizing lage-scale connectomics data.

## Installation

To get the most out of NGLui (interacting with source info, uploading skeletons, and more), we suggest installing the full version of NGLui, which includes the [`cloud-volume`](https://github.com/seung-lab/cloud-volume/) dependency:

``` bash
pip install nglui[full]
```

You can also install a more minimal version of NGLui without the cloud-volume dependency:

``` bash
pip install nglui
```

However, note that cloud-volume is required for some features such as uploading skeletons and getting information about sources during state generation.

## Quick Usage

### Building a Neuroglancer state directly

Here, let's use the Hemibrain dataset information to build a Neuroglancer state.

``` py
from nglui import statebuilder

viewer_state = (
    statebuilder.ViewerState(dimensions=[8,8,8])
    .add_image_layer(
        source='precomputed://gs://neuroglancer-janelia-flyem-hemibrain/emdata/clahe_yz/jpeg',
        name='emdata'
    )
    .add_segmentation_layer(
        source='precomputed://gs://neuroglancer-janelia-flyem-hemibrain/v1.2/segmentation',
        name='seg',
        segments=[5813034571],
    )
    .add_annotation_layer(
        source='precomputed://gs://neuroglancer-janelia-flyem-hemibrain/v1.2/synapses',
        linked_segmentation={'pre_synaptic_cell': 'seg'},
        filter_by_segmentation=True,
        color='tomato',
    )
)
viewer_state.to_link(target_url='https://hemibrain-dot-neuroglancer-demo.appspot.com')
```

This will return the link: [Neuroglancer link](https://hemibrain-dot-neuroglancer-demo.appspot.com#!%7B%22position%22:%5B17216.0,19776.0,20704.0%5D,%22layout%22:%22xy-3d%22,%22dimensions%22:%7B%22x%22:%5B8e-09,%22m%22%5D,%22y%22:%5B8e-09,%22m%22%5D,%22z%22:%5B8e-09,%22m%22%5D%7D,%22crossSectionScale%22:1.0,%22projectionScale%22:50000.0,%22showSlices%22:false,%22layers%22:%5B%7B%22type%22:%22image%22,%22source%22:%5B%7B%22url%22:%22precomputed://gs://neuroglancer-janelia-flyem-hemibrain/emdata/clahe_yz/jpeg%22,%22subsources%22:%7B%7D,%22enableDefaultSubsources%22:true%7D%5D,%22shader%22:%22None%22,%22name%22:%22emdata%22%7D,%7B%22type%22:%22segmentation%22,%22source%22:%5B%7B%22url%22:%22precomputed://gs://neuroglancer-janelia-flyem-hemibrain/v1.0/segmentation%22,%22subsources%22:%7B%7D,%22enableDefaultSubsources%22:true%7D%5D,%22segments%22:%5B%5D,%22selectedAlpha%22:0.2,%22notSelectedAlpha%22:0.0,%22objectAlpha%22:0.9,%22segmentColors%22:%7B%7D,%22meshSilhouetteRendering%22:0.0,%22skeletonRendering%22:%7B%7D,%22name%22:%22seg%22%7D,%7B%22type%22:%22annotation%22,%22source%22:%5B%7B%22url%22:%22precomputed://gs://neuroglancer-janelia-flyem-hemibrain/v1.0/synapses%22,%22subsources%22:%7B%7D,%22enableDefaultSubsources%22:true%7D%5D,%22linkedSegmentationLayer%22:%7B%22pre_synaptic_cell%22:%22seg%22,%22post_synaptic_cell%22:%22seg%22%7D,%22filterBySegmentation%22:%5B%22pre_synaptic_cell%22,%22post_synaptic_cell%22%5D,%22shader%22:%22%5Cnvoid%20main()%20%7B%5Cn%20%20setColor(defaultColor());%5Cn%7D%5Cn%22,%22name%22:%22annotation%22%7D%5D%7D).

### Building a state from CAVE data

!!! note

    Using [CAVEclient](https://caveconnectome.github.io/CAVEclient/) with the MICrONs dataset is required for the following examples.
    See the [MICrONs documentation](https://tutorial.microns-explorer.org/quickstart_notebooks/01-caveclient-setup.html) for how to set up the CAVEclient and access the dataset.

Here's a quick example of how to use NGLui to generate a simple Neuroglancer state from the [Microns cortical dataset](https://www.microns-explorer.org).

``` py
import caveclient
from nglui import statebuilder

client = caveclient.CAVEclient('minnie65_public')

# Get a root id of a specific neuron
root_id = client.materialize.query_table(
    'nucleus_detection_v0',
    filter_equal_dict={'id': 255258}
)['pt_root_id']

statebuilder.helpers.make_neuron_neuroglancer_link(
    client,
    root_id,
    show_inputs=True,
    show_outputs=True,
)
```

This code will generate [this link](https://spelunker.cave-explorer.org/#!%7B%22position%22:%5B172452.0,115986.0,22351.0%5D,%22layout%22:%22xy-3d%22,%22dimensions%22:%7B%22x%22:%5B4e-09,%22m%22%5D,%22y%22:%5B4e-09,%22m%22%5D,%22z%22:%5B4e-08,%22m%22%5D%7D,%22crossSectionScale%22:1.0,%22projectionScale%22:50000.0,%22showSlices%22:false,%22layers%22:%5B%7B%22type%22:%22image%22,%22source%22:%5B%7B%22url%22:%22precomputed://https://bossdb-open-data.s3.amazonaws.com/iarpa_microns/minnie/minnie65/em%22,%22transform%22:%7B%22outputDimensions%22:%7B%22x%22:%5B4e-09,%22m%22%5D,%22y%22:%5B4e-09,%22m%22%5D,%22z%22:%5B4e-08,%22m%22%5D%7D%7D,%22subsources%22:%7B%7D,%22enableDefaultSubsources%22:true%7D%5D,%22shader%22:%22None%22,%22name%22:%22imagery%22%7D,%7B%22type%22:%22segmentation%22,%22source%22:%5B%7B%22url%22:%22graphene://middleauth+https://minnie.microns-daf.com/segmentation/table/minnie65_public%22,%22transform%22:%7B%22outputDimensions%22:%7B%22x%22:%5B4e-09,%22m%22%5D,%22y%22:%5B4e-09,%22m%22%5D,%22z%22:%5B4e-08,%22m%22%5D%7D%7D,%22subsources%22:%7B%7D,%22enableDefaultSubsources%22:true%7D,%7B%22url%22:%22precomputed://middleauth+https://minnie.microns-daf.com/skeletoncache/api/v1/minnie65_public/precomputed/skeleton/%22,%22transform%22:%7B%22outputDimensions%22:%7B%22x%22:%5B4e-09,%22m%22%5D,%22y%22:%5B4e-09,%22m%22%5D,%22z%22:%5B4e-08,%22m%22%5D%7D%7D,%22subsources%22:%7B%7D,%22enableDefaultSubsources%22:true%7D%5D,%22segments%22:%5B%22864691135491912167%22%5D,%22selectedAlpha%22:0.5,%22notSelectedAlpha%22:0.0,%22objectAlpha%22:1.0,%22segmentColors%22:%7B%7D,%22meshSilhouetteRendering%22:0,%22skeletonRendering%22:%7B%7D,%22name%22:%22segmentation%22%7D,%7B%22type%22:%22annotation%22,%22source%22:%5B%7B%22url%22:%22local://annotations%22,%22transform%22:%7B%22outputDimensions%22:%7B%22x%22:%5B1e-09,%22m%22%5D,%22y%22:%5B1e-09,%22m%22%5D,%22z%22:%5B1e-09,%22m%22%5D%7D%7D%7D%5D,%22annotations%22:%5B%7B%22type%22:%22point%22,%22id%22:%22da517dbd2ab3178900e9ea3e5ff01f4d9e8f0df6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714896.0,474480.0,852880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8995dff1927a3239c0a1d33a34494858f487da6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718440.0,440968.0,915400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22956acfd12cceb7ae979442c69ea9bb7ffcd170b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777312.0,451368.0,882640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c8f1f0fe844eb1cb89063dcab105aeb8d00fd3c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720480.0,452192.0,842200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253cd6228e348f665e6588a60c21b028db7ac2760%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604896.0,368400.0,978920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cd3301f179b7b2a6917d46d9dc84b6a3396d3ede%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700600.0,450824.0,897880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2ef65cd1a4933351198011ae5af8c8a5c226627%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676536.0,430216.0,919040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206100066d0ef47fa0835119ea3164b85aa3d7a1c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697512.0,442016.0,887800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af76200e9dc1fdfa8cdc9eea6453448f67c08774%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675224.0,448120.0,882800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265caee069c1b5ec9f13eaf2013bea2089ab46ca6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703744.0,370136.0,987520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b01632a8368e302643fa5b4cdfcb8f76e410357%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631604.0,440136.0,812320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22186780139e65caf37133cb718f5eef311669fce0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692116.0,439348.0,893560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f189e3e213cc4a8ebc08a4a9018c302fc080db2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670040.0,398096.0,1004040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f40114df1697e97c752beda62c9133b6af853817%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717680.0,422656.0,872520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267e8647fb07998b4d52a8d4ed3294d761f66981b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B757480.0,363088.0,938720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22607d9f54bf4d87e8eaf7d793f3dce66282912335%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618088.0,395784.0,802920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2212d043eb74cfc567e2224a20a065c2690691df99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640824.0,456368.0,918320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22891b04f7a269fca054d8690ab8d65949a97f5907%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716112.0,439640.0,868800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22188dc9a327c815840ce7fd74d9604f0c4095b56b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668664.0,521768.0,864360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a423a7c39ef15287be6e94d486eeb9e7bcdb72f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707680.0,368912.0,995960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dd8a642cf3f33000259600a2f604b8a0878eeb35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674864.0,463952.0,945840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22acc717ba2b34bfdd6f0d612562da8a74bcbf207c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647880.0,414368.0,838600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dae3c08ed5a3aa09fcbe3793a6a137394987f63b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B588880.0,392504.0,815080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c0e03c8a1ee42510b93e0fdf50d18af443ee674%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679616.0,406736.0,903720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d09ee68d7d55ee1b18ea88e3c60ea3409663be2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690640.0,467840.0,880280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e91165050c0287525070eeb3eee7971879e3806e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623376.0,461168.0,876160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee4affa34cee8eeb9a047c9e9dd8266e7cf74e28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B551896.0,393640.0,809440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb0c46070b86e449e23a4196df3e840c7acae030%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B790480.0,352736.0,939840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3484ed45cbdccb4e5774dddea566f6d62ae992f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B802096.0,343608.0,986520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207ec0838a22605cfede58af9da655e98b9377d66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659896.0,449496.0,862640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229da02532f64386bb745afa3a4aaf7015c01fa95a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647824.0,456032.0,931480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2286a39b791d5dcad747234e7afd066184e84901f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752320.0,419856.0,966120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7e4fedc3ba8f825fb0357631b0c96291e119e73%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691568.0,408736.0,830160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22490f8ebb13cfd02faafcf714f469f5be4e3f0f14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710000.0,393184.0,929520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226647ef665b47526569bd84d04c36c9a586c18540%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638568.0,492880.0,900280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2262a1cb4aaec29e85f38ff37cb8c71133feaef328%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749528.0,397964.0,954080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b19b43ab214af51ca53e9119ace20e013db2fae3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676304.0,503176.0,867600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220ca6dae19a037d3b404397f83b1954ea4425900%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616504.0,405592.0,815800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22785d987aa0f0e935084839c9cad76dcc29485f4f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677408.0,376816.0,815200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ae810a05569bc8ac09d149a73d3a692027a74d0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713752.0,439944.0,917480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a188fd77f0d46f26f18af20408404050f88a0be0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720472.0,463128.0,974280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c9afc0149be48a7e0cb56b3d0350e5f4d902109a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B551336.0,347920.0,989680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f63f881362db9577f24870113376c4df0f8dc4e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630448.0,392516.0,813520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272b645dc9bb89af2246325b2ee31c331230176a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B598584.0,367176.0,977920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227b393f46105ef561ad4a3de7868d50917d55a3e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704888.0,445144.0,881640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2214264416385e6c570ddcf8f9de9235bdd9ecb4f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708400.0,451776.0,874760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b623d17e3cb4e76f5d5434656d40c4bad2211359%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709176.0,429592.0,879520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22053859395d5be63990e5b211d55af00b2f49229b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649448.0,411312.0,905240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bcac94defd81b0f4b2c9e427291b16398c676090%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707632.0,364608.0,1032680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247839560cc6aaf6a181a7ab907ebf2fecd034bf8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603016.0,419384.0,910760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c35887fe5f3684ff0a227d172bf17999107457f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607904.0,419752.0,909440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aae9b84389568b2148062e517e4b1083a5b8d0e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612144.0,370968.0,978440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf188c768ff8f19e292f4682b78f303acfebdc53%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B798480.0,453208.0,881000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a10a1ba53567f47474906b0ce4e411c5f315fb5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658824.0,451520.0,894320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231c9478cdd3ed93e2c2e2296de0dd0d7579f0f48%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B746752.0,421224.0,960360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab1fae78e820fb25027a200915a64e76bc95302e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672872.0,405908.0,859320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226bafc168952a197852ae15e02d727d4492448fa8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679296.0,388400.0,830880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2212f608863aa77eb4ca40f99a43f0c0240c69b7ac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701480.0,434576.0,933880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228fd84d57709dd770d91424925075f41143973c80%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685768.0,482536.0,981160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22500b3e71fa556fe101c8735b898395768219d7de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645564.0,483296.0,902000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6a053815339dbe5e53104cd8ce94eab462c4216%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595992.0,395736.0,814760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22421899860aa25ff17f2a6a21559e409e7ba420fb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700960.0,435160.0,932240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af6e3a1fe8c035d3629be8f95e5993229cef2813%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649180.0,466608.0,948840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc6954ceba026f41bf90810fed7382828e0831b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702112.0,394680.0,903200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222125467e9d23b5acff57e5498fa546260074523e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694328.0,356392.0,1057240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e05c0ec348c56c7bc82ba0e2cb2c55701d15a8c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674352.0,448744.0,889800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224233e64ff4979e9fef7ecf9bae0623f522fa784f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685336.0,458968.0,941320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b6cbf3d448c90dd479d03c087735252d79093f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714664.0,443288.0,984200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b56dc4337706779612628ab24d0c9fc9c30df614%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754264.0,421240.0,968160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e160d2b76df2d96701f7c6e08d9de2e3fae4e87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740656.0,422816.0,957760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224ce0ff1126e49496d5bd8eef67130d68424e1807%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728648.0,458968.0,810600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1033db81bd42b19365044490d85ec7df7557c87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709240.0,448512.0,882200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae417302803e54b6f328413b8e672d461070ef76%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650624.0,454208.0,895640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224214df5504d086308c88365be106aa9bcf420c73%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726084.0,453340.0,830000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ab718f2bf73af09fe2ac413b5f7ff92730cc30f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668088.0,421416.0,934960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226efcfe69072a4cf741730e7fbfd405edc5420b09%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665320.0,364244.0,788560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b8750a57f70bccd816befd0ed3b0e5c54dfb8f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690600.0,436120.0,901880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225fe4acf88452292de6e112f5cbf29a07702e286a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665728.0,458048.0,863440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22400372891e23fd78f02be11a4a66e1255ab4491c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683660.0,430324.0,907760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc211ef204991639d59830de6ffc35bbdb91fb00%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668720.0,378624.0,1092160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22feb1396f6b335ef4a01a22bbd794255aad263017%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638224.0,494584.0,899960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22547be2425ebac115ff5881fdb58b0f0cd7728ccc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733616.0,429272.0,960560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266524600f0551975b649807cac6e2e1dd4dd126b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673104.0,402504.0,852960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222f0a0c68ccb41e23e643bab1fe2b763273a4024c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635864.0,397760.0,817200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242a06a6996f3373ec73ea4d130602ee41a99da1d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679360.0,407888.0,897840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa72cecdbf0945fdf78c8656538926c02829529e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713544.0,429720.0,941040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2216cff416bd854037ea4f19cce77beb1a8c67380b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717152.0,471520.0,901080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c87e410b2577f63576afce96c8d0d488ab39fb94%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666520.0,404176.0,982760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ec29317d755bda77bdd8983a6b9dfe6b1549e42%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705668.0,491032.0,837920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222456ba0ff78bbaf8ee4a93809aa6e4ee66226751%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673280.0,450632.0,874520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b94a5005f0e35c0986071fa147686510e06a006%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668192.0,410728.0,863040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b7cbb988e7f34875df2ec64d72058667f19fec7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705184.0,399024.0,881640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9ef89baacb80220a12132638c1e66fc79bd2b39%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743816.0,382616.0,888120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee99745031972959458a0d4d17be22883e39e767%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678296.0,447736.0,876440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7b5afbe010d658503bbcc88fd8134c1edd2be40%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762936.0,353736.0,913880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224af485045b7232b25ca7ef39d678803b378336b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625152.0,414376.0,914720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22728f883fcd215de50b4555d9934d1409ccebc528%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627008.0,408936.0,818320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d52a217d088bae1adcb8b9de79751e61b318e22e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709568.0,449864.0,885160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a60dfd06e2c9aa01dd0f48ca5eb19a0833a0a388%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666528.0,452544.0,904160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af7b2694c9f2ce0dc4112e55fa7e83fb5a679be4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B775712.0,357864.0,961360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22067196f633db726b0fce878b605661fef70fd0d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678776.0,382752.0,821640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c0d154e4c0550e70d3152471496831740a1d553%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B605440.0,390548.0,788640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a9455e97e406673d2977b35711bcb892d17993bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698992.0,434976.0,925480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242b120047bc5b23c6526564da2bc42e26d0923a1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B755760.0,362584.0,924720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee6bf1b37ab01664e8677f8130ac48f48737cb45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701592.0,363568.0,1037280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b941592d3ce0d792b834b7a7e77a6d01c11a6c26%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682768.0,399168.0,899560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253bfc7ef5d0a73e127d164c21a17f0ab5e6dcbdc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711496.0,394704.0,929680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22445dffdebba719c42c4a86ed78f889fe5e284aa6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619640.0,413888.0,921840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221095452d2186dc29c55e16c8ae02eec2f1dd0917%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646712.0,470184.0,880520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228105488c5360b3c1c156ea1e686e376f92bfc73e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731832.0,459400.0,840000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e205adb3ed0985b07acd90bbb7719543ec3aec2e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713232.0,367728.0,1028600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b83629c39a9ea5d72a808badd7edcf201ac392a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675504.0,377168.0,813720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207e32f3f74a3437f8731abcf92630426d8377944%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701072.0,379120.0,965560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2281575af66fb3d81b4542e835114b2fc818222b4e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718184.0,448312.0,855280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ee7fcc3d380301b4116db82c7f23a800794fe31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671264.0,453660.0,873200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a0e91807cd37d558d1463094a96c41b1401e0fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715536.0,444312.0,994160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22766dd80272e8eac59c857a67a9c9748eb84c14c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711976.0,488704.0,839360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b33b9a751d487dc7949756841ff6f50a322b0268%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680304.0,402496.0,1023800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b39e022e3dbc51b67880f35d1d236d37bab4da3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674392.0,407160.0,904760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271454a700b35f03c572e50a1f77f301d1f4d1f6b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709768.0,364856.0,1031600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22884d0d02cb55d3af87388e8c6da2a8959db19bc8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624448.0,461904.0,877880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22512e3da748deab3c45b6c233222388a33f574fdd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656392.0,410904.0,846640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297f373a45d7003bc5dc3fe1a71afbe9a86d0e7e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643256.0,405648.0,826800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22443a5f5067792b61843fd692c27fc02bf7748123%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749824.0,397824.0,955000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c00eae5ae2714b758647a1380cc73d8fc6e7e246%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689040.0,461888.0,946080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b44f2c65139d4cd00f7c9ac8cb100df9ecf8f89f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672664.0,466368.0,953600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e5730694386e324d70afa72a516ffc743fc401d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715176.0,443096.0,980680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221f3036aaf929ad40e4157a23ccc15f0922293fd4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607168.0,465104.0,868400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2219664a3837797f679089c9606c770026452c0670%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B758140.0,437996.0,882160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277eac2a99b7c7c3c7ae5d339c708be154ef731bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650648.0,452384.0,859600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc88a724685db8a30377a3fa6554ac40ac77dfa2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718780.0,492160.0,1002760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aeab8e17efd38d4c15bfdddce63fa52398f3d917%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680240.0,409928.0,851800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22665d7bb504610f72e9e188194bb30403a7b849fb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718100.0,450384.0,850440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ef048d6e296b3ad7c36afc280b610da33497c45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B791872.0,352296.0,938440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8ce40a906798bb5a2862d158278ed2749db39b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713432.0,431624.0,951920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7a1fc6c1600defcf85754142262967469aa9164%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701024.0,579984.0,914440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c9a746ed44e9fc2269da17897d75164ee3e3caa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729232.0,492808.0,904640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db4c9f578e0e447317d3bad26dcc7e9e6d51f4c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665216.0,459856.0,861440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22350b95a8e7906dc6b1c1b7024a39f0e24ede44e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664948.0,460632.0,861280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226db096a12c7da598f4d4cc132d086bd39922273d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712100.0,457880.0,869320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fee07f114c2969cc245a87402e9195b1d838aa1f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611200.0,478664.0,943280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b06d4f7dc52717a71c79c5e2c9df713d4a8c83e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667512.0,364512.0,789080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22884e189b385f4b60a43836c2af7da5898b497f93%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728320.0,456336.0,847600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6c7823e6a8053cb31e0510c4bc3f857648ebcc0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706504.0,439248.0,922880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b75ec32a64faae5190c22eb06893e38771ccd7df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641384.0,472144.0,946840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22466404f1b4035206fddea3b55c87f44fee95290d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B800888.0,453868.0,878720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22024eb044735f6d858a6dedf56a6261f7548e3658%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677008.0,380168.0,1082480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a0035ea1fce10387dbfb3e53d7db6746da161549%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687416.0,477208.0,966760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220fefe9d8614d878084671238a7f99556071cafeb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665632.0,399808.0,991720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22541ddc3b41282dddb9e4ccc68b231ff180ca18da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B794608.0,450568.0,880160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b925be3a8a25c5d006c2916f41fb3f6767259e96%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668056.0,442344.0,928440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22468ff04f06c0f619018d718c7cc3e772fc10077b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709984.0,435288.0,955680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b76cbd8a0f4d97a189075c0ea7584991e759da20%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617600.0,372552.0,978240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22806cebe894267b69009abf2b4a1f376d96cddb5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652680.0,465704.0,884280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229776c1fa4d32ed1077d9eba76573a48528feb19d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651672.0,419984.0,851040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242919d75d204e8b398eabe5d7e7439f5fb3a71e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745880.0,443388.0,902640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a489b53e70641016f7534a8d585df575c2cbcd29%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718032.0,366256.0,1009440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229cba045b0a0e25cd64c229618c016873d71cf403%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B588064.0,394088.0,815720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fbf887f895ae372521848e88b7c82b9fc87455f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729432.0,430512.0,958160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b01180e74cdabbc3142ca35f705ca086dd892c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647384.0,393424.0,916280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c2db4eace57a12a542f9f2a85437b638b566e2f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718040.0,461776.0,972160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2250de5041273ca4d68a5189e7ca3c879f011f030c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683592.0,405208.0,903400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e39ee1c012c75bb4ed974e9cf3882ef98b4ee409%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620336.0,373248.0,978000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22149d73d71bff354100050ac71d485c00317c79b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739944.0,422356.0,957440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d8e4aeba78a43ba5c90e0cd78ccd877dd7dde03%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B564288.0,352600.0,986640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278c0bdd2a44398c1911787bf62c7468a4e5c9e0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744068.0,368756.0,923240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220085703c4e69afd07f2e4d79aef9244db388ede8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708604.0,398080.0,873800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b9af6165c5e26af5556e60b42f5333ac9382313%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619656.0,458732.0,873600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22101929748c31048ce9772bbb2c751ce967441b32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717976.0,394464.0,932720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221a10beddd5bc885832a29a3813420a1344584a0d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672336.0,442468.0,928200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f07717530f6892c43f78b4c7c987f6ee81ff341%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663984.0,457816.0,911760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdb004d4908da4ddf8e5e7d3fa1a3426ce2d50ec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722992.0,455296.0,837000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22346c69674e699f49fe597b4093d1987fe6b03fe8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B799876.0,341964.0,988320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203cfc80f3b402eb685b54995c8e6f19cdf01a638%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670528.0,408200.0,863880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22056905512a379577ceac40c8adf523b8fe75bccb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654960.0,450328.0,914080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed77a66f119b31f1bb0500f803d2566180080f13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723928.0,483408.0,902960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c9acc6bd5aa838baf57af22520a978f06b069e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664480.0,464376.0,897160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22802703247a5dfb31a67686652d9c05c8e658db82%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720232.0,391120.0,933080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22506e1a2adee4424e0641a11066c7e84319f74c5b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666312.0,446784.0,897720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c70f292226ca54378c633dc9b82d516fe6ecd8ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651776.0,411900.0,946840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296c2081a06de9a7fe0110f4f33b98d1594255cf0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713592.0,441144.0,868960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e025a0629d15f367750c3c222e2a20ee013c512%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B776872.0,356312.0,963640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201164376e4937b8f503ad7ee6c5cd5dc480f9841%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611940.0,367636.0,986280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203337f5665a3d0c62465b61581ef619c36b7a703%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667184.0,403536.0,908280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b6ee4d968cd73e1a31e9350c0afc7176e86c91a2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B793632.0,353280.0,939200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2243646444a0aa113afc75c2839658a20a0b0e4fab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747040.0,367552.0,926840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22694245116db3d43f1353420c9a0a145ab98be811%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677696.0,418752.0,895840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d366ca7bdfb40e24c6563b7f1c8bd7688827ec68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668680.0,398520.0,1005000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2286ebe0b05cbb012618fbcde5a28396194dad8109%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611736.0,419748.0,910480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7039e44b8a32f29a61d660bf65d63afe18e7c7b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681556.0,451588.0,919120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a860a66b2cf12025090751f6bb5047d6e9be0722%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697888.0,435680.0,926320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266129b0fd8f46c542e880e0af2bf1b7e636a9b94%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752912.0,435288.0,883000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a031e3caaca1a29b2c53a447c683801c36e2d7a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716256.0,460904.0,969640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22847efc6d9d05ef6c2604a35874a2bc766eff1221%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747232.0,417752.0,823040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2222b888d9e02bf6f0e98832be9167f135b630b1e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708784.0,449480.0,876880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1605ecd80dd1b38df7f99f90fe2fbbd17dbade4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619120.0,471744.0,940480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7d6af2458b4e5ba4c40ba75a6aadf1f849845eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646552.0,415112.0,829120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d05b14937ffe6e180cfdd264b5fb954457c6759%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681912.0,408760.0,845840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22caa28e3bcdb7a2fa9eedb06020bd84886b948454%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654960.0,465672.0,943720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2248c9e803b951ff8844692388d1e42df8ff2c940d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607328.0,415920.0,914440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b03f18de2808c55c76f198fb10e0b3a09b5becaa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660308.0,415876.0,890240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298a58f996ef70174c7013c017210e9ea74478788%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639208.0,388344.0,921560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d176f06110bffa7457c4f0e2d328eedb67c79e4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727528.0,457160.0,847280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ebf38f70193ad05ae1c14c85d703ca7ac2418aaf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684920.0,427332.0,904520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22df83a7229747e5142d3a950a29fd16b757bc8e05%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664632.0,446616.0,847560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225dbbf2ee03d8951aa9b6d933b487fe54e68487e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669184.0,453992.0,939840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22daf2ff4936a7a6aa4815907c03ccca5b4bcc6b1f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728184.0,423600.0,947280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1b8ec3be4d981e19393fccb06ad0ed40b5fa1ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761040.0,364288.0,944840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e320c8229cad473f4d66361c2b713f08d719a191%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637648.0,403608.0,891840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226df4d36b9dd86c09adbd5430584c7ba066694e11%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674568.0,464096.0,948960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22000f9718417827db7962d15227994935eedc191d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639192.0,489880.0,900560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22357500d5fdc1df9c17ffa20cf7b4c081706626b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629944.0,479248.0,873280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b9e3d456eccb1bd60cb15da48124566dde95bb16%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B590008.0,393528.0,815000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b61dbcdabb9359cd72bb041be8a09fb67ce7f10%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B804712.0,337384.0,996200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249b93af50c118064158cb247c46352d0507a7ae1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716376.0,487200.0,995480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d61562595f7b6c02146a74c3fb679af09ac1ce7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745816.0,420600.0,961680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22859bb8faa9ee82eb26fef70a97c51d6d0d961435%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642376.0,405888.0,825720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3da89f1d54842157b890871abf52fc0d8f36f88%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699000.0,441992.0,886560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b4538e4fd393e71fbf3fc23ad2bdf20f1a852003%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707984.0,395800.0,872280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228782dafca6a7011743b94712914c6ffc19225c67%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667384.0,411312.0,863560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2259782cbe5def4518560cc7feb5f0ba9d5ea0b0c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603000.0,466808.0,864280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224ff26707a0d2df2d12009acf6bd206abfab80ea0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744824.0,415528.0,829560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc29b461a02608ba0fd55a1c5e4681e11c3e4b10%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713648.0,446872.0,877080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e529d35f3bde625e176d2b223f03e8573332832%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646520.0,415608.0,834400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ed08dc13cf792252b3a4cf99b26ac1d05549afa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706384.0,440288.0,924920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d73c9e0db742055590f61d9967b46c3fabd7b591%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770784.0,449520.0,883520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b18e8bbe7d5cf613b2f5658daf6c3ddc12dbdeb5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636980.0,402148.0,892600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22795e9642414edef90e56173deffa46ce7add127d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725416.0,424280.0,947040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b621941de1c8801adbd7ae72402c1ff1a07b58a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692664.0,440864.0,884520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253ca4914d3a77938bb70771533e211611a2df24c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693992.0,441896.0,899680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278eb55def5403165a1dc7dd4b988f979b039596e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699672.0,407144.0,822160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228658e5f8ca57d665ca792168937e06a3ac5e9315%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643152.0,463384.0,935640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22642a646dc0f7ec7881757997ed8b0adbe24654f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697868.0,436044.0,922360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229dbf2148369fe80ef0183ef07eed96052d727724%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639928.0,404688.0,892080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210a02fc06bfddb6edac3786e23e28a6df756d684%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697784.0,384248.0,946400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e1e1d0ebde69274b6072a84f2a93a8005bcc4401%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656856.0,448688.0,835360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2216242d56de86188a718ab05f0b65a2ec3f34309a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635424.0,415360.0,908320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220d746122800416483e273e0d51f083c87379d29e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726152.0,487208.0,902640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203dde977800b57fc42e43ddeff3d77543ae6acc1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673960.0,490608.0,973240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0b17d5cfa46b67c375f860284a5302dc5b0d878%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714304.0,427904.0,941880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f2aa8effe32a22891df416c02ecb7b2690701b73%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719584.0,472032.0,978400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22808eb9a6e7c46772e7d72e0197cb21cd2f43fab6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763744.0,449936.0,887400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c3b61bce2a96ce0f75402835e289f177201fa16%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710984.0,434480.0,956040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd13651ff664d87ec6017dcd1e3327f47bf9f651%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642672.0,407104.0,954280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221656f2919dfffb6ef04afeaa58a80a6f8bac0bed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B772888.0,434448.0,881360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221414aaa7d3b345d538d15c35a307243bf9ebfa1f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652408.0,421328.0,920040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224375fda321bec5b5b0826d8da0052e8cc86d6e2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720616.0,479000.0,985400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22350a53bb79daec06fbe09e079dd4ba7b3fac0d07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670040.0,373584.0,798160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee6d7b9567f27ef21c5e45eed4bf22812c31e178%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668368.0,451000.0,906840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224dadcc69d84fa9230940be15af1ee23e5339a931%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645272.0,446784.0,824680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdae2a02303544f09f8da8820a4b2555a279e962%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667696.0,403556.0,981600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b771a4f066a4d11476f3f7047005a9341f7ef9e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720352.0,450056.0,852000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2268555dfc166be24293185ecfc099105996905f49%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770304.0,361920.0,955440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad28fde9f759ad8a821e0f859b7bd2fcbe56b704%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659200.0,416184.0,939680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22502480e88cfad984322579f0bffd88cc3de605da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684824.0,478776.0,875360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223cb96d0e86fcbf268d8b5fc9a425b15a4fc29880%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673416.0,453400.0,938080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc8d945a42d563bbcda5d8b0810e00bdca63da0d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680808.0,406832.0,848600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222eab0ed4c455afbaa52cec977d39ca9ea91b0390%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652460.0,479356.0,900800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225810c14c7a7bccc9e077ebdbd02a855445b1dcf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637400.0,401568.0,955120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f978f4c23c0e11174dcac1abc59b7ab375d26d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730512.0,431904.0,958760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d29c042d91649442de34f8b33c01a934b9f130c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672696.0,399672.0,960640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb68a5c6702f8011ea8e0ba9e58662432e013afa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625464.0,412904.0,808640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe80dd11cd2b7f5fa7c674a9112b002690f9273b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738192.0,422488.0,956880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226312ed01c57d26cbea023b377459a4f1785849e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733560.0,424448.0,951440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22445c22a15de0a64c9c7b8612266488866ee619ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B758632.0,446272.0,892680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222de86d9535ac04509f9266796d3b1ef87b576c97%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729504.0,415200.0,855320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22baf3c4fdcef193ba79b1f860eda86a18ffd51d1a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678364.0,499408.0,865880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228885a88db5b6e5b5cacb8b1d6849ae0da64bbfea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B811832.0,343376.0,936200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc158eac4022c372dc17b0122f6b15f8280f3068%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704464.0,399744.0,851920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3e802127d42fdcf31dee832b2f2ba2abf4bb635%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635536.0,413776.0,907680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b2a13e9707beb0aaad071f61e8a3d4ba114f637%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687332.0,434124.0,901160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e01ad69777b1124a2bc28d099a0aacbe1dda47a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658472.0,446280.0,907280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1eded4371833ea6ce459b405a335456eae0681f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669632.0,456084.0,940600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c4868e7d8418ad434db3d646a3c0df836008470%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640616.0,403784.0,953280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3aa813e52cfa1774886a63d552e2ea523743cfb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740024.0,412160.0,848120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d40b41ff6c912fdffa185d3544bb8a06df09fc54%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630392.0,469144.0,936280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b4801d68fa065e5849fd7c8b695bc1b31cb991c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667536.0,366816.0,791920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22797bf86022a2a28f3b9d5851e3f2d4fb92d34ef5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733984.0,440056.0,911600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229df3491c7f98616fff6b2f8b59acf4267e34b860%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638368.0,388616.0,922920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224dc3f6ce90f7305b90da5904ae2aa34aa7bd97ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724792.0,367216.0,1034880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c62661049c07ae062d7cedb321124ae73722610d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645508.0,455516.0,914920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226554761216a906ba9e06256f7f44d0760e8e4048%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B759088.0,361600.0,935960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290f0e9f1b9bad7b39f1e17eabb46a4e5c39f433e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738184.0,395176.0,945640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb269749e107fc8a4f75d5cd1e6102dc79ff87ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703080.0,372232.0,984160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ec3b84037ce5134039e598ff99ef161b2573a104%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B786960.0,353732.0,973680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279c0297733618f1e800828dc93aef5977a94032d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B755952.0,422016.0,968360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225baa17a5985a116144a59dd7e46100e6e224633b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655312.0,449536.0,913840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22271f265ef41d377bad94ab457449e40cd53a668f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673680.0,450032.0,874280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221df8404658c09d1b62b52491b4a7727d79eee0b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B582344.0,359352.0,980440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265cf4c90189f677302c10f24f255138bfbd8bca4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676696.0,407936.0,863720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223259b823dde94e611b6d61a26057b4a6ae1ce5d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760664.0,364944.0,944680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227760e9ed88b5a53580299b4acbd954a89c723182%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672928.0,441144.0,867760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22363d394123a217d68c4f0ac92a28f98f14115674%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727504.0,358912.0,1048120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a628791c0bd3cc9825e93c2a3efbd892689baae8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695976.0,400016.0,901400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a72c73e6b9ce51806b1c9639d77c3a6c3037db1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708056.0,364672.0,1029120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d47ec533bb62cd6ff62ea7b7a51df13dffa0eb16%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709584.0,367416.0,998680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220280f6316d5d322feb805c1c5a8bff972d51fadd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648688.0,411360.0,906520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bfafb97492e6af2f2afe1fc3295e57f0ee04a238%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627872.0,506480.0,898640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dd9cef74a80c5ef58e80438e33414aac6f5f96b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712160.0,431152.0,949600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22976c958e49e2b649fe7c94cbbcafdcb00c35912c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655496.0,412424.0,942480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233556b1cb74592265dc9fe81c491a39969dc95a6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708952.0,394512.0,929040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226362b12563216bed3f8c9fd27fd93451b8c4b569%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675312.0,430688.0,874920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22338c5c4d960e406c0fc9b35f6e438499d857f8e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B838952.0,329424.0,1033640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227236f71626891fdd93bc41ae88e5a73ff7e24050%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B597052.0,468916.0,861280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22838ae6e5f37a90b38af12c3ae230c8e2fecf68e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701768.0,395992.0,902160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0f1ada61d1496103ff8a72c9d03031f0c2d971a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646472.0,413688.0,832800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0d69ddf10dcb7e76eabf9618e2b7e051304149f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647240.0,471968.0,876080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f86c774dded7991e7c0748740f3bf3740241539%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675688.0,449464.0,874240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224ca2da5623c4255342324c421f6a0116120a84a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709888.0,429088.0,877720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290656b188b756088ac068b11247d13d95aab140f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694552.0,405600.0,891880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c154feb74f4995a887a382db571eb32eb3905e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642824.0,458704.0,890880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ed498fb36e291809e66806738ffb65fb3251c83%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712864.0,356360.0,912840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e598a33147f9401257f31c31c712e85db78ecf0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704392.0,434472.0,940000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2288c99ab6b63acc4ab0a9c46b779e5c8d7fe5f7b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650976.0,410976.0,836960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217e09c7c0abaccc35d8966451c2e5ceb1b17fb42%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642280.0,412672.0,906360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a890357aa3fd8f3e2d16a7a68b523f977d8b3242%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674552.0,450168.0,936880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203e907a17f8d3a16b11209704424e53b68e6808c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686572.0,430260.0,908160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bbef80f3419ab144325f0d23ebfb7e891d65d2e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630720.0,458464.0,882400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220429bc49c7386bf49991f44bed291b876ff24f12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671832.0,427440.0,870720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e50d1db934a39a36e79df2c9abed08a90813c3c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711760.0,427608.0,875480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ae96cc96938553b5eaa9814384c63af29693f07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689512.0,477680.0,961680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22725970c722b6cbd7f109aec7e67065cc27f06906%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617960.0,421776.0,911560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3f92629f3a48c399399a31f8ecf651acb93af1c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688912.0,463088.0,886760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224804eeef4b07dae5cd1346cedcb2aa1f968e6695%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645976.0,421192.0,913320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249839ce974b3e72cff79bc6ce8d679d43ec246dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725712.0,525784.0,908240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8218077047709794df73e5fff96dc31a89f94bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630832.0,398856.0,893800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22012a8d5b8bdba7fdf5f3fbe0a9950dca9c3dae71%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689056.0,401904.0,911240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226f5c66ac56e65da0851226ed1a6c6db979c9c5e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752968.0,448216.0,895240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299bdc1253aa50eb1e9b84ad50e4dd3b286a7861c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726968.0,453600.0,853280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217468a2e6ec33f855dcf0b840eb7d861febde70d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692584.0,441904.0,889280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202337a18a5838b796c646c04972a384a21da8c81%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651104.0,410264.0,947320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b23fcf5511810ee6721b3392ae4a46cee8793e1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706376.0,439556.0,918720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f28730c4a0ddd874948516727c65e777a400fed0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613808.0,413632.0,924040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f25158c7662ae42f0d888ec7b96c94b845e34915%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630056.0,400152.0,893520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227138b10ad506f6062affa7136c5bf225babf8e88%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756392.0,362032.0,935440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285c2bc4ebe217ffc6a4270f5a4cd787648282341%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B597656.0,364920.0,976560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e331c86f0c9cf7f044611150921c21ea943f55a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697192.0,446616.0,898680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2252958e58e686d46ac0c5bb0ef176fe01406fbf54%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B590568.0,420968.0,912160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253a074784c44f13fc4f9e0d0173281cc8ae837fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708328.0,397784.0,843960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7cb5acaafb0f6f3ef5fe44a45bd9d03b8e0e782%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709048.0,430744.0,880520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228469147286f515ea8bc1092f5256e0b5f1c1a66e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710272.0,428808.0,877160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c43e155411dd22a849ca32f4aa42da7b6409d1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715960.0,460176.0,966400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22855918293dc04fbb6a4da89c58646ae69c40b037%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727472.0,454648.0,852920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2263c941450ae852416e8d2450c0074f632f874c1f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718752.0,484528.0,988880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5038885c0eff2101096db8ceed2aaa98d4210bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714800.0,454704.0,959120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292bf71d7052f750dfb4da094350513ac03c820b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674496.0,464240.0,949720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f1132ff9777fc079befbfb76c6cf62267b23553%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712552.0,441584.0,875200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2234d167f9b465cee1b6dd68c08ae98bb491903352%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B776120.0,437880.0,880080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd51af97fb2269814f7bac87d9a4b4a089b93fa1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638400.0,413720.0,905560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b1c5c11bb6c5fd79adb777d256ba2f22a863a663%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743976.0,422608.0,960320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e323ee3cea088a8e16d11f2432745a5b7a4fc769%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711124.0,454292.0,871560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228646f79e7ce9cf84ea05510820763b9bf39115ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673664.0,411640.0,869280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f8d5581d764f72ea1a7e2ffb19713bf384b004c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749184.0,419328.0,975240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22675e605bf6dcaf1ac9808534b83cf55ad166f972%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616952.0,427912.0,774960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e0bbc07663af5b53e6fdc3ab6cb71f148d85b57%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634904.0,421856.0,913600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22136ccfe28862d17e507dc642b16d64e4d1c39d67%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672552.0,490536.0,972360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e8c4dcd3fc01be41cf74b0d8d1cef12f5725719a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712600.0,446720.0,944160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22809c6173eb3c9111a7ac7eecdcb156893ac226a6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627200.0,388736.0,966800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221bf939aee2bdec3959665470a4a44fae72d94b16%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687444.0,472412.0,877200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b208e64ad836e76807aa7ae5ba3c127be4ce6658%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665648.0,460448.0,898160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c68303853ff83981eb6b437b3086bd49c014816%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683976.0,425136.0,902440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a761cc21c71125c01175d1a643498c15bd28257a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676824.0,411456.0,896280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1c8ccc8e58b13f90103867cba9262ff26fc1972%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691136.0,465528.0,949800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c951952ebe19768dcc3a8f4d30d80174e922b318%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B753300.0,417336.0,817360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202fb01d71c2496a5fc4ce9095db657ea448b3a6d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729560.0,505616.0,910520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e859b5cb03bc5e8eb2f16b95c8f8d62165a7491%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644264.0,419544.0,915360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ba7f36e199a38b6372387937973d9be19eaed44%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676264.0,443720.0,874360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22211bd38789ec5e1dbc6c2c7463ce6c8cb1201e1f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675960.0,399632.0,962920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22776acc0f96ec09794929a6e04f89274f6ab54791%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673536.0,442616.0,868120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc62a09363ac62c1f2542568ed90f6d59cac164a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658992.0,422824.0,858560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae1d277720db25db39da938649301919913bd6e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724712.0,441488.0,889600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af25a9370490df8b0ffe742f1373ee00dbe1f84a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724456.0,516784.0,906640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ea9dab6d7c277f28672e95cfd825bf349d30f31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738216.0,383960.0,892120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22776861472f53eab9011b46cc3aeeb2c25786a55d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615184.0,395480.0,800760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c7693167262a650434ca1167a97c65f60e1e970%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625356.0,386184.0,971320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2276fc65b025aa10d846f16b455a38f63e2a10b41f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724208.0,484200.0,901920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a612d79b7c252be8a31db706b641b4d53e5346ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729584.0,457840.0,840920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b0453d70d6a23893c39dafc06f98f89c93798aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B805136.0,350472.0,934840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229274936a0a89b9510e092cd827f5c30d137230b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733960.0,443160.0,909680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b51a52ade6dd628aadca5d7c72e07e3f68ed696%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663640.0,457568.0,897880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e0c45d12769e7b41491bd4a85c5b15df2c583ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675256.0,471968.0,959960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22816d21f982f3df6ee90968fbbfdf173820ab177a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628784.0,409296.0,819840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22187f018d0b6766b05c181b5b764b2549f6ef0e61%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617824.0,424168.0,780400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b270c0f3e80a761ea1e4ff2d97381635d4903934%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707480.0,394456.0,929880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e513f6e9b185604ceed4fea2fac69caec9d5f36b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667576.0,404192.0,910560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258032010fef189bf50684144ce4f2d2d74774f30%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745680.0,438636.0,887080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2213979906e33473d2cd6aa30fcd341679193cbdda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721200.0,483568.0,988040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22930389a4d6687e7ea5cb5e4e2a88e0dcb2b12055%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618192.0,472016.0,940680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226af9fbc5feadedf48e59b382db4cf2542498361c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676532.0,515064.0,984640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e29fd15e704e02fa205f9492cd0f9e08dc8bcdd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B771856.0,355488.0,939440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22685c3da1a7ce8f675d9fe6728a18a5f2e1fcfbd4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756856.0,398560.0,958800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ec9baf7289849d67dd331529aab5e81d0e13d02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666512.0,404728.0,977400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22634e15e02f2f8d9fca4065739d78de48e05c1b5f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726944.0,457408.0,814520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae11240933969b5e0c6770d688ef78bde2c82ade%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725784.0,524024.0,905680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2237dea1097c13f512539add008394ec39a9d029ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634560.0,388140.0,927520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22185299f158d6c5957b0bc74c46497c2412b87dab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B757592.0,447604.0,894120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223334d1ada984a3f4ea0c902bbf3b7e121f5f353b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727632.0,440360.0,911280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228cd2072876da626ce924b42c5326bd1991872e3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681244.0,403632.0,1024960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dfde767c50d21605c83c7ecff664962df7578b87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669464.0,427192.0,868680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227b77f09e6bc6a18a0f745cc37fdd5c2782462fad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692068.0,471508.0,955200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a427d89ffe9df62454583e6322baaea1b136b52%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745120.0,413552.0,835840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f61f29106eeafebc64d4fd203042bbb2c9e8534%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644112.0,461464.0,932600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277c9467bf72ca900401b904a0125e176665b7835%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668752.0,452568.0,867480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226eb4f8874af0de49689d48c26a6ab7b8815a7978%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663864.0,446872.0,895680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274527fd82d4de97eea49820a863f5332031c99b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669128.0,409296.0,969320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22436ceec5c659e11ab1bef09467e5ca7dd57c803c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694444.0,404052.0,895040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb2183a485affed2500856c4e2756c60c61353b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707296.0,448208.0,877000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22abbf82ddf643173cfef51c0185157197478f5e9e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608032.0,418392.0,912920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274260a7c765e74266b2b4e8d0e83664a5d6edb2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705304.0,452016.0,887240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241faf1f0db11e1895ca2074deb2b043163067f64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707840.0,458088.0,899040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d412f8332e904b6d1cc2540000010542fe4f3589%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677376.0,410864.0,898840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d2d444a0210f922ceafad5148be93e62f2ac85f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635656.0,404768.0,892160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e8a6065450d6db0322e6d18dfa40d0787357e00c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623984.0,408584.0,818840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22412a294866c7744c24461851fda289855b88ec76%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693920.0,403560.0,896480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228674f9e419aae9b1bd2bc7712eb25a2bf6c5a6f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710068.0,427804.0,876480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22198283894af454012d56d2c1202a639b0479db0b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671592.0,378448.0,1088680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22968984f5c38a5992f0a377ce01ced991603385b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618032.0,459256.0,872720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257fd84d38950b2da038954ba8c5951b3edfc4f84%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731152.0,502584.0,907800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d4744e87db5f36219361aad2412f60c1ce32e885%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722112.0,382072.0,898960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e05a53e21a54898fb099864f260acb4baa4262ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678056.0,381872.0,1081120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205f36c9d396ac899d61d3f35f58c402d05dbaf48%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683792.0,441592.0,908520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e83088b2237e8b6bb4f0e967776102645543affd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B560888.0,392904.0,813760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab1e74e8e81a0955e90a34080a11f58c046f4079%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668024.0,398400.0,1002120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b39423c574d273e3f729c27e930beb9b42dcee10%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680056.0,434000.0,914160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e03447f8df2faa49768cb3c4d431e5c6fc781fad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B549520.0,349560.0,989400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db1b6eb9675e3347caab6563e54c1aee714dd15d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706392.0,446120.0,880800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2243f052aa5d0ae9599411c9b6cdac2bec774788ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680504.0,497512.0,866680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d3c5042726b57ddde44bea936effbb31c502556%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696480.0,389992.0,936600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220707e3ab44d2114880ac4ab16ecb0eaa95f9ce34%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743376.0,370072.0,922360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2237e2a1e9a6f099b6c41b3971a33c7ba75b229194%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672808.0,401048.0,848360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f6db6e14e08d1cdaab5b11ad8d58385b587f036%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636616.0,388040.0,923200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229422dce7807912181fc478035d208cc5afdd0867%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679144.0,494364.0,868280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c71e4748c701ad92e61392b06356fe7b2e8f8d85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667704.0,377256.0,1094800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f5db86c1999d16ae32f1f8f68c7fa984702e66fb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721852.0,454652.0,842200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6153f6b5d63c7c3acb9ffe6ff81161933539b14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644496.0,468424.0,948120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c2d345f937a2447b954635f7290235a5e2c9137%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707560.0,439568.0,930720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273a6c3c2344842750c5976f991d3e355fd7e9936%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613024.0,475936.0,940440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3d65b62b2d91e1b87aa09f7614e6a6e44ca1b64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670256.0,409880.0,945080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fc5b58142e303e16cc16dbe15a831ef5c5887f37%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665744.0,459296.0,943600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222705945b2dedd2296b10dd238b4cba75f5a3bfed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B832728.0,332824.0,935760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ae40270a9b7344a132ce61572553ab4dc697695%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B576328.0,356816.0,985760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228222edef02468033abbda82febb2e0aeb755df0d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677712.0,382568.0,1079360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22167830ba4c7e717d54bab71e235b6299533aae03%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669736.0,413612.0,940000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7a2fbe784ea0f3ab161670e7e1b9124af406b3f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B577200.0,380280.0,809720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223843b7906dbeee4a199c38801863b2f01a497949%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666000.0,405112.0,978680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c074de5c865147b96a620160be21bcffc2917058%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691864.0,399304.0,918960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cab437523cdad74318d71f9ade1f85659018bf90%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678296.0,395904.0,842440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e71d68044fa2cc777345d332ab2ea090335dd785%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704280.0,398400.0,881520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b9d2d72be45568a41e8635ab2cea77e9a5db7ac5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666696.0,402656.0,989520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2289cab9598ee8d3c4342f469db382032bd06d0f3c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679144.0,383136.0,823760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221bcce233dab1f0ebe7c3ebbcf575462571cf24eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741296.0,422000.0,959440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22856cf4ed9b36470af7ea54cb765efc234134003e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676136.0,410048.0,858720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ed55a835fe0708b08f69aa9d82012bf692b4f8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686248.0,482032.0,972760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b322ba27f9313e594a56d25f633b2bc670ae2bec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649944.0,450504.0,828520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278645ad79fdb41e9aa80ab4fdd7b8ce807a728e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723968.0,439928.0,889440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2218bbc39e6b04d2bdee87fa24d3e329ad3b77165c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613912.0,436056.0,766880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a86401a37c2beeb7d63f535a559662a3c3f5a3fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708896.0,397904.0,843360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a685be4f9d55e0e58db852ccfc63393c40e304c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713888.0,438336.0,963680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2219df834bb92bbb69b9b5ef0170f16511b8512f15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666280.0,416672.0,938760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee7ea87b98896f993f668b97b9f07f47cc13c255%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762612.0,448896.0,887920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22995310e61a9d6f2f9c6cf7a107eb361899da0ba3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648984.0,481240.0,902080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228825f155a27cd3f1111606faff731d7bb2d84b6d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B573968.0,390016.0,814360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22872f67a5c40ab3a3fd07aef81235c1ed12ad2045%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726192.0,458744.0,815120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285fdccabbf19494fbc4e13d6641103a31e1d49a6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702784.0,451368.0,897640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221345e2f3f07f7658024d67d9ce23d279bb888ad3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730184.0,460432.0,807440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220e61128ed25c046ba7b5bc4af258dbcfeb9fbe6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B757312.0,434848.0,881520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22375e31f00a8f0597bbdb9e3e53b0145217c9a099%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714168.0,440888.0,976080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254a264cc6e1ae65994613241d8a54e83a54d362a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684696.0,442480.0,909240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271260a333c953033f1242a924851bb1839c9f40e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726120.0,366464.0,1037920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8105d4691b9c3060d571e09ce371101041754ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725872.0,455816.0,821720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258498349703573daf4b2e5acc0c112315b626430%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683664.0,456976.0,935160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb76ed5182594fa80e6895441b9fc89acdc17fdc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686708.0,481700.0,976320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222f0cfb7e4d84720c5f87b9ece8fcc9c5415fbc7c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608448.0,481912.0,944520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220dbbab218b3f095c78826845cfd2f05c201b4139%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718736.0,391116.0,934120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f59792f6c7c00b504f358c71af3445df2e955cd5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666832.0,453920.0,902760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225383b9c64f6713b797ac60fb5fdf46cd0accecff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629744.0,408440.0,822840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b6be5f1d0124bb66d1509e87f590c9f9fbe8fcf8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711272.0,458376.0,868560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0aa5a18ecd14f6eb08df99176ed077224adcfcb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689408.0,439600.0,900840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa6b4d31de74c0985395e482986798494a6e0178%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664868.0,459180.0,863360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22adc67974fb7073c4c7d2f679e3aefe68d578b684%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B772816.0,353448.0,939880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22571a19f00f713b9a84f2014f6a92f547cd468876%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714160.0,437808.0,964560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db2a76e617347d78a2fb5bdaf39877fba04d2854%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677504.0,407504.0,855120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224c345aba67f5ed6b68efc03397d7d757cdb7113a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685560.0,448600.0,909720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fbfb0a832c0609d2855649040ebfe658e0d98c12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697344.0,385176.0,943640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227877465d4e3f000ca2c7e4c0da9491294b2ad2f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646808.0,458944.0,932640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254b7f19ca25c839279d9a9b1f3795126a921bd47%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609448.0,477976.0,941880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cec6c2a0c1d5d9a3cdd2faf54aca8be6ac4faab9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725728.0,440112.0,911040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea80c255b2844dd3888bb7785163680213d22a1c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695488.0,392536.0,932440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22146a4237d82b78651645dd654f9ae1a622ebd2ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726704.0,440144.0,889520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273c0dce13d96baa54015a08bc7b0718ab3b2adf1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718728.0,492184.0,1007000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e476393734489135dcba14db6b1ae601ad2b2d46%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685632.0,482240.0,988240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b06367a9494cf9ef914db35d7018578877beaed0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713560.0,357216.0,912960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2268007429fa90c61920ac48a905537fad789416a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718840.0,443656.0,870400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228cc89f607a7abf256016ffa511539f8491458699%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707716.0,456460.0,898280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297fb678acceac1218393642c1ff536022ce29553%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677316.0,397052.0,966600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227cf2451a88c32751cb831619a1828c123078f8d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690704.0,404032.0,904240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f93cacbc75dfd5a5069cf6f54db2704ee49dc696%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729816.0,416200.0,857960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a08b487361a7dbe03740cc25d899981a8abf1dee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635416.0,401160.0,956800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b157cfda2928c5ba0cb351462a13715b4816f410%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727304.0,362752.0,1042160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22212e57e1a2ba0750ee7659ebef410f8875d29999%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604544.0,417592.0,935760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4bbc51d1b8440863ea1d53332f8f3e128d678b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767312.0,361872.0,953960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257df0199b17fca47602d455bf550c661b3332e7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622936.0,473000.0,938840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221bc78a9ca088bf53f59a46974d7ae868a049c075%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690264.0,436560.0,901560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ea8fff3b15664f8ad7bfdc3be655de381bb2bc8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675400.0,399744.0,1016920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3b22c50dd36ee93073d379e533b486f92a394ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614152.0,367008.0,990480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205317f00fdb2b8b4fc1fe3579e5fa397579f0c91%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614540.0,474808.0,940720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b52a36a1e9712e8309a42c8c125ad6eb7f918bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664280.0,463128.0,858200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa7fd3d8e47e6a82cebf246b620e1f847ac4cd3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731752.0,414212.0,854400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222cbeb9c576347f8c73fc71b617ee5ce6bc22a5cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719624.0,451424.0,842960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b536cbe3b98e32de06c9fffeb9f8186e116b9d56%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713360.0,441568.0,917240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d0400df57b2f3b90f8e9ac344747ad890d6f243%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642312.0,405456.0,892360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b48ee14ee543df933b0579a189c9f704211eedc6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658784.0,417120.0,941240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ada40a3cf0c47ebbc37ed84547221825c209e6fa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720832.0,478880.0,986520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221380103098184883b154932c14ae07cc6ccca2bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621568.0,383848.0,894840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b41281b88b6e19cce5274028bd2f33074f41766%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622080.0,413408.0,805600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fc6a0ca20841e34fd9f53496a09f0474a40eec85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642456.0,390216.0,921000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f90a690048c0eb84efcaeb2fcd63272d26d2531b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712616.0,468848.0,859320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22808f95f6448c219158e12cb51a91f17be5462e59%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684540.0,481572.0,979760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228bf78b9e0747b5cb520f9c5c6300ab0240c83adb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674064.0,436840.0,921680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f94260c530930d87062b7328fb1b9d40a0402977%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673800.0,446280.0,875200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ebc16121aa10781dd0bbd2884b972e490b614b20%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674296.0,445912.0,876040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f09ec3e45ac4302a6f77c813753a31f04073021c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719632.0,382736.0,901280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd0ddedc1a184dac402848b36e96a3f1881ac1d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600856.0,417176.0,917640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22434a6aec8960c0bf8fc1ca4551ea7edf1660c91e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719856.0,453368.0,847360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f66451795b54595bce7e9eceb97c25d7f8364a72%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B581520.0,359008.0,983520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22285446fd12c8373426794a94d47db72ae453176e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687248.0,480176.0,971400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227dab673295929b45f88cfcea971786945c85e819%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665128.0,414984.0,951720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22894622e0df2b71151631c899e2bcfb0f7383b521%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663664.0,463384.0,860880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca091e4982e6dd824e89ab089a2269538efe1eb5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665496.0,446816.0,899440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c21d9151f18d57b880221722359c7e129ed01697%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637404.0,421696.0,913280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a9c8d1ce3c469ee8bccb62a301f1d57fac728a63%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634364.0,471708.0,874080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221952a408c673e27674950eff3a9d1dff70e5ac53%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650240.0,410168.0,838800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221dd8b04243dbc32fbbe99c0be02ec10414013bf8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655080.0,422780.0,919960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fc85d33e01a5d3207b2411bd9a2ece8fc02d5e31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731624.0,460384.0,807480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a16aae623751d81ca0dd8bb9e34c00f9e802425%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613640.0,362408.0,890240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228d22399fc44961ab0483e30a9dfe3d6cbee0f364%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656120.0,395912.0,913640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226046f870bc73f789dbf1caf876bc6c596c76f219%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B755400.0,447784.0,894680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d8b8e81f4d2d3d1024dadaec3212c32957fe61b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715968.0,439656.0,869320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226dd12d8cf00ffaac044c91d0d39c7096a60b4f0f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676960.0,418088.0,889400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e3a6e19a90e09aa5a755b5bee99af921ecff8ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762832.0,355440.0,915560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22260c490899a4752eba6644c492ab18a608e47f42%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704920.0,371520.0,903280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22091afa9f31c01f8c61b50a154b9ecacc861918d2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683808.0,398880.0,1042320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f438a03dfeb547438f4b9729d64657ec6cb3abe5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726056.0,453368.0,851480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2224cee5e7a5ae71ec9c25f41e187ffd66cb63db89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673848.0,469704.0,959120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220cc9e827f66031f01fed796997ce0e2515d5c078%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699832.0,393736.0,927960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b219b37ab208aee00ab054065602f3ea39368e74%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725784.0,457104.0,845480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d446b22f04037a2f30585d810eb6b5cc2773eb40%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672192.0,477608.0,889440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a567209ee45260d2c2eff16227d9fbf7a3d4dfdb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656952.0,451976.0,893320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22018eb16fa4c5e211928ddf879ed9428a714786ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659928.0,399680.0,913280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22680792fface85a4d1cdf72aa76ba182f1a6d7538%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674036.0,436032.0,926440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ddbc3a197b3661943ddcde50c47d0f92c5320f81%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727304.0,528760.0,910680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228055ece1145bc03d6edd23858f0100f5ca011c50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623920.0,471264.0,936240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff0ecc50a02f93a5976090fc026938b4f2db3d16%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B764528.0,358168.0,935760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac812c4516e5b219c95b2ff952d199987cb037fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702524.0,377568.0,901280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb175389f6d4d35ddae4502f6a2510845064d12f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743896.0,422144.0,967200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bda10a34c7f1b16bcae773539bfc2d5ace94641b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708760.0,366440.0,1029960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cdf13447b93707d349e3d7cb6c99d9caedcdaeed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747048.0,442368.0,901480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1a01035714bd8ff0ca359bc6915162f994fc8cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617392.0,370848.0,892600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22140ceb0c8fbbfef4410723404972ae3660a494bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765944.0,361920.0,949960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247459b2ff70cc28e74928a3f88546ae952cfed59%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705408.0,398648.0,876520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22838cbf95b140b3b1062e8ad355fde2bf47a6e673%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704912.0,366492.0,1037360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285c72fb7428ae3bb3109128d940adc72e8d8c653%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654568.0,420400.0,854800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f7dfd10d1662b94297a45e99e506408a007a335%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726352.0,488664.0,904160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a24ae7e3f00add546030fa40a76b26de9bf14fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B807744.0,335776.0,997360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22652aae5ff107832f7533b749b54e90648346d9b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B835240.0,330016.0,1028120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d97ee075781eb6ef8e0ffca8163b74282851e48%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665776.0,402696.0,982240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b514965a8d4759748c356fc3279a2ddc3d3b2e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720144.0,450864.0,845400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2216d49cef9cdcc61313d5bfdc92117e3cf44098fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703300.0,402804.0,884680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da64e37fa0942d1d196a608b0becd1b05869db53%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660168.0,457912.0,894320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2238a7e7738e79b1aabf9f10c14744c54aba530a00%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B580904.0,357360.0,983840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223296ca00d00551546b8c1599fd1d4211ce251e8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690336.0,441592.0,899640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266019eeef1884a089e59fd9437c8f1fa1de2c669%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690008.0,434840.0,908080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8d990276f31721c85ceb1abb534abe929f6521f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725376.0,441248.0,892200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed9ec994a86073b6f2de9025fd42fd12b40b1a9c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649856.0,467256.0,880880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22361031f2afeab2a7f733a98ce011cf7289223665%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701904.0,435248.0,885600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e44d883c9006915b22da1bfdb3b287c49676e69%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708592.0,399088.0,845600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a0968de853a9274137fa27818d351d3a428d51c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626656.0,462176.0,878640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e15bb649446afb694c89293a3e30d2cc3127b73f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680608.0,493408.0,868960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a86d9045399272edd1eb0420a58523667787e084%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638744.0,401224.0,819360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2291bcd967bcb26fd44ed4b21c07114fddf00a442a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714736.0,444960.0,992240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e322b93de5f891fd1cf6ac898fd9c040957d71a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706640.0,431120.0,881640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221650ed999685b09f6433349b4bd4fa66be8d6b7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666024.0,412128.0,963400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22986e8bf326ec53a4bbe3fd01d6bd193aba5fd41a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616676.0,418820.0,787320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228cc41656b7db3a6b62f885d1691bc87481239405%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616880.0,421472.0,784200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9abfc50445d0fab8715d6941de3473c28ef3d95%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636824.0,474552.0,946920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221dcc1e01f2d1a57946cec9c6f3bb3154b41b97b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710048.0,451472.0,874640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223764c60104585a6f5c1eb815f784b3922fd055b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600204.0,416508.0,918960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed028c3de49ca2499bdf6b12b5614a572b2a5ef7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672280.0,380264.0,1086480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e787710c39d597746bbe8dd3035789d3062d8b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682472.0,429520.0,904480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da2b865e8baa0439be92769b6b1954f42712bd72%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708784.0,443912.0,938720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1cef28cdcd94d55cd021d4f4dcc5f42b77fd5b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B778760.0,452568.0,881880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2218b3a88f9bfc68654ae8187295c7fec1c210c903%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674088.0,487776.0,972080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222500c13e8f8e21ac110f7dc2328da3385e0fc68b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732128.0,430712.0,960280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ecca025f4dd5b7b6ddc86214596ab7c225dccc85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683504.0,434488.0,910760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc5fddc15a860f422235d4c9410020e80db79cf8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632928.0,498592.0,899720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b557a55d7bae3fcbb4a127f67a82257c9a32b309%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720800.0,445336.0,867800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9655a64599f7db295bef0229857cf81a0b6b020%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632144.0,413152.0,910560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22080605440396ee16724f5f239eff532ae8898362%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713120.0,450864.0,952440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d6e6a1bdd3e3ec637449e232f5df6a765c50253%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747104.0,440288.0,886960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222706db2c0380db8c998229bb8440e49d7ab0aba8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714800.0,441408.0,976880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22039a5583fb3442f261d10653236eb9f5825198da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682992.0,435280.0,910760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ebc5b482e0ce9e7bd7d5b6f660bfaf7625b58438%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674448.0,444904.0,875880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f048ff8cf398f64726019da67b4e2f3c65fb538%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642952.0,401880.0,824400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d49948f3aa00db0a2a7722e4bf26e322100389d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656904.0,414768.0,894320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb5a6f9abdf2030172582f42720ea523dbef0fea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685040.0,430400.0,908200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203f3a7da8677aff15fafc44db2682c6a43ab5832%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725696.0,416136.0,861600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225904fdd39300eaf1d288b47a5e448f4b17f8058d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666888.0,527008.0,863960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22953125d9874e022d17fcd9dbce537ceb0d3c7c64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673088.0,444800.0,894840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b2a8f59f50b01129683754bf8d89b6eeb1ed5af%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736392.0,425008.0,953600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d2792268b98e78e78a8bc9ba3d0f384ff1d2259%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651124.0,466244.0,947160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f9873813f84f8ba4a8d8a80bd99dac4cda65b9eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724944.0,417492.0,859200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223521550901bf38a07f2c7bc6d8213a71a8c845c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B769984.0,435808.0,880840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220034d38ef5f83129d6dec9aceeed3f30cbfef179%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634744.0,396728.0,958400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f2bdcf630df32ed3174fa8db6758a4b03f8f5b8e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685140.0,402436.0,1029160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229cb0d48d143d217c647f9d198ed9b1898b4e105c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651832.0,395520.0,916880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22685cecb8322c480183bce13f2103c54d2e6d16c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614304.0,365328.0,988400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bbc1a6e15e24a6db1b77ae51659255aff99f3d2e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B836512.0,330064.0,1029400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bbd823e8694cdbb85ac4bbb1a0ecff7bfb196607%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676192.0,417968.0,892080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227586e85c75d62b46231a7d76d29e93869c4ee67a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762848.0,352664.0,909640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7524ae395e212e5965fa4c9c1612dcb9306db10%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B778936.0,450600.0,880800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22911978fcf1e0764abcbbae5c6c17557bc8a4f327%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665440.0,405952.0,977080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22011d9d65e31a7c6ad3ef9a37b59b7b264a58b420%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B599168.0,414816.0,920000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a78aaf97adf98fb6e09cc4f554b3f387ceffbea3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699912.0,383816.0,955000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bee1d55dc6b59fe6a98918e188ba62185c11f5f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653504.0,411336.0,889240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e928829b3035001bfbf8f45009cdddd66d41936c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673848.0,442536.0,931240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220d1c97c615b1d97e83db38a31f88353679a5c0e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B587784.0,423080.0,912640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b44de1e9c9afd89b0299a7a1c5b8ef3a581f4b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681400.0,384584.0,1071960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2218d5b8833585191219c2003dcd888b0c8cd0bfd0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674068.0,449216.0,883120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c693dd11d8b572cc283a0eb256c0d03e1950ed48%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666624.0,411800.0,962280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b88848763508531e1d1e4f3087574bac86e85c41%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667536.0,455992.0,912840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f38f0cd25dd2b4f10b881e83ab8d00236f26bd79%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651376.0,393352.0,916840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224517c8a146313bccb03c6e18fb7766ae6f266d08%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689848.0,454176.0,891880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fac70cfa541c5f8b9a5932753d02983eb9f38f78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703928.0,432376.0,937360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a1bec7bd31100144a74998acc51c602e268dc62%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608752.0,403856.0,813400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b832ba93dff30e9c41460c4d033027b866e0d2e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644160.0,449032.0,824160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22235afde28c0dae0e9417c37db7c09761e8e7d3c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749424.0,420560.0,963240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e1e0fba43befaf739ca1b1f30dab871ff30621b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676832.0,397680.0,845080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223bd00e4190561f42bb9f3d56a253f9fb55738a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734600.0,412712.0,851480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22895885d6a7266623b90465690d857a8a831502bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716448.0,393560.0,931480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b998f7d11284ef657bfdf7f61ce1288756bef6c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777208.0,438248.0,881080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6f3258d43b7141c58ae91fec011c32ffcdf3fed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615432.0,415080.0,922080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba46d4beb544af2c3db2cae05c8e437dbad3df4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652480.0,414320.0,896360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2216dfedd5cf2ca2191c8728428238b6a423110266%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694736.0,391856.0,929560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22248b52cde627769209cd795caa5e9a06bddb20b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695984.0,386504.0,937480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea9a688bb59bc3300a364df49d7677c6b629ff29%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676472.0,419768.0,890600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf79062b9ab8eb258f83da23ed8956bbf1358226%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627344.0,409792.0,813160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc2853e8049038a5ea2111d9f29aafe03e768d0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619176.0,414216.0,801760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273d28e550463f5943a7c3aa6129ba9c3f749804a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720808.0,381752.0,898960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2224e61f93d52e0df22fb39877f40ed1e30c226357%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727896.0,458696.0,844520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cedbbb9064accde3da4eb5e0942a159fb2c795e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719608.0,447944.0,866200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272435f4b807d8fc4a8126fc71a4710cb9033dfb1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648520.0,412024.0,948520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223acf9733b2ac4e90000963e9752a581ad9b69001%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688840.0,451200.0,893200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e511840bbf66c760f0d0feee845db593f763a430%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635632.0,462896.0,927920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2288696c77338d32b1bff392194bb3d1fc799670f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B566456.0,355728.0,982840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3540400ec46546471ba2d89431ec7d470a15e2a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683812.0,435356.0,901080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2216dee3a5c59313a2445ed26bfed764d6143276de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642480.0,459336.0,851120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc9df36d84e00aadf0e28fc5eded919bc6f85599%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649768.0,409904.0,834280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231be84fc24670276675583d57d97eb40eb444615%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635816.0,398992.0,955840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c89692d4435d7051141a1eb143cb8cc699b41adc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747360.0,396800.0,953840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267fa3af69ef0ce05a29e7f1e61178a16fbb3edbb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676696.0,515312.0,982400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222a9658d555beb2f92b12b30dd702bce75eb2b065%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B589720.0,364168.0,978120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b9aa707a6d5756e22f1c43e810d480c3f880e57f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649896.0,417696.0,844920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a1a80584330c7c43c84ce6254d209e304dce991%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631608.0,422120.0,912360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f74eed0b7cd98ef383e7ca83393334e2c2cf06b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703968.0,451688.0,892840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa7fb133f7e41798f793b3dc0313deaaa4f91f90%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674032.0,435600.0,881960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e808defce9766323f33a3a44ad1469785016058a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659728.0,396144.0,915360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22233fe3003a7854a24bdc1dd7aa35fe92103a87aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714104.0,451536.0,954360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e99a7cb1d112b27edfd76d45d60a58237332967%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B774488.0,359136.0,958080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f95cb86f88d0746ba7d5183cf826a5c2fc7c10d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724904.0,441584.0,913120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22347c73dc7014f9d69f2464081a4126f4d5656c72%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672864.0,438624.0,926560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22623c34629cb7cad2548161478ed71d4ccc8a514a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723520.0,430504.0,956880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c6f05f3532e94b2d023bfa5eb8fc357085075d2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718504.0,446984.0,1003560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22098f32a90d56c52c478f6a365effb964f629a47e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656336.0,463168.0,943480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22217141778811860edf5169ef05ddc5197be4c65b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B820936.0,340120.0,934600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c4a29b4e975415a6f7f61b87c5718fe4c79d0c2a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724224.0,424464.0,945720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206bc8d9377ae7bbc1be5b608624450be614d2754%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B565816.0,354552.0,985440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22459611462533abbdcac6f5a252b33a972a53fc33%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630528.0,412832.0,909000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2250cabe27e1b0b5dee0f40aa6df7801808a5a654f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723856.0,431720.0,958320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb1ce15db672a7af27435f2a9e2a618237508b99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727280.0,458976.0,841560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210e42de2f9683a729e90d209a0257d1bb5bd9584%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713024.0,459140.0,898320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224cbb289da6dd64fd0f02fa29c96062e41443436f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677560.0,416280.0,885960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6dbed42c22da973606b0b71c4e1c4b1f34a51ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715036.0,462876.0,866720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228cbf4a52c470aeb301032633af199f9f2bab1789%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697832.0,384064.0,940800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ce9404dd921e684017530468c4a6a219884edec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709400.0,396608.0,856880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b551c4f118c908bea9deade8ebae3916fdbe890%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700960.0,376896.0,971120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e1ab88436260df44b5a79d57adc2cc090da83388%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B808632.0,346496.0,935800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223badbdeabaecb0a12618101a26c7f883e33a9f90%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663408.0,446672.0,843440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22302d5127f8886b1a040e125fc5c87e574e672739%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647056.0,415744.0,840720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb238fa1647ee144ce8693ed4e1a5a974d899cb2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676408.0,409320.0,861560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227365b23a76a1da10f2e35d5b651aa90caa188a5c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689976.0,475024.0,961600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200410cc384a58b825cbfa366ba7a310c50511b6e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722612.0,382460.0,909040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22677a8d16cc654f3408bb7b99fbf1257433744a1a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727928.0,511928.0,908640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228d3edb6618e171e58440e66d640d5df5ad853ab5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648240.0,407624.0,889560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22acc2678f1cc966b90d2898caf8b2a60421734ab1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706560.0,394628.0,929560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221257154e6a93dc80f5fff9127f9389ca89804bae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655184.0,472648.0,905480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22044e2919bf681640e5708c7fa467cc04d660d9d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673936.0,409856.0,866600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225132761d93619b3892b26736f1952b5c7fd53aa1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706304.0,434928.0,886640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200c1b176b5e1d21507fc69a7a36339dac228a2ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B789208.0,355176.0,939520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2228deb598e7cff9812d0509ff14552b4e1489848b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728384.0,529228.0,911120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223e5506acce68b3a63800f3104c71cf84984f40d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B591064.0,423328.0,911480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e3b540ca052c41d5fbf7bc1766805b458c9174f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B768952.0,447560.0,885280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5ce052a584e00d83144c82b4241dc81d0ee7a04%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681416.0,451904.0,922320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b9d7455dbed1637d98d2bede3f6ccb68d68bd85e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744944.0,416144.0,834560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22760a49977d832b595c8cf83352177279b9df8a29%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672088.0,488256.0,971200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201d4eb2e98ff7f92542d38b13eb363598cf09b26%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663152.0,455832.0,900000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c76e48b96a51dc9013df858f48cecd2d4805914a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612656.0,361160.0,890560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3b541aeef52a4d1f3e8e7fec28c90b7b29e14c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636648.0,408672.0,827960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285f98a8664ed3d259a8fa73df23feb2c960baa49%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658896.0,415360.0,891720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256ef229f6ce3ef2ce36757f4689e75d9dbb5af4e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706648.0,445568.0,879400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d096cd138b8b4f7fd9773325518fe12ceb61f83%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641128.0,463176.0,935400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3f502b8d04075f6372dd2486c447360805e9ddb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635032.0,441760.0,818880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22926cbe2397e9d8208134bb8126f4aa9a3a84a28d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B779364.0,356148.0,965080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241e877e8df39d97075a9c747cfe3b2095624be58%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667424.0,402912.0,989640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bfb6f83324e1f58a4c3a4e386aaaaa62108b80d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644280.0,462712.0,932440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200ad3a98cf8aa31efcf867ed3e20ea63941e69ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671704.0,446488.0,871680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228eb58f7ede48c68089a3838ef9c61651ba12a33a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601480.0,395176.0,783280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc3fbd5ddc9da9f75c20cafc0e2308528b7f7166%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710424.0,394312.0,929960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb655694a0f845629d5c60988d26b00f00bfe2b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718208.0,446768.0,857760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222112c359ea33e3e409069ddc8469a84e4914aa9e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641008.0,407696.0,952680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a787f0e125f4e02a83e98eb095bf7d4aae5c7c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B585824.0,422184.0,914000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228d2a87af3eb267d1a937450ed05476de4580461b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667080.0,413872.0,957480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22608d996f416f256c7b8dea477d2b85ffbe5fec3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675008.0,415424.0,881160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe897b8774aff54f5a67073aaa5d56e3e5073552%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719496.0,474192.0,982080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ccf7359f53c360c82b658c75bfcbdc1caf6bc7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669688.0,408816.0,946640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2280aaae763f1ac848d298f9a8287a75f83053e764%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673336.0,439968.0,927000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221468de78ca8549116e560684618c33c7b76dccda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767776.0,449048.0,885440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ce53c06c4deeabbe800a4cf7b7866068e8f9201%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674336.0,471988.0,959480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279171022fa8929970fa1a884a1442f0861f18306%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666344.0,443600.0,854600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224407f3a65105e7f547f9f95e81c980aa5acb97e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725672.0,527384.0,910080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c28ad0bda732b5757ffff4795f82f32b007cc73%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666656.0,406464.0,976400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271b6d328798c25c9b23c56d56d6b550fac10dde8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711808.0,426384.0,876800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d62ef7da5963338b43b2508cb9e98dd5d72965db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696360.0,399608.0,900800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233c29f7f546096af889ed95eecd6ad012f7ac050%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765488.0,400936.0,961040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229001456f28077b91de2edc55f1242e41dcef6463%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B759072.0,361384.0,934960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2269138addc0cd0615890d5a1525189c38b04aa4af%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690760.0,441528.0,884840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f3d8134ebd5eac782da89d6c5741240242daf64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638336.0,491480.0,899560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2238ed762880219f4667df37e3dde908ddc05cb2ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652432.0,412376.0,841560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c5f7eb671c75d62953d2efb1337b546a5d6ceef1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628888.0,469912.0,937920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223afc7dcd15dbc6539166bd5d7636b83edaa06bc3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671516.0,491752.0,881840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf28182a9c05b103457118acdc78d58c5fd60359%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672160.0,438032.0,887200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0f4bab742dbedf2e5af3671af6c1e6423946f77%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665120.0,400592.0,913600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f746a7f8fb74ee096d4218574e0ed0ab65e6e22%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705880.0,434688.0,936200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d218a3d6d153649c516905f62809f1c570157e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699616.0,375844.0,966080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f5a61037e4b4346aca83176dfc0b5e2d8a27f89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670404.0,483232.0,888440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d034dfa58c9101a89d210f7320e3def35016409%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647656.0,391520.0,916200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222271c57e229f648ce943067c170a03b95a5ba4e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729576.0,440136.0,910360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2248a66e0ac0fdfd5c26f37fa1897ab0383087ed22%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717904.0,438096.0,890120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223074824747da9b95e2f83092463dccdcb667b81d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691324.0,402680.0,914240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af2f1cd1265481d378a30522a0f85e50ddebc45a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631368.0,419280.0,912040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f5fbf880761dfc0e3953eb3611966576eb362b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742488.0,419960.0,959280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa625bb2d422a9ec58dd643bc1edaf5f83cd796d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637384.0,445016.0,817880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260457df7ae5b0a97a58b021cc3ca90e9167bf7c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675408.0,482728.0,964880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22be82f49156a308baa6ef6878936f42c9d2daf699%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619896.0,372136.0,977280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22332daaf1fd971d2a196285317aba17c544732daa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673408.0,505120.0,979080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab586ed986e10bb4935ceb7117803fb1df390c12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680736.0,384240.0,1072280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cdb290c4fd45ad5fee785c86dfdf913325f4e81b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670296.0,453224.0,871000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7b44bf71fdff38252f2a9dabe5f4d51db391db2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665888.0,415752.0,952760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22533ef39bda97b2798bfadb7e1ca056c860d80702%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644080.0,406272.0,891120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fc6c150ebb26b61b611e1a7eea42334b4cd605eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739736.0,383216.0,891600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22501c0e3019fd4e52a56f6afb44e2bead875e30cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770960.0,400976.0,963280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229756ef9f1386228cfac58a87145742ccb8f2fb21%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676632.0,450240.0,875040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c93118dc3ee4cdb877d1eb2734b14ff45dfbd576%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739184.0,424712.0,961880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d66613d36139b445ddf31813c8b0d5b2893da09c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679636.0,419324.0,899120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223917d40884fded75a87c3523b5d880459630b2bd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676984.0,379368.0,1083320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282007e0051fd0f3ceaeed95b71c8c1886b2081d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669088.0,486040.0,886120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22271e6e9193611d2e31aee7aa49215721af18aef1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708056.0,361256.0,912000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232e54cb7d657b48ba5fab015789523e0e57d7de5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639340.0,446152.0,821960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b50c6f7f5dfde0d13591b49b1ffdcf1adef19c7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717712.0,426520.0,943960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cd7aca864b225710f6edc711b2b43716f9e181cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711848.0,435344.0,960240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8a2a838994ac819dde7cd7eadb630d9b39dccba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711956.0,357028.0,912520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e53e7aac0194329c900b19a17ba5ce4fe8c02643%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710432.0,392560.0,867200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ece9822e6847809b932ce5ab654cbfd70f6af02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714620.0,430292.0,940040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb1b5357ea0bf2792316ac92b372d14322c76a88%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712712.0,437400.0,959400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22663a52efb9340e1dd4a7398a525b5ebd0d0cbb87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721824.0,454632.0,840080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226ca1cb073bcf046f7f95e7339ada340e714ad12c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704856.0,371016.0,987240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ad84a204c8f96c0c45edcc1a1cdd1a36de1079d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690864.0,466152.0,949160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22821131373fc260a0acae72459ea576fed51c70d2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675036.0,443348.0,897240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22109ce631df1998f9a0a3eb1fbf6c5b87ea75bdc9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677208.0,378264.0,818320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ba7641f8289369ad27bc7fe0f701ede1fb86039%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714200.0,446008.0,984600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241354bb79c2674553ae2cc1a3d437a2b33a682a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724752.0,447560.0,861120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b7bb7d92da20a2a7561adbf1cab81538228fa65%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674016.0,443544.0,895560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d38901db666f0375c2797430432c4ab30a037e06%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613376.0,368632.0,984760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f2f30864f50c5d3cb07304fafcfdc9f826669d17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666616.0,377752.0,1094560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266c8fc1fb8140fcaf3c2e1327792b041be232fdd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628624.0,354328.0,1012040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225fc21e96a0c341774843969bb61fb27e163221d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617200.0,515128.0,898480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232baa666dfcbf41c1a293a100a7ab9151438d168%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716512.0,440540.0,866760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f6a0405e0e8963a34e60ed690c4cd1f4e8f6ca07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663344.0,465408.0,855800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad8b47fbcd6ede6be9c5983de0a72ba3cf3fc7b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761008.0,359528.0,933960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ebe9ff8ae6132189ce4d7248f6bab3abe1a7580%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710888.0,437200.0,956440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22177385a8cd4e11310bab51b43ba2bd1e93473960%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707312.0,432552.0,882840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273742b6720083c5f2803929651358cc32e0946b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672304.0,442008.0,893760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22123fd70a202d9877b1407c72ac22acb64273b3f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719992.0,440944.0,914520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cce3b680a5218dfdb186b32447390c191d0f9a6a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732824.0,459992.0,837920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2245b9cd5a33a035c6ba8789bdb31f74d0178526c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724416.0,452408.0,834080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221445b002d4dcf60bec36c51bc49e30cf6f189282%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691568.0,470448.0,953640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297c6e77082664e42f084ffd96c4196fbe50f24af%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B552152.0,394640.0,810640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229273c4dd47f156aaecb6995c8deee23ad75f2583%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742076.0,440880.0,908920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22165c14ffeec9677b820f5db5220db79c6a51c4f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674960.0,435904.0,923240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b62d8c90e717cc1dba066769ae7f9e75de2f2790%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648008.0,407936.0,833120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224118cc2620a09f29dfa939369f9b316e81369a79%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650624.0,412040.0,839800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298c49de3d4db88ac3361dc8d405c5d0ff7e16af6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671936.0,378976.0,1087920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f47288d2bcf9e1dff0f0a17e72538c433e1b82c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713176.0,482712.0,846080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229baaeb5a6c7f3091d1656a8a2790e3545da09183%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733536.0,351592.0,1059120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9659be5f88892d80174a5dcf9fe92d51f48e373%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716264.0,464016.0,863760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f72ff1e7b692503b8cabe732d068957c177e3304%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606272.0,482392.0,945920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222adbdddb07634e64f046947f809d606bf4734029%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677168.0,517864.0,986960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f34bc8f6c8db640c50de530c7f9a957db866ae2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728400.0,460024.0,810840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22059f6d781b0a58e065586e8ba4e9d9eadb51f7bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640096.0,459408.0,925080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ef9f0e2561b7ab23fcb478f4e7486e8280461f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656264.0,453528.0,929520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ce0ba38a8d5f7530fb80d87ddf82fe34ed66591%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B583896.0,423512.0,912320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d56db706bea223cf1b06396ba736909e38f93efc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720696.0,365984.0,1017480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a272a323775b93746f77305b7ac2f2e96df23e29%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635384.0,402728.0,893280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ffc151813f31619e0152651d7b4f21cdd80e4233%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749544.0,420208.0,971920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22440680c040c4d3eb19c5c77c835cac04fed05761%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674992.0,448040.0,873840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242d33942585c3d4d5a60a88cd84162664e6a8762%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715432.0,467312.0,902160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220253ea800ce089674d59d0cdc14bdbccf13d4e4f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691344.0,476072.0,961560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea131f43b7767fb93b0ff5a8d44feb6356ac956b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725344.0,453648.0,833880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201b2a70692af0c1883a0bc44129f35ba0a6004b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623856.0,507240.0,899440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22098a2997fa1cb2b69faf461b0d5377838d1b7576%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616016.0,393496.0,800080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a753181b390aa9b657e6a4a1a1e4e82de3eae21c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626576.0,482672.0,871760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b771c728a2f3286939c698eea566ff724b66be64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B803408.0,340812.0,989600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225db041c8a34381b4b83e7d79441d552b9a0c739b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716216.0,440448.0,916720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220fb162868bd576c06002d1d8ca5c43b6e1acc3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622296.0,484160.0,871640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6df9aec6821f5b25f142fd1fbc3575d65766513%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731672.0,441128.0,911400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a335fffc5611f51408115d9097721e4b79e517b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704216.0,398744.0,881760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ae92800fd116b4ba37078d5d1cfbc29264c86b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686688.0,481264.0,978560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e1d719e387e68c96baf7874a9c74b139afdb36a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756680.0,438080.0,881800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b51d5c3694c24b97dcfcf39d4506b1f3019dcfb0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685096.0,404024.0,1028240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226dba1ca2f213401a9d45e08e4647cc6c2781f8c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689956.0,468256.0,880680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266f516e14739fb3c585181185aae911fc43465e1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702608.0,376728.0,900160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22756ea48842f702c25854272001a6ec1afbc93eda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728072.0,391600.0,939400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241c964f2cee482176fdf8d545675cdebc7761a5e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673072.0,443344.0,894920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cebd4ca293aa7fa05ac616ba20c80220fc79bd49%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B553724.0,394884.0,811640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22989ab3e363f6b6754c1dec9686df057350b4516c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673784.0,375608.0,804320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eac0e44146015a066d29932bde077a73246e05eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671624.0,427200.0,922960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22312a74dc56a58b41477d04a0a0d019d74d6fc936%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650668.0,411572.0,947600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a854e2439d53b5c8158abec34c8e930fcfd977ec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B586000.0,472848.0,853040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b045806b6514a4f205a235ec206447c9d1b3179%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640324.0,420592.0,913280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224947d7b23ba2cc6f5c2f24602fa3d572633690ac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681360.0,383328.0,1068080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22993ba0f1eb57e332f00b0f486f13ffdf738433e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722064.0,391032.0,933680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221990801a983a33efed40acc6cc0b1d20d061b44%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679976.0,384816.0,1065800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ddd7096c472c225b397b4d06c474d04baf2bd4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765248.0,362528.0,950480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22332e9365243dc66588b1c31598a187782a721ecb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668580.0,443364.0,929360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f048eb1efac856434eb2de815266f911c1c4b23%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644528.0,456184.0,915840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a60fc1d26143db5858e44fbf715ebe0aa11581f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634536.0,460272.0,882840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b308cf12d02c762a60a95cf8ee7c29e0a085c374%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B755208.0,419496.0,967320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c3f7dbe521c1190cb626d0cb364416dcc10f322%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734736.0,439896.0,890760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22008324e3ef5181c4aeeb14d28c47f5a4cef857a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708312.0,368392.0,995840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227606a734f48488af0a02d45e01c67d9f745a5d02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724800.0,453224.0,835760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2237947b17a53e7c7cd488e9fe00ec862647f342ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B548176.0,348648.0,990000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ca0a46b71d24d519375dbdf5d0f1aaf275ad8e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639120.0,410088.0,826280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7a21786ea46b759c21ff90a14af4bb1d6fe7512%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646184.0,410888.0,949480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a15c45d95344538213936c7814832d10857f8426%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681544.0,384200.0,1068960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c80840d43189589be38cd7160884923e49095b8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713112.0,470640.0,855520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22480e18f1cf6b98bc4228c84915f181a2af5872a2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714632.0,480984.0,849560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2213e700bc8a894f63048c3f626f6258fc2da0c79e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626120.0,388024.0,968680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ff1d9e01f125e394cdaf314d0d872cac34ee24d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728688.0,377016.0,913120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c00a2e259070e4a273ed9efc860090585d66558f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715808.0,478736.0,847840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fbdac87031acea0420fa6aebef3d20f9fde27514%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687736.0,390000.0,898840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ce74745ec8d52902c0e54fe1a799ad4084b13cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680952.0,446684.0,911280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e84897822d5e5aaaa36075ef31887c140503b270%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646656.0,447912.0,826440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b2c2842acfa4c6bef30ec4111003a2efc4ebab3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B589880.0,394064.0,816280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2216f6cd565dd57e334544b1ac19d02e722fae7fcf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706560.0,398768.0,845800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e3d7e2407849c3fa7f64bdf80e9178798292cb6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668912.0,375704.0,1089400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223972cb0cc541828d6a6a25dfd000998b3ebec45a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673912.0,379176.0,1086480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227dfa37b46cbf492a8d8ebc9b286b5b225ff3af21%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680872.0,447024.0,910840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6f105d54579f209d28499a08c10a980e73eb3c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713216.0,393288.0,931160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22259c058f5467beb8c5356e6d2278c7261d1a3a14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671520.0,404048.0,855560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222236817545931ab60543089349eba3f554fe6534%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682992.0,456704.0,932440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dbff07135b9791b8ce77bc4e50c9968c0478d0cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675544.0,397672.0,1013480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b230b44a78e5ee01f1f55ec0f1252cea43b6ccb8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647232.0,469880.0,880680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bfc0d56a70264f18c39a5b35e40dce670e8bfaf3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717548.0,443068.0,875040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22acd8da218955233776f45cf24b0a2033d033aaf5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654440.0,476440.0,902360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22373513027bcaf37ebafaba363c00ba1bb2e44c68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683688.0,487344.0,868600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22062075428d9f3a8192af98269e2b2990066134bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687836.0,431040.0,902800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240e47e90b745e9a3cf34fba7cfb52e34e2e054d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708296.0,491120.0,837720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9d8b00037c0e8897f52a7ba763579bb92b7ed50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656608.0,459800.0,892080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e2316febbd21633e17a89d26fe60cd21947f3eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690408.0,465880.0,882480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fbc35824a190a9ababbceb751b5d8992adb4d8bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632560.0,422200.0,911360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3ea6cbcecdcc7db633e87c28ca97f70099a0e95%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664624.0,410252.0,861440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22503b51a1fab6ce5204b666166f69cb781a667a8b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647064.0,449560.0,827880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c5ece5443bd33889459da2a3d999f6d511964e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640680.0,458696.0,921240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221004165190320457f6600c17595c7011d8ab6a8c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694568.0,385008.0,899880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222db26d6bea59be5051a8c6bef3fbdccab8e8f9e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673056.0,413424.0,874400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2248dc438f6ddb86813f39c6113e30e614177f0fd3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683584.0,456952.0,936880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e2ad07fa0af25f57146b2d03c30657f1a238b7f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662944.0,399904.0,998040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dbec5e67e34046e726c199616c895994347a3993%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681528.0,399352.0,897520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2209f56160ad9df44e004a0c9b41fe1d34aebda0e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663336.0,401232.0,997080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d76d91946542ffca1d32b1aeedb55dee8693cfee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688648.0,478032.0,965360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292f1975deddf545bad9859bb6156782f9b74b178%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607928.0,477896.0,944120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad770e5219c8bcc9581806ae25800c2bed3cb3aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672080.0,479056.0,888600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e98b55df3ece84884760ec76c67a4a71d2a8c310%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717712.0,445816.0,877400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2288c41190c6e437ea6f21a3111748392dca7938cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712024.0,487516.0,842160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2244b79fd63d503ab90c8243865ba8b90b07813a7b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724360.0,455508.0,825640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298ff00106bc0365e8b9cc80963613f993d46533a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640480.0,404648.0,954520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242ed1a3835ed5cfab09021314004f96ffcf3eed6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624496.0,388360.0,968000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220d2cad837eec866ad697a924a90d2ea3582c19b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710032.0,434776.0,951080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc537878a385e2d6d321c35eb0405e7192750b38%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717600.0,422112.0,870560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b183a5861bc927df868c7b6bc6c811ef38dd81c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621648.0,473240.0,938240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22336cc07064f8242fabb927d50ca430ad9eed0cce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660480.0,462472.0,942840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b247c85cfc9cbdfa75df367ece3bcffb37034948%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734224.0,442344.0,889920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224311ca13c068b31d9c4378d1c68799281ba9d82f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601264.0,468160.0,865680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22205edee775db63cfc5b05d896a4a86a8c4a878cf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723944.0,456032.0,816480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c80089811d75f09badeca762bfe841e8b07d1f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737232.0,384784.0,892520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd3b9d1141efbb1f7dc44fa07ae68fce2a85b21d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690808.0,433256.0,904800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7e4a4a6be34b9285fe036b8187319ffb801d874%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B585536.0,360528.0,979920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e57b95a236f2573957a8bc3aaf8a1ceec69cf82a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719472.0,381816.0,899160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f29d8f72fc320d7ecd3c0ce3d6ca6be595624db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748800.0,419848.0,970640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca4e9bef2486a3980a7e61fdc772ead45ac6334d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B773104.0,354544.0,939680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2275e0ab7c0712df1b7d65cdb4ddc14809a707e3ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663264.0,399928.0,994560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211cb62c793de4aa2c76ce1eb33e760a3992fda76%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691104.0,433928.0,905600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225d4f1f0bace5eacf5545666fcc0cd55e17ddbcf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B610560.0,370824.0,978840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2215d7c502a4250c7aca204c0d47a0a4e2fa0e5b2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729688.0,376416.0,915080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2287c1da04ebb16654031171d85c4b025c5b3e4a4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670032.0,454304.0,914320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d0b17b9070df091be1cc905e4d34dd360ad767a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665160.0,407776.0,974880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22826b59a9bcfd8c299d6a298842467a5422a32da2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725832.0,448432.0,859040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226eb549696ec214b8f71b6b7da42ebc9c50f3ea99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717720.0,386032.0,909560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e6f5a7fb94d93c77eef76a64ef2a5dbbbbab36a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B769984.0,449744.0,885280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e2d95397abc2f5841492ef16ba652f1f2c063f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B566712.0,393104.0,813960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fbbb6423f89cc34a9bee038dd873b8b41edb34a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647240.0,414552.0,841400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22988688d97e95b197169f8fc5a6c6cdcb95fed021%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643800.0,460736.0,932720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222495649854321d922776581bd4e555e5f7cbf17f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731728.0,414024.0,852880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297b205489c3003436bb5c34cee5400e266c453fa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707096.0,399896.0,848640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f5bd1bddc69d23e16f1bb325b2051a6afd10bc21%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732392.0,461584.0,836560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22021173b3c89e6aa23096b54adf32ef8bddf49fee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B610768.0,476200.0,940120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d96009d1a4a4dd6cb67b391e3c34ccecf45a31b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697824.0,387104.0,940400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd72ead34d7b3857714ba52b83d4dfd526f8d045%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765928.0,433320.0,882440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d119f46e7da3fdbb1c33b84acd956ef07848267%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B779304.0,355600.0,963760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0fab8bdcf1c7962bff7722eab3ce9b8f0aee9c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715792.0,455632.0,958720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22095873c7bbb72e39b3875c41cadf1f8f195e2193%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724504.0,454536.0,836480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a97656afb625f6750025815151443100f1e7fb1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635016.0,473368.0,874560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226ea00e5ac6078c8b60130a7f5c03143163bd82a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713240.0,475272.0,853000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a86b996726d2dc708eea4e21b56c70766589a3fb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B556336.0,350988.0,988520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22163de9db8544071d885aea1149ac7ea874a4cc7f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712956.0,463228.0,862720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ffaff935120e25d8406a1c3fd9172bda8fc035af%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630608.0,476792.0,875040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c0fe36d63509db1637e3b66c0d8ea995f518be3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677728.0,503480.0,866080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2293614627aaad0372e18e7e58a0174101a3391106%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732352.0,462744.0,835280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bfd1e3eac94b5478416e30cc059ed65cc69929d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635240.0,441584.0,816160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e0e3df20c48fda3869243188725e962d9895a2f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724504.0,447496.0,861360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cd4d1a7629db4c0b8891f39415dc3f45e55beaea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725608.0,518024.0,905320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b625bab942700436354fb8696b3aea01707831ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636008.0,397640.0,958440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e3fb15fcfc42a60419b17adf4da3df031797bf7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608208.0,482216.0,946040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a83eb9b6c4f823af09318e12106b42a400f9ae45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726192.0,455224.0,823800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223eacc367c8761883ae1165bdc26803fa949e565d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667352.0,420712.0,933080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da81b4f6bf36f5853bbd87775d58b778b6a611f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637896.0,401944.0,956400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222832bf2039c35fa04101bf2910745ab7b7a0b9f3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657376.0,448176.0,909720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233319eb8a5d2db7df2972d8b734d5f7049f838b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640160.0,461248.0,923200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d20bc9c69ffee0e96bf8285171b155f823ff4412%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667248.0,402472.0,990800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7a6726f7b942ede5c0a9de233081b5afb08f265%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655088.0,471816.0,904440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2280ed29ddfcff4589b6b5e168f30be5ff6d98a340%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694172.0,442576.0,899680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271e60259255adf8f715c0e92a95879001cba106f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627168.0,470600.0,936680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22812656aac79d0382499d433445ff071b5d511bf6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667416.0,473552.0,892840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22935a169823444dd7f5260383f65ab331241dfd95%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719408.0,365032.0,1013760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22100f29ee6c4e7cca557a0b137190ef9d59530046%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720112.0,420736.0,870320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2275c8f5b21c630a33a0c72ab4d40a635c5e9a3ccc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700936.0,435424.0,931480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1ce59cd31534d629d0d29aeefaeaeeb7209654f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711320.0,397496.0,869680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274133f51e38c8321cc7290bd3e145465279b78ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634276.0,496524.0,900960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200029e6d940bb4a5cf62a199b2f7c14968b43f0a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673224.0,445720.0,893320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2280f058b357f8b825ac40aac9e6a1452ff58baf37%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705216.0,370024.0,992400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7a437da55f2aa2419fb88c8cbd0fa72d8c8bdd5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B605640.0,465312.0,869080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254bb328db59fdc6fc01079a434b7546edade0ecf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733064.0,461408.0,834120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f89d6889bf023545b2ac3f888728e614c09d14b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690776.0,475320.0,961320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a78157b6b235aa0a69ef704f01ed6ea8bc6004e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672656.0,417288.0,889040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229dd4a28d92f7708e6e39ff726b08cedd4ec36a7c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728000.0,453120.0,850960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2224ed4f54cdc85a4a69c5bd0294965db0e3bbaadb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708608.0,430000.0,881920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c2982256dc79a32321dcd35d8c66103035cb17d2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709660.0,359504.0,910360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f70f15d7f946c8f5e0d4619776cab3d300248d3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682532.0,430924.0,906280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ee330166a9fe98afbc5b8ecb12556f424e7356d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608352.0,463672.0,870240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f0d5df1ab90e861377c0a0f2ee7c625ec642c224%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673632.0,399000.0,1013480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226fb0cd5997879d61f8f97f4d92706c3441d2284a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669960.0,478160.0,889240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22925a5ad12f7874cc0ac79563cee51b0272f26a64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669048.0,455176.0,942320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22732227cec1e4651fce9b0b2e1ab068827d58e9da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706064.0,398336.0,855200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22712a714704d286ad4106148449165237d099f69e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713136.0,475712.0,853720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221306e2204919a1ecb7bd17568f0f91ab7991da37%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718208.0,446768.0,855520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9e68883582d7a2e0b32a59ea29b6f949f8bc0e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729656.0,355656.0,1052760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c75c6d3d00a174232f4a48af0b7b9f7589b13dd5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682248.0,430232.0,904760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258ffa1e65f9aedff684f05cc4f90bc0ae10ced83%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695904.0,440072.0,889480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2280ed114ec39b80e9f6a38e62e1d0cbeaf72fcc29%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690144.0,444008.0,897720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227775948fa14bf977f0b7d15c5f468eec359e681d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756104.0,362112.0,935000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2234756a47076aa8fd3e1a741d47efeb695af40837%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622664.0,381368.0,977160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f973a3686889c6aff23d90ee2a71ec7c028f6537%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B569744.0,355632.0,983640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2264943b3c29aae208404b49e78b029be7356fa2f3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658904.0,450432.0,894880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2268aaca390427d9536ffd0d2f602377d27ed12c8d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676512.0,394544.0,840480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2187bf59a52c81d6b78afa934c6d074c2c4392b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667528.0,366144.0,789880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22205ee8c6234062bb338ec3d80618bd8a6e210bfc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688792.0,477304.0,964480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2216c1d41558beb04f3018fed16fbdeedbe6be7934%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713812.0,446920.0,947000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a35933eef6e76e9b81db1878d60f7ae55ea42b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625192.0,472024.0,937480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2261d83ca9df7092f1f8a45a740412e70159c566b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B782688.0,452640.0,882320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ccef544e955affb06b676c25cf35ab2ba8a6b47%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701360.0,435552.0,934560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ed4ee7441efe061631a402823495b643b586d7b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674632.0,460392.0,944480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4c8b5b564d678f623e3f242055a48915ce65b03%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716240.0,440880.0,869760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225df7778b2b5377fa7423ea42c03c0e1b7e4c8e70%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664556.0,461376.0,943320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22846426c69d1a0506e5488fe7b00f4df27dd5bb57%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749984.0,419376.0,963840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c20ed081821bb31b9442cc901eb717daa747dfe2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649696.0,410680.0,836160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203ec3f94ea1de714a2c43a114b7df2e06535b7e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B798032.0,352736.0,936520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d0a8a001327ff662b791cee4d7c456b4b875cac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714648.0,464568.0,899040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223b7a524941cb0357e9bcc4f9347ff8d56ff24bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B776368.0,435840.0,880080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233a1266ed1a6b0d22c414c26bbebe3791f267fb1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620896.0,374072.0,977560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4673ca748503d8e9014eabe57986f568e580bb2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620824.0,472304.0,940480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296a63aef34b5659e90381b3dca1d25d26a6d05ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621244.0,458992.0,873760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22019858b89fa557ebfd97e4908a3261660e39bfbe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682144.0,395016.0,1052560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7f6067b7529f6b316ddeb5eaa34879ca349a5af%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689832.0,471612.0,954600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2283c8bd6f946cfeba777306b59353fc72448dcd89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612072.0,405360.0,814240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e75e1e4363cffad4d2d49ed2e3ded74f9ca9834%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691248.0,401096.0,917920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ade9f626c1759d19ac041b0de3cc11a3b7c5643d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617952.0,472264.0,941040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224892989c340093e1a2f566b3c1745e3f96eb1d97%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667592.0,421256.0,931040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2ad48cb41c891e58481e353fb85bd2b120ab11e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658752.0,447112.0,838080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f2ad2e1e6d28f04af875f2a4e33d02125e6b16f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681080.0,391768.0,1056560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267df054eb61c798010a937719c24ae86f8b3143d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672488.0,427736.0,871400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a6d3e629f715e8c980a8ec00272e3edc66e7d3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B813408.0,330864.0,1004360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22924488fc4027483620899f2fe66250d9d26f3565%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716400.0,445128.0,985960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1fb40ff0b9f6bea888853fc1ff7b3cfa3291aa5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655720.0,410456.0,889040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ad4fc6f29eb2dbd2d36985d67df5a5d1df5d214%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666384.0,404944.0,984440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225796088f8b54e2f56de1766dde9b70709aba34c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709848.0,390488.0,903320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249ef70581cb839d8b75aa37bd6544474110bcaa7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678024.0,417268.0,885120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2248489f18b909e07f6aab0fd7ac95e011582463f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709172.0,358540.0,912000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f772af8a962fc0893d987525a953df63f206db9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725184.0,457616.0,823080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb99ea4773b6c3586fefedde2a2f1ca8b0a46169%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644088.0,456872.0,892160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd026f2eceac7a9f4a98df2579d9a71c85997138%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725580.0,440708.0,889360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224223fa2905ad01505be5ecc9854495c152c37516%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652272.0,417520.0,846440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22850d715719566a0095903c8c12be256604e9ab6b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703776.0,432736.0,883880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2291a4bb01ebb592a4b917e6ef124356805b33b789%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673448.0,485264.0,969000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22791644d8fe0d4c9385d3b1cdd562dd5ccde1806a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685516.0,433436.0,901040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6a7685983e61b29e0d052b98f29719dfa3ec31a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726464.0,486432.0,903720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229be3bd4fc9f193da91b78b04362e35092ca50db4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691232.0,457440.0,888200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b56d9c1be7f64426d04af4c48b7fecfef029c7e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B591736.0,421280.0,946040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2275ef540ddf23c4843ece0877207b6eb49133ce83%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622712.0,383024.0,893680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226fe0421bc2371aa53116442b048472cdf4153146%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639984.0,467824.0,936240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f8e3a21fd43ae8ca79acad70e859ecbb47b321a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B585504.0,390240.0,816880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0575f66d9f171016fa84a5abe1b11a2439b1513%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734224.0,382832.0,892840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2280a6a2e0d2b0a679c539f56cb5ea47d2958ff9d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661736.0,398568.0,914720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207b9f9710a49362b5adae91d599875073b6b497c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604496.0,482528.0,947480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22737bd6d91defc53e07112da13c10048a59e3373e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703568.0,434520.0,939560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2294d3297dc99b5d39f7b87a89e236f66666a7748b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677312.0,447080.0,878840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227fdb3ceba01ef9dcd4464aef81b56001fc244e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729328.0,416200.0,855320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d396ab50ccdd110d3b3ee91d089d63dd79c86bd1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736584.0,426440.0,961240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210879871db298012749ad5ca928870515d89afda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665384.0,377456.0,1098200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf1b80a111ceaa11b4c3e7119e4a37725fb2b5ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665492.0,413636.0,960560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8198ec64be2da4e20c3eaf0d198cba0254a2edf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667484.0,473532.0,894320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b2b2185753176afab3ce74c64f05d372adf72ee0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675616.0,511528.0,981960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de0e5b9fa2109dee9cff9c7caaa3b0ba32d5d74a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705988.0,435868.0,942040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e8979c7a5e99e78acec20d83baf91833d52e64f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650304.0,415448.0,844080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22612124e16c4afdb12bf25a5a1b5b21fa7fc70f43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601336.0,529280.0,898800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226416d360f1671be09f304aa9c595996ae57307df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685016.0,402968.0,1029880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228782207f8fcedf514cfb35f5ecd50a6b2acb82e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708716.0,432356.0,938760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e4e59007fffe138ef5ac24d6b89d9440306d7d0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669976.0,379056.0,1091560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e3c04d7bdf2a13a138306b9c8e72c13d33e8620%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722104.0,453264.0,838560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b83d4336778e2ff0c7b65fd22124a2fad86d3756%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654496.0,396080.0,915480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f3f2c45f58afad2fdb0a714756947e87ab51d41%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616128.0,431616.0,772160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a066498397f4e8ae5de6ac02b38bbb66a208bad3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761856.0,360656.0,919480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e711251db5c74d40d8390ec21a766bdc751ea048%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732104.0,460912.0,808280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e4006cf74d5e4b2faf40fcd2d0ede4de9b14a8ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653528.0,422040.0,857520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22addf6b707ccf090e0e52ee56edd6ddcd6e78f1d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685248.0,414432.0,902240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c290b21e8ebae46433d9a5f8a1ed757f1b030399%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677096.0,515832.0,984520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0f4c1f3e80e566449d0e6323b66df565167b150%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671768.0,450808.0,937000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222a4265b21a39af2eabffb640cba57d92dfedec9a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668088.0,455048.0,865880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3ef5f4de3ce15bedcb65abf7de9dc0264b8ef97%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675848.0,430384.0,918760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254fe13af98e632528d501fc95f22cbba0ee79704%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651032.0,451352.0,829120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272d500943885e2c1c04b58b33afc8c446bca2dbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680888.0,438776.0,901440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd3b87637bf62282a52482c93276f4fc51f3ee77%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682176.0,437576.0,908080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3fdea8fc2f6ead0175769fcbfa12bb2f34ccb18%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669584.0,398136.0,1006240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22279f202ae6111e19973b414cf7fa63391a15ef39%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716440.0,440864.0,864200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa73a13c6b730a1c79df172a92d01f8ee58a68e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621920.0,472344.0,939520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2293713566575fdac7e91ea98123808f58f8cf70a1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681424.0,391220.0,1055640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d6b9ad750eedf03e325bd83533fa28da2cdb513%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687320.0,429568.0,906480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295d9257ac4bc729920ce65bdcd39aa8124bad5db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679880.0,391008.0,1057680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c2f02d89523f6cd09a7b2ea2ffd1bc754a8493c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704392.0,373520.0,978400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1fd871a597322a6b1f79da2a4f564a8152f3676%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646216.0,415688.0,832600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f9a4e20232ae9a1e5b336e2e0745269ce6e3b4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704552.0,374400.0,975360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223c852f095ac303204269acc21c140ea92f30f50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678824.0,502032.0,867800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22479451176ce20a374cf7e39ccbefb2f3875795f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683808.0,430116.0,902560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229797a1a4794c2d7f14ea8257f3157a98e5844ee2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616624.0,472408.0,941600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22175f666207cbe581dc4e5d9ec6990a7880cb4b68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B833416.0,330304.0,1026600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a27bf530c94d2a7ed3b4e7b34432d4d1d795b686%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678872.0,382280.0,1078920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f91a28f369583ff14b6c0d6f750362f37d9c16c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741968.0,413808.0,841600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea9acd37acde6f0215f7364379df50229e05ea4b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681104.0,385648.0,1065280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271dd344bd8c86b0c5935348d733554e307df6d9b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686720.0,459336.0,941720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c5689a1a3c92682c45bb258672bbf098a297ccdf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676248.0,432336.0,877000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222bb89a2e4cb744a1a6b87a00aefd26e70ac13b8d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720480.0,390384.0,934120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2288e3d330f66121ebf53e93d40dddfe536665f3d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715864.0,443168.0,982600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4eca71447fdba78d182d0b8f4794e4abb837781%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739344.0,411816.0,847440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ca595080bf00d98647ded118b171c11b4b4c6c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B836992.0,331488.0,936920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285ed2acc1be3959c1db0750aab3fc1b604429a89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711760.0,485392.0,841800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d20b52738847ed88c5c313d5975a49f75dc0eef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616432.0,416736.0,796720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d1d1b810de1260d7544a0e024338bdb267facc0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659168.0,461032.0,890120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f43412ca890606354743d54bc4fe515fd109189d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643864.0,409544.0,952680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22176b79920a74f5f1e93f105d5c48db06fa60479d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675480.0,407088.0,905680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eae7bcca91c70f8ca2256280dd64f3e8b80d6159%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729800.0,497896.0,908600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb3df9679654f8034de1f226d3cebf67107658a6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686372.0,473972.0,876840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229285115865ebeb1ad984ceabe75d2857236d131d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670088.0,405592.0,906200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22caa42e7cde5b4af896c5d345f20df91eba77b6ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668680.0,408888.0,865280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2264f8de7ba144858399df9150677110bdbab6d029%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708544.0,365824.0,910560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22321b1a9372c62506937c39c6c0f6bc8a1ea40653%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673192.0,459216.0,944520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22efd9573e3aeafe08ac06ef74e25fa72d623d9443%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606384.0,400928.0,815080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da65ce63aa820aa58f69d7f1e4355af7423f9287%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673568.0,480384.0,964080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b1cbfdb12f017d670c53971663f11b4d6b30e50c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600032.0,469616.0,863040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c16810f7bc207df4e11db5a9226629a77ce5152%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691824.0,475320.0,960240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225fdbdefea2c30e91ed65da1caf1c3b7006b30528%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640136.0,406792.0,952640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227785bbba07f068ee9de6416ee201205dc43ef227%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626248.0,395312.0,894560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a5e24db5e0ebe4736a04fccbb00e41e5d6148c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655080.0,470188.0,908240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b44ba0a4e10ad2845f41cafc1800c868a428a6e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623696.0,381960.0,974280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22464a3595bf460a5fbed8e38ceb9d9ca5e1f541d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653136.0,421144.0,849440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273851f4423ceebf3c9985505944893b33af77f97%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681148.0,384632.0,1075920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca657f88bb131c09eca2299bcd75873e9dec4089%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704632.0,440408.0,919160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d64a75f05ad1dfa8490b6a6e42f12345632a8189%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701784.0,378488.0,963920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ed58dcc614aea64dfe6327fe6a51e9974c8af4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679104.0,387632.0,831160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221fd69b24bcde001646361ab10ad1a4b581e150ac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732424.0,466040.0,802240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a30c874bbe2ff797e5d395a624e5a40c9607c94f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714408.0,480952.0,849600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22012dbe2981f87130279b4292bd69e538399a8edf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744272.0,369344.0,922280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220aaff58ab0838dca472df1cc209d1331047dbce0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742368.0,386104.0,891000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2288771d1734f7f3ab6381f49c94843f359766327e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675328.0,375976.0,812800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249478d57ae0f18e4759341069b5a1616cd10f075%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624344.0,472608.0,938120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22051d45f258fd18cc07086bd09984162ff956cf89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762832.0,363848.0,943240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ffe784a5cb05bc2d520f3d480aff3cc2c7e4f517%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750640.0,365640.0,928040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235c2710832d503b0885b09065a73286da3f56548%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673952.0,457960.0,941840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206aeeaaed5be03fa99bdac72367ff16ad2d4fff7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B549112.0,394784.0,811680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274ba761c2c92f633c086ca3d9216b27bef179b69%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687952.0,440256.0,904160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220348b1f2b52cae939468ddd657e16de1f83de39a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B556488.0,395048.0,811120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b1ae2855d1b77ceee336b7583fc761b6d2544fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689784.0,455128.0,891320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b9ea948a2831bb6883254423db6541f2547fe4d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713280.0,480792.0,846200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8c45ee8211ecabddb811d4d7b7b90a7fac46b2a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697560.0,404832.0,889600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f13df40ce18fddc500e9f884bbe69b5c63bcbbe9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675992.0,480528.0,965440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229861ce733694eb7cbda7dc1e63e30c740c5e4141%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681504.0,436660.0,901760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223bc37dfbacd51507c195d4e9593afc51cf00138f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615568.0,369264.0,979080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ccfbcee912fa0dd4183533252d90a4e38ebb8a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666224.0,447944.0,898680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224dd372b4d7491277d4160350351be0c7eaed2420%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622368.0,483496.0,873680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c7edbd37de8ecae874d4203555fd54b7d9c03bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601456.0,419688.0,938360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a53162fca5472e7cf746c6f0122c82c60874ec91%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631696.0,399592.0,892640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220d1a7efc369619a50ae101aeb2e8326a3cae8189%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721640.0,425048.0,944520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8fe5c495fd0907d9ede77c1b36650d3952caf43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658376.0,421760.0,861200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2283cd462f5065971f772a9c5f9f0f1d36f92d4a18%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679256.0,408536.0,853920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2269950b9101684266cedae17ca022b28e3d9266c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B808424.0,333304.0,999760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220cbe341df8125202230534634ce2dd8d8d690454%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649720.0,415920.0,846120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221dd59bb2f0192d74d9792b98ea1e5ef7b42ec4f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678256.0,445144.0,877320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2214459a5fcab5279489a3a061721d52812fd6fdb5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701576.0,375664.0,971000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220bbe55b16dbcb0b66721c79ca3deb9d6e24f2304%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693312.0,390808.0,986520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aec96040fef2ebe5db43f661326ff905ee6073b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656524.0,412856.0,887880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d5eb534cac90a06eaff8f4a67e2ce0cfbb16a3b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634416.0,398416.0,958320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fbb824d7c5ffb957961d836df44ad0441431723%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731704.0,422536.0,949840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb31cdcd1afb2111c81db4975132977fcac0d03a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636240.0,388080.0,925280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7e43a7eb513c32d4049bdc17c003ff1e1b2c9fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676352.0,445688.0,874600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222162e4053c1c950d2d9592529ad287baf7659b1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690480.0,401152.0,916360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf76ffdaf821e31393312414e5b462423bb2d698%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728712.0,357688.0,1049080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2264c0af113b57aa062ac4527085219e17f0386261%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672784.0,462344.0,944800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22efd5abe86109f46e2a1e9c7b0b7c7c3a50f51836%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630416.0,414624.0,908960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b1804f88aa5ee33458898dff3f948004e74fac9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693048.0,398768.0,919400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267930125a7f9dd55365c03ac649d0fc7af0df779%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631112.0,502560.0,900160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e77b8a09b64e353faf257456666a5288866b2b0d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B757152.0,400960.0,958680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de3bb1c90838c35e2ad34b359d04e6561fc7fbde%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632848.0,466656.0,935000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223292ef86203b0b805081da52666761759f4e0aaf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669120.0,422536.0,929040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f73c5fabfb1f8f1973ffbd0f1129f40b5e93a1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672568.0,440264.0,928440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e39c2f8fac7f37f5bbdc3da276c1d422b8d43847%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708168.0,395736.0,856400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222cb604ebba35eb2c4befecfbb5b48c374a6ef476%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600168.0,398184.0,814840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b27e04c0810b6843be94e8525dc3fef5d8b7615%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650456.0,418144.0,846040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220239b62131907a55635e4cb5150c0204428c85d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707496.0,434800.0,950480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2209dbaf8bd1e6a1a32c36486c3323198eb84eeb14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698760.0,380536.0,899840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e53873928f4554fa5b8541d923989c5bd873c19%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628904.0,479944.0,872840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f6167a11710ed415205198857fd004a6d69bcdc4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B583384.0,387624.0,814480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256ae2789fa35cd9a77d8b756e6334ee391691838%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622960.0,405804.0,820080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d50da4adcd727f3fe1bbd67dedfc3554669a26f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658280.0,464296.0,942680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e904b65fabb2253c82ea18ac574e1777267f7448%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B787544.0,450840.0,879440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f995ba2ada1d088a71b1363596dc6f013da8a5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640088.0,465832.0,934400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223511be893dfe2cba2fc568f23ca6ac00bd2c024b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731976.0,423828.0,949840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ccc9c70ce42a42b7aef9e12e170aec06821e1f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716880.0,466480.0,900240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f97f58ffb7060cba32c143eb16d544398f6e2557%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B781392.0,356160.0,965680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22022d2e97045702a16b2d834f81e6d595fa816005%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669848.0,425928.0,869360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cd01243bc60daa877e257c691e65a7ba896a5ae8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652112.0,414160.0,898200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d7bdd8b2fc2e1230c9901db1ea9487216de9f2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704240.0,365352.0,1034040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298347f38aa736d9bd33f0927f15946a6f417aec3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B768656.0,449728.0,885680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc87f130db6c7ba13e73be5b73ce949726d74e28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686000.0,480280.0,970040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22360fa7e07cebfcfb9b637e082f3c9d4f86c11759%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680380.0,433112.0,913800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22caddc3b39013522996eca37bf53fa259034acc45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660856.0,465192.0,852200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223965c2aa354d83e9d01d9e95b9647a33539ca572%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641800.0,457760.0,847920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b746c5971e647952f4e1d19557f3f6175b9e56c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604604.0,390340.0,788680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22492f5ccd9c09edbed098d3a9a77f1cb173085866%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690600.0,440248.0,895360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2228691d93e939bccc850e8ac9dd313e7ef8b6e520%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715880.0,445232.0,987400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22971ec1919d7022dec40acf1272450096863e6c0d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696536.0,389000.0,936320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d244f9d234d89ee06c5597b8612539371cd217b8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665520.0,445024.0,929760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db20b0c62f6638ebf1d056ff9cdefe33d261f8bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703856.0,395672.0,901200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22873fc3afbd349feab7fadac49a475599e0a774a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649128.0,411608.0,947160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22554829f1d872e240eb5ab0f6f0fa26ae58542bd5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697072.0,358368.0,1053320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7cfd97b28bb6fa6321f3548cb42b7fd2857b350%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713976.0,449112.0,949600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22915d5b0e10e5b6274d9822572233a33b2f987ea0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B818232.0,327760.0,1009800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22139705b4ba4628fe19dc409ce6734c49ae856347%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697464.0,439128.0,887160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0ac97825cf901a3cf1ac46cd3e31be5c0d45856%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675544.0,429792.0,919400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220eb03b1e2b36120e46b9fe154a88a89f4ae8b213%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665920.0,401448.0,993480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223acd0a36865baf9dc21d36b381f94255f194e446%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684404.0,414044.0,902360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eda7a103b59f1c47ebcf9a3d44f2946e4a23bced%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647296.0,480432.0,902040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b1819a185fb2d48b99e35dbf9da3e9aa2af31ec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678908.0,431884.0,916640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d79ebe2166ea85b00e3d1c0f2d1c34b101644745%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718080.0,441176.0,861840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c4e4e0c39810354891fc4f3f0f533a977769039%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687920.0,471368.0,877000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a55137257d6401ec781080540ea611328361b0ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721344.0,483520.0,989760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d10127219065ea8de87146159d35b44e464479c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729680.0,376296.0,913880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bfa192d3161f594a49e3d55d617d0d7133cd92b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713512.0,444464.0,982920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221937d75f654aa1e28fce73063629dc3d86308cf8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603736.0,390648.0,785600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285d3c26689232ad63b1b1330207459684266598b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770108.0,447588.0,883040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3f70c1f8804695dc7744ccd379c6249751248fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620776.0,374180.0,978080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2214c685347d669d9d51f0561054ce7ee13e933d8f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727032.0,488568.0,905160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af42d32104a7c5a5c02262c35c3cb7e226c90286%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B746008.0,415616.0,831680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ae9a158fc2faba75ca99a5fb08f78ee7eefd1f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748528.0,417224.0,822960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2234653e825fa2671d784569744b6fa8571138d877%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634184.0,420968.0,912960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fea15f55e4e11937cfc2da0d60ca7b153599da77%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682144.0,493496.0,868840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f37a7def9a130b7462103ccadd46fbd597deddaf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641136.0,463024.0,933480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202964d0ab6da27331648dc44419e3837e086ad51%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658856.0,423304.0,860640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac14b11434b845828029ca756f7fc85c09b5f4a6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636408.0,403784.0,955080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220330cab1301599ac59facee541ba862d0998ac73%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676024.0,447240.0,882520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258d3c9ba8fa238aa30fc0936ac4d32b54e4397c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664808.0,416456.0,948720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e991edad647011b86c5153963ba4a554f01f77f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674480.0,432088.0,878800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ccec4b3e63a4dca98c5e1d6af0126f46a9912fc5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683368.0,452880.0,924920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22454f26b0b5d9cf99580be5e70e90565984df70bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672160.0,377312.0,803000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228dffe4c78371ceb1eb91d7e1af6106ddf6016cfc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675064.0,431752.0,877280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223198177f6f055e702977e0158ea305f7602e166d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625656.0,409296.0,813280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221991bcce93658454236bcac4499e18a2d3e094c2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635108.0,441988.0,815040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221cdc8316d7f427672870f3d26972ef237fb0f53a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683004.0,427200.0,904160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22265887d2c613c377e62be63a71ab1bf65786039b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B778744.0,452936.0,880240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22549967a01d37e30e6d4ebedbef9a809e71ecab21%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B569664.0,356208.0,984400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249f75eef62ad0454ae3c27e30f2cdea11330059e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657264.0,396240.0,913920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f162d198ef001c8421ed094102e96508b8f03eb9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665240.0,456176.0,899720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8632bad5b43c86e3573ff7bbc6c9edd3a610310%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734680.0,395360.0,945640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22411f4a12d0ac7e53ee8944820bd3b2b5104425d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727104.0,456024.0,848280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a7c36ba40d12a14152aa022f10f7772d4c91461%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728416.0,440200.0,911880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22527c31fbe89b78a3a62d29a82749986e44472e49%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725716.0,368812.0,1029640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e5158e0aa75519ca938b0cd553ba75473684f480%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714600.0,439856.0,975720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff002899ee0b595db94a687863cf6b23b38bcca5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716328.0,448312.0,851560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cee76aa5f16bc08418fdfcc8bf0a3b1c7f851f05%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B735168.0,525072.0,904600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cba557fd5833cde5814bc5a49de6bfd67bfe45f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712120.0,440656.0,970440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aede26ef24be3847ba4dd70470c113c56a8d2afc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719768.0,450752.0,849440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224ee48ce6f433fea191f44be1072d6c52d95e7feb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633488.0,463448.0,929520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f1e8be144d4ef42691897e4d02009b98f27b3a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B590880.0,472800.0,858000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2230971bcc50065fbb03f077a80da2c4c35699afd3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654528.0,448904.0,832880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b50d017ed7ee5244fc0e9b6bc31ede1d49e34945%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618468.0,459776.0,872120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4e203c9242c5183c64291e94ba125d40d8d9622%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689064.0,465464.0,884400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222999452894abcf72fa345c60b2460d7e85421101%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642360.0,463064.0,932720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6dd2ed1947bd37823c3444617c911b1825cd650%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714508.0,440544.0,871840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa19bd88c1d6d983090f44020c1574b6db573ec2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662984.0,418440.0,941760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eeb600f1f98d8cf8dcb1c3b8442de6b341e02f37%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625772.0,409532.0,815160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c2b4edcb1521ad4cafd7a139d0239c95d34fe1a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708728.0,397968.0,850560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b75b292e3f8fe2952457db3dcd1b8e1192cb610%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633004.0,441168.0,812360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231b709e0c5667f3c5f4f597424768c47ec21abc6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703792.0,372560.0,980160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225333d7fd33990e357755a0646a92f01920e96212%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710500.0,368608.0,1002240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e1905b0bc94c0804e0350b3652198a5a598e9de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645808.0,408768.0,832080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220232b306bba7d32f44a39185f65834fec13d0f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B580548.0,385564.0,812760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229227a72cee0e611a1f893baa591104203f0f8414%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763696.0,448576.0,888600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22878d3f9f89670e657e916e66b24912b1e9269877%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688576.0,431184.0,903440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22abcaf34278f1e701e8eef4971341297c46e4787b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665496.0,466728.0,895360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aaf2c73611513c1fe111a86443ce17079a06bec1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681520.0,488800.0,869040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6ec59e4d8a6ffa583e1fa6802e71375c3fdcfef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711888.0,445440.0,941000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22100da2c06bcf0926d97e19b736b848ab911e0d07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656480.0,397224.0,914440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdd7f76cc68d6aa8d14461a348796c8021180b48%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B567984.0,353304.0,983880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201d319fc8ee7446d1512d9ca308b47afc89a0036%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741616.0,398120.0,951600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9160dd8192b3b51d4281d8f36367f78a3d99cb6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707808.0,367976.0,908440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22808c7f30a3db8b5e779cd2815dc2728685c4f979%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B824584.0,324008.0,1015360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e399eb415c42f11ba0dc0a053725200869fbc2d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671448.0,404208.0,857680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22df861d0f5015f45c0928687b3cf32160cbc71334%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B781304.0,452256.0,882160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225500466daec0657b19055b88301dd37887ade179%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672084.0,404196.0,858320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22789f4f94462aa4d3a30372a2436d4c4f85295dad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609504.0,414008.0,926520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22059b3686261ff9813e406ff5d654f9a2bd16c456%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705672.0,443480.0,880440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f5fce7764acf43e971b18c20a01f500261584a44%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628152.0,421104.0,913520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2230219e1d5b4ede2da917b3a81487153106b385a2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609776.0,363256.0,891160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ccf35027a97eb399e81240f42718d247a86bf5c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680128.0,398464.0,970200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eba0e683f137c49dd5111db93c062a86888240a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691408.0,469232.0,954800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225674e6b2e6275dac372259aa46c255239be86a75%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642920.0,444192.0,823120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f591a26d3af790020f854418cf37b2c309444fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651968.0,413304.0,898760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab51f74c6e4fa9e572b5507217c139d0ba96765f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692760.0,409880.0,830080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ddddfd9e0c01c6ca43a3bf5ef902f6b37a2f50c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660736.0,409520.0,852800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226611a1d201f23b888c263e0e9521cb1df12cacd4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689472.0,467640.0,881840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22715754c29795ccd7a0f933009b7372dae88dc367%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640160.0,420720.0,912360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227803d6523630d5a2bd54a2f4da170aaed68241aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608072.0,368264.0,979360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267a53f3b10a3bde7c6013196c75a60df2e67b825%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730864.0,461240.0,837240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c20b260aa7c5ce96080f5e279b02ff85b84bc43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708624.0,436696.0,948240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb8d8f53ea09fee39a0f37c3f15af2bfc5448f66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761472.0,361360.0,936200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b63d398221559643f862a0dcdde316872491b96%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720808.0,382552.0,897960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22970a0575fdd71ec0d415f8fd4992092c63c08532%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673400.0,464600.0,950880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6c1287aa9054945cab9aadb9435865d143b17dd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726584.0,425728.0,948080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221947d4cbf53a1778ffd57a38e645c14ac0baf7db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678688.0,397640.0,967800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228baee8237a68ae025f666f58209225cc1bda5abe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B802304.0,339384.0,991720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a27d6e8fc571441d1f79276773758b8ddae5da40%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685664.0,392032.0,900480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22428f804e7a5cbca9971c8cd4ab8cad6161244334%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656224.0,461240.0,890960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c03952ff19cb48edeab8f3935ef0d3f08063aec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632264.0,477480.0,874520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226f2744f3b1f2b198be80561f5175bfdf524ab83%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600760.0,415328.0,920280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c37b46180db5191c30fe98b057410f69d2af656e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666608.0,415928.0,889360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22144301738b1c3477a4e65299161fe5c65fb70bce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615284.0,366012.0,891480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220bcf38ef73aa0292cb714c99b515a3c953767ac9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666952.0,412492.0,960080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e17f5d7b18af951240f45f722a089a4a12854b3b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655728.0,475036.0,903440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e29b4a893ee4e38cb6d6088586a824e7c616783%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665592.0,410920.0,964120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22317cbf27dd8500d3abf76d0de3969fd97e6a3a8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672608.0,445920.0,932560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b5538af0b3257eacec8a15db926b1453bdc0f76%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728860.0,356580.0,1050320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a573f8e0dd70aa73d90e8920346b75274796bab6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732592.0,376320.0,915840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2209cfe2a12d7365aed55cc435192963c19887e0ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744104.0,422072.0,960760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a041714f8965aec07371b320f7a8788b6844d1b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701128.0,379700.0,900200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c577c0dcfeb3cd8ec7399faac6bdab3ef87c09a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666440.0,421880.0,932520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b24d6f22137cd5bb7714d98b7dc61e7f03012b5e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685912.0,408808.0,903160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff8c7e9972891fa521651e9db90f6e5b6cb2cf50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668208.0,413752.0,942240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e679d3a4a78d832acd7100e66cb3bc5af5739e2f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713600.0,444700.0,992320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22648ca46ce5a94aba87af4fc000a43f54dd3e9277%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722804.0,448148.0,866080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22164c01a0e147d2c51059f8570a0bc294a8789065%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777448.0,438456.0,881840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2213db00f5c8555b21e0cf70c171410a29e3065c9e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683144.0,483240.0,871600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad134a78fb3c747c73f8d92ddc0d39df771d7567%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733456.0,423744.0,951560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220976e44d2c50829691bbb898af804cf346c0ef17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680496.0,445136.0,877600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228dec24928970407c0f35858cda86a37de04d4d30%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631032.0,393944.0,814600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e61c615b452998b78f5fbe149b39a5bb8815522c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723592.0,381480.0,897720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d89831df73f44f62a1c997c63ad7228144d8b846%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627000.0,508080.0,899280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac0e2bacdd77222d9a9e7d432577f163667b3ca7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B596648.0,422864.0,911800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299d17d610f6b6704fa14b859641fc50aabac7329%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619616.0,415200.0,916360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e53653e8f406718c12f2de9085e5c051a8070032%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681744.0,490232.0,870240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d692d28746105460b9f121e922d5b753425a787d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671240.0,411928.0,868360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2ddbe4076c591fb6859b86e8417fa7657d5e36f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667768.0,418160.0,888400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b5eab6ea13261f9b0912e3fedbe06d1840efdf82%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701472.0,376672.0,900880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f36c289ce81012bf06aa76f24fd54119ec73a47%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690056.0,459424.0,912480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4075f8795e5ca5093fd150f20caa89be8c8174a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734688.0,373404.0,918800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c5b0d3fc802915fc0cf27d17ee277ea009adf4b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687992.0,461656.0,943760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22778350b92e0ad58d9ae239c6f6e2546dd1ecc02f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600992.0,400200.0,813920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228125cf2ddb1dea571e2f5cd3339499a6034aad68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665000.0,447176.0,899840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a890a812ec6c75023fd13d8cfb197c141f926043%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675324.0,515480.0,983920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222befb57168d1727b138d84df2124b5800ee43164%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676536.0,374112.0,810160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223419bbccf06369f6040649a6ae7015e0793f98ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683936.0,439456.0,903280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226e46f35799ffb95dff934a81894d91ad861f1e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748928.0,442688.0,901160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223be91194abdc918f284f9484803fbebd78583886%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698112.0,441520.0,887760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a72e423e6e3e37f458e4ad3b8a19bb4a1d3a6880%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728032.0,423960.0,948240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225a247d06cd02bd401f18346012914422c7547fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B594096.0,395640.0,814920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22677728c36dada5141517eac36a41316217f35357%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682748.0,439408.0,906680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf2812b903494ad3e7481e6f6256cb77ac2ca360%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615456.0,371928.0,980480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22099c28cb7cbda5c68fedf7f43582f94a370e875b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663824.0,422552.0,864680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f305d0b752c63aedd62e33c81c55020b790ddf48%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673472.0,445744.0,935120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221f03977187f745116dd86808ae3dd6a9a72762e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643472.0,458336.0,853320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221bea3446975b7e3e4f613b0ce74ae5e13f8b5d78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639944.0,411280.0,906320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf99f81ef85fddcce92528b699d952ef4878cdeb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684204.0,424216.0,902720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d10021bebfe378b485dc66e0f7dad28bca8d9e41%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718616.0,458968.0,965400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22415f8336205dd520ebf295f55f8c9301f4fabf9d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B579960.0,391128.0,814960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d70f014571f2ffa0742734c6a042dd668164fd29%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635000.0,497376.0,899120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c26f677c44f0c441956a3dec1075664000f48e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681688.0,445896.0,878400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22103590b9b53a2fa7d787f8a868299b7db4806f74%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686112.0,408240.0,838800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b6ecbb54ed3f4fcb42ed28b19f4b2d814927568%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B768448.0,361192.0,952760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d566a0e4c4d319a268f94687d9516206c55702e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685472.0,407816.0,842160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222f657c63a34d438b3641fc1d3f1b6df9fe5d2a4d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652128.0,454344.0,895560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c4ce9aa004bd542f610b7c296e73f1d1beff49d2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705144.0,393520.0,905600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a424539d2e6f565e3f522cc93acc8ee16c0202f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670808.0,446304.0,866680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2f268df0ff53a0592e912f5f7b4e50f344bf21d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721344.0,446584.0,868120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22605b0daefb8039e4a61c1589d07a826219955991%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716208.0,454544.0,962120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220de11dedf8b5d20a4fdf1b7100962955f76d8f28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659376.0,448976.0,838160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de99d35076f639c4533431be5169234d06520a7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707752.0,440624.0,932440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c8960e4d4438075d27adc31f7f49ab134ca9da8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B826280.0,337280.0,935120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225fbf01521bfdd4336c6595613b2f470d3a96eb3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625488.0,411264.0,807600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222bf85208a14762295c34828f94a55e3d452686fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709528.0,431312.0,938560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0d3593d1e78ac8f3627519925a25c1442939817%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661336.0,416080.0,889920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce09c96071ae5b74cb3dea63ac256a6cd4262f9b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666080.0,458208.0,941000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205a5eb426bb8e3af75d0f18b9387f5b0f41a23d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721432.0,365112.0,1014000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a041b5e09d78602c5164b877fa2f37093fe59d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B755184.0,360344.0,924880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c58322d57c8936855227d7d99b60383c0983bff0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626416.0,392288.0,894520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ca29afc77f5a908d76c2ffe2c5c83b792f800ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672632.0,448520.0,938040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e102333fdb9eb1ac7bdb4b4f5ba1ad9cb47f695%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648000.0,467640.0,948160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22345859248cfd48bd1c1c523ad6ce3fd5c5865a93%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711512.0,428368.0,876840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db500f88d870b440b8b3f60274dd6139b1eb948e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651072.0,416280.0,846520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b54516a85e328ddf7dd1c8f01632d9b16d0b68bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669992.0,411216.0,867040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ffc441f3d48698a2cd57d6839be6b0c2e3a8cc9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B591056.0,474832.0,855200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b1b03c1b7324e1c2c30f7c9fee5ba86ecb2a578%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656832.0,459948.0,892200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e4c28ea6712f88b255fde8a5f5c283925a2e9e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726120.0,450664.0,856600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e91ac0d9dbb448460d9cc1412b21422b874ac0c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671072.0,488912.0,884440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c22795ce31df565f027bdd1585f6f9cf66d34f2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671504.0,439448.0,927640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260e1b49e20466b3ef89f72de02bd2519895083c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733288.0,347648.0,1065600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad9e120582b23911f5c3104ace56439f173836ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739000.0,412952.0,848400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2244d4d4bbf4d23bc509da76115df055e1378d90b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694376.0,384552.0,899400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220eb8496fa2ead169ef37e0f93a7bb45fda10e07b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691504.0,439256.0,894400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22261aa649d01a8507e66b34c402b46e7397dd76c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754760.0,364880.0,933040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22252c9e4136594f2844691d977a4f7a3591e1663e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685808.0,452704.0,910760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad541e45a8a709ccc39be71a03e80aa308f416e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659760.0,423248.0,859880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c0096d261a84643cef5cf9f2ca59888c0ac06d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666424.0,417920.0,889080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cbdefaaa1725a68fe4db8a4c309e5883267fb853%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707616.0,440072.0,921920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260a6315f7c00644bc78df020166d9ee27ac303f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697480.0,384264.0,943760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223a195dccc1bb716dda2fe85b145504f62ecd6c19%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719264.0,440112.0,916000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7342f0f164a1d181fd4154c49d3e3359916c8fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761080.0,359720.0,936000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a219e164c94a551dbb4171dda26b5f54f64aa6fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B808240.0,335048.0,999000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a43e85ed0aa91a6941fdb83502b95df81c04c23%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B590568.0,423120.0,947000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225db57a4c68d744c2dbaad6a6a2bcc6c266f52243%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709384.0,394952.0,930240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22404d06df0ca849746df3a287fc473e6b70e33e0b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675056.0,447472.0,879960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227bb412d99fa18174c83498b2c730d1e936e8f91d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681408.0,437064.0,904160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a5e547b7c3ed651ea3e206285f12bf462769135%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607128.0,389864.0,791280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3db61566e5d48b66895ac403f2df14ab723d3e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B779576.0,452400.0,881280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271f86eea213f512beb592b6ad813efb341bab408%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675096.0,448880.0,880480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c6bcbe2db3c859275460c0ffda5397e9edbe311b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726880.0,439888.0,889600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220174ecc43348095fe16463d451f4832fcd7f34bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B602464.0,527992.0,897560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e43f8d14f3ab544c8ca980c94d041a888656c597%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653968.0,410352.0,890120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b0f60b5edb39d4d6b89b1683e405af8facba0dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708600.0,433648.0,950800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207cb4da1649ff1c48615e028b8fff6709421996d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654216.0,451560.0,860800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2294f872ab8633052a2d27f443215956c7a85be27d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690408.0,409752.0,833040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa9b71576da7dce35248163ce17b779cee5985d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719272.0,473112.0,980880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b5ae1db62e1d8e643972d60a8468e2035bc2c959%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688680.0,446512.0,896960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c745e98b1492adaf05efa77789c0aaa77086e46%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653416.0,410040.0,890080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e5afe07f40da1720a89147ea66a0db4c492ffdad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659320.0,458040.0,896040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f8eea7ab9bd44bb8dcf950ee98e61d76adbac7f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B805048.0,456736.0,879680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2276c22c4b338e0e4274315cbbfbabe1ae6ad9a6c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644252.0,407596.0,828680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202aa0c6c9024ed9cb0ed9bada9898b05028bb726%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682648.0,451472.0,921160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2214078fd2624a39a31347da82a4be01c945f59169%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B798296.0,344128.0,986320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207bab170e68f3c83ca24395e5ce769ff0e7c5c20%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628856.0,504824.0,899680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c477eabb00d85e28873497c62561ad0b1bcacbd7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700592.0,435328.0,884880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271f709e1a7d8e1f56569b03312520fd4bee590d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B599680.0,468392.0,863480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22703364682ff1e3c180d3d4ad6193179aee0181ac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638616.0,493016.0,898120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f9f8878e7a6d562c839f6dae6186e6efb63a72b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718304.0,484784.0,993760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea82d5f76f92edb29a9b58336ba2264adfbc8735%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651496.0,394448.0,915320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2284d0e21451375623d7e1b38ca081ff47e8e564b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711528.0,353080.0,911240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2a2276bb10d66f4785b9f5af79ee3e7356cc993%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717960.0,440712.0,865960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282ca6e09f13cccb09ee8890f6c325244d349a0e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630648.0,399616.0,893800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229057ebbeac931fae68173265969f99b6a0c0e682%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729920.0,497752.0,904640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203fc4428f5283f6e308b48cfdb89a4b11c905c58%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618304.0,415192.0,919360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d669755a673bafe5d232cb0b4498576248cd15d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646840.0,409656.0,951600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f7e11ee5320e86664661e819e25e26344f73ae1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B784328.0,355016.0,939840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fb181d4163bc125970a498f0e2941604d4ce08a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672856.0,437020.0,886120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220039cb79f423f0cdcc9c2be1be63d9f750e61d70%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694632.0,437168.0,915720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22334de7ab28ba9f6aef512192dfe6ce601dee91b8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674240.0,487016.0,971320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ee6d4cbd2604f00f361c240158ad8ea11c0db74%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678328.0,409768.0,854240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f6ec8e456b0039e96bdcfb798937c93a7e6ce99d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673368.0,497760.0,975200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aff23a8ca0ae413b68c29bc04a37eb2613f97493%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715272.0,465248.0,861840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223a842e6ea29c880ce8322d5fbb94ac5c598db0ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700816.0,446904.0,897960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2283e1dd5d4775390a900f5ab2dce1c3616c467380%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682952.0,406920.0,902200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e59a84e582012e87d8dec1b3dcaed06b67a245e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732696.0,394344.0,943320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2291370b68ba77497111155f61039c273eeaa9d91c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615636.0,473776.0,941280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217dfac1ac646fb553d8989e6798534f584985662%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666484.0,419832.0,936000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227272ac7eb0baa6b8e4bb9bea2c1c6a27ee2aca18%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749376.0,445680.0,899200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c443dde400b023a6baad9437e7fb9ecee2eca761%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726968.0,492192.0,905960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285f1df58c70502a615292f3319ffe5457b0b3f35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623936.0,470712.0,936120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233aabab2b5d2964871e616d3c3f1410a5dcb14c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627752.0,460432.0,877640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e7a84a496bb1116d9c73fe3da545b8ca60bddbd0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636760.0,445032.0,820440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2219bcdff7065b8636c065e9d41e9c59f84baf2f07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636544.0,420872.0,911240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b370540a7b844eff549807651c2b6ff23d877e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653288.0,420672.0,851520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b587dd0f23712d97de6794845e48c628989c016a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632280.0,476240.0,875040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223a75c64b400e59511ae8b850ff308112016669f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686608.0,400968.0,1037600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2263b9e33589cc581e6e28c586fe022e87fe9488b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628320.0,410064.0,817880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2218b8e3b0088ffc7375587583e2d260dbf2f404b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683112.0,435976.0,910600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22559883e336095c3e59a7d64acfdac48ac3ec4ca2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712232.0,459336.0,868400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22293d3064f68193aeabd30930ceec981d9f460b03%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666800.0,409216.0,965960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211dda9ee8d2ab71819e43f57b30221cb8de73af9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673136.0,428720.0,921320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d23b90db641d4e00b68cbd43041f9f5e5eb5ba1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732752.0,414832.0,856360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227632dd1a6ef0336399cc64db5542a55067c4fc21%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709640.0,455152.0,871520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e90393b831aaf1ae16d8f5d6b33d96057e8c7426%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689048.0,439696.0,903880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223fff44eab03ad82dd1e8fd764c2ac5995c3f2bd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709264.0,399440.0,851640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226181cf6290d2399b478dc8eea54092926bb8cf2f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725848.0,418240.0,860680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2567e066201a6f72e80282735501d8a31e6407d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721600.0,453560.0,840400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296bf0071dcc12d0db135a961da6267c50af60312%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B769728.0,356488.0,939000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fb8c2374ea338716ac014007807c2342af8dc5b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672284.0,452448.0,938000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217e4b35c12fbce36f9e3804ee5a9c32446f02cb3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719480.0,471520.0,974640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ce045ac3520404f54623ddef9b79f927e2f0bd4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724176.0,452976.0,836240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207c4bfa1d16382bdd5c548e4f1eaf45eff82de5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689940.0,432728.0,907280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22197315b981141d48d14669e653af9acf45604695%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681456.0,438452.0,900880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2236d646d85a4a1c56b6e2b9d5fc6fdf1081eb5a0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595228.0,397420.0,815280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f6823264b8281772ea1cf039e0e3d13f2f65fb78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607712.0,464836.0,869080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2212c2bf011480209d1b104f7a81fcfdd072d7ddfd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672024.0,437800.0,884240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224ab270576acdcd32f276a7bd8478038883d35c87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678888.0,496280.0,868640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca9e22a6a095327754400b2c1a1ad2d5f9c26ac0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683504.0,394656.0,899920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22834627d0f4e43796a94698bcebd18d8080a6a6ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619768.0,373112.0,893400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22257e725fef17d9d8023592ed6a2b9772ac77dad6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664168.0,377080.0,1096600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bee3f52d8ca7b0cef5a6b7e07737935ee744393d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678912.0,387448.0,1063320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e9beb2ccda46f40af0d23489745db0570c72003%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662776.0,449376.0,864000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1cd605271f9f56dcac7153d9a8b54912f38dcff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677912.0,384208.0,825480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fc5700d3782d074a1ba003e83078e2c860422db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688920.0,467088.0,882760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2e6e41ba8587134a23ca948a96fdf1147b8a671%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673536.0,398912.0,1015400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232ea8b86bc191aa4ce52676bbd28f2f3cd73f5f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770760.0,356056.0,938960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ced7c590971688ee90029eaffb939097098fc9ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729428.0,379892.0,895160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6ed9e0d30b252aaff931b1f1661e5689f633f16%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712776.0,366168.0,1004880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c012320dc50d6f07f57c47e012b8552f4641c0dd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671900.0,495900.0,971840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c6c2736b689c794d0b6515a156d99ae08c03982%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B573372.0,391440.0,814600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229eaadfd0429a2e284fcd4f88b309881ca44c4247%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653840.0,451488.0,932160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f7de683b54978083e68c73fc50e443659ee570d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649752.0,467528.0,879480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224cf609143fa7823bba0b7fedf076a7dfd03c61a1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690160.0,474184.0,960840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ee0ecb855ab15b196a696e4048d30c1815cfbc2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715944.0,452160.0,956520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220833391fa88aea483a7e874f1afce04ff8542b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730256.0,439536.0,909880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b8c74df87ee13b3c4b5089add3d5d7b938fb865%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695640.0,410168.0,824480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22318ce9fdcff8e4eaa551aca32455c1ad0fa07d43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756872.0,397480.0,957440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221656b482155ff721246c29bd07cde59fc0b98ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604304.0,416800.0,914720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e44e924a2d5178e7a4f4eb2140910fc052921d27%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661880.0,462792.0,913440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7965afb8aaa13696d6ff362f2fc9d0ddfa80b0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667384.0,452832.0,904000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ce15532cd2a3bfd40133a1449eea3d1f0831b3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626656.0,408496.0,817120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226fdbdb1aabdf1dcc89768a4b6862bbef049aeabd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726480.0,457392.0,813560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cbc756576ea815f46a02680e459cdaa4bc63ba13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655268.0,477172.0,902360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bbb5b865ae3e5086fc0c24fc31e6585934d07d9e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713960.0,440744.0,916360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a9d3bd1b53a354643d8f05783a6ed2249619aa15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763808.0,364392.0,947320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d53976fc6d15fe919b64982d0978ca79a54a7581%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740032.0,469320.0,814880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257e99158fd41f04ca4927487ad29d743d3dfb73e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670128.0,451704.0,909440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273fa3a226f61278c9d9f3ea9b4f5a482111f9bff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666344.0,414768.0,957360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225da6ac0180ffdbc3e0a2f3da220fec4cf535cbc7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730112.0,502008.0,906800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db6abc7f385411926f1c40222d605fe0af3c96df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664800.0,444136.0,844720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a15199a3d7c4af007e99bdc8fbea633caf41dcc8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618956.0,423536.0,781520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aaa61ba6e7bc85c192435dda0be077fa783b7b33%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700360.0,376592.0,968920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e319e36ea9c13d619a4091c879345eb60182773c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655424.0,412824.0,945520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b47cb5d70cd3991120b75c8b0c16bcf6bd13939%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713136.0,463296.0,898800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231bd587adbd4aed11c354ba2d490d1ef8553419f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665940.0,447960.0,894760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c89a0a6e8e8c33d1ef6aaaf3f0e41538fdc362ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661832.0,400632.0,913040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22911dfa837a4c31e9f8e76966e6c5b8a94219361a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705004.0,392620.0,903680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f475a98da91bf2cd475e90033fbb50537e38113c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672168.0,442584.0,889520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1ff4924ff002806391afc6a6797eae285757253%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713808.0,473768.0,854360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227226cc0db2ab4a34597d74b790aeb7cc5b92224d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709920.0,452352.0,873640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ba8e3b1b39dfb649894a38d8c65e147576da532%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754480.0,417760.0,966440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2208cb524faf783475799d82d5ef0391d6b360926f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B582152.0,389344.0,813440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d4407a75a656f5a597df36822a30e29dcacc6efc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615880.0,420192.0,785640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228486d6d2c03c2c3ee19b0dc104b218b007ea398b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662496.0,401840.0,913880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a75a95245c4b3ab592f01be5b827a09d79d9e64b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694612.0,393556.0,926520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256aff55cba4f0ea34a4362b14d4784874aef169b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713368.0,444856.0,990000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22be5c9db5d0a265eeb62fbf09da136a24277d3b82%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711744.0,357188.0,912360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b3a87c11706cb5f864a79560e2479368e4b65cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756848.0,400616.0,957600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277162e48015173f311c5cf0fd65ce36173718426%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617040.0,371120.0,894200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bfae0c1b2e97628b3f5ab4986123414ae6164454%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714584.0,439816.0,963800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c6669ed59b0d9cebdad3f3d024cd34ae1d0a9fd9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712120.0,458328.0,898880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226bf9f9abc35c3ec4339f88b8f410bdb3430deb60%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717320.0,459792.0,965160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea5846dc7e84b565887ba7f84f989bf6f7c5f007%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B598576.0,420616.0,910320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d315a92bef3d81ea8777971c5ca71fb1d33a7e7f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673856.0,419600.0,888880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8454be552d6be198de1ea5adfe7783a233bef27%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624344.0,420040.0,912280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2250c86ad32ee35b9492f43112dd02f5cb8b25f5eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708688.0,430512.0,880160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22077e91dd8b17dd7e75c050392576416f852d94b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676008.0,432632.0,875040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f9daf8908def23f5dfb1b7594b39de48f1e15658%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670640.0,402440.0,954960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22727a0351c2900718ffa9f0537f29d2ba4741266a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715176.0,385360.0,907680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce2242f8c19df7cd8e33f737f956c93a50e17f3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671656.0,441376.0,892280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ede0c952e90a32cc9d375aef6d87e13f79bd114d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719072.0,475512.0,983240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a283184b05c2022d3cf8f370a00f72049fe14f32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622992.0,391640.0,806240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae3d3ccc25fbcfb889ca9abdd0d530a4c78df535%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713160.0,452560.0,954400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ef5012bd1b98b23fa5b70866f5dbd38594b825b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709008.0,443176.0,938960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229757626d7aa7497a38a82c86fd7f243d4e4f7b07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692712.0,440192.0,890560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272f9a819b8336a219c064768fe94d5d70f03a15b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731520.0,441568.0,911280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224bdc82f449edb20e288d52fd3b53dbf68d4e6163%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756756.0,447208.0,895200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2228000ac269edacf9bc5a0f1dfd530117121b3d4b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606792.0,414504.0,930080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c77d14acc384b8d856d21791008c9de4c8cf1e32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B579128.0,382488.0,810760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ea3dd98a1b3456f7b4b87c9b47119b97d192193%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651976.0,452488.0,931800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225107140e4bc66b4e8cfadafc5a8d03ff789be40d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667488.0,454696.0,913360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f9188c5fcc9e44fc46bd94de74944afca171db7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713784.0,435264.0,960520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c4d0329866c25519a44ee4de506642af5541e4e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660088.0,458744.0,895240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224af4a70c942dd9633170de1ecfc99416da6a0dea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B774424.0,451664.0,882840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2270bd474f8f81a4de7e8c84923119ba151234aa3f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703792.0,374072.0,982560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb7649d8b69a1480a49594ba68eb84a431aa7236%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680936.0,436288.0,903560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f41f64f07213abb04498b6330f48f447389a8eb3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756144.0,422072.0,970080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2209de807f5efcb17bc7100803086d1d734c23b92b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712528.0,437352.0,960600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22974f819831b4bbc64e863965d38f3851e735970a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623048.0,408624.0,819200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2fcebc344e73297a6b3b3b1337f39e57a7aab05%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690016.0,460032.0,886840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b84118ee2346b94bc586e4f8437e9ed2934d6fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710808.0,435096.0,955320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe87eefe0e953969ec19ba323587043624dd6995%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B772264.0,447672.0,882320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a16a0a4ab5c3dc3f60759f2b4dfb1e426e060712%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664456.0,447872.0,843000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223538d36d8944d256362c2a7d3b280ad90afe91d3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728560.0,489024.0,903640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eaae470a5beb2831221467ce7f68690c91401e2e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712224.0,456308.0,871560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b66ec8ae45e9e1b73bbdc967d20a59859ee1a2de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708680.0,451800.0,884440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e62c82ba8282dccca42b881a55bc484af874116%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723456.0,482472.0,902640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227146448c2b426795ad08eba893eb9ea3fb5a53da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754880.0,364112.0,934000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a58960202d9a4234d7c65854758cc7bfb30874bd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663888.0,410272.0,860320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c50714a6018339bfd1e8e0554cb241c6e02c67f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694128.0,403984.0,896600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299aaea234631c558dffad19f842f23319805adbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606960.0,522800.0,898960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d84b1a030efb6fe2cfb9853a6e86539a38f60ef4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648120.0,410400.0,835440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257432e6d9a2cda16e291bd313036199d71b4ecab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738320.0,468760.0,820600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f111ca55e60c45b635272d30246bd36e86ee9c66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661112.0,411064.0,851680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c98cba64efbe5c725a4a30c630b11f693bccae04%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B576504.0,356624.0,985120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6903b9f3a7b0508aea3ff5c50c25a12e3564609%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653596.0,464116.0,883720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2294fdeee820a13a2b3fc03fe3055de488967db209%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634680.0,444056.0,815200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22224577bcef16e9d245af326b41f5e01d15d7e0c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765096.0,364416.0,947680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0d279922dc090d9ca41361452946dd679d1f57f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666784.0,425768.0,866320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b1f8f3240b4b89b5a9a599729ec08476ec365604%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601168.0,419784.0,909720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c344a8d0ef625541c201bed0918c56f95681c96c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661688.0,447672.0,838760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d190a4bbb4cff391a4fb678caee571c09fba8213%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664528.0,418016.0,941080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2230d5a601a5fd47bb10c89bc0f4993a067d213c43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722264.0,432216.0,956240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2270c5c2692a62db44e36d0819aeb80864b113f0a1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731544.0,440352.0,910120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6dae874103e5fde6d7c8fadaf54092720f88045%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672664.0,442368.0,889600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7b10c3c4b842ad2f8f0e55ae14fa76d953f7e2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665216.0,399624.0,911840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad3d43e94e4e9e99be68461de5786bc1a88dc6ec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615432.0,518048.0,896960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222043103ae2d78f67f164283a8fd48fb19f5bba85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681992.0,457368.0,937760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c576f072d2e155b4f7f94c1f6512f7fc47692b27%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723416.0,381448.0,899000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22829f21d66e8f1cae3b9c26b8412f7934bc84546c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713080.0,430552.0,951280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b8d55d42eb2c7ac60bfaa8e1ea4fac5fd4a1c25%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676952.0,417584.0,889560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22385bfc1357f8902a1175e4accde9df037e2b8942%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708976.0,435992.0,953360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f905b2c1a3c2667d22ce0e34ad76223d74fddcc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662520.0,416664.0,890360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ad62b1d4205085f9152c810a4cb3128e7362693%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665480.0,410824.0,862560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e26c71c6c451337fbc053292b83276d80fa6c54%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685360.0,481664.0,872480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa1ada504849c4d63481b9a37f7d74868b609895%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717720.0,383808.0,906920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228393e7be75dd2e8966004c36608de7e17edd14ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640360.0,420392.0,914040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224094b13401b5116dc8f44d8bd1c8a1853dd803bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653432.0,411368.0,842200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f31950a230cebf2f04abe8702a1eebaee0c15576%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663488.0,455840.0,900480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22710fd062a75ce5ad36b34d97e0aafd3ec4d9d856%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628984.0,407360.0,822840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e4e7289c9b5db97999aef4af99affcf14493050%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745492.0,443900.0,901560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22174072664f71b7633bd34bab69cd6576bb1c0a74%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709056.0,435180.0,948840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221bca948dd2273cc48115f8967adc3fe0582e737a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716392.0,441152.0,977560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c0a2c2fa11107362024d2be8c3e1ba0e25321d3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B819536.0,327288.0,1010480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22afcedeb13754a43cf9ef8ebb8d805663f781a3d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659904.0,461272.0,890480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8f91210695a413c4743cee33d13425b164222bd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666048.0,400312.0,997600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220298f1609c366ba62b4734e5abb24a6ba9469aa6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B546992.0,347144.0,990000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221575a30f4761e06d779bee45ca6a062acfd50268%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680056.0,384792.0,1068320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d09a179e9a6e5af26c55fc4609a32dd2937473c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719368.0,451104.0,850040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202ddeeda422fb1d02daab94cdc1db8c58b6dfac1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725488.0,456560.0,818600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d90f1c5ca1263c4ce4735d7e57a93e8031c7a196%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666424.0,403728.0,990040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da2ba20da865ff6ec0c3df90f932c132b4a5e442%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657296.0,448856.0,835720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff46b78cb0bb9d2621029666200a2794565b51cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717080.0,460632.0,968680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c85d7076c7f6b54ac6f67fcf1d02771ea3d783a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740440.0,470648.0,816040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22710c858027577961605411ce72a34c04b491e523%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708880.0,393660.0,870320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2230f2d5dd92cc4c05cdc706fa38bcf41b87a03566%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724272.0,441632.0,910320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc19353fee2f0c960f9ca64252c5e2c9f8a5ab68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687456.0,479704.0,970640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2250d339bfb8e6406bf252c5f33ad45c8005138b04%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632236.0,393028.0,815120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22228f37ef05015ba8a62e304a69e012cb12c74a5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731448.0,354440.0,1056000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d4be83a00e524090cd6b41f852aef671d8042ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B578384.0,378064.0,810200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f325450c00f7b2b7718108598b30d74a7b89bf1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730928.0,422640.0,948760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e0640834ca861b4e410a35d77675a5dd8603e3e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686388.0,393320.0,979480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e50a6981dbdf41ccae9cb38ab4ade21facfbfef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618664.0,415504.0,920640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dd53daa2a18b1a9db179ff911e17d80e114031b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688880.0,475992.0,964760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc96bd8f61d381370b9a70379830123db3b0f1d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654960.0,412256.0,945600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7fdafe208d5c20fb60027a5012d1a1bcfd68e8c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707496.0,366416.0,1032040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f67fbac707d60c06bae98d01a0d353e9d800e56c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638496.0,408552.0,826400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e3892dfe3c05f2f89c5b578825f7466df7c4ffa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689240.0,434056.0,908600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22edd243c5a8f267248549b08dd5969565fff0cc73%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754264.0,363920.0,936720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227eda8c985a023bbd6af6dbe371556695da1ee821%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646904.0,410024.0,950320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2246e6a6b5f6b2db65ffb89658ac3367792cf1cef3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611560.0,417888.0,910600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266bc923cdb35094f3b656c3b80b2d3cb5a03110a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643704.0,471128.0,948040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255ce085b34c64d80a1c90ce4cb0ef3e2abb01f4e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686888.0,403192.0,1035040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad3c751b3bc699b0d28e9a210976440b71eccd52%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635648.0,472872.0,874320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258f04c6b3342ff89647e578cc32b085cf0866daa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709132.0,451280.0,877200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22373285028373c7251a7da26a8ecd2d4f3a41e22f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664128.0,378680.0,1098160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228444dc7bf2539eda193e48685b5905cc900b65b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671624.0,373096.0,798400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fefd5ec8808ea60267b9552fc217e9f1e23b912e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654328.0,397304.0,912840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222428dc27bfcbaaa221c490cc3217e52e6bd58031%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672616.0,404608.0,858160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2289fd0f35f61b592694bf5248cb555f65626cb99b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685592.0,444096.0,882920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d4e484bcfc9331c96918b3a74f12d078b1d95d11%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700376.0,378328.0,963760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2208cc74aaad5ab887c28bc6f56fceab6a605f5187%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662172.0,456480.0,898320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205d748103ffa05b5cc8a4297c79b9dcc238bf547%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673304.0,467168.0,953440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2246aa3bcc6fbae60c471e6c54a74cc4be64e59e71%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690240.0,466192.0,882520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247319e9ed8ed931a9302e6ca4be291dccee3d62b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668424.0,443576.0,927640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b42544e8082bd87cc2e40b82cde99807493d946f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659240.0,447288.0,839080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22685e2eaa5eeb18b47c7f251fc45fcec5b7f51a77%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B561208.0,353224.0,987160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e55ded5ee7c52644c2329b3f6aa570b7a7b48b8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653616.0,419048.0,850920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5fcffd14538c07e380bbfcd407ac5adcb182e83%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652384.0,452600.0,915000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211e1cc0764d8eaa1386cdbdb8d534a03fd3a6138%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671000.0,481160.0,889600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2275b2f1eda8b730fde1f151b4915668292cd0e59b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723048.0,368624.0,1023240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f84cb59843d598e0447eb81878b1b60a1639a89c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731080.0,459712.0,838880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a84cc44f39227009455c0cc7a9f0a44d001c265d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729160.0,460320.0,808960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227cd0b9fca57c49ef70e5d767f11d11017ad50f94%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647520.0,468040.0,949400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227675348a67220060fa855a7ad6718af0512c348%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698336.0,403424.0,889160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22591579bbf342d8a61e69150d6f447431ff22dedc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663464.0,465080.0,856280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c762624d495ed825760e2762bdb8179d12abaf63%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731552.0,461848.0,836040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22617d07c0897f319e06293a5a18ae6ae5452e20ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635480.0,445672.0,819640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227904cf08ae30d4b5b38e20cad182a1bcdf6b631d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711280.0,435568.0,958800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ae25fcd91c730dd05aa9ece2d3fa57acdc0c77d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717384.0,425264.0,941880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba488b60d97302cb5b01b5593eb8a3f9bb0a5a0a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623240.0,421280.0,913160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220fedeed9475dca959d43f0e94b3f550b696784b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648200.0,421536.0,915880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227796e525ec1a9c299bd7cdd66295368bb1a0a071%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708496.0,444136.0,879640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22539996fc34bd04af8e8bacd24336862982df534c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628552.0,481832.0,872840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b0942677bfe4702e0c73a68cc930932721b8789%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720752.0,421952.0,869720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b19d05313a06d28cc94d708ba4aa2f05b003daaa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729072.0,392640.0,939720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e8e723f1f8d6d87d5210140634cde78ed88575e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777688.0,442432.0,882960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c966525b3356abd4b2a1f195c62607679a333e12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656024.0,448448.0,835480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff371b96f02f62676d41bacf6a81034b5d0ff623%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634168.0,395864.0,815400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2218d3bd6c5dee7eb04426c61c83920696f8569bef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731200.0,457824.0,839200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd845f62c245bbe2e5cf73eb6f40f3b0c275ac22%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644352.0,405896.0,890160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e4c8660b179a81ce49932261f3c18650b550506%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B578584.0,377624.0,811840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22710a53e1c822c42cb9876681e8b5608e27626b57%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705808.0,440896.0,919160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285499db06a6ec7a903a0546201c0f56e8bdf0566%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B795504.0,347264.0,981320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227015bc143f15a0b71828605e682c2ceb04f0720%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673240.0,453120.0,941000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ef2bc92e40b685b54d5de169d27d4020fba9251e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747936.0,438984.0,886280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22955b43b0c941410fce52faffc34386ad6795915f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730040.0,493696.0,906040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2288302493bb331e7d42280c60c9144fb25b58a0cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642464.0,454032.0,916080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2236eab8a82ee03be9ad14df503d8a228ef4151343%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639888.0,461840.0,887960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dd193f83c120f467396d360bacaa983dcc0d1f02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668388.0,398812.0,1003480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a25b83a04275c43e6ca6b90f644471e1e5d96eca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689304.0,403832.0,909680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb606e6eb32f75387799a7d1254823785796072e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681040.0,391160.0,1057240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2229bfa708bb850a77592b13174a8a4de723560521%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704968.0,398584.0,881920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa7c9e69d0c32374f60db5c1eee9f66bc8a6f399%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654712.0,412976.0,847000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220d927d5cb3cd3d92f99452fda7c318aac60e3707%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615128.0,427888.0,775960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202dd9a7c340dd1d3c8681274528ef284db2d3bf8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731024.0,414640.0,854880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226113bbbb1bd23eb7b6c60342eff1c2c99a3478f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736036.0,442216.0,908960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226aeec02bd8809e0e7e32dccf85c8e824e48c6fe2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661172.0,460888.0,911640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2252c72d0bb221caeba41f06d0361b5673e43fcfd1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658852.0,415400.0,940440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e2072da499aea870d347133abe7cc218098b0b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709344.0,368904.0,998840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233bf45a3fdc4e3457b4b107353864777edef050a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668236.0,523176.0,865000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2280a3300b292796e31f49ac02a4ed738d5a3bf57b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643752.0,460624.0,848840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226aa08d43765fb6556c05ae5b817b1bdcfb8d7a64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697512.0,442176.0,887680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f0eb931a8d394c2ddc76d0249ea42257b88a799b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B776584.0,451048.0,881080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277c97f84bb8436488a60420ed397d9f4068e0679%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702408.0,366360.0,1038760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eddaa5d288d3608e217140dca73f2a36fbc59971%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675088.0,510688.0,980280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b8c2a1fb56839d8a2f2164acee6778ccfab10c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697928.0,439472.0,887840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22465ba21a074c9c3702d7cbd6a8a0f8f9548adcae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B784200.0,355152.0,972600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c6fc84e08e4c3ab8e925afbf839f575c99a9dfc7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639528.0,464048.0,934040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223aaa8b99c753413c59db2ba7d1d70204373fcc05%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609128.0,403592.0,813920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220795b0cad9e8299fba324fc44db81dca9782616e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624752.0,415384.0,913840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22643bfb80482b8ef5a7de9f4c3af9495a79761832%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B550744.0,349352.0,989560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b319b11cbf65a98dce87dcd77439596b866d1c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666880.0,423756.0,933760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f9c4b09d70ef24ce41f8f9a942de76a9dc354159%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680976.0,394192.0,1051360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266688b06fa77c427b5d5ae06933ef3246af8ea00%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649624.0,454160.0,918320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ffe0d9378d63b006c93133a2b9759bb23651da3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657232.0,411768.0,845000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc13e9538ffdf70ca252a462cc91a456fef1cd07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671112.0,452568.0,912080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22159de4c09027a02349b3862901de75bc4f1ed6ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706560.0,446200.0,877960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226448d1b05a7dce523dba047d11338ea86919d7d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615880.0,371616.0,978680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225db44baabb089f6fb25e565c4451deb2c5437c33%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687768.0,477552.0,967000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2263bc1a1105b997d711e4c8a0d3553206ad13c019%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679424.0,390744.0,837080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc0d1b93ef36cd81718ab14735a3f8b660d7024b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649440.0,449800.0,828480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb83f4e0c0d65c6be71e5ad87daddf2324e479d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628048.0,409376.0,822000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2259e45df6bba9facce64278ca5edef733efd1ebc3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632280.0,441384.0,813320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf1f1c9001a94b83e09c6945d26252dd6c656397%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612616.0,518136.0,899040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bcc51482218f0c3f58ff368410aa42b7e90fb358%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730560.0,441920.0,891760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258016982885edbd6ff455b6ede5daf9e25ffd748%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713104.0,473352.0,853840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207681409a86f662a922096f65b6fa86137b7e077%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725040.0,368304.0,1032160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a6cd961bedeaa8231cf0f8f08e74f17f866bd99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715848.0,393316.0,932360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222987f5a11629c525b17aa78072c8f30ab2cca234%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616384.0,474016.0,941640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225b18749fe04f6e2c0100c1eeb975ea1f4c58aa0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683992.0,397904.0,899840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228496133689dcb9c9d41f04ca402cdb6a18210460%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729480.0,416232.0,858440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae6d4fefad38e67deec0bfd217d460b3c9c31454%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634456.0,394344.0,814200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22328d4cc3ccf818753cd3ef1f817e094408ae8fd8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643872.0,420912.0,912240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aceb2360a9ede80f4bab40be502071ae2b15054e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738544.0,396928.0,947200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2250fb6b1ea8d7520a8afa603f9ba7822339e5578a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673736.0,402448.0,854240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9d72f2d5a41e432307217715aea5251b279a24d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666800.0,455880.0,914280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221da8aa142e2392284a1e3dd1c318d3a7c58b8a1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682568.0,393256.0,1054600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210eec587da1e0f20782f2bd2f41160d4e7e836d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741688.0,412360.0,842760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2215106444f572ef99260a9d180699a83745b3caaf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637952.0,470104.0,941240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e3af159807ef82eedc819757a0c1d0619a4365c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625264.0,388520.0,892400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fc3c1b2991587a55f298b47269258a8924f7010d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711176.0,365256.0,1002280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a010b0d58054a0b1fd92afb2020d7985c6c7d35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704388.0,399804.0,852320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d810cb87096558ce7786cabba0ca4aab81ccdb8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724760.0,453768.0,829080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2239d50c6cc0ca3e13ae62c3a6ea2b26c7b7114d33%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737376.0,372376.0,919680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ecd23b8cb3ea2cb967bd525b9260e21561bb1b1c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752760.0,419352.0,964480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c156e9002d06fff9cb89c5333e05f5bdcffc596b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703144.0,399512.0,885800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eadb335c5656870ab5ab082e89f8e634ed09e710%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697660.0,438296.0,914840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dcf09da8e3a66cf0122e8c5bdd6a51920427345e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679208.0,383888.0,1074440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2268e2a35924f50e0bd0eac18f5fd0bc3fb118b702%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633820.0,459348.0,883800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249c86582232285a9413d149f752c60a448560251%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642800.0,406888.0,830880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22420de4b7005cbee41ff0729b7f7be70892e1b4b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736288.0,412024.0,851520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257293ea1adf5b964c44c133a6289b114e3433482%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659336.0,422544.0,920920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217bbbb9f3dc40004b469bee5b294a1f2514bd2d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744656.0,412784.0,837800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c94e3ad51eb3277c457abeab3ac80f48c4b7729%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716208.0,444224.0,999120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8626fe745ab6f22a0b4b3b9fa226a94c726593f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715384.0,446256.0,859240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22535f6fe06625934452126b95709ff71b5987570c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666000.0,365472.0,784400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c2983b837c8dbc8a120f1bd18fa248af9e8f940b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676448.0,434384.0,921520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22981cb5f7ad09036c92d72accc8a44796c20b1ab9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700184.0,442584.0,885640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22245826c253bea6aaeedcc24797bb3a7d89184699%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718152.0,450792.0,851880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e72360511bd20c45e9e6a2bed7ccdae1631bc17f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637480.0,472888.0,946080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205f82ce0d425623f1102a732ce39778c760cee0e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716208.0,460336.0,964600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223bbfcbed832cc2cf043d751a01b0746a08392590%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665432.0,420096.0,935240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b58187971c3754e08fe70791d0c7fe01806b6920%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622120.0,380120.0,975160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265b688797698b552e811a5eb6411de39bbd2b7bd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726432.0,528712.0,910360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228822b5cc3786dd13c77e985192005fc3e5f8c130%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718528.0,445664.0,870640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223922139a5924e96396007774e298c9985d5de2c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665576.0,414152.0,953160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223cbf0598cde6297d353f974445160905f2e78252%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680480.0,397248.0,972160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3c45e37eb9abbdcca122a4be8156d26d461c774%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665184.0,413816.0,955920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241455d95810c402a17a998c4561cefa0080bfc92%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611896.0,477000.0,942040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22192272501e9465770bc28de4d621b9ae3ddfc102%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665776.0,405984.0,973080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d61096b7d81b1a94c1835615b2c89114b3331ebf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608432.0,361056.0,892120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d75f9eae7c8af117771ba39b48969046e2a667fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672448.0,412240.0,870760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f2e45d6281cb4adc6081e594e3c7370f37a2ea7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715880.0,444336.0,861160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2208e2e1cf86e92ec1e28565f462ab8911893f8a0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678272.0,494784.0,866480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221cda92e53bb6ef79af2824ec20f3a64107b6b3fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666576.0,445912.0,895440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a04967e256ed533833f40fbff32f3ed2cf87859c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618992.0,373948.0,895040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a533bfdf90b1caba3979c25d926691061c2dd6fa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631568.0,476520.0,872000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201769b3b31f490c67056295b4e5db5c463ab441f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675036.0,450488.0,912160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22010b6eb77454d9b8d2008248cc506ebd84f5142e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664048.0,423728.0,922720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8f81ff838265f773a3717b20f3a05392035aea2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717912.0,460472.0,969960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22752bf5a5a1bae0c8178b7544d738ec9a2c684b84%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625776.0,388448.0,894360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ce08445334771a325603ca0561891844654ea79%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671084.0,446032.0,866520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a08ab28a8ec4ed60f72f78182ca60bf12763ed8b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777944.0,443052.0,883000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22477557a18c27d89acead3b1f107360a17f7ee225%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682784.0,425360.0,903120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22041b14e08033a281b92a20a332b3537805d085f3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674888.0,448512.0,883640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2d84864b3240d5e287ee584c786da6cbc1a29c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665336.0,403512.0,990320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229474d1c98d61776fa648e5fb00ff6f89572ba7b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B796480.0,346680.0,983040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22df3056e8b658b3eb4e2be62edcb975d9b65c47b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641656.0,446416.0,823560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b16e96d3de288ff3cf0c7b886eafbb18ac82b17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639360.0,467536.0,936480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228fd8c6e35fc1b13d2fae353fc5caba167d2974e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650552.0,414152.0,899240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad00b68d57f675f68e859604095528a16f31ab15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608736.0,476688.0,940480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad6c0521ad6c14d115e41135026192011adb1b20%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606548.0,401232.0,815600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c41055d5481b58e764376e6901998744f6703e17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669640.0,512680.0,866480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ef1990e6b37225ab00a0cd5de2f8de70bbcfb12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671672.0,439208.0,886680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fb2fe36518bdbb1e732dd24e6fee7d5ba511af6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715896.0,468096.0,902040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221d7a8acfcdcbd52809daca8d923910a8c882f33%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666376.0,475096.0,893640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22993d0b9a2b3dfe775fa128ce92561964520e9a3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737336.0,371096.0,921440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22448a34889f33ec9869395472589e537fb994b8db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648864.0,467552.0,880600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f55a0c3eee9b4f0be693091cd60342d00418bb0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715376.0,446528.0,944480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22504fb1a9852f7a3d0568a1fc793347a9769537b8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716180.0,493116.0,1004240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d3aa8232e4f04cdc3c7a83e8941409f1c3d3115%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672352.0,404232.0,854640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217595a91edec0ee324afded7db091a6c86e6cdbf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631144.0,419816.0,911520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207b758ac1e20944032aec9a0c4b24186b2c13218%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617472.0,369544.0,893160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221f82484b384bbb432b101d049a67fcfa125b71a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664584.0,445512.0,843600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e7b0508a2a853ef27eaf9f08d2bffcb68cb2a38%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727904.0,359096.0,1046360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273c8df1d670ceac6b4da8c82f71116025af9112f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B587288.0,394008.0,816720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227aa7d1b88ea98c7cf94cc3f0df9c537be54338f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670672.0,516088.0,866720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201d8576cdb9b704dff0175ccd2f7bf8df02df3dd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643960.0,454184.0,917280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298c97a3845f89f180510ee90e2c972aada1c9803%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B795592.0,353256.0,939960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22531ddf01f453542d191bc1065115c8a32a7c1b00%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629104.0,415024.0,910040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b39a6deebc60a47e7bdbe243050fa302ba8ee0c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717208.0,469272.0,899840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd3728f4b735e9cece492441e6c96283b3a9769e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685760.0,459784.0,942200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da887f492de1b4d80f894f26cf9642271e533c3b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646576.0,414816.0,835000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0a545352ece24cd25c1ca343f664edf8a8e3c4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B811776.0,343912.0,936000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220025a9736f86abbf49d2955de9aae76121fe91c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722432.0,454036.0,840720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e893f835e7ad5fbb76d647693ef81c4d1460be6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616992.0,430112.0,774200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221ce52e6c73b546869a1b1fc3f7b218618482417%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707792.0,371512.0,906080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22914a16762d5293a7415f6c40f100519b9f8ad9d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665872.0,467992.0,895000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224eaba7e2d901fa4498ccbb2bc4d13a428bd7edd4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633912.0,464792.0,929800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d45142d362d4b44be6bf60f011399ba5e98933f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702784.0,434360.0,939800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a1163ac18929915ea6ba248189baa888da576ec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644800.0,468936.0,947760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d8d4aa072dce80899a406b663ff92a828f48cc7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702784.0,451288.0,892960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2222774c44283bc7efa78f3e16e00fa7a2fffbe4b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728896.0,376144.0,912720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22170a1eb61c999b7fd0c08827f959fd3ae3458d0b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763684.0,353488.0,912560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ad58bd257eb63ea720daee8ce764775d52baa4d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616976.0,420260.0,911400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22607b6abf85caf66691419806492fac061615e6ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722696.0,366224.0,1017000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2261b7da6c65940f8dab2c709df60b217657cb7763%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679560.0,409544.0,850840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a0f926b9a1fc92873b82b06d593ae4d5dab9c6e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613824.0,364696.0,890080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c69d5bb018c0bcb33fdeb089a21679ac689509b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717104.0,469568.0,901120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5bf64ca5286680a7ef049e9ef2e83a8615f0778%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674104.0,379896.0,1086040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ebd465db4ad6598053368abc7238f470535e2d2a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639808.0,460288.0,922960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272fca6ce8c4b9fbde7a9c740321228c2c98988ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697104.0,387672.0,938160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207abeba72e36eb7497508df8201108aadb3465ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603908.0,401316.0,814200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb8af5330fcfce8b221022e09383400ed3a910a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637632.0,472768.0,874960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e4a4e1f927fedbc68c690f17e7ae5243d67c44c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636256.0,444624.0,819440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2280b39dc03d98091ebab6503ad13f5fa47f2fd3eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680840.0,391072.0,1057720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e27c21746cc83702b35a0e9d227ec44c4673e107%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647936.0,481984.0,902920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e670679f11d0d52b0b95e83d12ec76f4a4c85a77%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725608.0,456808.0,812680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22637c9f57dd89a534b4618b3256ef5b7d6e3ba623%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643696.0,404728.0,826880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fcc1a6cc410c3e788af239cbfe4d45e00132304a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B599776.0,415664.0,918640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb35236be66f125c2a6b00874dc4acce37494ae5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680320.0,438388.0,901600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d3fd41ec905570ca6fbee055219c56f58abe314%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663280.0,448008.0,930920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac282ccc37cb1fc96a1dca7f30dc490439cbbe6d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603296.0,419296.0,935880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a24afe70e665d46da9f0e49054735e12a791c25b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724936.0,456192.0,818040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225687fbc5408b1e1fec4eb8a9e03312ac3990c05%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671096.0,436844.0,882800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22067b9cb4e7997fb5af61fcf058b839f14ad54689%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727232.0,489032.0,903040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22884c78afb6b2b0b2ea6f58d28adfb062fa8775a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671456.0,488008.0,883160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2234660f9953fff0d8230b45f20f0faceaedc7a0cf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669448.0,440672.0,862560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ebd1b82a5beca6ea2bbb24377d5cf0e3990a5abb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673616.0,466032.0,951320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eff400959144620a04462c6683c0045e8a70ecdf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672856.0,399396.0,1008920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2215bf5b80ad52b7bd7babcb56c12ef41c14ff2189%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681144.0,435200.0,904280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2269c874c67e6af822ceb7bad745e6710375d3c586%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674280.0,491344.0,971560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d6a78fd1b3abca5a77bc0cafdc4cbed5a99ecfa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648648.0,393536.0,916800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e8a0f45f4efd035b8e706102183aec92aa114ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662244.0,422120.0,862280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290d3b6207fb355400bf0bad2a7bb79f58121ecc4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B793808.0,347896.0,979280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f374cf838a316101092f5d6fb9d66dd32e132d55%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636416.0,461072.0,885320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a88435c616b3c0b4af104ee6f3651f7f99400e6e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699592.0,449040.0,898000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226910b7de876137b47fa745d067378545bb40bad3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B585768.0,390136.0,816240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282e124763ec07ca789b7784de7d897bac7850df5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668688.0,454696.0,940600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b1bd2f69333138700981b29e01cd282983310ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628536.0,470856.0,938440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225bc4774d52370796e6591e23f62343164937b724%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752088.0,417264.0,966480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2294f1e6d0e601a9566484f3d9c6e1602c90f90525%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673104.0,445880.0,935560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22046af849061ebaecb3b42a1f66eb8dbdb16b353b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716360.0,442208.0,861000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f48344aaf7e4ad6a6d941b90eb74d860ae36d6ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714120.0,473488.0,854760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265b893c73169629507edd96317d453c7c4c80122%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714024.0,441968.0,979720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d4634b413c01a96ac45c57f677519a658780c65e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756492.0,362220.0,923920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b1c8acaf2f363a0e9e83ce88fb31f2e18a5ee7e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686032.0,431376.0,908920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222a38b3b2ff12ff14fcc9c768e9bd37a1c3881353%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666776.0,403304.0,985840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2246e2a4ebda0aee135262b2e402a1f06a9a39ad9c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720064.0,482400.0,986720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22790cf64c941edce38bc1b71f513c208962f64193%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677568.0,498544.0,865960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa04fbbd84f1f066b68f51494cdf3eebbb409ba1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657584.0,422324.0,856560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eafb8ca4704219f976ee2a3e38a15d1b340f6002%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720648.0,432632.0,957960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2251b048d5688e92b0191b7103417199e78aa48a2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B553504.0,350328.0,988560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296f978065ac3cf9e328d9a6e1c20b60d4fb41964%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706320.0,439824.0,927920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0fc9e8cffb5ba0b52859bf42de21a0ad71ff1c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676976.0,377528.0,814920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2287dbf050c10ea45cc37d429cd27a700e373700dd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670216.0,439968.0,864320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc0b3c545e91ac8c0f9ac8714958cc645d1b1517%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727840.0,457344.0,810880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a24aea0db5ceaa8c77bd69eea5ab8df019ff3a2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B786792.0,453184.0,879360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a67f4adf874879c0a17d09c46fa4970536610e6c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601752.0,418640.0,936760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220def5bded3bf7a46cd3b43ef82668b7b5279ae81%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708352.0,391648.0,904760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226103680c6a8cb9cd95482d7c94a66d258b52e8cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714144.0,463056.0,862800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e4264750a13fb29496da460a6fcb9d92a0940b67%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686752.0,391568.0,900000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22447e81865e1c926d1ec535464396f94a774d33e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678192.0,402656.0,1021240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c8c1a4b86730a60453acb49838e2e42eb6f78e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705560.0,450840.0,888960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d04765344741d370dc6b85dee970f16801ab558c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622400.0,376416.0,894120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22129a34a33b41382684bdb791031da259542e7a4f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685416.0,398960.0,1040320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e2f37ba7251a630a23bcf48b8898f5186a86a7f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656416.0,420024.0,857920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222209077eb31226841b555aaf44219e660a063fc8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703880.0,369688.0,986320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221700264a9127ab20a13f8f7a250ff2e295a33b7b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B594608.0,422808.0,910960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e7998331f8fe89902ef5cff6a6438673a845c56%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724544.0,453592.0,833480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220818d278fcbf22cd1e51657deed285070f53baee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708384.0,396280.0,857480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22019b4870b0f185db197a37f35bfea05e2bd60743%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723968.0,454728.0,837960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e66ff4730066ccd571e0e70413df5d5f4873c64a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667608.0,405424.0,971320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2244924c52b95e8d91e43835666b63eac93f0abafa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713312.0,424680.0,874680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e79038f79ba2c2a0d66dfa6561876de01a180403%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667312.0,475832.0,892360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2248bf8e36eb447b89fe56caf851d7601d0cad615f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677624.0,517716.0,987120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22961ab1ed37af0cc80baa1781bac36deb7f3fdc5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697344.0,397656.0,902600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f797fa4ef513b6178b66455a99ed270f93ab531%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664992.0,402240.0,994200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223a86c41541b108d265482b62400dce11a69502c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625864.0,412112.0,810040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f004f70802baea33c9c996c04e40f6a948c82d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689652.0,438392.0,907840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22388bf7f0b5b4ef977df17f4206dbaad0f542bc0d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614008.0,368176.0,984280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc40de101970d353e1d480849f6ac4da5bd1b186%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665008.0,445880.0,847280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220cf36eefd613e8c289a3999ce3fddfd81209d2b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B797696.0,346040.0,983440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279da3d5da42f35e5893e905c6e4e32c4031b2da2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742712.0,397272.0,951200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad80bc0f73bacd1e661a3ff7ba5a23bc07e30b06%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613088.0,521256.0,898200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22672e9f09ca3a7337c455a5131069bff91ae32e6a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707992.0,396288.0,858600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22939417b5fa5fb50cd7f4779ec0481dbbce860024%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691432.0,386144.0,900240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d127279f1f141be815c98396dd0baf367e3446c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682000.0,395080.0,971800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282c65f3277acf44ba8ed96c6b3c800198bb2e4ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747800.0,419504.0,962520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226de06901f025a61387fadd08264f72f21979a510%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678696.0,387352.0,1062320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229211a553cda08189ad91792d10c1409d615ec885%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647624.0,416120.0,842040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f7c91b5cd868955f07d295c1ee41dc80d112d6d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665792.0,404704.0,986600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a0c0f22f0f4aa295fc9ea8b25826d0c5fd81a50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623184.0,472488.0,940240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f828141be2001b3b791b897bb962fbd1e031775b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674192.0,448776.0,883680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e32e36c1ffdb27485de10dcc55f352bd0f111d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725440.0,452728.0,836440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22302fbb31d923e2efccb1474fe9e6ce9e4c4d41fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B589776.0,425212.0,948360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dda7336e9d5676f1c814e222db6e1ef6fc7ae401%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B753768.0,363560.0,932080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2224c8089c935857f5966befa8bc805ca5b8679403%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717184.0,493792.0,1004000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225bb449b279f37b8e8a3a8d4624ed9766a74e4c64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720024.0,382552.0,910280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd81d4f2816213b90ac97b41b2c118547e1d6584%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B579384.0,381584.0,809680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224c1c20d308ab8a404a6c4104b6916cec6454a0fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715816.0,444744.0,859040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22144079d712275e4187a915355548338d134e4660%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714232.0,451400.0,952600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e5cd2df8a0a21b71d8c0fd872deba822c8c86b40%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716328.0,440624.0,869240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222a7300bd484c9ebb57f23922be8c6abd485f85c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727344.0,454288.0,854080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d662d156db2897678a9bd6fdbb6f3aba09aeab7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743400.0,443720.0,907560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222807e06a36962d7c2db29c49419006b91f3cfa37%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B764216.0,354736.0,912800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3ca0fc6f5221320353baf9a364e652963d22be5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727064.0,367456.0,1032560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22abb32426d4b2160c78b50c7395b2a165a405d90e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B778600.0,357032.0,963360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227bbc0e7e42c85a2f2d0182434c3113366bc1fac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662072.0,446008.0,840920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220012bf9c5aff398cda2325e66c24471dea71c193%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622288.0,420880.0,912720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211502e82ea11ef2df581be20c44e89138d220923%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711024.0,486024.0,841760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f0aa4ceeb6ef2468473d75fe20e4325b8a0388f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678648.0,381656.0,1077800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c839f9f9c1baa3e4c317b8dd764c02bff19ad75%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727640.0,513888.0,907440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b1f8b86bc1ff65e900e27fa5f02ccd345c23f3e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603696.0,399400.0,814520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224cbff078b9218601616cff2805ee64550e6a33ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676136.0,435152.0,921840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265d4fdf2115bae7f0f97576928591b2e3d280b9a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649032.0,454584.0,856160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22873f080ebc66c966f2fa4dbd528bdcc94c080e17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624080.0,483800.0,873720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267de4df1510132c4a520299f09a4857223880618%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686680.0,402584.0,1036840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2270e6e261c4755ff44e84cbb06231a4b52b2e3a86%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763776.0,352688.0,910320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227795a6e36872e88f16249e4fe2a2031b0511057d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677976.0,397176.0,843360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d46adeeeada4688613a895a5db3a0d245126c5b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667312.0,445344.0,897200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2208505708fe6115e9915cc43798827f9c0bb82709%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723004.0,424716.0,944840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226bc8c8edce437b61a988a3ecc840af5816453675%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661936.0,456488.0,896680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22369099b1ce8ca6fec3f4c4d64f930f56aca6a983%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668576.0,376920.0,1091120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bac507e7ae9344a3437f8e9c07ce1a13bc2474d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698832.0,385416.0,952280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22afe12e5c9443bc6f2ad71d464548c2d53c71a649%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675348.0,397840.0,1013360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220cb16cc99038c5ae04d6d629b988127521bdf2cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675340.0,446992.0,879280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22546005cd50cbc7fee81ed852fd9deb6f414cabb8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761480.0,400304.0,960200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22998abf729d1c5a539b68ef011da18286daf0137d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717320.0,489312.0,999840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a22c4d6ee5b370242b72d42d91fa80dd12ff1437%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607024.0,464728.0,868040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22693ed3ad874114959c29a067613b4e3c78095b1d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669272.0,439624.0,864320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226eb872a3f776237c3b812e052ec52d5b21fd9626%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667800.0,399720.0,1001200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4ff6701a48a518985f2ea60e7bba3f21425c0f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674192.0,446536.0,935240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226588c7517c7f1142b81cc99986ca8dda803ce1a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650368.0,413616.0,900120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22155f9e7c4a953358b0550832fb64bc0f21dc184b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674104.0,399496.0,1013120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9378c85936b186c81925d5bfa23acf835d26737%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714800.0,440880.0,976280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b5ae84e71bdf70aa1238b54b26fd3a3c22023c28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767680.0,400336.0,961640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225514a27fea8318e7f3b8ebdfd353638dd163e96d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687352.0,406808.0,841120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299e00d73191c5a9dd05b8c14bc96208f0ea9de79%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689436.0,464112.0,948920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224978ce42259ff54a8ff0e99d279869bcdbc6f318%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681416.0,384096.0,1070360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa1bb633a9a6658680403f3f79174f65f6b89025%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666472.0,364032.0,789440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0af783f0f3a83fe125cc01ea2e3aa6cf7a7072d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666232.0,425576.0,923120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cda378a2256992b068c4d3e1a3f03f3bdbde3d3f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713168.0,441104.0,873120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ced30f9213477f83fa72aa2a89d2a08edf224d11%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713000.0,467248.0,859320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223980724ebd07a3af4bfd988cd1fab3d638a67a44%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686480.0,401624.0,1031480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299fe1d76d21b850942f1048d50ec7910596773cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B556920.0,394360.0,811720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254d3c9fd40c6f7a08bbe97796d3776aa395c6986%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729248.0,424552.0,948000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2ec8efc34320aec487a475d0b69ce24caeb517b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650632.0,464632.0,947840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dae39c849a0919efa21471b958bb5763ce7a529a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676352.0,504832.0,865440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22527a3209c81a9d5338fbb255e959f2d163dcf5b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705240.0,433312.0,883560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2237ab9d3dc609b0f71abb2a6ecf23a350fa8d78f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675040.0,399200.0,963960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8cb5f458546397a507d2bfbfdc1490923e69f54%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692864.0,386968.0,986360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e6c0c73cc9d86d3fd981ba138b6b9691818683f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659880.0,449504.0,931640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221eed2d42e14a8f3ac2f65679715ce8cf7ea5d059%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717196.0,444864.0,873640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e9ad441c06787f137f7bd30ac4ace30918fc24f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666000.0,400064.0,912240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232c275e3ce697337c3cd9d7aaaad12b1b4d2fbac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692892.0,442664.0,888000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa0b2816fdf72391d1ba951686bd6d42fbb16047%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717304.0,449736.0,853440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a506badf192cbc91d825285425a3a3ab3e43f23e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738712.0,384280.0,891040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226fdba128344cfce0a00010ff9cfa4396b68c0b0f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B757136.0,447776.0,892320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca47e045b748750eb0307bfa0e75226877a6482f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706744.0,434592.0,937920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e7390eed1534b5ede3ccd0449f390d61941d44c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696848.0,445992.0,899720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fbe4efb28a6dddcac6ce9362ee2740ece3848b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653992.0,453816.0,894040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210b802c1908dc3984b94855993cd73ebfb1b03e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622672.0,472224.0,937920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228362e53843a0fcee5c04a7e378818426f6097487%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613888.0,367576.0,986560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224303b0b5db264afc7221214e235670d85c20a4f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B775152.0,435888.0,880200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9135cb396e7b468c741ad0414cff7ccf488a7db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671416.0,453472.0,940240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d54607033087e88b3e381c9d519058944414ffc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620848.0,379800.0,894880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a23642ab67e5da164af2b3d7fe0f930fd71c2a4f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679384.0,383000.0,824160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2261aebb8f4e31494c016e0026eacf197eadfd10c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694248.0,466120.0,914400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab43bfb5b2a0d7f6b1d916f22a17baa1122a3276%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667980.0,403160.0,983240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d98200c3d2c65f2a6c2421943bc6ece283b3c19%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707880.0,366432.0,910040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e41b78be622ccc13d58044c446c69595a3c1a7a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716872.0,428376.0,943280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb32f29540580b51d3ec695afd3ba6327613db02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616360.0,419432.0,912000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2275db6985aabcd6ee97266bcfb63dbd450d4ec120%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694788.0,467604.0,914080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c54436fc4c101ebbf6830e87bde09859a4fc7dd6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717760.0,439240.0,887920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb0095becbf86384c50146216828d0b4d0095470%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651232.0,413936.0,898840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f7e69b51b44ac3b5c53fe696517a0baa3e9a9b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676712.0,397108.0,842920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ec96625a8382529a8dea0c0741d3ddacc7697269%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710064.0,452488.0,873400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b920477d92eb24882ed8658294e685f7647dc49%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710592.0,488384.0,839920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22827ee18e79642e098bda64eecd936a5057bde038%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B556720.0,351048.0,988520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221a0ff32e44e4b3b3ed0a9661d779de3abb4144cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692432.0,392008.0,986880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c914e6227cf3b60ee20bea8e36c739588251732%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715672.0,445064.0,859840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d882c8c5f2de2ac0611be8fcd0e55adbe6e4e962%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617240.0,362488.0,999120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266dde2658549eb9528c1285be947a96097ebbe7b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B801480.0,342464.0,987520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ebbb338b70ff3a9a4015582b0e8198f12f276ab8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B805472.0,456232.0,881480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2219d9021ebc1c04958d87347c33bd1e1c0b7d5a33%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708192.0,434856.0,952960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e44b489274b1d92739ca4487f0abd6d277ffbb5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629040.0,504480.0,901080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c58f64700d98d9cf1852253f181e5590b084b27%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636536.0,443312.0,818280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a92e4876680b14b86d8c2f82621ea9057759e47b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664592.0,464528.0,855720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265eea8eef4e434e4c393cb40acb55b87206974c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667592.0,407648.0,971600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ee6d479b7086a4ebe795c5b604595cbe37eea68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B598672.0,397912.0,815160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257f56902484ccc10c25049742bee3a30c7c7f692%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674144.0,492384.0,973440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22faa3987d9f85b5aa1de16c443df79a46d36d0e22%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721272.0,474120.0,980000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eeef95fdd87e3d83102e937515d873f990159d36%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725928.0,458144.0,813080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227589fad5e3dac89516819548bef62e16d95e6065%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722232.0,472856.0,981480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220528c92c7f3fe9f163a5282e84ccd7cdb41c1fa1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660840.0,447352.0,838240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8ce3f4f647f3cb8fd60547e9b595f39b857e8f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624584.0,415592.0,912840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ef64b7f50cfeaaa370a8554ed4d6e23c63b34756%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604680.0,465012.0,867480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223996b830a62cfa99654169357a72fdecb5c3ceac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618016.0,426400.0,780320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b5e4cb22e835bf6cd27e2471c11d580dea43d27%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648008.0,410056.0,950200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7f36de750991efc07a5ba90c4fdcde6defa2433%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701304.0,374328.0,975160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226dfe0df296145bbdc02fad82d5a50f858f7b6cf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677472.0,409104.0,857360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22beceda190d622f7dd1e3b002fc36435c7d047d00%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730352.0,460032.0,810760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229aca5b01a1d3ce93217775b82198852a72a6b48f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664448.0,410152.0,861320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22396a310bdab668ff101c47a06c3bd5b03806b5b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723808.0,382040.0,910360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22868056bcf4ac0104e5befe1e3b09434dd1766f43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723680.0,450656.0,859120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2251ffbd4fa042fa4bff579b97da966fc257e20a3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675136.0,415864.0,880840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2287296ee1bed8d6d69144867ba121ab71a1ea7cbc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B592168.0,422416.0,910960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d2df0204a71ba2ce3cf8231a3e5ef1852d467dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643744.0,409952.0,907480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6e8b32c9e929135722ce7aba1e9ee7ef419eb5b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730096.0,460832.0,810400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d105e6ceb59014c0e7631004e4c335705980d0a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666720.0,403440.0,983080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d44920b0056af403da50aa40cfc8acdd0defb6b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B809688.0,461328.0,881280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c88a5a08f6027327fe00c5d0271f67505c0fe20%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671432.0,412872.0,872440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223dcc021d153f1067427257c49c4fe142a1efe7c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653320.0,394360.0,916120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22744cc8e8f72c4a6bd91a1b968a329813f6263040%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750560.0,399088.0,956240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab7ac6797c2a5754d5cf7c2e1439d4c69d4712a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695984.0,409128.0,821680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22103745273f8d4ee9bc182e224a2d21cb2fc83c1b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731312.0,463488.0,805320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e86c76f3d6686861d59fce4244209160ef638a2a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672644.0,446492.0,892560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202581aa14eb4cf4950efd32ef536497bddb0f829%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B826976.0,337088.0,934720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22290da770dbabdbb273d7e2343c51a75419cdfdcb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660272.0,449920.0,932160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b2aa828448339485cbcac67f328006cd7f9969d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652792.0,412656.0,840920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226abb22a9b20861394c4d30bd304586b018b83f34%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703688.0,436608.0,938560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227df3089472fc057ab2cc2bf73c7ce9fe9d61c775%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710648.0,446552.0,880440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22753d7bd056e05756e5f0ad420fee08112c1e48d3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B826120.0,336320.0,934600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a5490ff1809018a8c781793764131d851daa844%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704120.0,435704.0,939480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fdbec8fcf2e1d54e908f7d3f539aa51700cfdce2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640496.0,411728.0,908000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22afda32a6c825fea27f8aed657507c7dddcd82113%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616024.0,405496.0,816560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a636f254fef2160ddfd4d65e87294be5ac8976d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675432.0,414352.0,876880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247b0e49c2b7f183d8112db6f5e478898c39a2c94%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613596.0,462292.0,871440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2252c9500ef93144d035bbc106d134384a3cb35e46%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B751656.0,416336.0,820600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e15e520360db6eca3a1f761ba261985c6bc7de5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651544.0,408552.0,890280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2219ce3dafdc6a3e66c66c70d1120a5535366338ac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726320.0,380136.0,911440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a76412dddfedb7f445ccedcea315f6e8b30f0705%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681432.0,435368.0,906760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22226734de6083635f755ad14ec3f5f473daf79814%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616304.0,461128.0,871920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3a77bfa405cc63f19b2278d9f9922da3fe5c5c2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615328.0,461880.0,871760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22115d73e38b926abf30c7bf58889eff616abe6083%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718840.0,439376.0,865840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296c95a3ed65beb156b0a8791cb44369bc592eaa8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725184.0,416432.0,864920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b5371a88e113c9612dd897f9a5459562781cc7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683056.0,407680.0,844120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221a4c100bcf61086ca93ab4073b426129d74569fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670296.0,492016.0,880440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a69b95a2f831437eba56c343092f8b7dfe3152f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732912.0,464520.0,806400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b4994ceec9fed6e7c1fc7fbad0b5eaad3c17af3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687912.0,390188.0,899560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222846d26bd250ab921ad0b59826c4c94d687c584b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717528.0,489600.0,998720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c4a7c23cbaca6abd7217f1e523dbc0bbccee5396%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649728.0,456144.0,893720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c6a1140c1422c301a2fca154c50679a981b31668%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716028.0,476152.0,851040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a801c5434833124dc61627f7e9989324dd417ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682968.0,458864.0,937280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224499a7d12a52954067b8867cab6964e36ef2ae9f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699104.0,383200.0,898360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0f66e447b90f8f3f0bbd411be49858a1ef8ecda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763808.0,355144.0,914240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c04a476a43f1946335c6f4a2fe4b3ab9c27d3a42%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683208.0,482448.0,872720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a781c250de3060dbbc521502ad2a43fa33da5164%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660480.0,460888.0,943520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa1841ad3b21137edd75fd9bec052d2f4a0654b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718576.0,445088.0,872440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22234000fcb54391bb21aa075ef2164b80e384d99f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704944.0,437376.0,939720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0cd24d21661721c1c51e3412197d252392731c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717800.0,486480.0,990440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22976b650111b622f5c2ca6e8a05e9373322d724e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686488.0,479968.0,977200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f8fe2498b3ce3e29e375bd3eb0ac3689af0629c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618736.0,374424.0,978440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299bed1160612a9f3f7c0baa45a75431d4473bf7f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632776.0,391680.0,813640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222f25c4ff0313784fc50934f9f5840aedb8676639%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741968.0,370192.0,920560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253169c6e67e6ef3a1471a304ce8b89bc95ee18eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B805936.0,338136.0,997040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba5bf195267ddc433aeab9e909a11be2c2da5668%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657948.0,446936.0,910520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22343672ee78784457d4fbc23b57cf9a6431898068%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720064.0,469696.0,975960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211ae1742693e99719ace0aef3483babace67b5a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643584.0,486936.0,901800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226fa33ada976b4e22246d546e4bb802c3563b43b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688992.0,432836.0,908280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22171b3ae07d2a5465b1d640a192c12641e9a57639%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670696.0,521416.0,864040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a04269de742f7a69fcb678ea5f02ffafbb977c8f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655232.0,463936.0,945160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22635be6bb2e3ca5cdb1429a8718491ca11da62fa4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725056.0,453608.0,832840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227840111f55827071edc930671fad2de64cd533b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670576.0,423896.0,927240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e6da19b62192f7b9f7d3285866b2a9aa7d0ba5e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640608.0,488544.0,900680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3149a919860e0767e1f525dba4d1eb97275fbea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727528.0,491872.0,904080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e90bac4f7d9e9e8e4e300dc9fcd622e21a0d65df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683560.0,423500.0,901760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d396d967aa88e0ab11257f9daea9eb12865ced92%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670120.0,424704.0,922400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273919214cfa0ca45d2306b0f3d23f9cb92d0ef5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676320.0,377040.0,814960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22316acc9c1ed87f543714f413bba6d06ad6a8668e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701912.0,374576.0,979480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c56fce48018d5496343aac12f0d4af592a609844%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B597320.0,397864.0,816000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a335e9de38ebdc44e36914b1098a0e669640c186%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685992.0,395496.0,976680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b1e0d99d78b629fbc6fce2157ad31c161895790%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609008.0,463080.0,869360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb87464f6f535cfdc51e0ead2c5244c5d29b0caf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730880.0,382592.0,894760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7efcd6de095c4dc57ede7d39bba73db41e7e9d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B772040.0,434616.0,880520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b688b8da105eee90a7f19570a8d4d6b5037b7a5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673192.0,508816.0,867640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273fd43d4b4f00f8c8af1da26f67f415a0bf213ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644904.0,411224.0,906000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2263dc21d39ad690c123977aa947dc0fb4b2e64436%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615400.0,420552.0,910400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3d175c84e99c8273aa37d4dd863ef79afd492b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B570400.0,371680.0,810280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222347f9b8d644cf6a03fc63d9c69fc740fd7a992c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715808.0,432936.0,954080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2243b8fc6dcb24c12e5f77c2baa4c597fa5b6e3d91%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685200.0,480776.0,978160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d4a0fc3fc5957be7602bbf1f95ed6524b8b97a3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678512.0,417624.0,888720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f55797ce193334b84edd14a523f4f3fc03ae3606%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724800.0,448336.0,862400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228500451ceb25899c2d60522b34704007df39d173%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690464.0,434024.0,902920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226fa9b3e1e3b4c96f3bc956d49c69f96f12009ea2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628768.0,392192.0,963120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5ef6ea8b0081b6d135a65b4cf30cb68fa78ba27%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644880.0,406328.0,889880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226420c033780ed5478b7998b7170d145637584185%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693592.0,404120.0,895400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f926789a391ebf0f54aab2baf81d101641abece6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738000.0,440624.0,889840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2287c509c6c6649188896d380b0446a6806c60330f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B755544.0,449344.0,894400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a9751d8e99977b083a6a1b6ed187c5868c826cfb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675840.0,478040.0,962280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22338d5bae0223edfe40e70249aff4b88c5fc269a1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689056.0,465152.0,885760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7e03939dbcc714f5c7452baffca018c4c798c3c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668488.0,422024.0,931680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297afbb09d17af68dbbaa1bea6f5d6295a89e0524%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619440.0,415312.0,801520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2251c09d3f25a21cf3e749f4bea4c690788f312a7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B803160.0,349848.0,936000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cfc1310d79fbfc578b6190f09eb34c513e098efb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643640.0,402304.0,824520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2239a948a4816a0250e3d7a7a6d83d6d1cb59b9d1c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702320.0,443000.0,882320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217eba3d2f3a44936fabd42e156752e9f1953c57e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B610488.0,360616.0,891560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a30c26cc78f8ab6893e4cca36309ca578586fa9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742552.0,414408.0,840440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258fdc75fe6b22bb43787225fbda4ad523b2fdcdb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740328.0,439592.0,889280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235f453d6f91b1177cea57775a9f7c4fccde34344%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668160.0,445136.0,928080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0033e3816f2db223ed1c55bf7456dc5719f84e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B808272.0,347200.0,934360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224bde4ff5132cd5fba630c5993fa0727528eac16e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619136.0,512584.0,899400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d0c0cddf480e035895c6af95bb2740a43619a65%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648460.0,417296.0,844160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224239cdf0f836314096b94678824bd9d35e92eaeb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639712.0,388696.0,922880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226257c8d5671c1a05766be67c7ba225a6d4857db0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731856.0,431800.0,959240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228d8995b8b818739d5582b71c20e82768480ac394%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668520.0,369220.0,793880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e5553f4f5f5d1a70a0aed607e28e47ec274986d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665576.0,425664.0,864600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22302a80a61a6f0666abfdca59912b37fce08dcc6e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650472.0,413952.0,901440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282102db2ebc0597e814dd4f4e929cb3966018f5e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653960.0,424088.0,921200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1f08834d451c1e959f0eaa0cd93298aa23f4c8e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698976.0,386932.0,944960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258cef14fbf0d43436ff9d66c723399af33ab541e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660616.0,447088.0,906760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a514008001aadfe4c77dabcaa0e1686b71b3e048%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637344.0,409816.0,827480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f2c31632da2f417ea2e0a45826deb2e55eddf557%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B771192.0,448048.0,883720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22350d8e3d39458ecd4c3cd7041073fed580bacb1a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B578016.0,378912.0,809520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200224cbc64df24a94f79964e4da0948edcbf10c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713624.0,363848.0,1004720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224336fcc60747f0bc3e44cde6a93661085efbc66e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642440.0,421776.0,913480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bcf66a837f64dbf65a0d1a26cc5cb9048a43cce3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732624.0,422424.0,949880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226581a855dc982e0badcdb082c4f94786b0c45d30%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B580044.0,358916.0,983600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227aba2a320593dbb85c33d3c51ef07d768d8dd369%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661904.0,447536.0,903680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2269b0f732d3c67ead6c511b5e7b63a1c856018fbe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671080.0,479480.0,888880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22389cb0d356040998e0cf4d8bc493e37b0ada76ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634904.0,397952.0,958200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221319ea2d64cdbb913e078d39011baf5a8f76fb0b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B813400.0,342896.0,934080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2238b461ad08232d75ce0cbe8f02d3a4075a15954e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761664.0,400136.0,959520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a89af4625d8d48c87b4e73fa118aca0d749d690f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703864.0,432456.0,884680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c453b20b90361d8cfecf20f68f1ff25bcd75dda6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652736.0,452412.0,858600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5cc1104b5ff10b695dc9e75de3b58ee0409d5ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675440.0,500440.0,978640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c05ddf6ced6a900f1c7a4d3975bdfd571f2ab67d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733808.0,412352.0,852120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb3b794ff382861c08b1c038fdb3583961cd18d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667536.0,407456.0,969280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7d14b36e9fe39fd1166518974293ee6714652ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645160.0,456800.0,853800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b4f717bec6ae02665a4ae03b8021945e2268e39%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667592.0,444408.0,928840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dfbfeca83a7214222715931a60563f635d41da80%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737976.0,426088.0,959400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab26ea35c7c0b1ae170ce4e07d83b126b37bd2fa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716512.0,486136.0,993400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce8fc4f725d94b60398351870747dbf57bcf62ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637400.0,413592.0,906240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22416ae3ab7c7a44ea4f8f0add1b56979eb245044b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614536.0,416536.0,793760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb013904baea9d479acbff47098bd57714b86cb6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752360.0,417512.0,819120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22763c5da76e8a0aa926bed849e074b453910d093b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706980.0,391736.0,904440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223a1e409b4b89debd6a6e0031756b6153cdbf4efe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656000.0,413312.0,844120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221bbfb61f3db5e812ffccf15de06ddccb9a524df3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664040.0,402640.0,994840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c74ab0961723f2848e1028ce3596a718f6b07f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711728.0,355464.0,912400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d026ba255561048aafdc212ad71cbf3df63a3422%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609400.0,465768.0,869040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22edcf7de6b3683fa6ed6029b8300eaafd12aef0c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679296.0,386872.0,832800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22edbfc4a6e140168c122cb81897bb76dc21c5af26%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686464.0,393392.0,979800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b52757d6a2f75c003b460974da9c63e9dfa97a6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B800536.0,353048.0,938040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc94e124bcdc7b605bd7f96741b6dc672cad0516%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639912.0,388120.0,923560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231c5d8c1a19c9a9ea3a8a70adc2a31fecd5e26fa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672968.0,374088.0,801160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2248587d0fd2d30433a3c36e1854be822143f2e585%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706648.0,435816.0,944480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2261edeb8a1b5a8c7835a04dcb65df21f9950667df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623288.0,411896.0,806120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d72e1cbd9147ddab635f49c2fe6409f2cb66853%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673960.0,489568.0,972680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226bce5e89142bde7911cdfbe4f91342b7e9c58f7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709700.0,441240.0,918400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228aec7ba4c87ce926288bcc9acdbb864611f6884b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719720.0,444816.0,869440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aab9a21f421e042eb7f6cdee3cbecc1027cc0079%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657676.0,423408.0,920680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab16a32cf79e2b9c6b8afcde10af8b0f7cec7777%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606496.0,524660.0,898720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228bacdb83b3c5f002ba92048ae182f13ad3c3d8a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665772.0,445132.0,849760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f874ab577ac830f8bf8752bfe3aa2f60f2eb082%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631936.0,420424.0,913800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b4c0cb1b5dc1537cb3e8fe342e7c6ffba3ffaa90%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686112.0,429912.0,907920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ec65e3bcebae5063fc89fe0d315928841085a14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B788240.0,353776.0,974360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e7a8e023bb8951b0c44c7d95fbec9c60ed167007%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655128.0,421280.0,855680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221000329e925c7431ec3fcbba80d9ec44a8cbd154%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700024.0,437072.0,887040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257e5e892253848689030b490611d3057ff8f08ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B766608.0,356336.0,938480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d69e566b8d028a7811dae4e04f1a672b284e19c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B610208.0,393472.0,796760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c96c3f714aefcf02440d96ad65a33de9ef40b685%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763480.0,433424.0,882840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b6752971de977a8761248b4d481d63446a26a661%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712720.0,440768.0,966680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ccc07488407798329e86a4181d8fdc1200c9269%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711424.0,394928.0,930480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22428433c7c898125af50c152cea690782adcdd5f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675560.0,450216.0,912360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223bf6d0f6c2373ed61da6eee70f7dadf1bdf5d81c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607416.0,421400.0,909440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223290d0cc18da35957a72c747c11c8cbf24f5d7b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676864.0,416392.0,895320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0173d1f820d22ad370a993892dc242a2aa7af06%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699472.0,402832.0,888440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2268ee3ed157d9b336dd58056ccec3ea37c4fc0e07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B788756.0,352876.0,940160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b5d44b8c97892061a49446fd3f1c9ad4fb6032e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625428.0,482896.0,873200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22217a3135ab12d2745d4a3045120586f2e77c97dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B781880.0,355608.0,970520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f14dfd790e3e99352b0c873417d612f077d0ab02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623880.0,386600.0,968440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2264c5f98101a1cb39edfee3200759f4499e2bb853%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743416.0,367920.0,923280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22772138d1316f7016b70efeb550f73565a59dc26d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631264.0,415568.0,909760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221aa0ae7250be5311890d3e4be63f24cbd4c5015a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695328.0,437560.0,915600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7dc49cc3b6765fa265fc83becfcdf1a79ed000c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638336.0,412752.0,906160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f6d363324f14ca9cda44898ecc63c37da61720e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698720.0,397912.0,901480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1f8ff60f7891587cf6bf144fd879f23987cb66c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665992.0,455680.0,913400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e87e36b84299bdcb17447d69b0acab24fda095c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628968.0,393016.0,962040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22be0db60ac0259b59c9e92ed7a30c7447c2897a4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627616.0,391888.0,895160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2281d242168e50826baf0c5d29d9e522051f195b9c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643120.0,471392.0,948800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22543be5f7d9b66d0be54d96f44cc1a5ad25d6b70f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663776.0,416504.0,943720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226198f81396ace1a79ef9836ce79f600292bbeacc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617728.0,361440.0,999000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2286d579e4bf376e7ec5d7ec5f7c5e92c498721406%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643544.0,468496.0,947600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e69adea818ea180f42de61c3cc60cc858a43f4f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634000.0,398808.0,957600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2224b13a79900cecb67911f4fd09ef18f2d960c738%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B592724.0,412356.0,923520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da71db3d06c859f2e6497cfb71292aac643d9026%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697872.0,386208.0,940960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe743e1c3f4ba25af3e5b365b1a7a38cf8f988a1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721112.0,465088.0,973040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb5eef8b72fe5c83229bbda8d77ce47b8ca29ba5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B779544.0,443232.0,883760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a05b894be4a57d1bfcfc6e074503e74dd0841a8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713352.0,440272.0,973720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2252891a029c552410807732684005bdacfc92c8b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673920.0,399592.0,964440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f951aa3ffdf191d1231032feff5c8aefcdc22863%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687416.0,479600.0,966000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d79c4e7ff9049a6ec7f2ab3a84ca272df737c828%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669784.0,517456.0,867600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227fe6fd34f844c05bd912422782ab406e9f9c39c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689608.0,435108.0,901720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227bf55e52ca30d8ca88093e7c33097d4ca5d567cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B788912.0,353424.0,976320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266edc1ef450374ffa965181d30d3bad285509bb1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683872.0,443896.0,878240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224ca42ded91ca3455e8d1e4b18884a1a22ffbd919%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668776.0,402440.0,952720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8175873317802559048c3275dc026d95c78e550%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717200.0,449320.0,853760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22874b58ebccdb1295fd490832893049bfcc95e4a5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686940.0,436416.0,910360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a59574a5a804cbe40db7fdb76c49714a9ed1806%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656344.0,415104.0,942240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ecc57560b75c4b009c8b2f1d2903fd0c4237b531%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674424.0,401480.0,851400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c4d349b6684b14d79771f10b67a3a8a8fee06a28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715784.0,444028.0,1000600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ef07af48898f7595ff54fcd0d6e9a70358c021c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703632.0,393032.0,904760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22655103417040360b7d5f552fab3a5b0e17ba1860%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663128.0,409784.0,858160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226936ca61d13980e62a70ab3c91643d215351ac41%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607240.0,464784.0,868440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22260158a8715497c844a0a48604c2a804291cda25%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661704.0,416912.0,939360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb5ee1381e2667f6d787dffc4ef1fa3263f6f8d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713240.0,447056.0,949600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d33f323b83f909398d038f9f40cacdc9daaa988%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672616.0,494200.0,974200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae19b131ca7a1b8acab15e2bdefa09411270ffc6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628152.0,408320.0,818960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bec112c3a0f402b1981fc2b67e6ef21cae8cbeca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754368.0,446888.0,895960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22687c1f5952e7ccf7302e39c64251eb6b9bba3774%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665024.0,417896.0,937200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b62db6ff9aea3b72c98078aa63d4f2b54ebcc76%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672248.0,443128.0,869040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224677c201a64b70d8449e8f72c239cb800ca96470%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747936.0,416080.0,829320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf7b858613541e93408518cf4b8774f8488b1000%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698600.0,379896.0,959040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc621b54dcca46d6e93d05b962fab98894925ea6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713328.0,442632.0,874920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255c64dd4afce9a13a80f27b558a4e877b042774a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730176.0,501096.0,908360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2259f57d74c914e78246968c4142fb823d27b7a7bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669304.0,405704.0,906760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1364068d15fb30c3d16db9855602dc7cc157351%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674080.0,506272.0,866480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2238710da991a1e69fe749cf8116cdb46c9ec2335e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678584.0,403344.0,898760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7b0f41a68e465817a7a3e257318a5717eec2b5c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B825152.0,324392.0,1016320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22193f8fd661ad86f9fc585b71b4fb1f612ae08e6d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726424.0,454584.0,850560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257fe39114e39bbac7b7882c24c7338e502ba22e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B578000.0,391576.0,814320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f07e08616a2bd77da8607e5625fc6d1007493836%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712936.0,447368.0,950720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb7af9b42bebb155cae46cc8e06a71548a48cb13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B746424.0,832552.0,920960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242f0903db9212be487b64a958a5f5266d2e45585%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631568.0,460536.0,882360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e720231589467b97e9a1ba52fd84bdad172da434%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744288.0,383784.0,887680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d167fc61a9c67205351b2116fb482443ae94a182%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691112.0,410040.0,827040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222a33d05467fa3b3128cca48d66c39f3b8da1311e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B800896.0,343908.0,986080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22efd18a5716c0a3976364821946decec11cf2f12f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691568.0,383872.0,898680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee5b2b5782ffdb08b249c396876fbca50dbef523%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623796.0,420256.0,913160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ba56ef92e9d74d124b003bc20a76c24d8f62e55%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705576.0,394080.0,905280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3e2b221760f425bde14cdd5742559b1ff8e1dfd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B591992.0,422368.0,944640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c78ad99c0637aa567c6378885eb6fbc80ee6fdef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663064.0,446976.0,840640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb99c7abea6264d5d549dd696410eb7716605b19%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734288.0,467300.0,824560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e351afebc19b4ccaf62d5500ab80ef94318c2c14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679168.0,389384.0,831920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220fbf945f5f7ddcb325c83d6a09e16ff02f9bcfc6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652136.0,452992.0,932920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c9c3e43a7b6937c69275201a9e34248d64342265%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679664.0,395968.0,970760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aeb94848600c846597f38c193b679b20d3b5b009%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673920.0,473888.0,960480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2250a7eac35df45925fe5e510992f173d8328f5f1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747872.0,366072.0,927320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256a45a74d57de16a929b892d3f43783a0dea070b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712688.0,350792.0,910720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22452606ad298bc758c0bbc5cac3c0789a4056cb45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674296.0,462076.0,947320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eec44235a71e98050bb72ae0043e17900936a5b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678960.0,520952.0,989400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3927815c37794a7ac312da36d098c6c18250a99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607184.0,388840.0,792400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d6aa97f12916c8eadeed84938c3fd866be127f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628760.0,420992.0,914120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdb8abdbbdbe7aae9d3e70903bc5d1615b2f36e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710296.0,388768.0,904720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c3fdb9919200131a7b32e989cb9c4f3eb93351d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716320.0,424216.0,870960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247483287497d596a73e1b9b8590d851e2f6b114b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604968.0,415976.0,915400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce36a9c419ca0a8815b88632d216ad7967719bbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673336.0,435048.0,881200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f805ac6eb986da78dcbf09a674bda04c07c291f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721596.0,477140.0,903800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2269a808c513e696e9a51f3fa1ce95ac1ac3a78e6b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630976.0,394872.0,959440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c47f65137dca98ed4b83e2f98979993d617ccaf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672416.0,494400.0,972640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221225f408596f459fc7c0f46cc4ce2c2308d4e7b8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629616.0,435536.0,813880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b99bd24d3dec7e4f39c60c6051ed75d58d2178d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B583736.0,390220.0,815960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22deb66a6e4a4296229d4d31a6e74e00b14da60436%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651504.0,451440.0,916160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c40982be3f48d0fe2eedfbd04d2137ecc147795%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611448.0,465048.0,870320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2245510f3b774d96cd3899d2bd046ab06a2af5ec61%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B592416.0,420428.0,941040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201a4af4d3e69e1f3c0093f5a2aae321038fc3269%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670368.0,400192.0,958160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22889be339e0ce01943d3a7aea6c6b5a0b070879c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628936.0,396464.0,894360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22796699792ff56d45ea88367166e21bd2dfbbe88d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688112.0,433016.0,901720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b43f9b6b676512c0a6d0695004f4b014b9c502b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741352.0,425432.0,963520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7b2cfeef0136bc48651a8583d197c278e35d9c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673632.0,458184.0,944080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222a5be785e9c755f2c8284a423fac4692415d9ba3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B794160.0,347912.0,981280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278d051a88e48c8a2c5431aba813e6da278f865d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661496.0,462528.0,945120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eae6f59c01954a7c7ea1d872f308049155f47641%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715968.0,445032.0,994600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cd98372ca4ae78732fb5a4dac14e776538d300af%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744736.0,440064.0,886200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202b77cee5074bd728e51a242e56ba0f4f9471d78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669576.0,439408.0,862120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223feaf751d044399aa8d2f486bf445973f6f2b9ac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725000.0,455704.0,820800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221246afce3b19c74e0054c4eba48140ff6e0e33d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678736.0,391168.0,836840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285a141ebb77f31b8d0dec62d76320e31d86c0bac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720576.0,425264.0,945360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cca99ef5c99a79de3b3ba9455084920b3d485195%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683308.0,455840.0,938040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22984819e4a0b03057b83eea44eab0287822b688ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675848.0,448176.0,880760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223855f1aaf1a8a4d67740be93516ddad594721eb8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640856.0,401928.0,823160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca6f204765bd9462e15b441651b868c4364d35cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659488.0,458416.0,896440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272b59a2f54e5fb6267b3f72932759a84cde707aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691848.0,441856.0,887360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22742f7fbb396438c90ed435eb152150ed543e41cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B759096.0,447248.0,892840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229450ae327c43694c44d95c67773aab9d821e8347%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B797184.0,352600.0,940160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ccc86e6cda786d39e9a422854a50c162797d9461%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644864.0,457800.0,854640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22681779cef6018094932aa6c3c3512b041474e8cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638416.0,402536.0,818520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7298287540d7e601efd0968cb24c160a6cf362e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B751920.0,364216.0,930960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aaa8a7a1a4d005637447a1072503997b9a44c358%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675600.0,483824.0,967600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a72e9dc6000b6392fcc3b12f6bd829e3eaae7d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672892.0,498068.0,975800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2276403f551b2b135196d93609320e9c2804baff04%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711128.0,366584.0,1028840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fdf7ac45ad33ed2ed97a0888df7d924ccb0f3943%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B829304.0,335752.0,936760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2284dc481081ce48900de1deb802fb0cec1e8a7172%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719696.0,382480.0,907640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228d80e6f704ac73ff58f580d99207170759e083e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630584.0,406476.0,821120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223dcee803c57af943ff0a9ab397a1c4eceff34457%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B755608.0,362576.0,935880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256703d7f3349b69ff22052437575dd201bf006e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705936.0,368504.0,994280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e4ad97f44ed11da959e8680e82e5e859f3bc4e6c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638368.0,461976.0,886800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c53fd528edb5470ca0b57e917dddc8ee2c3a21cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603312.0,527240.0,898600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206600501ffbc6df0e273b98ca519058accf72cd8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673080.0,463712.0,945400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a57705821664eefe7191d46e5e5bb7d61864c2fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691144.0,460944.0,912920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22697ecb28be5c9bb79e87615d03086f96abe8c5ce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657904.0,414432.0,889680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227ef4ed126504519ba5f0165510ebe7f8e885503%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716352.0,466568.0,902200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d94f52c66331e9cff9247bb4a7fa17087d05bea7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691248.0,399512.0,917920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7aaf384f7deb9df8ff39aa6a11362a7cc7df23f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B768328.0,433000.0,881680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2246c613da62b190aa5b1a2fcf2ca39bd62efaa09a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607944.0,391216.0,793480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8b0bbb5865f58739aff83908280021ee610a954%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B605152.0,416616.0,929800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22477866e75c9ed7abaee55fde558260e3f331d696%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677152.0,394624.0,844800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222466e1b9d6836af15c93f584a63c0cf8fb883b8e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754504.0,399216.0,957480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1ca96a0e61557bec4ee0d37cf074442202ac21b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741960.0,413320.0,845240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b81e4fb68a586cc22bed4cd26d0915b61179996b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673584.0,468400.0,957400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22edc43abbb053a501ded207e22054a546120b3283%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708456.0,456612.0,898040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b6bb73321da5d2cb63947a7297f41ec641ec2188%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689928.0,460072.0,887560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226737c73b75e0969be0c4788011ab18fcc06d3bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726600.0,441472.0,911920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22678a4c4836af150328a580fae254985b0e2934a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727024.0,513968.0,908240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b49dc17fe4a511b4081d8fa42da8a59cc0e7a3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B735764.0,383232.0,892960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266713662ad88c0ab655f899d14064cc7267feae7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697656.0,435408.0,923000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e974746c22369008c62ed4a60add5336f9377c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731608.0,380864.0,894560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b1f71f6529cadd1bf72a687f48d62f74466653d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744072.0,442544.0,907360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b191f60ad56e899925739b365471ccf08786d44%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721064.0,466744.0,973640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ddd3879ec4ed261e1eb7514c07512727d247e8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658400.0,449392.0,838800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f7d5d1f886191b086bcc6cdde800030b505b0eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629168.0,481424.0,871920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2230833829b9fe20c6a438841a150fd206b2de3895%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713976.0,441600.0,872640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3deb71749a57aab7e045180a50398237d9579eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685632.0,435520.0,910600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221a76a89b2a97e396c3068eacccf2708fcd6bcff3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675272.0,499824.0,977640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2222495c3f8746638b1b62fd291a717324b5764c45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608032.0,464992.0,869760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc3c11d8c426dc2bc8f7aac229a796086d9da5d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714504.0,482592.0,845880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1b49efc687db73bff31d05b50771aec95863233%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700592.0,383144.0,951680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f659652ff6459234bc8a2f02a6b2be55a05e6079%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B593136.0,423760.0,909960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249ced42cffca2ccadb9cd55e8f9ec7fc7b4e88cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678096.0,391528.0,835640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9e49d2b1468ef3cc8d0a45b4d7b74280dd3be8d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760352.0,360096.0,921320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e3b50663e47503c6eaf1f21298fe03a6634a8a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673608.0,505884.0,977880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22007d17b422dfde33cf6eaa010eb8265c2b512db4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739848.0,425936.0,960880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22392d32d7075b2a26e34adb1aaff4692555659153%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726096.0,367176.0,1030320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c181e3fe5403a4b5a04830d31cadc528a72391ce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709984.0,430192.0,879080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa8699ef0486879ce6a7795152bb112944a2784c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720860.0,478460.0,903320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d32193f6d9553aab2119b9425adb91f85825f521%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698640.0,385404.0,946640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b4af599d43c9bbbef7e31bfff035afd5049153d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699648.0,386368.0,947320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ec163036b47aab3c014e6ea6f45b9209da98e56%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709224.0,452624.0,875920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22241ba073be3323d435fe36edcb088114a590b548%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624896.0,415328.0,909200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228398650f928bfe6286c5e77fab05c97bad55f668%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666832.0,406144.0,977520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e171d4785e6af9acb279e055cff208acac7dc9e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717584.0,484984.0,992040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3913af5d86d03ebee40beb3add56f275d0e9e86%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611912.0,362080.0,891240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a43ea291b5b512542e8d09b75e163904996efe81%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670544.0,451760.0,871320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c99d0b72068477c2a35b0a4a4488c508700408a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700288.0,383200.0,951640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b42f6489776dce543c47a97ebe25f68b48a802c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618192.0,413776.0,921160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22163ad175a0080fa7ace027ae098cf9a33a9f3191%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639856.0,466664.0,936240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da50cd39da600627515edce8002ef9b919556a4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666624.0,406944.0,977440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f9664153def25682c2ea40385c6b85dbac09e3b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681944.0,394824.0,1049400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22715b9b8ac49ccb379426c4a842ca53adeb4024be%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666504.0,400768.0,1001240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d79801db448ef5110cd633b3b28b9bfc45487577%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673472.0,448096.0,891080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258a04928a8f09729f0d13be92f82327c22b369e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714480.0,422464.0,872640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6872117448eda81fa78c6217b903ab00a991743%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B602992.0,399224.0,813560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fdfb25ccec5bbce25d4e95857a99f46ac10d1bc0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643776.0,407488.0,827640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200917c5ad42690fdd499c4d650e526ddca1c946a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666036.0,445732.0,929400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2248a840b0a0b6cb266620e49866c2a2f57eff1161%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675480.0,448880.0,874320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd0145724046d26775cba841052f64b101e7b652%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632680.0,466312.0,934920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22135a6a08b29c81d6846f502cee9cd001f5400365%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696848.0,389040.0,934200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f55d021cf3412206aede6fdc06cb8a171ecdc87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715408.0,445544.0,995800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6045b9fb161211432c86d0df2f392ebe7f0beee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683912.0,397960.0,1042320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c11758b9b0369bbc398d356b46a648440654136b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655304.0,463968.0,884480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221dcc5314868627ebd62fb0e048d0eab6e76214a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677520.0,409520.0,850200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4445579f818e9393b6839c8ca0717003bba1148%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673192.0,428536.0,874400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dca9143aee0db389683533293d761e8a35ea9854%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647760.0,408752.0,831720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c674d55786342c6cd835540ae4f6f714f117b77%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B590748.0,421092.0,944280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217d76f4501070346e5ea426f4ebe04554b252c51%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667608.0,366056.0,783080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff730dbf4cacc2366d863406d23a60f5b79a740c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705960.0,453672.0,887920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dcfde30f573e0b57b1baafcbf6c52e56345f758d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621508.0,460056.0,874240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e64b4826c877a01f42fc161f997087608401b69%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B798656.0,353120.0,939640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c5a634f5930023de3237a1961323d7963539e8ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651368.0,410200.0,838240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277edefe0ce26ba3f5bd54c7229084947d71b4f8e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600072.0,467496.0,863320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c68ff7765fef2dc9739a0e663151bacca21495d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704320.0,452080.0,892560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210caca434e0caa715097a31228d101a5fb2ebfaf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632040.0,478304.0,873320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242a784e270caaa5eb6e7df74be7a9ba852e6ee3b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674016.0,465544.0,954880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249b114633776c2bcd6605d0ffbf764c6c709d5de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671880.0,445256.0,934720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0a39e0f1eb1f04d6ba0d37a5ee2162e6405112d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721112.0,450360.0,844280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203468ca8e8266d65f3d64795105ced2031c45e50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725240.0,453496.0,829880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200c0cfa32b87da2d1cb772896e47d4b2f8a472c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703112.0,372816.0,985240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22258afbd54427c8fbca12ae486b78480caecd96ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724100.0,439684.0,890560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247923937b8b01760c6aa331f2a3c750119824ea9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609192.0,369404.0,978280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a85a0f13247864cd9f9f5694b7f792b1b8a2936%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716936.0,448264.0,853040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e44f314dca1171effb2ad7274afe9908648d6895%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731968.0,383280.0,893120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22919a2b30f548371c5dc8513135d48b1b658071c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705512.0,453096.0,889040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dfafc9757e83fe43ad29a846b2e4371b246497bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749608.0,397048.0,953840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c9881c54d7e38e735af2495ecda65a625ac8320d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B798136.0,351656.0,939200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee23e83d7ab34f1500627da29f3d605321fc53a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642240.0,405696.0,892000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f32367279becbb7ab799d53ed34c5a33cc16a34e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B780384.0,355160.0,938280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a55952d483fba27e9226e6e5ec2a413c0de77c17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615196.0,435920.0,766520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224661b889ded948b9d4c4d6f36517747a06c927c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674672.0,375568.0,809240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb18fabe79d44ff4a3a298e673987bdf23d7c931%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B593316.0,473972.0,858520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c69ae3a9d9a89a564c2ba5cd14d90d96d3910aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725088.0,453120.0,827960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e4ae16c0dd47543f128b780cb174db6c25f2b26%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711144.0,435720.0,958440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d90a5edf119dcf5c628541bd38d91549bdbf2373%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B780560.0,356088.0,964800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f9fcac86111ab8029f42c6fc66677fea28aaaa2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B735560.0,373000.0,917440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22babc32a4a3fe5ef3c3f48af67e2356d00b578a1a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646320.0,390408.0,917920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa17ff951d473555a19eeba34bbeb74b853f5a8e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717208.0,439688.0,867240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f790ff677fd47b3186a079c7f570d5570b811a5e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701728.0,442832.0,884080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9855308538720f0031c6ac71dfab657c06516c2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724040.0,454168.0,837080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fb7d33d8b238bc5303907a4e5c8473e284ca7b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657104.0,415352.0,943440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c9b742ecd4877c91276aa1a4928ff02225eb8d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742168.0,395808.0,950200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d4e63dbaed2a967c42df292856fd4be22882e71e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688448.0,476288.0,965400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d114203c7d0802519d42490edabd0cb2c9de40ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645048.0,456608.0,852080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c5d353cb30aa9ee19ca8351e754d039ecaf87493%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687696.0,473528.0,875640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22452fdaacdea611e4e03e385317fb18d61cbdf9db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690264.0,439984.0,895320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9fb96f4afdfffb3b8582d5934533d3a0c353ee9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688952.0,461824.0,945680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226542c21f5f2169e63e5d63536dd6bae5925c26a1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702800.0,443104.0,883560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279ca7c94f1ac94ab1897ac690ec9e8084a3d97a5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700112.0,451008.0,897160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22843144a000b3f3e0d85260f25fc0271c7c523d5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672360.0,441032.0,929200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fcbef91bf69d2fe143f5f584154c7dd37afee83d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676240.0,398840.0,1017080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22193b950308ad3bd6f20fbf39652b2bf0efa20a93%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665464.0,460432.0,862080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226ac7f474415580830ce3d0f6ecf7411867647465%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B582080.0,387560.0,812880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2259b6ed9d7323381d4dedd277a9071d35b71b52f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624056.0,416520.0,911440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220af7d02c82e4ded619e9fc4eea5beff0b1ba9291%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738584.0,442108.0,911440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260be69fdf9cdfa94ef2350202af3ef7ef2b6b800%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639424.0,388448.0,922800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0dd04261e326157f5cf12b1d8c2b31a0efdfab7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675088.0,482576.0,967360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc1e638f8fe9861ae04f8ecdcf219597a2cc355b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706716.0,442708.0,934680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b9a5f9d4ce08a62d9df46bbddd7bfc91446ccfa9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692424.0,438896.0,912360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac8b02f30ba6710ec59a6f73f8ec676a5a900f71%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708000.0,441200.0,933560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223872af4bc5a675f263c0be27178cccb363baac22%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673344.0,427872.0,921600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f87b330a24a708067d4cacf14e66515e634efd52%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743136.0,415120.0,837440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f848c5ba8b8d11c9dde118bef048081ef6cf635%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674464.0,399440.0,1018600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2252eb32ab2199d37d449200ad19ba9a8ce47f2efe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B593400.0,414088.0,921480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3825b3ea10174a710d4b95184bf9a03a0491c1b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670468.0,483456.0,887920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3b7d7e7a9c96d6d9a2cb41dd2475d23c48d18f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653368.0,452360.0,915080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202e2335105054a5fd7b361eed927d93734f559fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682568.0,453304.0,925960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e1086a04091e82ad738a44885678f6900d89f18f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653608.0,465064.0,945360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227b35c9a3011a755f021a4933cce90d7f9564aca7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604432.0,525664.0,898160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a64bf73363fd5c317d4833f68761e7e9f9d1b2b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736568.0,467368.0,822360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f8ffdab016e1e235f93a788e350b05622d41904%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604472.0,415120.0,915720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3200f95973d484ac2cbd0b874abd494a61a864e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741496.0,469696.0,813520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2288855b28d24a59fcba7564327006f3efe3e7859c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767488.0,400064.0,962720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226138b1827c0340ff15a86a20fb4b85b2ee4f4120%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B591996.0,411648.0,923800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c716885eea952b39f42fdc150b0a195ec19c4e7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617728.0,394880.0,801680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254fa369fe1b93f7280f688886fbb57d8127928f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636424.0,472784.0,947480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224854e6ec554b3051130e219cfa78c62da9911a71%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649392.0,452304.0,915320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2236e6d836476dfb2e58103cdb211ad7b8f4fa8bab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679016.0,390808.0,832720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d72e45c7819107e612edd14e0b9e6dec8d6b3ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742384.0,369252.0,922400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c5d508d54658bfbacbc45bb2d3612d9c24b267de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688272.0,433956.0,901400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224142fff2d1573c682147b6b34e3f6f95fe8c780b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627264.0,408296.0,816320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2215dc8c9c57f47703c6ad41f22aa1527edc14cbf3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613320.0,367824.0,985920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22162c1b7fcb7f0d12f968ddda4ac35f020fe97bae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613640.0,418648.0,910840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228fdfa26c4f43bc959f12edb94ada4b30970c00cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628716.0,395040.0,895640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5d900f00eab00b59f033fbe3adaad56d08a89d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688264.0,470728.0,878000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3e2c2bcc414cbd983b559f66883561f1107ef5b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672216.0,397400.0,1007960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b02f2840dc642db566e6e69210ea19ad868f36cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707560.0,399384.0,842400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c6590982253513122d7702b0e81bfc2340675afa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716704.0,444736.0,857200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a2753971d6f2b677d3c9ff6310bc5ab4b41f020%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696384.0,387016.0,939080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fab5b77611773cefef7c268dbb3561401c85a2b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674080.0,412648.0,878120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2284d81f89e5459f0b92b87c22e4f7ee0d0b74662e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738552.0,398528.0,948320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d9daa7c9f21965c44cd00604ad3f413ad64acd0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677464.0,418368.0,893920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22825c5e315ac109df6009f331646815bb321af065%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692572.0,472000.0,957440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1d10531cda8dadb1352b590f8270cb7ae8a9c7c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716336.0,445056.0,860360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d25bd005ac67256c11e9d1dba55f875b1545d20b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659848.0,446384.0,906600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b24c98b72f3b6b9ab726b71d37963760129cbbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652776.0,419232.0,850440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e881f664e62aac35146663416076073d0722a0a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718720.0,445832.0,868320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2289a8bee2ce757eb99d40fc475b46b8e580808c14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677824.0,520920.0,985720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c93c765a3c10aa5ab88b4c709e4204a9286c130%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708984.0,433000.0,946160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f2bf56a69f9159812444136c4fdc73f6052ad1bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707480.0,437856.0,921320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242b5179311fd51177fe29fff688591ab8721734f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630616.0,391488.0,962440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e282b0b213954cd108f6dfa4719b177a0e3ce377%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667840.0,404280.0,977920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221a68edfe495498bc36b1ae329c91798b62b7ae9f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658208.0,422912.0,921920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22826afea66fea1d4cd34294e00da1dfdcbb6e7f8e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691344.0,392536.0,982480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295e4dd83f972d848e02eb8bffb31c3b23f6d3af9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721784.0,452256.0,840600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e5d6d0c80b0af6ae13914f4396e70121423c976b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641528.0,412800.0,906280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205b7faf45933d5c50955f84595c30d137a8f73eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690984.0,457424.0,888320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2251eb935e50da1c47629ce6864d72293d4d802cd7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685752.0,480752.0,985800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22212a8e7deb4e745810b2dc6433406b27ec36fcb9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683296.0,398680.0,1045360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dee58be7da4142cad8926bbc746991dab715ee5f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671312.0,454512.0,940400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247df157ebcd410e40c783ae738546c5584a08e9c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777144.0,355208.0,940720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22197f6230d48c60b6efec3fa948da242954ac93ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675348.0,429168.0,873320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c22841e401b25cb5c41de50051a8f7ac8f55f6ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B610840.0,403296.0,814480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da3cce8c33f0db8362efc14ccd306f1e131bdec1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728712.0,392424.0,940880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211e01de1e9c7d280d00ac376c312e3e2a64aefcc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607832.0,523152.0,898880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa9ac493bd58abf95690955b5588dcd2b0f78d09%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667320.0,470312.0,894200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b3b3286cdae773f4122e9526e8b605fdb38c6b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739772.0,384916.0,890200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b6d46132501610f4528f8fb3f7052c1ca3a703d3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606128.0,390368.0,789360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7435439b8d37511a5ce173e46b680ebdc3b005c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731472.0,354864.0,1055720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ab8078f848d41440a0f1c695dc96ae5b926e95c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705616.0,365208.0,1032160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a539c0d907a97cfd6b0be03181a354f89aafa79%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666712.0,402800.0,993200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad8c8c73f048cb922307311cecb92e80fe719b8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706864.0,441104.0,928800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22075dd8dd043b378fe2da1ddfacf2cb6276dd8508%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682288.0,408008.0,844840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225106e4dfb59a416b7bd66dea8b0522bc97590b71%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700392.0,434120.0,932440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226f04f703c53c8a13b6bae5363170739982f13bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729856.0,460032.0,809120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295a5efb83d4058f13fee0a6391beb49c97c7b53a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728632.0,459568.0,809520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c9d05fe650cc4631411e8053f3ab5ed0ebf43a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716244.0,445116.0,1001600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240f81f138d2514897ab6d11a8ee56db6fdc08f72%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711824.0,356768.0,913720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22322c68ed8355396bfa2e5a6a673372adec9e93a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671200.0,424852.0,926800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7a55cd61647af95f62b4f5ce1646e463572d834%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B593864.0,471408.0,859200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221f21efbd66a70c1372bdaafced504ab52cd5ccbb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706400.0,400560.0,848520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c4a4a8bab4844cbcea392b15c7abfba0b1a57c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654872.0,419880.0,855560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae550f203d9ef0b1e0c07d7a25b8e47ccd988c13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720688.0,445272.0,869200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200806a7f5a2c7a6ab8297b01baca90b2af207eaf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767664.0,450424.0,885480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226ad449154d7f092df85541e98464ba8ff1e4da83%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732896.0,466456.0,802000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b1a8f8dfcd8fda108a7c82f653f750d6b8b7fdf9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B564792.0,353232.0,985760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2224d5f716493a1ec5ff77a185e3477a24e732346a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616152.0,423336.0,782160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4982dc50146852d2a8623d3c0d828b70b2c4f35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718776.0,420632.0,870280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e2ba0f30ac4413883b41078851e2011d765789c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647292.0,452920.0,914320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab99e27b12b2de81b8a17819737e6a1b34d91ca5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665480.0,377048.0,1097360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b92c2abdd80d9f0af54f0c8aef1f83ba7efa6a0d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705228.0,399660.0,841240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222f17477e948a385ce5fade1f5822311140a4ba27%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677552.0,432664.0,917920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223a0ef71f336e0733b51d7cab2ed95141011a5f6e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B786720.0,353184.0,940160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229005504cfa4026b35df0c70dcf7447ed50fd6145%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638136.0,461248.0,884880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22065e27bb9621e19018a31e44d0c8cabed377dc8c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684552.0,483160.0,872120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225655f9cee88b32d2e3596ef695dd927af3bcb15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718808.0,471256.0,902440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f34679024ed806eee308028b9961b2f526fb3b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647880.0,415104.0,840240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fcfc0f513ba03f6897c7fff645240c72d187973%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674000.0,444760.0,933480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2251e9133635f326c6a51fae19313550c955b44890%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733712.0,464688.0,803360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2269d5281d08389e99f9108ec24c2dfa6f4d701129%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621936.0,513368.0,899120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292562952055ec12791ad3577d28ef1f8ec7cb8fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727976.0,415880.0,859760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b111ffef0e097f114b6d661074787811bce7569%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626240.0,470144.0,938080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231cd036ca166b5c15320baffd72b47ea8221014c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684600.0,446820.0,908720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3c707d70e95b706bde0211be0ba9aaa3825604d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694616.0,389504.0,933440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e59f1614063c982bca87ff9b4cca0992ada2ae1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B550736.0,349784.0,989240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c16eef39c7ec8b369e61e4fcc086c04170adfd9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661268.0,399672.0,914640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cbb41a2a0771186359c8f45065602ab515248f38%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611856.0,462680.0,870320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e045d080fe935a167d95dfaf7ce32adacb032cf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660720.0,410024.0,854440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22380b6eb57db5f585cd7a6334bd9ab724ddb6b7f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636600.0,474544.0,947000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a80db8dc55120f9813f76c339fec2246e606fdb5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676816.0,391376.0,1060720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e976ff39530a5cacc41cb947f069da378d886425%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621056.0,472816.0,939560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb2baa800394ac4af8725e7ce804f308103f62d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710072.0,394536.0,869040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223590b835756f2af45462be4e5b6ccf470ae641bd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B775304.0,356264.0,939880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22635b002dcc1a1d47833e870d9379a23cbed808b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670120.0,428888.0,871520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22968135a4d7ae6244b5646b1b3242cad20ed9c09d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B813216.0,342432.0,935360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2264d5e163f41026fa7f2729f02c8b1e40903c8b0f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701600.0,450352.0,894440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22350eded759ba2e3f0224106c6733664089e68fa6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703864.0,433864.0,883640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ef7629e7b6183e732afb54c00fd3bdb26d0c961%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669104.0,406856.0,950800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226345ad0ad0ffa7be62f88feb09538d0c4420892a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672136.0,402592.0,855400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a9a2f2663d5e7071b153778d688876c41498d161%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640704.0,400248.0,821960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220133bc7730aae88f61435973658ccb4a7d683eb4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B590608.0,420888.0,944000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223749c715c4c57d2f116b3334422bc00d5dcd2c69%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678792.0,396288.0,969040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254d9cd67fcda8294e359787ac0fe3754fe19fae4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B785632.0,452520.0,878800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265000a2f216138b3080519577b5dd85456753005%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638040.0,422616.0,911560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dcdfd420f3e60b961c505058e07698ab0b97ed10%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B592200.0,423312.0,909920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d6974c117df80aede5c823f5b7093a9e36c9dfb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703776.0,374432.0,977440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2291b6224472497dc9a28e2e0e584239b12b916af2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726184.0,527780.0,908040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206ae68f769269b22024626d3eeeff99cfe1b2d52%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B605912.0,390576.0,790160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221831e29e56c9943ae4c689f7b65700541d1732ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644648.0,404360.0,892040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb00034f5fc177690c533521632040eac1758c27%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690544.0,464152.0,945600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2243c9c81db5e3c07e6e2bafcaddc038a261e3ca53%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636480.0,443800.0,819400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22484151a6d07da4b8164ea9f0ebe907ce44b88c99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653224.0,449584.0,911880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258d9db28fbd66a8be3c5e15a580f9be885de0b44%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677592.0,391840.0,1059360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7cc29da8675127274ab1609e3fad3948b3a8fe7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687848.0,438192.0,900480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b122e47e063c3e410cc0cb74b158ac76e74f2a9a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701632.0,403552.0,886800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8d8e3a9a62ceebf7da99359208fe4080bd2a2e1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B781872.0,454296.0,881440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2245848a0df0947dcea0d0c105cb6120eacf51db2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717776.0,448672.0,851960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22402b6d8f345c7d9141c34f942dac6236c04dd23a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627976.0,398992.0,893880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c43ecbecf48d3330d33c6fc35980cdffad57be6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B772016.0,433656.0,880640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2228f0c00ac2a4bf6503da842a15d9f6de722b42e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707848.0,399928.0,876600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e37eaf74e37c1c30c789eb0d7f9c2b64c784e2f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614672.0,368296.0,989040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b2bbc4e4fbbac33a23c1bbcdf74fceb465c49926%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715908.0,443700.0,990240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22003d673e51b19223ce57380eef38421ff66d2f43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719136.0,475696.0,984520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22800a04482ffda79bd148acd45eb7790adcbb60b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658592.0,447992.0,837240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22838b4ca5c148c645d99290da50ed07dcefdd92a8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663992.0,400656.0,997440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dd8020d2824f5e94633ae14c0d462d97eca7c563%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744328.0,443840.0,901920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3b15aafc3cd29d83505191fae32c4ac8c106156%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727392.0,515976.0,907640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f55b47cecd9ee8be4e686a6cc22f312f35f13e59%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647384.0,405784.0,891080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f3c4e7486742ee6584aee0752a57839a9e848e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B804624.0,338208.0,994360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22827a452212747176314fd29238f767543e83b38e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725864.0,379920.0,912520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2280117bcfff1c0d41c66738b0d640afc2edb239cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670616.0,404688.0,907880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2294bc8aa604c53cf74e62a531a1f752bd93498a9e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649864.0,419608.0,915840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad3fc6bf4d5dd7f3c837768a83c5aaf7aa1a6458%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619176.0,414256.0,799400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c5e494255d03cc4d491bace29338ab3365dcbe5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630696.0,414888.0,907400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221790961a9f0443c9bbd0c694e5dc915541896299%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B805352.0,459440.0,880040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221a3f8ca432b7e97ba48655e71f7b25eb1024e4ac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704728.0,443488.0,881720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d152d091ab0228fe92466881e1e656dffa46644%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622552.0,406064.0,821560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222516baf8c430f5734db87f72ab04a7f809541a0a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678408.0,381656.0,821000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22657c7e31175937176a5cdd20b4364924eaffc85d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B768840.0,360192.0,953320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fdd58025eb7b04358f1244103263fc33a2b6fbfe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710988.0,455600.0,871160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ebcbbf4b78d36063a91def05ecb423af196ebd1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734092.0,466844.0,829720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa0a13847f6e33e5deedea167afcc58618a834f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632384.0,472848.0,874320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231bbb97ade8af6aca2c787d28eaa1485a6153456%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711904.0,487584.0,840760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ced7fbeaf9d3c14ab21ad756a0017ad55dccc62%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712536.0,462128.0,899800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e1a4e6093527a98aa03e6def513e0d8add41f64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677232.0,510976.0,982120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228bf369c4991d7dfa3e73283b16bba75172339572%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720096.0,462608.0,972440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af5f218fff1a6fda2098b1e264151c15ba9b9769%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699128.0,437344.0,886640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb51ec687332059149b2d964a797774597d6cd49%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714432.0,438816.0,962120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3dc802588c95a0649a9b1b3f7f185b01ae985d0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670768.0,406184.0,860720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2d95e002b6c2eb78a9814255e5ba2f9cf3037de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713480.0,443744.0,943200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e856804f27d8ad6f46d8815a87978a22e2f2a5e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656296.0,470400.0,905680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e8bd3e6f518a40c3cfb2dc18dc6a5878d540fb5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B573192.0,392024.0,815120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224c8c9a8f4485154b73dc3e842443f08f47e88e21%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648888.0,412272.0,906240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224021dd1f6c0900c54edcec5babb50181a8ccf361%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632064.0,399944.0,893720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22620123652fd73cef7fdc95bdfa6ec483eacf6274%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721392.0,383736.0,909960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eaf729cfca5f4ace097bef90f4ac236c695eedac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736008.0,424464.0,954360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229975d2524208f640523f4454bc6c6cc06ffa6455%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636008.0,465368.0,932960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220714cde1d18f416b6807b993982845d9b4b4bbc0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706504.0,489280.0,837560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e028e9bdb76bce4b1c13cdaf7ea2bea5257a91b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650208.0,416784.0,843800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229427fe3551ed6d0efcdd1fd075bb3f5ba6411441%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664304.0,400488.0,912440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202c6d1a8eb48422553a7c635c88d1d65f599948b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683304.0,455228.0,931120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fdb0a8cb47e192c278cbf45e3d9670deb56c4624%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762960.0,355072.0,914640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222eaab72437b6ad0aa0151ffdc5b6dc2a1edf9d4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713456.0,468192.0,858720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225630ada5766bb28a50ca1c40948a086686dc5022%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704528.0,373152.0,979640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c820f8e5626d6037c60cb1943bc3ae87731ef89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728120.0,456016.0,851000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b30536b1c54c76b2d5f6ea3ab08033d35a0a53e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B583488.0,391256.0,816240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8bf3c99c9496acf23ca31e567fb13b3a8f00278%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748800.0,443352.0,901480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b74064e8c6196f1d3a241e9b26c3c2e1b36de45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720824.0,453360.0,844280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc609779c522b55aa4d39682540749eef29004d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667264.0,377056.0,1095240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228bf4615d288abb80f89c1876225ef08ea3f0398b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717288.0,441120.0,888160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3cffc2a2e7252326518f1c9051122809b6288b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B578416.0,377376.0,811680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b1eedc6927f7ab2d0fb5ce06331b0b8d2875e7b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715560.0,477016.0,850280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a359ded0b03eced111b76c6cb3b9befecd75f11%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698528.0,357720.0,1053400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b2b82e477616de37de5bc1632950a8185759c024%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665068.0,442184.0,853000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ba12275c9d4410105cab12d67fe64425b3dfec3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667240.0,527472.0,864680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22df578e0d6c2869e9ce135d34fcc60f136fc7706e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754504.0,398520.0,955560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fda399fe570517822abde24dbd02da976ebbc8ce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679408.0,402720.0,899080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273f949d6af0471232d49891e67e872deb8d07739%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B596840.0,419944.0,939840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c34b01de3b8cff5c868549156f25ebfeaec1cabb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671672.0,378104.0,1087600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6f1cd4041337ebae426e5463aa108aca1b0837f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713312.0,384928.0,902240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224252686335f0600851d399a838caed3cc6be50e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668912.0,411176.0,946240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22debce57d21b3817570ea99db4969708fffaaa15b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630784.0,479368.0,872880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2284333cc2a4fb6dd1d675b304181c8f87a2d7ed90%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636296.0,409400.0,826080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aabb84745d34bcc51cbb62fdc997c1845677d5ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715768.0,478304.0,849080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f6367cc01415b2aef9ca05125daf9a0d8a4c5426%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692848.0,473664.0,958880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f07fcd19dff42a00bc69ca056ed7ba3a37357986%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B605536.0,465272.0,867480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f99e2e7aa6836c9a9f1de1328204a058f20a2e4e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665424.0,465728.0,895640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278c2da1938c095c6b5f5044adb91dd4ae68dd3c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652272.0,420616.0,849480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22539c16dbd0cda25388deb7d8dd06cfdb3a12d152%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617440.0,372536.0,976880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271b654a5ec084c2c83b6903338cd81ff352518ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718216.0,492332.0,1003040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22007b127fc9c642d8035e2f6f29db11d8626c18fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721768.0,453128.0,844960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c34d89a33e6ae47cc860fe67eb9715d25a6691c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623848.0,483688.0,871960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cefe120fd588e37d31671f947eb072e3421be14c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665008.0,399472.0,997040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228bdcfe791a47229761936306d38ea6aa8ad13708%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733552.0,394704.0,942920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d098b95a231d02c653f6310bc31073c982776594%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679560.0,500992.0,868000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290ef579e3c831a11ae54540787b44776d2d9836e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653072.0,395256.0,916240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b2ee7a5e69ab94ccece0251a6bafc7e33081ed7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678848.0,380824.0,1076000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225333e4441097ec06c3bf86bdc9cd3586c4c0432f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691112.0,402000.0,900520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22298c87d15d975097f871ef9a46ea13463eaa0041%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721736.0,472352.0,979440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22829be31fd5838180aa0ca5a9dd57e66f1e06b1c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B590872.0,393736.0,815280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b10ab4e5ec8c233d8613a62b57c847b6fc624ab8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630992.0,419696.0,913080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a22c9bd91d1b18893ac9e0f2486a7855d8c429f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715512.0,463368.0,863160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223afee3b57eecce38c9204613a3bee51ac39a9142%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718104.0,391760.0,934080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a98e62b5939f7b97eea9e331d43c9c8f8171d0c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B788756.0,352076.0,979120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227cb51312e1ce6e0882089e60a4f6cda39c1df98b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622920.0,384384.0,893320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22383f72e44a204a696ff8736085e4a33bca2bfcfe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669864.0,446144.0,896480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220884ad3cbc3fa8f5c194cdd7324f0d33a087f021%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669208.0,408072.0,948120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292bb8b63bf370d3b8071c187257f4a8dd4846443%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707360.0,395888.0,856000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe2b1db86626a71f0b1f9dbadfc447064dae5ca8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670176.0,441744.0,926720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f9b2d4b1bd6dd3f54d9825a521aeef028e3dcd77%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B788960.0,351896.0,976160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22744513eed0b657ef135e6a73225ecd784d016ec4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652304.0,413080.0,945800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22820b4ea59785789b32fb97e7f331ad0f6afd3338%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654040.0,413400.0,944360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22126e54f78fdedf7b083335e3b76c32a8c8f0b947%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675872.0,408856.0,857800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2268b55f7f200af13fecf35cb438ed4ee3ef72cbeb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674400.0,444104.0,873320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22403dc186fdcbaf7e08e729fa4882efd6778efc1f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700824.0,377664.0,966400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e461c410ef40e4428f1d6bec935ae7cd95d7fc35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732760.0,373504.0,916280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220be6b7a3552e1aa8a8aea36c951772fa9f83b504%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715768.0,443584.0,985440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2251a47785ed83446cc8fccb59e6cd546e26b09478%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715320.0,463624.0,899520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2261e577ee7a236523d1b5b76b003fcdc2dc8a74cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636584.0,399352.0,957600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225357b68b30e104e463000de1dc19e1c587cd396e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630288.0,416824.0,913720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b33b18f1f99c022d50773fb371f3de7a1f2da77%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688760.0,477016.0,966960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ab1605b02627e305206eeed5456691d9c7b78c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B801672.0,339720.0,988720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b148891d5708a9d303fc5b7a9cde48dfc3ae66c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618072.0,421960.0,784240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0ead70f83b51b867773ea32ce993cb62c6bc240%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672800.0,444256.0,896840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3993a349744d6eb7c5a5a0a1f39f1880281262d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716544.0,458944.0,962920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ec679e796b6fbd77f828eb241d9ae81bb290c375%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669096.0,418040.0,889000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22edf8d7a2db2fc44f2cc6fcaf2bf59e65844f6328%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640548.0,458964.0,918360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221f9c9a5e8feb05db898f7ca5db08bf4ee96c39e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677720.0,517136.0,986480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205ca21181eb7d7daec95aeec30946e326c1e73b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762968.0,360768.0,922800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221414c66cb135df349fa14b94d60d470e69b1457c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727952.0,377536.0,913040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2abb7f0c19c478785a2b44a03232fef92044dbe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712688.0,441080.0,873360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c4510df2b606022ca9705d24079e1701272bcb2f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615800.0,433864.0,772920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22570ee6c03920496c445aeb3ab61325e376739661%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706832.0,438840.0,925080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224649c5617332a4dd24ab57f980095d1054caac64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660920.0,450544.0,864080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d4e17be930bcea4d8531a1c67b4413332b01b78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671548.0,451624.0,910120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295a4cc13ea8bba6aea7ba3111eab1fa57e6b5ca1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709184.0,367324.0,1000480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d0f0964e58753b387cfd9d372c0ccd817d656b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661552.0,411792.0,855120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22308026d32ef013e761384443f9a8fbffe60ba54b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770816.0,356368.0,940160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7269a2417fb5b4219a763ea66b4aa1684a60779%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674064.0,514224.0,867960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22894de653a77f2f6d04b571f4572355b7fcd62dbb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689536.0,461088.0,886600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3b384a3d86079475ffbb5d48c77424711b910b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676480.0,379304.0,816360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274e8cdb6ca9649311e35f2be5ac5049e773f6943%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672368.0,411992.0,871800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f25d79e1425624b7f9f4b0fc15a7431fde672f85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644672.0,472912.0,877640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22295883f0e822525cf194fc82c447081c406e634c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763840.0,448416.0,886800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240e17b3e41d50af4ea71b8df60f12275eb94fa36%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700848.0,378728.0,901600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a0e4be17d2689d8e66bbdc770aac1fd7b2d5e63%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677680.0,407952.0,898000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22097b3a8ba325eaf1d5345349ebc04967ea8c1d58%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716000.0,468944.0,899400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc98b3fe8164c86c3b5602f806b56ee28eec653a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639908.0,465448.0,934680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225fcac08fd1c5a361e6ed77df2b7edcfc2f980014%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689824.0,465608.0,947480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f95edbe86bd610c0357de1174ca8558d2009c34a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B814904.0,342540.0,935880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22532a72798b5ad22c5e6419dd8a1af83337f08654%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647216.0,458096.0,892240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd962d74e7abea4c92af67c3e44c09946e47693e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655472.0,449144.0,833960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22153944620e4247cd2d44a6708bd42970e5ec700c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682200.0,488688.0,870680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e17e5a650577d47c013c486289a457ae89bf805%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619856.0,371584.0,894680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2289f926cd85a04ec857e4b232fca1ea1b57764c76%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673388.0,496996.0,976400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6af883a5e51c65b83b657c9dd8c3dc94d0ec5c2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674648.0,508264.0,867760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2a94337f3e1ad3427d129455809e0ab2714af85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617680.0,415584.0,799880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22885da611c4e91ed4ce86da706f0846b8759e8435%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609152.0,403536.0,813400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2250aa1a2316b9ae5db3f53128c1675737c99f160c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669000.0,408712.0,947520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f21f5be2ddc4b5d6af10bbc3189619c8740d1af%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B584084.0,473916.0,852920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7997f0ece39561dfc500d9f809cfbad6a038be0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646288.0,470144.0,880360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d439f493f42ed1976c0253099cc8a3783f75d92%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631000.0,439776.0,810120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da4c8ea5b129413f9233864a661dd9f918615ecf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671904.0,429136.0,870960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2228d54c09b06857ce1eb8a8130cf94a674318b485%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B805752.0,336888.0,997000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eaa2002329a80028e24d17cafaaadcbad9abc497%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676016.0,507152.0,866440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee10d5abe6ba6d05489e692f6e070c9c5af444ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737376.0,411512.0,850040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ecbcb4957401f2ada4eb0c37c1b46ee9419219fb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625928.0,392032.0,893280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3a9ebc5d61804762903f45534e05ff1530bb3ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688768.0,464248.0,883640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b961050a68e6ea8bbe51d451bd35f4d6cdb9c960%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658448.0,413272.0,942120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3a66a6acd979dd113a55bc5b8b1817d3d2d237f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736288.0,371184.0,919240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd1164223c3eac2d1041e43583f30709ad5f2be0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696260.0,396092.0,923120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2268f9a08532b5b9d74fc1ebc98a51d7320d49e96d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633776.0,475352.0,875720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c25a8abd972267d32a33b4b787184116c7d38e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723200.0,441456.0,891200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e8d7190af7ecb9543dba2dc462cadf9f63486bfa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644056.0,406184.0,827960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb5414be72dfec06de2791f204f391d0a820973a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645676.0,457396.0,891920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22737565b05f5d7de909107cc3a5a507f27b8e8764%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669936.0,411048.0,942240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225719a8732c6c01938c77479bf4ec114338c6a2bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715128.0,442984.0,981200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a23bf221070c1900b5157bb591469b87d665838e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672664.0,403448.0,853960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220498129fcb5b0c33fb70d7169880b4f14680c34e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696576.0,440320.0,887160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5b4f51766345686c94e51e94e5d7db307d33302%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674456.0,455752.0,943880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cadeb49f412457edc1b304bb721aafb8119c03f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677196.0,505472.0,867200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e634b2c7fa764eb41e3813626f93e52a931ed26%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713480.0,451208.0,954080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f8bb2daa94d1142f58a415adeafcc2fea2775da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724440.0,432432.0,956880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22710e2508b6aba3c920b8217ab3d487479267032e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606680.0,414792.0,928520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290a3bc0cb0a8c02c9dc1fda828875ccf49bdf442%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636440.0,463480.0,930120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255ea82a272edffb38548257e1baafad99dd3120e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713096.0,445152.0,942840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225153e3c5d1684f47bcf3b595c444b74bddb72877%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658512.0,396176.0,915440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b4d410b1ca588a29944ecf79f3d21161b3ff4d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706760.0,450896.0,876720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fdf71fddd58ecbabd50b87183a58d3bc8fe2bc3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645144.0,406200.0,891120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb787165534be4e932fa82a2ab95b7100165530b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674768.0,502256.0,978280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257c717c51f22c4813e4aa7e9f97640c331de8e4d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692368.0,387680.0,986280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222841277ef629f25abed5c86d8295f6f324dcb18e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657548.0,451616.0,862240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fcf5812f3c5aa7c907b04f7dce43b4bb4ddc6553%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701276.0,383868.0,954360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f66f60180a7147c99ba2ac93db080a89d1b699de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B545116.0,397604.0,809640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8ffe6c8e11ca4f167787fa8e58e35228981783e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662896.0,445072.0,905880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220d8e74619a3394a0b6ab9aa3a82a8325fa901d2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760240.0,361568.0,922560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235da9bed2ad3c6d8c34143b9afc118263f474a13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676176.0,408576.0,859920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fda1bd1e1582db409a055b5373e75e20adbc276e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685516.0,480700.0,977520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200cc9c4cc5538934e56ad137322058f2b8800aca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634384.0,441760.0,814320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2a7f0f5076635cee2ebad60b3e752c902ab942c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698696.0,387560.0,942400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221d9fbe4dcc08bc0e7e341434332b7564c5cde20%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660336.0,461416.0,913160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a871891fff1a882fda0cfb2f6e65e50e0a419c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696448.0,357752.0,1052440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2082e783be6623debf5e58c9cb0c745af8d9358%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671864.0,446040.0,895760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a9eeb33fdd79d4371654056759a63842d232b965%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B568592.0,355960.0,983040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca4cf88e3698ed73427957494aa9593a7aa78bd3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B753712.0,437384.0,882720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ec6a3db6d2d261b9e648b98e1bd582a5a1383d7a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708376.0,442596.0,937040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b48a574fde645b389ca21e6ddcac3338190ad49f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B584048.0,361096.0,979960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cd4757604f52173d3a0e6cbe84bcaa1cede761b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B751792.0,397624.0,956960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2280c329bab3ba1702380fc158bf5c7c7d5f4335d2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694720.0,397336.0,922440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aca7fdbf9734a11b7868a67ff76c661e7579d6dd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733936.0,412408.0,853480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274d3de64ca73e8e950611a5af3c1ecd3907ab7be%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685020.0,437208.0,910680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ed6a67012b159c08704c363a1340fb818d712ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B796976.0,452888.0,880400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b6c6b7d4e27ece01d59e67aec0f72b7907f6daac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677848.0,431928.0,917280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290f022f8c1ab3babbd1a417cf75ab9d72b619fbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B838424.0,329384.0,937320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22554c5eb02477bc28012ed5e2585b59585a5feb0f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B584108.0,391740.0,815560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2209caa02ef7002de98acb2980a454588f5af26aa1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669352.0,424496.0,928040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22727d6888b805a9f31a6f7d195313e088e3c4399e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697180.0,445140.0,898760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c0362fcfd9ac5c4a3565610a6bbe2d39ee20b7f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671488.0,406072.0,908720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a6d3ea339e45ed9571805d80bb2b6cef9283539%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643072.0,407536.0,952760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a4a7abbf558651d6c010c9f2b8367e8f666f929%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B830624.0,333344.0,935640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22942ae87c8526cf553061ecb2a38b476dc15ab390%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719016.0,444896.0,868640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3e65af062f0e1c29a04e1fbbbcd323544382bc9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696272.0,404304.0,891960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224631be77de49cfd55bfd77146fce3ab234a162fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680496.0,409384.0,848320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22baa492d913c86feb66d15ab754623859fc38bb7f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710300.0,445172.0,938600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227b190f883c95aa99e43f14fdd07aa6ba76597d70%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720944.0,365068.0,1014120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e9605897c59d4ac1fd1885568b625d6cde5d6ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706584.0,365984.0,911560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a954a90a62b3afc30e8ce7effab36eb3c5b5427e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721080.0,484296.0,989680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2264e4e36fe095a0738de8df9b18da20209e8af0c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B779120.0,443528.0,886240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22036c454157f707b60196b5912e94961dec69724a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690480.0,438560.0,911560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd2f392c6c75bd4f84c84d71cfd2b389e33c6110%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710008.0,431848.0,938800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22adcabc2c904ec69c74cb6e96dafc0609dd538e8d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611488.0,413976.0,925000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3c5cabf860af5558c5bcc907c0d23e40999159a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658896.0,414112.0,889640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223cd31b40325e84fb737c429402fc44210fba4a13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706192.0,441752.0,932000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8f0114c6fb2738b6a8c52d070688e5ec82af651%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604808.0,391288.0,786240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2283cd30cca0c3e06086af67ed0ca33affb6c7e94e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721760.0,382568.0,908640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d88c9c1104dce5ed9f1f51e75946d5f9f85e0312%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618384.0,420816.0,913280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f12373f1da2646e8a6ee084d999f117773f121e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659424.0,449784.0,894600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221723846ad76d105eb96ff310d583a8688ddbf576%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720008.0,470120.0,974240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255ecd9ad9a6a718e8a7a28be529bd4a261e97add%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625984.0,411136.0,809720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b1d00e3c05aa9fc5620301979007fe37b759b6b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670256.0,425168.0,928520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b516199e8c47aa3981aafe293c492cef3252c5e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684952.0,427872.0,903200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2215fb041976aa2f7a8b9f21e4cb6275d989326d6c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727160.0,486816.0,902480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22179a37910cc835cbac48f456a72d1ebcb86ed020%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724584.0,368536.0,1027200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224c851995f035c7f5086642b393f39c0ada630d6a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676384.0,418248.0,888640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2275d4bc24b8b74cfc866d93f1d324d80b40f07bcf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649360.0,410280.0,834040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c33e87a0ca1b9daab3adb373067c75f1011f100a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770560.0,361720.0,955680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf75289ec6a55b64913a65e746fc43e2b8eb2204%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724008.0,369088.0,1024080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7bd6202cdd07cc007a77188633721b257418d0d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668736.0,447336.0,866520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220dd0ac035b2ca1f695cfe0b78606f98125e0e5fa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675808.0,397744.0,964480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22adeee9427233c49bd16890b366aafcf117f54f60%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665184.0,459272.0,912440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2239b5b8f3680afaeb3010f8f9a3ceaf28598456e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743328.0,440072.0,887920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224c603d944223b15225549d211d775a56f29a5313%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690176.0,469072.0,881480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227fe7fd76a7c4528d9c7a7cfe1845c7f52524cbb1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679388.0,432836.0,914960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222cc1655bc135674d0431154a79d068d2f18a6dbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664488.0,423192.0,862920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b23945c9fcb297b9fa90283c57a4a0948c9e024b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B809396.0,345320.0,936600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1e4ecc1eadde8faced8a7c9f076d37e271f118d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659960.0,462704.0,913320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c2c07de375fc1113a25c168fc04e2afd6d08295e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732016.0,375324.0,913920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222dee2b77d0bf9af2c543a529c1c228fb90bd8ca9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699568.0,384552.0,948600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee5bc96535465873c304bac561d4d970b908b1ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595360.0,472476.0,860160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223a849a32ce7058ff45039792f6fdc47ffb56186d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604816.0,392152.0,784800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea2083d5dd71e28ee636b6f3a58f7f758b7d63f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770640.0,448928.0,884120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274e6ac5c334c78057348e2ddafe2c51a6d42e10a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663744.0,448376.0,843000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a83bf805042400edee24ad2a835bd6607f05720%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656120.0,453448.0,894120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae2abe127b2cfc3654816dad4cd41c2f02b0787d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669704.0,405792.0,949680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a99509d0c6d6d6f7efa2c970b625baf88903f24b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712168.0,394496.0,932000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2284cffd01fe3bddd7a88d4ca1a56c15d941360e6f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707856.0,439408.0,922720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225bc98f5917163bcf88416d641a1079f445d7e302%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668712.0,488016.0,885560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ff75591b8b6aa45f9220d5928b8332a2dc6485a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670032.0,425088.0,927680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a25a369c84759e879d44d540b70b84bfbc310c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695744.0,396296.0,924960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a8ecd8bdf4e92f68354dcbd45f3a096136ea9be1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709544.0,451328.0,884800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225293be4e38ea421522b8ce85d215fa802c56f70a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714960.0,461016.0,901040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aee8453710c6e5281fbf8e5b53a17ca232c9ee00%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B802912.0,352408.0,936520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22afe4960920234292d2db9a2faaa572f48a14b923%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674840.0,485688.0,969080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22865a11334051fd81c3809a5a17dc4b1f1e2f3707%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660784.0,449016.0,930280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ec2968d0a491ed3bf21446bc1a9e7a1c2aa4f2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704488.0,395152.0,904440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e6f410308caa3c437159d4a7737b8b5738f7f35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676816.0,411720.0,896400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22178be7679ab622c410b9d1690945e1ed026a8a46%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689688.0,402528.0,913320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299c4c992c94f05d02c46e903e5a2880761bf303b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722584.0,479224.0,902640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7f0f2c9a765a0b44dd1d46934178fcb865e2d07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656072.0,472000.0,904280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22493469eb821bf51ab79a113ed6b4b095d8c09d19%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601400.0,398384.0,815600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f572cdd64d0146d70817c2f5cd8cf23411bf0f90%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728832.0,415176.0,855960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22169078c1099fdc1992eff356205e1fd288572bbf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665560.0,415984.0,944960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eabfdfca935054510036b76cbb5682972e21c352%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714024.0,440552.0,969320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22608966d34377e1fecacd259841c58acecfaaa873%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679832.0,387624.0,831080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aed27c15c0f011e42e041256f775d0bec2c8411e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689336.0,476392.0,962960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dbe06101b43bb413ea83bb03d2487c83ff198b08%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694256.0,409696.0,822520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3cf47aae8c40a173524ac0cdb30974576d0d59f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704528.0,437044.0,939840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ade7728b9c7624fbd74ae1133fd3d8780d7bfc2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667288.0,364800.0,792000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221bc4e1de44febbf91e33f9cac1f8f7dabe731f48%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656256.0,412448.0,944840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff3075b35a978a5524ba62169c60b39256431e0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734368.0,468424.0,822960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223736b356aab3f7bc54a8f28f4218611a9701b0a5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718472.0,485032.0,991280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a6c99a0a2eb1845c40c6c2d4ec150ab0f222b20%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703224.0,443760.0,881200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b24c19c627956061875b7eb6b53f9155dc481ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B787316.0,353176.0,973880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a9a9192ed934a9e5be9dae87d7eff89f6990ac5e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B583672.0,360448.0,978680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b41c61d6924d9d8c63523d6a9a35cc7f43712d33%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747344.0,423224.0,969360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d165d1f05c5dc9a085db9f52d3b5979853531bdf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658616.0,446084.0,909400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254715e44b8bd162cd9b68c21176e85cf0c4d2e9d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677424.0,516232.0,986160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227d0835b51d8f8e7306a6ca9838a4158acad80bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656536.0,423208.0,921440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22be44d2db9c8a4c13bd531962a22d02b5c2cb3bd5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646712.0,414296.0,838440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a6aaf85fb238ea99a1556220e737747ac634827%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765352.0,447968.0,886920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225758d85a5906f3566727ecfd5ef71c9ea95d1236%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656680.0,413508.0,844800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab153c13649712a8d96e704fc9e64668319c9c87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706888.0,433528.0,882200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e706e67a64459b4e81f0bf784851cee31f45fe81%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615992.0,426896.0,778800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228991026fe85682387c570f175af0b467337a4f03%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B785464.0,451624.0,879640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2281ff172fc8abf2909fccc77c19731d143aa83855%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743664.0,395280.0,951160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d15cc603ff9831c2103fe8e6dcda6211cd3daa44%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712224.0,444496.0,942480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255d8bc6a3fb3ea1ce7b8c4a96e8f3362a547d6c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713792.0,442760.0,991320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a246b1ff363b4b1023ecdce354ab15f03c4fe71%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726360.0,390608.0,938120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c410835f17d05338f5b4ec2b41bdd655831d0bd6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727616.0,390948.0,937920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265d1126ebbf6e0b3337c34a3bc5d37481d138469%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688152.0,402912.0,911040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a8f3a68a413abb08316a5ea39c608e85f2c83d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673232.0,410920.0,868200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aec28248c0910f7b205cd2780c11a77fe3121890%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688688.0,469848.0,879040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1d2f61b51fa57b63916c3e02a5d8cf01beb47de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667120.0,454712.0,912720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc0da22aa19b48a01bcb437fde682da5cf416fce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741304.0,369944.0,920680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22848d1da94f092991373d8df0389ff5709adca48e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651832.0,464176.0,881960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1bcaabec64b044ff6bdd143714800b8732b3f13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701520.0,435360.0,884440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22457fbcc46a4e56564a9a40a95015c91b38d1b5d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692916.0,386948.0,986880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22104a8f3dfa6b1da62cb8056f3f8d166871a85899%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655120.0,413480.0,888600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22594f77d1dabe9135fe53e20cfabf60e6e5d5ba2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674264.0,413016.0,879400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22625e29fb7dd3cf3626e2f3dac7379db661ed1d90%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680936.0,450168.0,917400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f07200d9735fe66615fd8eaf8c28013084f059e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727584.0,415384.0,861480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292f12862caef398463779d921def0c935a872f75%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703824.0,434360.0,935600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b5adcdb66901f2b432fb2e7b2c7dcc8bf5ed9a0b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652304.0,453392.0,931440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8ba7953f074ac2ba275b5cf0180d6c19967e5fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B596616.0,422440.0,909040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227fbf5b88276950cb2abf5a32d26dd60b9ba5992a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B837764.0,329820.0,1029320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cfd0bd223c583954becf5c643b9adcda4c652534%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658736.0,468120.0,851920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221f17f7db73d87c87a18aa26e6fe864af2929596%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682096.0,436816.0,908440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cddf03e628d3532e12f1f8ad1cfd76da78601a32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634792.0,463792.0,932520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226ffb4759be961b37fe23afd5fb4bc4e7d0091691%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707448.0,436592.0,943840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260f8dff1f613403a477fe482723f88cccfa44f1d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674408.0,468752.0,958720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225fc650e441fe3b68bede670a96ae618a9e4fc460%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B753768.0,419072.0,966400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220821b7db8abeca3015af4184cd312609cb27d673%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663656.0,418736.0,937440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257400f17ca86713c644a9c32cf09ee39a0531c1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664728.0,410488.0,860080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221cf65d0b49d91a0f7e2c3aa3758030003d9e5dd8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B589288.0,425112.0,948000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228bfed6f51272a754050d835799a2ac8cc6809aeb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668760.0,420936.0,935800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272964e14f2b0a22282445ceb4e8513baf64025d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656648.0,464536.0,884400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ce3504f1f5d9482e36fbda009629ebda09a6953%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719544.0,488928.0,999480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b9e8930ce426dd7b33c11a5a02ece252bab24a0d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720864.0,440136.0,913520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b1b845760ef176ee346f5f68fb710add4f7f6c13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B795472.0,352008.0,939600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22724200ed9a14674c28ce0d304b9e29bf2e86a23d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670320.0,402432.0,954400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3df23858899830594303a0eacd8a64ab74f0d85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626440.0,391152.0,964560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2252e7ccbdb5c3f66bb316397e382a54b1f8d30b3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698504.0,384400.0,946920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221461504d8ba364346cc5e84cde6646dcc322686e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662360.0,445288.0,907000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22062dcacd30721d8944864ca269762e69a0c86547%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685488.0,458768.0,941000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22138c69257ad795da62393736ef9f856634a79f2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660424.0,401824.0,912920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226dfbaf477e5aef734bff8e4dd89b8260e15df759%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723840.0,425288.0,944480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285b5e471cb464dca2de1384f78bc76a72ca55128%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616456.0,413832.0,923480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0dbd30d1e48a01aa11fc800cd700bba34561a27%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B597408.0,418840.0,939320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a2f48ec9d5af63f1c43e769606018f2ef6f691d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613576.0,396552.0,798840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7632592745319e449bf484928618e9ad817e53f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669752.0,484136.0,888680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266949c48ddf72402da922da1eb4e630a84182043%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701568.0,434048.0,935120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227bab3201e124d0a172f4abca851988a15a31da47%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651032.0,410384.0,837400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2281c1bd97425556d0c596a14b3efac470f6106cd6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668896.0,418864.0,889760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dac760be9cc7510dfd8a17e92f56aef42927ebed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718104.0,438944.0,888480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22611568620355f5710a810923f2b0f9810f18661d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717232.0,456768.0,962640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3721b42c13233e77516b8df97d1dd8842635ef5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709128.0,366584.0,1033960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207935cca320cc939b9ca125670944e9f9c5c7a8b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716232.0,493136.0,1004000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226de5cb1ab474d3c779543fec8cd5fc8da4aaa7f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656464.0,450912.0,862440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200b182b6e893a2c291c467419d45a9744d19e9f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721008.0,432320.0,955960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279b386769647753a399b1f45d9ee11233a8aab25%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708616.0,429704.0,878440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225cda12e6074709311fe8d2a6fdb255ee7f2bc272%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666360.0,410520.0,964880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad26dcf1f1340d88d21fb411815b4e0524924a62%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715456.0,476728.0,853400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220d84cc0c47575dabdfcafc7a73a021910c5be209%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692536.0,409240.0,832600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3c090516f24647ddfa53631bd5736f93d3b9c69%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719832.0,473296.0,904120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f428bd0dd7a7e6907e8d47ced6db2018b374704%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B807020.0,348984.0,936440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295e535c8b6fbde49c005290b0ced3591cd034ff9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713264.0,349512.0,911080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d94305805ffa8bb3ffc19e17470b20f6d78fcfc6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760400.0,446680.0,890120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225388839401d5d63879f43517ea6e59bb4c86759a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742768.0,442568.0,907280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e4320d764dacc8439ca24c23b400c6484f64a13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655824.0,471784.0,905880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22592758391ca5a1972f2a9b5a8ffb43e9aa18f1b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720968.0,450872.0,843400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a645bac6bb74da7172a9ebcd5a9b5fbbe113345%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673336.0,411472.0,867360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d394628ae868a439dcbbd83c7ff3c56b2c79188%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700816.0,375600.0,967920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d38e3f91152e71eac62a323327a04b306e6a465%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713000.0,432440.0,951120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d0ea15bd7f2aaa8806ece5d04b088a6e4189477%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674952.0,379160.0,1084480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22668c95deff9c3b3afd54fda239f220cd0103e4f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724192.0,419800.0,865640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0f0c1e082869dda77fa85833fe4978446983669%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665840.0,414752.0,959280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229664d3f9395dc33a47475e3bc7cb8455c40288a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665704.0,407696.0,976240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bfea594c8218d0b4824e750c6938caecc4f98dc6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727272.0,363720.0,1040920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225301f8e5df3d1ecd6c73713c31321fb40e96d23%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B806096.0,349296.0,936960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2268838be1c67314fec61fa657a5fc4261b914e959%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643832.0,457192.0,851680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224ec4d8ebd6f3d6df1934b8d05b3f75e75247c7a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671208.0,410632.0,867560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1e5e770359b8f3603871a66351898cb19e3e134%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744200.0,412808.0,838400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223deb757d8e617e5594691c0e7ca5b9c861e8578c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712000.0,485952.0,841720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224de302ddf6a01b3b867f8d7933c8043fc1ff9c60%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690232.0,466264.0,950120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278cd17fb029e4b6660efec10ef5a26285969080e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704500.0,394828.0,929600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea8d0fa47ade65ae3437afe468e062862447712e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614824.0,363520.0,995280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277d0354246eca7af378103728c406d7658476e2a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699168.0,380416.0,961080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6534f8b64c202672cba27e044b7a59bec753478%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B597716.0,469592.0,862080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e24265e306c947534b960e598a98e13b7cbeda08%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624800.0,356848.0,1005520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f25f92536021a05f3a85daea87a9b3e42c67151a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705936.0,399160.0,876080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201a19ce23feeadbb2c99d639a0fb6bbd820403e1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665000.0,533640.0,859360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22171a17dab8126ced2d2e5cb63e0eb879ffc79619%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733324.0,346748.0,1066120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eee945df09efc8d6ebfd588a846b0f62bb45c777%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603016.0,367792.0,979400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d834759dc2ffba3aad260f3e3b047ff955b5a76%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620376.0,473480.0,941000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223673dc3bedffbc88a5366a5c71d248053a9b8a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619520.0,459720.0,872360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d88fcd02539e3945258d30734528559d068c2958%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700480.0,395832.0,902280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d97bd256006c53a5388532410821d82c80847a1f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732520.0,459720.0,837200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f592d35290e6cae4238cc76d45ea5f32868dad9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733400.0,461688.0,834040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2284eca5f70d8737be8ccf0f2e1c28515e6f5d1f28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B769888.0,358624.0,939160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cff3afd0fa5bbdeeeb7d0ee9de49a21aa72e4d3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667296.0,404352.0,988160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249bec7fad9990b8f5d4f73f67a9f7807593c695c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743196.0,369288.0,924480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba784026ba9c41af9c9afeb714625bbef55102bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708480.0,401464.0,847200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22594242efb587149a7b9be588081b949343e6bd61%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668584.0,451728.0,873200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f8442fc286dfe99e5235009f065651cf799aafc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640704.0,460832.0,847360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22342da4a4da9356def859cc93932e11331f3ee228%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595096.0,471660.0,861000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22353ccc0e278241fce30aea96d5be2886dc5a3c97%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716240.0,384712.0,901400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225759250feb41b1db15f3998ad874b59c11d9f8ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714536.0,442976.0,986640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a079ed83ed2bb809279f66433d037ae4dea035cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672920.0,452176.0,912400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b20474b55a11848d9f154694e7e6a481634bbfa8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716840.0,488736.0,994680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf8e524ede3c76da57a76c09481f233ea04f1306%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668824.0,453144.0,873520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c4ae5b88ddca5420629d8e2d8ca8f4f3f3477eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675736.0,380032.0,1083360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f8c28e87cc2885e26f6ac79413a7469019bccd8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710672.0,394364.0,861920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22226f8d0e170d865778590d7aa3dcd2cfe26e1c93%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636536.0,473400.0,946120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2275621c68cf1d7c4b18b7c242f5d3dfeba03ce0b8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B829644.0,334296.0,935160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223db499b27547b8d6e13025787718c04e16ee2137%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736336.0,395008.0,945960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b421f9684087a53a4a235e8ce51ba3ee5c83c834%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706688.0,399200.0,851680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203a8cca83ca567060e4bb3837c4d6b3ef6bc8688%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B828192.0,336720.0,935040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22062524e55eeae879ad5fe1f2c28a161c85d85bb4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B793256.0,348216.0,979600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292e1b32eacb849cee7aa56468167c5ba18c652d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703312.0,453128.0,898600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2215843fa9079ee6f7696363463ce8d1019c937072%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671000.0,399112.0,1007600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22781053763ff74da0db98c682d3f4760bf61cd212%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680032.0,385616.0,825240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22291c9b036de53c9fdaede25a5f0316ff58ae1b32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767440.0,359344.0,937720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2263bfe3df2200fb53a753d8b9d28338272d059da7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B588416.0,391176.0,816200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22608385e6c75d4684d5ed4e4d0d622ca66a1d5568%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665336.0,364240.0,789640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9238c3801353a613ef1a4eb774844a3c071e177%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767456.0,434936.0,883320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2243c0ac877206158ba779a86332f524ab6f36b71f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673784.0,456440.0,942400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257d6395bc4104163fc6e3cbc97cbbd9e84545306%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685672.0,406088.0,840920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a7267ca08edd2ba1d6485b172766383d325d88e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666056.0,399864.0,1000960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271b91d318a30d8258672a6bf93cb5eb020b9a5c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656832.0,472464.0,907560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b496e17a8b77cc660de8d23473160e37f0cf64c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645512.0,416120.0,829360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22291db037c87a6e3cdacf1606df450987b1b47dca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719552.0,441104.0,915400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274293788a2c0fb40d6dd27ef5347ca36f5f5ad59%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711800.0,394028.0,931080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b2bee44a32f34f6adb81e8619c6cbcbea64d9389%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687672.0,408040.0,837320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267707aea01b537f4e2f6dcb9759d2a3dcc8dea81%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B735504.0,394664.0,945040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2283a7f0cf0ce7c3313cba282e75fd85dd36a1a025%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709832.0,447736.0,880920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b8205f3381368fd1ffaece8590b46272bf6a3f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673896.0,464104.0,949600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223dc6f326598f5016d63287a73c6d9d603dfb7c21%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698720.0,435128.0,926840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228cde7df5afa4cec2ddd7a986936ae7c8a5b22fe0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726368.0,423888.0,948080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217595c0163c46a6d1ba299bcc7a4b9220bfd4e7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641280.0,455296.0,916560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255fb13fafc89aa145f468a1701e302ed4e9c4774%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717208.0,423688.0,870880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cdf2d49d0fae90703532da5bec063e0df728f4e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767392.0,448352.0,885680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d477fc271753226ce60895017e75428766d24c81%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715616.0,367696.0,1026680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22895d12f538763a5e6e1c3b8db382d13d9fa42977%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693784.0,383552.0,988040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22392332def37abff0f5fe27b2995f64735dd1f3e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650540.0,394492.0,915400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292870ac0ffe94acaa13dd66bb5bf276556976584%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744432.0,414040.0,839440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fc39ded308d9ffb3b1057989a708a5ed1bff6b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733816.0,441080.0,890880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2262ec879670f6893bd55955ab8d59ac4c4e4d4a85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699936.0,376032.0,968200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228cf4ff15c83dfba385b6457c7451938cf53f4f4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665456.0,404688.0,985240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a8ec49109c980654d3208785632db37d70e6cef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617048.0,416480.0,797400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c19b5fe72cd6a7476d41e05cae4c477cc4a541bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616872.0,415616.0,797160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b50049fad3fe82b7ab3a5bfb9273195a23328fbe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677088.0,395496.0,842360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a373761f175d644a08df5ecb827656b6843cb92f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698448.0,380600.0,956400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221dc2588bcdf572050550df536bdd5f91b25c3800%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733660.0,427152.0,960360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202e82e4137385ae1a26d7a26bddbd77b559dc001%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676856.0,521576.0,987920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2216dcd65bb718334b67d0c1af5544b158affb653a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633008.0,395656.0,959360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221558746f06b059f73d55c56e71b7a6b7044ef053%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661392.0,423728.0,921360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3baba3efc7b393f897b2e2f34045ce45d8d6431%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606560.0,368552.0,977640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d0a39d19d517f3987591d1e4bc37fe7e2af0a6d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615072.0,363864.0,992520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221f4ba74821930cdf4db430108b4fedd6d055f6f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664232.0,462008.0,859320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ae8941fdef3e0e90bc6c77f3dcad22dd430b79d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B787240.0,452360.0,880200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22428bc6fc4e53c7945e615dca1da8f627f3d0d5d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706648.0,400768.0,877280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb432b113803bc5664ff1808cfe3b6c81f52e765%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691136.0,353384.0,1058240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c62da6acd34b92f9f950882be84ce3c769fa1b96%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607160.0,480392.0,942840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f6173c402788703e569e8dc084e9f8a596c8a01%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715600.0,438728.0,866560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220968421173eb3c32e31164703de720dd8e15b46f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B602424.0,416584.0,916840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22503f6d5d3107fa42fc681f339470806e9ce8be87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657816.0,447376.0,838040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b441e21aa26eb857fc90935687c3c64e5c12d841%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B587148.0,360756.0,980240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229576f31db3909b25201b29251b14ffa900e7ec8e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606664.0,421912.0,910640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226435c491a86592fcced4a500256063a5c3237f15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621504.0,413968.0,804880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2261c28b9e533622f0dc7fba89cfce20c6be1c945a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707808.0,368120.0,999800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256fa4863c8abddb0a6aaa981e72f713b189bb338%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677416.0,399032.0,964480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b57714bd422ae7ad3cb4191b113e4b38e26c79f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716632.0,444472.0,997120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223bd1eb52007635d1b295a041dc3fee7e487dd617%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738648.0,422928.0,955040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fa78b069d3770f2d374579d6adb02ae33040845%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728544.0,443384.0,909920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d601265ede5b448504dc6dfe203071fb3f9ba50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708648.0,435160.0,944200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220afa1c1a6f565badad6c8be5065404472ea16eda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664360.0,423784.0,863760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272feed330a7a32d2dfefacec35fecf999bfd9135%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B801536.0,453088.0,879680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ca79a3e20eddb3c008281ba9ab46f12c3ddaa17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B591524.0,362664.0,979760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc2b2830e74eb422b228116c932147e266c631e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B548432.0,347312.0,989360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6bb2aec58083e82b34b64454e8a79edba721775%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681320.0,382712.0,1072400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22779cc79a0d4fdd3b406fa36cf4d9dd942b3b6002%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688360.0,393496.0,978880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22869cff30fa3658c210c098fc557837581abbd6c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613280.0,370504.0,982520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222bff098fbb1cf4e7e25f570d61eea25e36a14178%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777744.0,436792.0,880880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d5d75031d8d07e2278b94f1dcbe0f06c00bd0c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671012.0,450544.0,908360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2283c65ad677bbb4b55719005221afe25441916a49%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676344.0,481176.0,964680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a406cd3a6c4377f71ecd6922949458bd864ca86%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740984.0,469840.0,815840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae83d03d34aa4b98a9d4581f986cee6a9cc00fcb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630608.0,408352.0,822200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f0c620fb2e9b70f860ec8a646f6cec01f497b34%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B753520.0,362636.0,924320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c799d3859b99ab7a86bbf163ef102e44a987f28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668112.0,407992.0,969880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1c7ed4c900d0deb4988176c32915a1b528125e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694080.0,396720.0,923920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f70a213a45e0de35772a7ecca2d524371d30110c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667472.0,457952.0,941480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b1a343e310b8546e8c3b765f33c4302d283c4c67%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731744.0,459312.0,808640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b15f01f6342f10be0ac7b46762437dfd69ffd1fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668760.0,452888.0,873160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf9a9fb9aa034f563469db80df5acd8fea33f466%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689280.0,458872.0,912240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed83e4c0c353360b793c7d438f54b12668d34d1b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741056.0,370776.0,921880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b36f15a652ca0b0fca18b209598ab93769b26f09%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690352.0,473616.0,959160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22676540338fdc5843357f878022a365c3d1808434%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612920.0,366056.0,989040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222353b710f8c2969497a6adcbefb6496cc1af57e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716912.0,441528.0,862760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274ac13921446a8badd7f07962a8791c0346f15b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710216.0,456008.0,899280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225630770108c9ba57b1508530629ce27d4249f675%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B735088.0,462832.0,833520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226426bc6445b358a43eebc35ff7f5835d2dad0e23%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683728.0,401368.0,1027600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8cd69db2ade23197571a4614a767f8b52ddb45c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719160.0,476464.0,984080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22982bbc83d2f3e4940182229e616334676d7dd91c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679888.0,407376.0,849640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223a4f1c802a2cb7be085657bc9df099c326d86e86%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675864.0,401712.0,1021040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d39b185140c0c36c3a25d3221a09c6f9de4e75e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689844.0,441756.0,884680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22551d7073a28137d313612a95ad1b58c0026da71b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702464.0,434688.0,933920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe9d133e3ea827b4c734f60a64db674784109222%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690816.0,441440.0,885320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab6f64f09b082228b31ec24db064fbfe42fca60b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639784.0,403396.0,956360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b87404192ec76ee30f4bf0e6a9b94c528fe6e982%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646312.0,407768.0,831640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ec00aa1b5d0f765078c42ab8fc7bf8edb708f0ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621704.0,473264.0,938080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c18ac02b30b77db75baa39fd2b38b593f046680%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683704.0,481712.0,873800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232bd3d0abaee7f6632295d927a103aa21d73d6df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669448.0,409960.0,945240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220202d6faa5d6a7903837e26fc106382baef23783%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613536.0,434328.0,771040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223da6a2e0f661c43d2fd5707a6c39b1ce5c7bfb06%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731768.0,353824.0,1057440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2204ce388ca62dced92ae9950842ffbe75027327b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664576.0,443480.0,848480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a81711262817b270d850390636b50984f9e183a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687456.0,403408.0,1032240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22143e6150927440b7e3769a92979162c70ad68d2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682968.0,396584.0,900800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233662d2e2e487309493888597ef315f0da124633%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707672.0,433848.0,943680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227082264b664d1b98d6e143f64f96db54c4056fd9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745824.0,415440.0,834200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a133ffeddb8a6cc958632067e3ed76fe2fe8be41%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663608.0,416072.0,941720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f0f5a0be3196b252466242d4ce68f1c9d9a3031%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663488.0,465080.0,857400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d95c59d385c1fbfc09f59f857c2dfba76c644c63%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634624.0,396904.0,959600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207144614daad8cb5704c50592b744f61b7bd69ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744880.0,442320.0,905440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226df4b6e300740d3265d9d3f91a52e4943cc2ce66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645488.0,407568.0,831960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c43a5b96655b1e912660ae93c811cb1b4f3b6399%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673136.0,513792.0,865560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a9061810f227f6f51030c5f5f9ff11b7b63b39f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641896.0,445496.0,822920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5639d4f57098b0a4e92615b01bbbcd2753d7578%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669288.0,444208.0,928760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac91f3729d470a81d41a756c1bb326bfe149923d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693128.0,390784.0,984200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254cb21a3c3d5a1230953f4d8c7950cb127ff776f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763976.0,352464.0,908560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d59bd943506583cc9bf4b6e342ecb39cc899e7f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713232.0,470576.0,857480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a8ece28e4d416dc2a451de3f72fc6e2495c73da4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724184.0,446136.0,865600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a3dc704675dcc1ea3bd0bb4fad2dcc6b91ac00e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737656.0,395672.0,947440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa2922e8f71be8489c64d0a76ad1038d495c6910%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B764104.0,351872.0,907480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a3c59b21e257fef6e7daec7ad65c97c0fff7079%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628764.0,407928.0,818440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228bca0b36adc027c9c6775a874031fac314446e67%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660944.0,416832.0,939120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2262a2e4749fd2efb6f97f2b583022d73851c75733%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B589112.0,421528.0,912680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e11cc8a159b8e8e82bd10962becb2f6f406d1da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658032.0,463384.0,945000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a83ba22ffdacf31f588674efa474ef50056d8c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657184.0,464452.0,908600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e1ce368e8e0a9cc5ca7af2234da4a45ac7cb121%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688856.0,401928.0,913360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b999b48899b5b788c5e4d93481692e38ec0e9b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670136.0,453336.0,869920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200a679cbc3bd263a098e4b2408a38fffdc831f0f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739056.0,470056.0,819000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225764c268d8558bd75e1d0aabc190636212735ae1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643168.0,447320.0,823400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c2d006c8a631b941801676a1cec5b1a5ca362c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652016.0,451920.0,914800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22128e9a0edc6c44ae146282eab6def8a0ea5d294c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744560.0,414064.0,830560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228d9384bbf6a0c3e93175d516b2c21cee3b0faf5c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733896.0,466364.0,827280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227736059f267fdc3ee4a78a4b2d4885f4b4fc05ce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664880.0,445928.0,903200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e81ce3d472b4be94914c391f18d22b28e8f0034a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694920.0,396696.0,923280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227fecf792c8555ec8495d5ff11ad9f1e9fcec12f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674732.0,444872.0,873040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3e585be978f23cc4551d41863d925a653bc1556%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690816.0,409944.0,830840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221403aaca1aa213095656d014dd5e85b8316b362a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691688.0,392208.0,983200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a697d485c57124a1ab5e42bde8e670478433d99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670880.0,409960.0,869640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2215a41d03bb5bde671c3d8eea951f6f693e679c96%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652176.0,463888.0,946040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fd68014ce65fb993b11b3e1c016c2b8b33e3b00%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671112.0,453604.0,873440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fbecbbd0a9f3ebff7600f7a3ebef0d68a3e6a553%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652728.0,450040.0,830640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a54973415958cf6f0aafbe30b5af6ce1634b8bd0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609720.0,477376.0,939960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b485ddeb42e010e8b2d55fa2a2418b41f795d4b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667752.0,403848.0,979320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a362e389b49d805fd7d54542ca52eaadcc40d9c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698428.0,386636.0,948080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d02325bf340fc13e04f1125f83b2159f2293f76c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595432.0,420064.0,941240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e012c9415be159bfc0118a9eb61f584740baaae8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658704.0,464136.0,911480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d53683a811ba5e029a252a5cd70cf191bd7d608a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710696.0,442448.0,876160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200d68bc6b6f52b2f8d77ac9769d79c01640ea644%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703112.0,372120.0,979840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22705ac4576ad6efa0799d021a4b1782d85ebdff5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731384.0,507464.0,911000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224970345823a356932bc577eeff5fa5ea8a23aa3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704248.0,371696.0,984600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ce40bba895ea1b5c6890917100817495cc10331%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713824.0,482792.0,847840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297bc0dcf8f48e2c5d5be0009a381fae1b9f4acbc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686432.0,480604.0,974160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225140bd13ef938e36090b723bddfae964687439e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680808.0,384392.0,1073800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273e229318b006c70ca6dab19c5556f2ab9052cd7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673680.0,495112.0,974040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273382912546646af47bb95ff83c493df0ac7a8bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690904.0,409808.0,826600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222452f63dc02294773648000f6086ae9f8e40bb66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685144.0,483696.0,981320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ce144a4286da2ffd7e5a30b32167f9010557281%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666088.0,531752.0,862480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2230f115b52c6072ee3d86122981688a4d560813b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619800.0,414880.0,802440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b965259b82f811e29eeb953b9b9b08e5f1f7ebca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682688.0,485232.0,872120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d49ae94760a246bf91984f45fcad362fbd7c96b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B783688.0,353304.0,939720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227dd4869315054ca372fbfd813ec25188072bdd39%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740056.0,371880.0,920920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b93c8437619f0ae0e8093b82b8b0427a182f1b59%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639592.0,465440.0,935760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2293227e2302d2678e6d1f18d424e5e5a3f49f2dfd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714080.0,444776.0,996400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22573a27d99b3ffc2c27f27a76f6f5e118f6c88503%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708572.0,365916.0,911240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278ca39c3c25907dc7ff3925a8fb5d3a64c4286e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720656.0,367872.0,1029200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224cbc2b82cbb493b2d741b6d2627198f367147330%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717080.0,470912.0,901640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221a4ec3b0d23d9594a814d5f2672547e9e9fb120a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767496.0,356780.0,938720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22267573a1b3c4119189c3d12af28abf95513c6f7f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703848.0,398512.0,879360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5b53b6e052f040d7df8af55448a37dcedee9d3c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645560.0,405712.0,828000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22855a7049dd216e6a42e35cc57d97e6a3eeba0b4b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676112.0,405928.0,906080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e216d67ff56cf165796d0736f91d37ed1329aed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671200.0,450472.0,873600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22faf287f659c6fb24ce374779a8a8f656bca24637%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B546352.0,347464.0,989480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8a34f688de1d359140fe7843f1997f6f666047f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664280.0,416584.0,949200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2214d911d4b80a1d07a87aaa3ffec97962bfc95862%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620240.0,395264.0,804720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c5df69c18642ebd7855da87bf6e65481d53fd78f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628524.0,505444.0,897800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c08ba7daffd18dc7b0ed463cf8c853b9275bdbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614832.0,473760.0,940120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee634e66d6b9453f7094797c633eee67b4964d32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671456.0,407004.0,860280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210bf6db52b58309af4ce66e5297303a986dd298e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726376.0,458176.0,845600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b472d53e36438b2510a487af6ba934e43acbe0fa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601224.0,416128.0,915520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc6722b05c503ed29ef888c515683ca49f73356e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678888.0,445776.0,877440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2270c661cba954e9627aa18313d0c6fd3721e1a168%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603728.0,481400.0,947880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c221a1cfa72f9e93bc72dd6b674eaad656aaa65a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724128.0,453608.0,828320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1fbcfc846efb4ef9d1a0cdb89f9ddf652a52177%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646488.0,456456.0,854680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d64ed41a006f1d7e1dcb4ce62f182b108b01b060%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637128.0,495432.0,898960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b9bf26df48efe9b71a412f766e2ea800e947b73%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713672.0,425776.0,875880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a6e2a95f444940a120028ab4b72704971a902a5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B758912.0,447600.0,892840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d54acacd8176c9517c261b75daa8633de62bd4e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691520.0,469360.0,955280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22856fb4ce51caaa0dbf6ab91c74ea6433933225b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733664.0,374448.0,917320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22368017d9469dfe22ad730521aed44f2180cce4d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600240.0,420176.0,939040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c63476f9fdbad871447acd740b843d97e32cd83%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707776.0,390920.0,904360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2224381936698b9bfc47a7674bd55abaa34c2363c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740584.0,412112.0,844800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22951ed9c8b76cac54709ae22966476bbcb9aa3958%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706504.0,442432.0,878760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a80b8c8ca88ec76712170180ce632a46cdca297%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670984.0,441880.0,889320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221740fa8b5e01d5628f035158b6be2151f15b019a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745128.0,396936.0,950800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0f414d74122daf55c08112e1a3f7783b850ef28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722192.0,419744.0,867280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228658b6ec6be9ed250110e18e29aa15fd64a6be69%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707832.0,439192.0,928560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231fc0b2a259174a219e2827d208ebafd57e190f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B822792.0,325672.0,1012520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b2961bb923aa6fc077c99b70b62492729a849006%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703768.0,438200.0,916400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253584755bbe3b954b7fd9505693374f92656a636%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713256.0,481728.0,845200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247427966d45e6325f05d5bf97ad0d13a8fc1cfe2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621864.0,459968.0,875400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ea0ecc4f3aeeb9a346c3b6666c84e2130412127%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680976.0,408360.0,844480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc0e5379b5434c68f89d3fc26fdd7e9bc9df9bd4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B591424.0,422472.0,911360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22928caaf044e3a058c01a02527025b3bb350046ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763304.0,433616.0,883000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8602adb52b24d5256274ae5969ded7ea8fe5e91%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655032.0,450760.0,914000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221241c2bebdd3da4bb339fa6dff2e9bbd3588606c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708736.0,433992.0,945920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2239d1358708dc064db1462f2611363d1965bdf362%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B782416.0,356368.0,968120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226986c69ab07365e874b65a40786bab5311ea64a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708908.0,442568.0,936840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205bbf15d6b4bc6d9d0d16d0cbce92a6c375d5ae3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B778296.0,437984.0,880760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c55f2b39083ae4fb9a68e068fa071ff23a794ff0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B782680.0,355480.0,967160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2244fd04cd154fb0be367a21fcfec12b10ec4735d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B591944.0,411704.0,924080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ca8f41384f84d89b0b9e4a4819eb54df5ea2153%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627456.0,391608.0,811280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae4bb5fd299e13724fb23acc1f6999fdd5893199%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674392.0,396600.0,1011520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226eceb5084dbe0573d0e1c16af2b32988a345d269%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689712.0,461376.0,886000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac132df7b164355951bdd55a5d538bd65dc8b5d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711360.0,366152.0,1026800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b459f40d8159d3e4abac0fcd7124fc13ee5ac352%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B598784.0,366920.0,977040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22849fc2ddb44651648b91972c1fb0e6099c3bb4b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715752.0,367384.0,1029000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e0dd4889108d747dd950a0b69c1483e80ae74ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676684.0,519364.0,987000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7fb7a932c0bf19a36e7ca402fc26c60b4d7e73c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670296.0,408224.0,862720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22167731b47a4c9a72c64fec172a35d153d8244180%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660064.0,467624.0,853760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d43215a3f4c072f4d9c76bc66f70a4723eeb806d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717388.0,432128.0,955880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c2e0d94df629b64a74590577f45f00eebea1008%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619288.0,406400.0,817960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2287f402dafacef538006e8c074b0bfb0a59759eec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654680.0,395872.0,915120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ad1b4edf7ea30ce9fe3fea04ad02f25691cf7e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625024.0,461000.0,876520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d81c7581a92bc8bfa25420f85a62d1b05fae934%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687288.0,395408.0,978480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d509938a61b2fb71bfd6360b6a3db6e73bb5a1f3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678208.0,448952.0,876720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2b73ea420a8b65b37d5b0ad87dbae9fb83b1d3b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699176.0,438440.0,915400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22571dbd9dae439f754a043cd84ed5a66b91e817ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740520.0,423152.0,955680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223903d7574f9952969c41e446be6f99060a587119%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677136.0,417728.0,886680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1d4a03ef39f9340f71c2cf202a2ab2e5fefe875%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675496.0,510888.0,982360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f3fecdfe1c2f14ffca383f9b421633061990801%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B759672.0,361824.0,923720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f87b932175b704f14d126f82c0ca254de056614c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644776.0,457776.0,852400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266da17978676de85eff558e8e2cd7dbf506976d0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654744.0,422072.0,920400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d98fc492da8968f140df94cd77ab1aba95e388dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665360.0,416944.0,950120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2252c181f44bf729d843cd7a39407e944b6e10be26%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B790824.0,347968.0,979040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296bdee76905fdf5725d8192b3a7ed58d613eb3d0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700304.0,384008.0,946240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e43be604267c7398b43d09984d16322a150e0396%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654872.0,414108.0,894840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c5a8278023c21b76e3b087b63c71769abdfc3de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683584.0,421980.0,901760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b6a71be9a3a8a3b3f7ec707110753885b263b73e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638504.0,434488.0,890640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e274f1ed01a42c34ad99070f19b4cf6dd497c299%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B810432.0,345504.0,934960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc274041a51a475923c5cfd087227b00bac07fc9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682000.0,395752.0,1046000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278af278a269ad15c24888c330b7ccfd902006ef6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763432.0,447200.0,888920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217b69947fa61ed2bca09ed21784cdf94a871dbd0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670864.0,406528.0,951600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d458e9b6e3cfa26fc0d186822acf125cd8a5c0d0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663664.0,418368.0,942120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ad0cc95440585aa18e6d7847d59d2b54f02cd19%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B602296.0,399112.0,815800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de0221946ff8ed7c74b565d8b39aa57be5857b03%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636640.0,461192.0,885320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d461ae55a12d880be6b715584fe1848abd32038a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670112.0,409080.0,946720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc4c8da3c788aec2d1e2bfb48d5a888ce02fbc4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636952.0,421568.0,913760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8a959a3f4d0d87e960df2954afd3764bd89913e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638296.0,470128.0,937880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea8250d38c0746b679a5b335bdb484462d92531d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645104.0,457664.0,930360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296828487ec409737bddb079aa36c8a42c12b6b6b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740536.0,412960.0,843960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ee8d209a9028f9b008c3c5d98e098172cc2e780%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665600.0,407128.0,969720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f17d4d3730d821c8efaf2c10a4445ab5a103908a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664448.0,455552.0,900600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f17acd8241e5cdcb891d088debc0b5757890a56f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675352.0,449440.0,882080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c569b00639a6ed1aed0f4a5f805ad997886016d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667008.0,426504.0,920400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2214cc3c139359d44793a08091943f5969c7e3b8da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713432.0,469200.0,858160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa10285b442c2fa212e56ad43791c556c8a74865%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595272.0,364208.0,977360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b6e6c3be5b9f74dc178ecfbb27c9829442be052%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720024.0,485104.0,991440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba6351680761c6a8dcc18e2071454081332bdd57%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632888.0,501488.0,900520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225646dbe4de68775de2763568cdcae15cd4a26374%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719768.0,451344.0,849480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22caff91da132cef476b4fff5f963cae96dcf8ab47%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608576.0,418128.0,912880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b2a8e2f0a5dac3f5e75bec9d629389cf717e8b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689984.0,387392.0,900600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b2af8ced102de0bdb42de8d5e369cef5b809cda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635184.0,413968.0,905640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2212dd1205a9fe8e81cc1f116ca38fce6d6aa3d3ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640424.0,403024.0,820920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221641c47ed3e2d18b724bad5cc705e5788aea961f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717288.0,451032.0,852080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e04c15de6a4e2075986d69a06137094f5e0e7a3b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603856.0,414676.0,916160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b54fc1639e61b0a6857ae453e9557ef22c5142b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684160.0,456792.0,936640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b2697e5f0e536c97969698c892227f1ac6bc721%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623840.0,378112.0,977920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ceb7d1b288aeee733ffebc58ae1e80b1ab921bfe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609416.0,478680.0,942880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22713bd0759081eecb8924c46d8727f26726f0868d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675616.0,377400.0,815440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4d6c7c04b1516e681228f3f1d63a8b6db88743e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671560.0,427992.0,922040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223530597207448d67e980e009dd2a3744e9177ce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627400.0,355024.0,1010600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2237636aae44916a481e49a8caa84ef43ccf207b0e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B759768.0,364168.0,941120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c41440666711dc618baaa5cab14d892e704628c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762208.0,363408.0,945040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3b9f0335b1c26c32f30f44afa69282386a71e87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643592.0,403960.0,890920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22524aca51f2670a5b0c02711c65c7eb4b3282b42e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682692.0,438928.0,905720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1d78e2d9f1aead8d43caff5c7de9a767f4ef447%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643848.0,445552.0,822600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d2625ec5eea66974c42649254c4b11da113f360%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B827124.0,327632.0,1020640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22591cd9c3bd3cf0fca028cf5a7ea545900b0a83d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716272.0,440016.0,888680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2212b9aff8f321d5ea1a1206cca541434dd0ac3586%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725072.0,484608.0,903400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a965ee312c884011f21c3b0cd79435ee3f0cd37%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B610544.0,421904.0,909080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222a882f464035c99e17acc676734018d96ccc5aef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716616.0,454984.0,957920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab2e80219d9baa0502b60b76e904873fee26f8d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702008.0,374968.0,972080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1bb3733c5d7924de88b8dbc3b74f03a9596b88d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673572.0,444576.0,871320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c9a33be3d459ed16a702c71b03ae1e1ce59b26d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699176.0,435680.0,925200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2204ab5a32f1bd22919fb1aab47cb35050224812ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713912.0,442328.0,975320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22787ac0c33b1a66f0041a9f956964aeb783fd11d3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B594404.0,365264.0,978960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bca73ecabb60cbea55ef9963025f7fef780168b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B560704.0,392496.0,811360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f3eef1f319f3692e3c78a2baf90525c09b98ea1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B597392.0,396056.0,816320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9043b16b96d0bca3189415710f23447b396610b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679512.0,389968.0,836960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273f9907ed057359e2074b60214681a3889633a68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668272.0,418960.0,937320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e65b557b55e737303b963a1a58f51994898647d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B774104.0,450868.0,881600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c28080e5dcb61854dc97d84cb9f0256a290e273%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726064.0,453960.0,853880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0f58da51716ad94540cf98cece7f94ce35357c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682064.0,437864.0,906400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226102720aada3511731d4a77cdb5557178a28db28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686648.0,482352.0,979440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8bcfb68b406cb08faf1a5fa4602cccf71615402%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750432.0,446328.0,898800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226ce210892572dff146e7291b57e64f0d5e13701c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713112.0,427360.0,873840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bce0c231330e311f640dcd5970e43d3a7a8f0ee9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724312.0,454264.0,834880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e7d659ca9e708b25e80239a7203ff60f8625e90f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726504.0,432600.0,958920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b05028203c53fb53d5d9582be34aa92b0302ea34%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B548128.0,395712.0,809840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220cdbfe6d4c334d9bb043044a94cd552f12851b80%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672368.0,491096.0,879600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22898f416e7aa6d64e602ca194fccf9f7737f2965a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670872.0,439328.0,864520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1cf082f5aff63e4ab14175eb6903b920705c560%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662692.0,448132.0,894960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203ffc9b94e979a4b133f166395d9eef940a526d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688704.0,406072.0,901560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ba3f8f11969a3460f0bb2f1e1876f7913c87f2a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705448.0,369776.0,905160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22524a8e7a259cf070d4b0ff1d38fe96cc82bdd524%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688608.0,410936.0,835280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dd615f6600d3d1d621e2d9aa77f42aad2a87798c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719624.0,452352.0,848680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0cd52f2f92e1a73d64955f46e6a8532e496c1c2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B799896.0,343952.0,985680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241b1be4ebefc0eabcdc29cbe1f0f650d930d38d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743760.0,384944.0,888040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c66fb03f6eabcf054ee1da1fe0520e489a9bef4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618704.0,472304.0,940000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b69a93b5a4b1890bbba43cc2d2d0d82aba5653b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705272.0,455088.0,898840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa6e5e973619638e749961ffd00cc6f38c19eb44%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673668.0,490628.0,971720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b4af102e75cf0095ea174b00260363963d97e7dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726968.0,365920.0,1038240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fadd6c41545f82f1b04b72041eba27748d82538c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756292.0,399056.0,957960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7ab0ecd9a3add96cbb83196b3a6a866496655c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671152.0,378152.0,1089200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a61711aa3f2469bda5f585ddba583351207149d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728360.0,503560.0,908960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d01b7cd0190f30efd29c720a265aea6b1413c5f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642576.0,419752.0,914280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fc41da7c5ee668005f65642c36d0e6ea2119d4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739248.0,412968.0,849400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e119e08c83a887f7693a3d03c01fcc37701bf371%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666152.0,405544.0,971000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22abf631a62dae995bbe68f0ec5997d49ed4a97848%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673616.0,495200.0,974560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202ee8085af749d2f0be407da7dacfd28f7632f38%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673696.0,413280.0,876920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282b73dadaeec33438945c962d1ad54a54e87beb8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712208.0,435536.0,961120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b582f3ef8a2a49893e0298e0daced3370bebfda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615432.0,393344.0,800320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f08181188dc877550d0c2ab6040516fc23d57016%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B602832.0,392640.0,784360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c95083ada1c5e27931578a4c83d78a0f24b275ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709616.0,454760.0,870640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224efc39cd3f59b9fde520334a9b2ab74e1ea4e6b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716184.0,475432.0,853080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a707a0d6c6fbb3d7ee4e3e200503a573fcc648e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655680.0,463768.0,943640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223facbeac0bce689b0ca83325c4c71d3b98bf9cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716344.0,440296.0,863080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d413739532f11759d2cd6042c3d62cdfc9ac6fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601776.0,466444.0,864880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227b7cab92a75018021d185a0f799c21162adcfb11%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731744.0,462560.0,807320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ea07144579639c0634abf7a76bb4d32c5a165ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720680.0,451016.0,849800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221990c6e66991f71edfeaec4078fe3e427ede3bfc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600704.0,398292.0,814560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ccb7a6a624371bbf153d33dbe8803e506e1e796%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704664.0,452568.0,898800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2264872c6700d4bbdece578c8cf0d0cf3ff1ae8280%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670208.0,424864.0,925400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e630dec95048f55869dffea08c31d9fa9870f604%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713024.0,394980.0,930720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2215ba8e1770a3a3f838ed4acb1ad06b83c03c6570%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659664.0,414256.0,942240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22be94b72115951fe080cd4d632f05262310b27140%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633376.0,460916.0,884240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e8baba7af5b3db15ce51de4a86f980f3336c1287%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B807928.0,347492.0,935520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2275b40ede8a171c1a6f989952b308982bbfe1157f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B781184.0,452880.0,880680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2228a2abc2f0ae736b06fe2ab2989e3e4ce0f39b3e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677480.0,375016.0,810960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226139d8474f281383e60ee994abcf197c1a8bb93b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B758296.0,448840.0,892360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203e5ca5f3e870c057f602ce71f3bd4eac526ae13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621704.0,374400.0,979240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220f43a07e5bfeb0794b951539a070d6c80e65dd8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B797440.0,450424.0,879200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228db82fe61d2a5851bd04298bbdcf3c253e7ae8a8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730968.0,460192.0,836520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e5f9c8241461b339ee0639828e934248c037dd6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726436.0,456468.0,847240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221993a80e46306a669982ec5dbb2352816420f715%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740832.0,440408.0,889480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8ef443c0673a42616f02a5c0196a16b9ecc4fae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734544.0,465952.0,825920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22307e48b612423fee7a526a50c7201566ea118254%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670256.0,452732.0,870960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ee5c11ee3e2a42ce3164b1546ee7be0cd019d5f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666588.0,376636.0,1096280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220907f36810c02903f8a053a3522cd1167a77534b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640232.0,491584.0,900520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253c2ad60a5296f943044c943927ef70b27ade3f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714528.0,478296.0,849760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217fdb68a55a518e1377f82540a036c52e7c19818%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709872.0,399416.0,851600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d75d2bd477141c49c11220c918b9fd333e51198d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674904.0,374592.0,809960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae21ef877be435d5ad0bdfa4ed127a38235fd8c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B605680.0,415608.0,915280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd37a9e873448c09f0f2ce70ce7368f040f0ea53%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B598104.0,398552.0,815760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cac53c5aa75e6b0a49d724f96c31b34a67af5589%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721088.0,452680.0,843840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2270f6422b7a38dd79738a4e1a377780c4e8156a9c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777536.0,355424.0,963600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232beb743e1f3665f5c1556883f4b2eed5d1146e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688472.0,478128.0,968120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ef5550d89d823f83b0e43fa09314f431e5ce5f8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718456.0,424920.0,943800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d57d2fa38010c1b8d18eb74c346c7fe0b2e12396%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715488.0,444900.0,991840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229848b4f973f5589a20727409c8615b912ff74707%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719184.0,472912.0,979120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e120ac4faa51b6b17d5742a167c1247a27b71e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626984.0,420496.0,914000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224994878d28dc440c66abf4e5dad97cdd2ea9a5c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666084.0,427016.0,922000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d5c266f3f394aa59aea8b1fa924b9fdd31c18b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B597436.0,423048.0,909360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc05aed852504ccd2cdb981a83cafa1c2cfed473%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616184.0,473992.0,941280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22736f0455bb9c0734c5fddc7e82427f7e460180f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B549540.0,396048.0,809400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dabb9665dc8a434cd33e8b82c6018b361023730c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719264.0,484992.0,990200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285c73d90a78f7e9a4ff3e5cf74816632512c9579%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677136.0,408840.0,855480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207baf5fa24215e2f82e38f4bcd2fdc35fdc626aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655728.0,450616.0,910920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e273ff8f3fa2e1209cedc2ce71ffcc0bbe027440%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684680.0,408608.0,842200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22651cd8a240a0a56db5405725c9914e587a301f8c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719336.0,481584.0,989200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c5edd3ed8ab73ccf7ddc48cfead169ed6e5a57c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629016.0,420120.0,913840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a0e0b16f8af1f52015517dabb9f13985a06710eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730040.0,375776.0,915640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c4423c4393b68f47ce03107a4857ff73e1bbdca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612008.0,413472.0,925600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22390ccaaf21d5245a11b8ec645ce420d104b5d95c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693480.0,403312.0,899280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2276a175633cded77c98cd93f8269b66b1419e1e2f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694712.0,403672.0,894120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d4eca559e7a8392f8f48cc5836bcafbe36b9231%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685000.0,458336.0,941760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba390661a134d7347a0f1c17a61ada3af9140133%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706568.0,436548.0,885640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c4361a689a6b44003e11befac5e085547aad787%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679488.0,390288.0,1062320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255cea9b3afd37c0b4292e23e18e2ef950734dbc0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647088.0,447328.0,827320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e24e93e4c8fcaa524901e94484b9054f9271d425%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731168.0,465744.0,799000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f649a5df250dfd83556a76ab4d32790a4ffa94c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663812.0,403268.0,992160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a6c01695d468a43769bb385505630c4c75e4594%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713536.0,428344.0,940800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226225138bff40df6339c0b35ac1cc01c52a288d66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659608.0,412904.0,851240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c318b8a0f452a2cf5c40a33fd7dd7b9616437d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620032.0,371696.0,893600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297486c4612611453d4790a711caf920339b228a2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727112.0,379504.0,911680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c20235614739205dedc97faed03d4f83d84d831a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680352.0,383112.0,1076160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a7878246600a32b3275a931bcf87c044935414c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666344.0,410064.0,966600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22063804d7a446e640843fd9ca08d58f73f069bb6f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721520.0,452576.0,844600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2289b59a727bca83bdd174332db9ac35e571b2b54f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B835648.0,330184.0,1028920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f9cc109dbfc9b3f5eb891ff021fa37fd21d77bc4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696200.0,387464.0,935680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8ccfb446a659ba2c9a37d87838a152892f93864%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727256.0,452080.0,854360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b9ddb9a53cf6de485b019e15378673d019aa3c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660968.0,414032.0,890840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e30e024cfff2f4c1744bb74dd1aae571eb7accbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630472.0,479872.0,872120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225afe4436519abc0190e2473c6ab9f68e4cc7468b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724664.0,454312.0,829800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222590c1f229d6908568eeff7b685a110ed99e3c0e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666880.0,402332.0,910640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2229c47b37c0360c17242bb809407c8a994fdf16b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699880.0,381520.0,958280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d17ea95b09b3fafc30164492f93b6b714f121b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687880.0,408320.0,835680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc1b8d315672fd3f1422c7988c22cc3a5ff53e67%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664888.0,421040.0,933960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22766a1c002f4a1e2fbbc4abb8fefbab10332c32f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706008.0,447776.0,878040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22037f39f52c446cfc5e4403032d9b777a79cc0d3e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706896.0,366072.0,910120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222a91e85aa066f2539fc5e064dea6b951871b3a94%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675472.0,479024.0,964880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282aa09dd01bb10d3e207ed8e2f0d6e703dc3138c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686480.0,411200.0,903200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0a8ef5303d56797d4552317a15e55e5cfef9604%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742528.0,424664.0,962720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce3b216cfb120a3af4a7187e3a5d441e1a478f15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675392.0,468896.0,958200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272b107678f5397cd4f6d3beb697bc73a9e51ddcd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681560.0,392264.0,1054680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224c4a81e492ab7788f0a2d39337cf9dd3b2aa26a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661888.0,424808.0,922520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a4e497c44d7bd90c7b16c982381a7cf8b82e8b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706864.0,399440.0,856280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0cc25865b518e89f460a3988d5273ab84a6744d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760160.0,436736.0,882160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22359033e768c6d556cf94334f3e8dcb2056310aa0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683432.0,482976.0,874040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2276618481caebc1335e8ff95a9b5f1fab1cb54ca8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645000.0,472400.0,879160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c179bae195bbc91a43acc79693a81b8399b26d71%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741768.0,413576.0,844000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2289671c8c968791b437383e35cef1a1b44d8d4df7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725980.0,482616.0,902720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22993d3a40d46f9d295acdc7c87b2f79349f7db217%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672028.0,454672.0,938560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c11939be92af7b08f35993ad6b80721e9b061a49%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668640.0,403320.0,910360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4c4e35a6f3d6766fd18eceb77f5708706c70507%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700680.0,375984.0,966520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220084d75b06d5e511e36a585a023a1cce48bec781%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709960.0,435800.0,946480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22949c7e30dd14a1f0e5d9d1be82d7524e6320546d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B775296.0,357992.0,958480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f4b22e59983c05580e04daaa10db077e35db1ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658648.0,416312.0,891480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d3ade49772686a1f7ca51cc0eba9397d96ac075%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713040.0,436032.0,887280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b78cd5a0d824cb3b2af184aea1c4505a57af994a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728696.0,442528.0,889800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220357b323a32bc19603a27d158c2dce8925f08a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B572928.0,374152.0,810720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa1c03e58d54704d0525920e6a195ab5d7b9cb45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701856.0,434280.0,933680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b1e931eaf7b9439cb062cfbf832543bf6e067f12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659536.0,412672.0,850640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e4dcde3f66a43a460cb4839072aff1d4f0f527b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689376.0,404920.0,902000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e92871a060ba344b730f9e7a5534af9b89ff90da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673428.0,447268.0,892000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a08aaa203bff36006ed03c837767424aa528aa0b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634840.0,399832.0,892920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eace708b187fedc8a8b1e6358dad18245700b0a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624208.0,384464.0,973520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22496189f2dfdf294fe09a2a64a6d093a89295b9b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727624.0,366824.0,1036440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229152f6c6d9282d5aa99fc2d6e549f0aa7bd56221%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B735944.0,413248.0,852000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0a660f8ddcaeae4f16b20f05a048dfbdb644292%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623064.0,383472.0,974400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202f749dd9175afa5433cd4bb33e1d8a94afb859a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730456.0,391488.0,940760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e4dcd50eda208b65b95e8518e1a757a177a93a3b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676680.0,448768.0,876880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2248ddf96ea9e5b9e700a7b3e64adbd43b758e9fbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672376.0,411736.0,872720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22297ff806d6510c7482723c62e228451bd05408f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738744.0,467576.0,818720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22630db81d637f401c58e9be5c9611e3d54a4bdc23%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777408.0,442392.0,883440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22536eb339062441857c407329acd6a390a3a30c81%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710696.0,432624.0,947440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228caaf2b7bf86a908fafb8e50037bec49ef9393ce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678488.0,498688.0,868400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b43640a9d6c5ec2835f25734cf59d06c39bf946%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658240.0,412760.0,851000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22904ffe97e935b3b8d8369874dd7fc291ff351832%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640456.0,389512.0,922080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220640c529eb36990a33e1f758de11443a57a771c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739336.0,469616.0,817160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22147fce4d3e3908571a75df93aab5876152cd43ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749480.0,439360.0,886400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235dbb1d05f47e831c5c2187c0628f3280fa925d2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701528.0,434616.0,932800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226cde5bb87fe832b0d632661a763e74563cfc84d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733008.0,392800.0,942320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd491041381ac869c8327dcdca92c5c97378c0b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643728.0,457288.0,850440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c92325dacdaa8367b7564cdfd2f942f406a69d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728104.0,454280.0,851720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f2280cb52b791aa43e2ddca9c8757f84a4ac2a5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614040.0,476128.0,940840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bbdfd314d56103ba9702c406d68c87f34f8dc447%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616204.0,515080.0,899320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc37bb1df218a805f211cb02f61dc3130ec54fe4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659224.0,450104.0,893520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224c817797100bb184b3babde5a4deeb33aebf3f4f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B801392.0,455968.0,878920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222a492b60114dc9175aafe2f281ad137abcc8f46b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627248.0,415480.0,909360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8b6b8b9a845a9e75d2b47886ccac1712b7c2130%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709296.0,366616.0,1029320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6492c74cf33f0805e7284eda59cca2fca16417b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689568.0,439104.0,896240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bfc03ad5ac0143bf2d5c06fcc6c5177084c4c17a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666384.0,443808.0,851120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d9c2373438766125f4839aeb318c473d1c02b7b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647936.0,422896.0,916920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c5bdcd23c75393452d0de4e5ca6ca2a3f87d351c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676680.0,379432.0,1083840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273cdd6aba42ceffc96faa23b8490c38883d1dbaf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658288.0,461504.0,943560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22607782aecd447936039d3f68044fdcc6feea0bb7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666984.0,365200.0,784840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d22d30476e3d571d75412cc8b3f7564a144248be%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695528.0,443752.0,898960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2248d110b72a082b6267b5b3902ff3e67a9ef15f5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684776.0,444312.0,880440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb3ba3a3395717e81eaeed1e12e8339f0a1a0ded%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621456.0,420688.0,912080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2280666574a949b04c47390245444c20480e330ef1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B605712.0,418000.0,933000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bff4640e90defd4f9783293f90d68a756d6894b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680832.0,437656.0,901160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22772c5b287b93313a1a2d14f0e566df512c91802c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677248.0,517720.0,984880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22492dc955220bb3a1bbd4a24698859fe419647aa6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713304.0,458904.0,867400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207f2eaa6f0de092ef4d9a0c0758cb1c109341e0d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710264.0,450632.0,885640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226fe711092eae1ba9bf3e7ed0408f64d1e6aa1117%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689416.0,408776.0,837120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9471129429d410f2121714a52f4fbf79824276a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745256.0,422720.0,961560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0725557d0c39442f0b8f9b4d9e0775c72fdb0f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714336.0,385376.0,906120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226519f28b7892996ba7641a904a66fae56334e832%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721872.0,448344.0,865320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ff72a4ebdd49b142acf13f034309afda4aa2183%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672052.0,374800.0,800920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac5919c671d8bf0baf2a2e3e8012439871289058%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650128.0,421608.0,917960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202d2b061ba30875149326e64dc614dc65baa4c10%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656432.0,421472.0,856120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f74776f51ad032a1643f8fcc3ea05ddd90176635%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678112.0,389116.0,834720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3402ad48fc1011b831028e30bb66ed5cfd81457%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741896.0,412320.0,844680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d4307628af119c272bc722e46f11cb4220638659%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669040.0,424472.0,930960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a0e89304af8480c145dc35bb3205d2d686ba7a51%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659768.0,417304.0,940680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22951a8aac801119762d39f505ead50a948f3ef486%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668992.0,522112.0,865440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22889a112eca70dccff743a8306b9c45f4d675c7b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657816.0,422856.0,858200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22607a157219506c562305c7f3d20d80c9b49582ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669664.0,414672.0,940440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228dc66fdea646ee5d1a76859ace60297c70baaff8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713712.0,439200.0,963120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fccac5ffd6a406fd9185ee855afcbd1825bda3c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667352.0,448752.0,866560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228edabce33df30c7e499486d0a093cf2f24681e9f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664864.0,441536.0,856240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e2259f2d25ca21746aaf7e01e51936bf0a1ac9b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606784.0,403656.0,813800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f2b730ca212d5cff8816b588023146f10083de1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684480.0,482544.0,983120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225291d1465387bb111e1cf8b7784a62f80e48ea3c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614600.0,418872.0,788640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f37b1547f95e76856b3ce44fdeaecdee7e326517%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725488.0,522896.0,906320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f00d31a7c4e2d288b8542f06c0b6c18accfaad29%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B757828.0,401480.0,958560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e82d7b60d71fbc8b12d0d1379d41835bbffef9ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701920.0,443792.0,884920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bad3bdd0186e2bab43753e85d05226c9d576e531%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744904.0,369664.0,923640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bac1ba30ac8c6de19553f05db07eb43be4f811a8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B596488.0,419200.0,938720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a50f9c26f3cfbe45f7110dc854f111556624647%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723616.0,440668.0,914200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c723e35d5558703f1fc024e87e429b96e54c8c2e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B591836.0,472144.0,859120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2294f99c48b2a34ac54da6ce4de1d20ab77e2c7d31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705248.0,373936.0,901200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f9a9c1282f81772d1b7b81d79c4f83e0840b4fec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615168.0,370480.0,980840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db05a90d70a77f7487143c32f4299dc8da5d6bf8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653048.0,452248.0,861240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e7b1ca690bd362acc9790a21d9fc4700628f0e2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636904.0,388784.0,925200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ffe01c88b3f3a1bf1265710d5eccd2e9ab624ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658064.0,464392.0,944080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227b2b56a5da2da8dbceca383f6bab6a66594e98e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699320.0,384112.0,945120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22935d169add42834aaec42d88345a0b55992b6780%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B778584.0,436328.0,879440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a847479a3c232159df2e88133dd35d484b4fb5ac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679312.0,388824.0,1061720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224ee3715ed09841f7f395e829ff4b9cac3f629c92%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684272.0,455800.0,929320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226698dcb7c2bcbb1792436a5cecaf642258f95200%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724760.0,418040.0,863240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225aeedac493ae732a5a59c0343f7dba79181185d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741344.0,369840.0,922760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8b5823cf2cd6b292667086723cc22670fcc8da4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682176.0,450216.0,919000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225201900a3ba55e230f21dddb439627664512f7e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686688.0,474360.0,877800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc0570cf4a1974fd5ece50db0127d241897f2c55%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613376.0,404200.0,815840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a7d2ca948fb40296a0cd3975bab37ff45341f5b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B757704.0,363800.0,942480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f6c370ae171821aed1b278aa2bf7e6f9e771c43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689920.0,453304.0,892480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e1fe66ee1895495c14aaaf836949f669a2f3a91%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691624.0,441952.0,885400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b365f540171cb42cc74f02f40b57f22a2feb767%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727104.0,365224.0,1039000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e34b7463c4ca96d6fd5c82630f407f70644515f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728960.0,506624.0,909600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22113d4c48c9be5bb4f3e4c463775f7f2847e38c64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717288.0,444088.0,1001440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc5aa7e026f1a7e1555e1f51d61e139aa882d930%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745056.0,442464.0,904640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2848df063da2f13e359c16bd5271a0f8e4f2116%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695680.0,393684.0,928880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c61fe66f8364d4c713af2c32aa806d00e29927c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B774224.0,435120.0,880840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b366a9a6e8e1a57b182fa1ccad7cbf2993faed9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728816.0,457960.0,841320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7388d93ae86e805fed0ad4ed6a38227fd074a1f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756016.0,419680.0,968200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206d7f75c7dd3cbd357e4515429af7d2c130cd076%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668976.0,426168.0,868440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ef43e18bf0a70382949e9a0410534a1900927c25%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655768.0,465376.0,945320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227b139af85ed20958c91e32a3c4c51fb0eb48c508%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750112.0,362984.0,924280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e837d6e3ee5660fb233783a336a8a3f98ff6a7da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668152.0,456192.0,866480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ae18ddc5a3fa7f34697c1321a5d9da45cdae7d0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658936.0,461952.0,889480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22495a8d80b0100370a3cacd2f23cf6646587460f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650120.0,450568.0,829720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2222ed8a36bd36d31a519653e3167c66d308b91bee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623664.0,393400.0,808000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2239a4a7ff88d97d5fedb6ceea7a67054cb4cf6194%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675056.0,432288.0,875160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2209844a89a5c6817849105dbfd4155f9425ac84d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727112.0,366816.0,1033480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ec6be9aab124b2b28caf730b100367c550e3a9be%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648720.0,411680.0,948440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b28935305f87f1f081797d4bf11da5fb69f0a70c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718664.0,363336.0,1010040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6e99a8ebbba1ea1426b817d182967382b5b0d38%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614352.0,406680.0,813560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22df07b9c0ba727aea8d1981db115db6f1212ebd84%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681808.0,394848.0,1048680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255cd143932ae0df095a6d40e5fea982f62578c72%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726652.0,361116.0,1044320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1515fb8f6d95b1d59c7432fa1d1896cc9e0c825%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706784.0,439156.0,918200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de29de349024a35a8089207957a423bb082f5197%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714304.0,461120.0,897760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229cfc11bc11797d510c60c17307c160e26a1b85d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628848.0,481328.0,873520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d36b44c61a6b8729208bc57dcb091cb903356ebb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687776.0,461448.0,945280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e843f33c0da6816ea38517db0f4336dddac85e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642488.0,405472.0,890760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256e1dbe8cbbddbc6bcd36dfe4033075776a732ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730968.0,498192.0,907640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a3f3fff8dc32aad08101337176ecd1171649389%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B564800.0,393888.0,812880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223941c6ca96ceaea33a18e856ff338fc126d094e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696104.0,388424.0,935600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22df9ab03c7677a6d0d84c91858631ee3b482f1684%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674696.0,509512.0,979760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de784fb2d5096107d6e38f74aa1072b52036414a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671704.0,440480.0,865040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f0991d52ecf18f9cb3ea63095ae64a1b4eb16740%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678720.0,389528.0,1058120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bee23f297587d95a7f4b8f53c5fc723f9e72be12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674040.0,508960.0,868920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221de1a12a56e33af11f3e62a4d58ddacf2bd47ffc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652704.0,450856.0,831680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f1035f7802bc74ad797b29f9b525f1d161a2d82%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609304.0,415880.0,928600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6b8eede4e756b6547a69a4f89539d9f8bef7aa5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643344.0,473264.0,877040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226f8ac2f0ff5d44bc985fecc3f27cf809a9b5e4f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682344.0,396504.0,1045800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dfb1dc08426aba05861aa19ad800fc29cea64a17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733768.0,349472.0,1064360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229831b64b8eae793a395bc20c1ea6083e8edf06fb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708648.0,367704.0,1031720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe2dc833170dc9e0aa2c9fe293712ed5206512ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714952.0,453696.0,958720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b1d1e74b47ffddcce8b6efe0ddeb29dda3c60b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648752.0,408488.0,950160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228bd2b94a69bb48cf6940c2294634b00e049aeb0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709808.0,431432.0,940080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f5fc605a2caeeef360650ff2316fa29bde08bb4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722528.0,473040.0,981760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22be1d362d971100078fbcd0924fccd3b661d139bd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693624.0,386800.0,985000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205fe374f2cb51f2715f3f1edb2f7cffb6b940d79%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683064.0,487992.0,868720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229100dc7af72743dbc4fed96f4f0842367b9d804d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670048.0,489984.0,881720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272d4d352155bcff800e06690fbb0747b0391be41%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731648.0,423304.0,950320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2291dcdce10dcdf75a1cf05d16aa1fcce9ef8bc8f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644192.0,409008.0,829280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c049a63bccbf1df38803e920330604456c09b9d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661552.0,417912.0,938360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228d74fe4f13518dd55113b6303bdf0c4d145a0dc1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603544.0,467568.0,864760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22893f3a76b71ff51d13f7eb4a1c9f903815aaf10e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675472.0,507416.0,979360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22834ba55ac28f00633711707ec26b15bd9f8e3ee0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635952.0,459408.0,884640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ae30d0fe5fe53f5d60dfdfe095694ed22da9d75%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635496.0,421040.0,912160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b99a3a1a03e8149f018144a6a42fe8c009437d8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B753040.0,449336.0,895720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf8b55b2a940b16f017da86ef734f6e13b51b9a6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672300.0,493564.0,971320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22500c8afbcee253d93f3c6807df33beccffb41e5b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673248.0,446000.0,873800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ec1d79ded3c3e5e5b9ef50038afd38259213d65%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661528.0,446528.0,907720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b83b5b6f820ad9c1ab01f2a9a4e22f887d1d6fef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631240.0,459344.0,881240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235fc07a666afc9eff29737778a7b80e4fe92eac8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B758488.0,437760.0,881440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ffe4184a4731a3ceb0886ed0dfeb7eb66d0e2e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601600.0,365856.0,978000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257212178beeca0a804aecb80b6854a594f5ef8dd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686352.0,403384.0,1034320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222abe68843e74a2634439c81d89594f75af9a5ce5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726520.0,366600.0,1036480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292938beeaecaa2ce31b90744ac7799a615913d1c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707968.0,450216.0,876360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0054377fd9c14207f939ec25ed2a7b778e04b29%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629816.0,407672.0,820600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22deed2f54904359dbc4669272fba39ae081cec078%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B833944.0,332584.0,935120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257bdc6188b5178ae40d00b09fcdd617527e7d1ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686292.0,442328.0,882960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225998e4639591820030109f31a2adc8ca2e6ef98%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655800.0,412696.0,847560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2264197265ba4c7b0d87db1cf5bc151ef25c116662%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663400.0,463464.0,859120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eeff1c9052bce5e623f0584db2686912ee64d27e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668208.0,484936.0,887840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c86658015e51c52dfe10b44923716aced699b6c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705608.0,491344.0,837560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a72ec94ecda44fc33b2b33d95615e0b8f9c575b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696344.0,389504.0,934280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226068c6d769901501003261d71048cbbb5d3c3e62%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621968.0,459464.0,873320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c02a51b3b44aa57afb041d53382c809436abadd7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651048.0,412144.0,840640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7c041ad9164ed826d104558dc69806e33c5fd4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665392.0,401104.0,997800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba76bca53d7accb9b98243d9c66a9ffa800d867b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699624.0,381792.0,955440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4bd8ba62fc8bdfa9599e7c1053cfb63e8f86912%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729456.0,458452.0,809640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fbd8005b7028bc6f7f72704c4d8689f2708d858%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619720.0,416160.0,916080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7759c4e264a282c340a888d4e8ee994d8c3b25a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720864.0,453672.0,838640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e955eef6c0d38cb098625763b7591a32639c50e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B593976.0,423676.0,909200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c503685510736bff7e91d151e7e7e96c4bb52a79%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762716.0,436204.0,881920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c0aa852f524724668d819cb82f1f7b604fc76c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726120.0,361296.0,1045920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2224f728abb52d8270c1506546353c644ad44416da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676608.0,416568.0,883280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f7d24b0c7a3f76ae866d522608e06745b0d7b75%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702008.0,435760.0,933200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a04486183d1484384aca116f498d61986ad43a3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650176.0,413280.0,903920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c4048964bc2d6b8b4d24d4f458291965940dca98%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707760.0,434800.0,950800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227795c12e49e9a0afe3ec7ee830a883b1e8215f35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686576.0,392496.0,900960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab9b3d3b037e2f76a7facc6a0a5ee18cfc6e724a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700696.0,434704.0,927600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22712152febec66679acf12078baaadadf879d9e85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709632.0,433592.0,948360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c943dad5601dd935f63e04f9523cc667a90a24a3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702560.0,441816.0,884480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2251929af0afba4c1d089c7608a33b7c2b4b93b480%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657320.0,416232.0,893920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b3af93887e76bec9db9991b66d4c4d2f34f2a88%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750440.0,447208.0,897320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de6e0ea31934ae6500761d2de2c3cf5ee10be405%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704096.0,436192.0,940360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c2b971a7e0d4c5a1191a3b5674744785903e2a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761532.0,357644.0,919080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22896dca5f362580b6ca857b6afe859e5c297fae4f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601072.0,421096.0,910400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2218b01ffac67fbddff5d186cd63f187cfcf0c545e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645104.0,407208.0,829280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e98f5209a3c11e277afca81721ef2a6cce0ca68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612720.0,364448.0,990480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22789d2111cb880ae9a35e9571e438d89b96961b00%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B588560.0,423320.0,911680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7001414f6f249fad2e9a7f0784eec21e1be6e56%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729672.0,424672.0,949640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b4b16bb6654dcbc301790f998cdee16e19ddb29%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642704.0,401384.0,822160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22113a45b6f666a62f4680fa17b4eddc8c18d6d994%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677240.0,449112.0,912360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3ece93c94e573f209acaac26879185ec8f5167d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752184.0,418272.0,964840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2237d811ff8f0209afeb1a2e06ed7640fc03512833%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614264.0,437008.0,767120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22be52c9ddc2167541d5af8295f5bddb3407964522%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B605064.0,421976.0,909160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da4e64aead89d182fa896194a1d0d918176fc248%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680240.0,433112.0,915920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226ad76c51e9afeb52dd35e3ae84fbc311c0a3454d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713184.0,428608.0,940760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22957d2a62d8d08fd5a9a6ab5d826083eaa86c0d05%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B546168.0,346024.0,992120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c81c6eebaeac19452723daa37415d75213a4e7bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648784.0,409768.0,949760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222089f995ac0324bccfa774518b67840073f19e15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714776.0,465496.0,900160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e426a9f2461a9db19c7e3bb2e615a70bd87e7f52%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679192.0,385864.0,826640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2284c8dcfac9a8b2a71f1564dbbda1e2a0b8e36598%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650160.0,454968.0,895080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cece42e1351a460ae4d6ff70ee1b2798d0f851f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718016.0,488336.0,994080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298e8d44f6e9f4194ef54f4fd8cfca3441c256f34%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B587512.0,422392.0,913360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225800e80ebcfe10252577c44bbced0a42009117e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687360.0,404560.0,908960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22983dde36509a5d26e312ec471863f7445186e088%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B764488.0,434880.0,881720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229aa7bea2277f3bd72ef30efbadbd76341d20fc43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713368.0,462840.0,898080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dcd2d0eaa8a609e3bb6d973944c54face28d59af%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671140.0,425424.0,925520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229184155435bca2680ca69404249b4bc5cae98646%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689580.0,401816.0,911640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d660fdf995af58ae86d9fc377a1a9ec6cb5e95cf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733416.0,440696.0,912400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ad99f1769489a088ba587ae568ccd36001da885%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678464.0,408816.0,858240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e743d7adb9983d7e958b49f37b9028811cb82f78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709928.0,435640.0,948680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227150892216781273e07ebe9053ec76dee758b7d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731352.0,357560.0,1051280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265b889f7dd58817c48742f53fc58895c24df2858%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719544.0,441544.0,913280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d9fbb213b9273885dd986ad567db76b38d1915c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611344.0,395088.0,797400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f9761e92a0e1c4ed57702dcb584c9abb1ff8499%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628824.0,613104.0,882400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c5097a8af1ef05b6d7586b73d1be0b50bfd3ba2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690064.0,469112.0,882840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e12de2513cabc10784ced1d0d7f4f930dbc673b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648624.0,408872.0,833320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228852f6115439b6d0e2d4bf4e6e6b2eef769915cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676428.0,374112.0,807480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f2bf6e2dab9a8bdfc82b29aee872f95670deed02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725592.0,457816.0,816840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22892b05bb1b78dda2a1a82f24d48739d004000896%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724744.0,457448.0,818560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22937ffbf30cbcabcd58ce92889e5f9d80c86a0fc5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B775112.0,451816.0,880640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c827f1b3b83e6de631660a16fa9539329cb1f55a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671560.0,452488.0,909000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e53fd28e4ff57fc6ab2e6a9439998b9f8dca745%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708872.0,433736.0,886280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e9412327f302c84d4a5769e7ea00e77c6486eac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720104.0,472112.0,978640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295fcbbd509e48f2532a9f508ccd4303bb189e286%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667128.0,413424.0,960440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d3ea364ed0b77e22240f3890b8d4b27b4696c6b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665096.0,366096.0,785520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da3a2e1b3515bdb1925b7a8ccd2442f71766bb78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B610296.0,413744.0,927880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a74af41ad7fd4a421284a3b0d34095caaa00a9b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B746416.0,366672.0,925040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22782f00219ba655f8f28608b1338b37a2a4e6e1d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725184.0,457952.0,819360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b945935f8a1628e0fde3651429f092f0ec3391a1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702888.0,373232.0,980240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22131ad87eb5ebc7035f1ff195e6962ed1dc81e05c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B788540.0,353416.0,941240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b44e38b4ff58ec2d0ccaae8124c53e3a3393153d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684592.0,399584.0,1041400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8cf5f58fb27ba79aed0dbf9bffc0efc17255ba8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683912.0,420848.0,902000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db7183479a2ef448978d3db009c4c082cb707eda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713776.0,482072.0,848480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc972eeaa16fe4ee97e859b929a4a1a18bb329da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709904.0,488328.0,838640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22337ad8ecdd899e643fd19cb7c185535c70583e5c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600192.0,415896.0,918680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ba974d5343b0a3f98c099bf0493d48a635c05b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666680.0,410576.0,963480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5c4045caea9fda298cd2dc435b6a535361437dd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684136.0,398912.0,1043080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af0cf5c60a54f3e011f89e913d0fca81833ddf96%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670848.0,416928.0,889880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b767d6f9f1f80ecb1fee05ec7ba95e6483a9baa8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724488.0,381992.0,896960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b1700ad93134bc4cb9ca999ff85b35d53341175%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716544.0,438100.0,890000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227261a3cb556599ba4c0fc2667ee770bb06669195%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603832.0,418400.0,934480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22878c6fd8fb97d52a4f1a2721a28580ca59734a8d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727616.0,457152.0,849760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222bb244c0b95ed70b66efad7a244c846fb154d966%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656232.0,467344.0,910400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c6f9186395bc85dc7e9484092a23c83e1272df5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B823908.0,324660.0,1014560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22321e8dcfac2b8cf8ab7f4d92dc2f4f8c19efc6ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B579080.0,391648.0,814760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5ec83b710ce573eeffe30c40ca97ff174eb45f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B797776.0,451968.0,878360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f0f7c50bd316e93e2dc8f128db3de31ef80c6ad0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B769176.0,449728.0,884240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258889a12102b1df1553465004f68e9e1131c52dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639488.0,446040.0,821000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e73fbf99e3815f09489872db8d468fa006a773ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665088.0,415736.0,889000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e61cc354726fa46b88058186a6152a004b9c83a2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656776.0,472744.0,907240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229317e8a65cbb939ac61358b5fb4b9bac08aa724f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677880.0,381936.0,1079680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228881d20037d8a7ead5544fe69ea4725e293847f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737096.0,467160.0,824400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233a451972961c8314b6efb2a3617e46135cad219%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701056.0,433864.0,884880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b4f4fd8c8485dd719c01b6fac5bc189e8fb5573%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688800.0,443304.0,883320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22632a0f112f14f83da0c2376e1d84588fdba4e6ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647368.0,456840.0,855160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2222b964f04100b1fcaea39c44755ad25e39715e89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673088.0,404528.0,907400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a9a64dc686af794a39b298af5117f6389953e02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725264.0,452640.0,854800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b0a1e7ed4a254ce671dffa6329ea845984ac3fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662888.0,411620.0,856880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd0f416fa052782e1970f0dad12950f23cfd9161%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687256.0,480504.0,972560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2214251a82fffd7282c698df207264add3a38ad3aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686528.0,411160.0,902760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22053ecb92f154df8a85658f0d610ea5a9f7b5338f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640760.0,446456.0,822440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22812474220878a04a036654a62f6406a6304ff942%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645064.0,482616.0,902640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22376469862cc4c772b87297aef2ce5af82352d481%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658840.0,412504.0,849480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22669e39f5ed02018832497f2e2ec1d2deefc975f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668184.0,426488.0,921480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed2f95d3896adee1c6c0166ae1efbcb7e276bdfd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682312.0,398344.0,1045680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225af302eff71e1e211118fc22564079f9e5b82008%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716480.0,471880.0,901600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f73ec7d22fe58932bacee336855d341b9213d7a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663796.0,461560.0,859280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22531e77ac297d98c40c836bcfbb849126fcfc0f78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682656.0,394440.0,1053880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1c4c21eb0a3b3f7c355b1912d6c4fea1b207b00%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B577488.0,379076.0,808360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22393b5222af82ad31dfb8d5dfdf73aa9b776b8d86%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638880.0,462112.0,925160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1d2f7b8937032349d5ff5ea743c45ade46972ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708960.0,367032.0,996600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22326f452cac99858fa2ae38efaeeed36514653e0d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703368.0,365072.0,1035880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22040ebef7d8f8b7a325c746e1602c7bb5ff4b5969%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673336.0,398360.0,1010320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22105ebba2ecba3925d333b96870490fb3ac9dcf68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687464.0,395088.0,981200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223841c4c820ea5bf5b3e35ee0cb0d37b19c70fc5b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615976.0,366216.0,889680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d80ee5d87a05f908cdcf5e755c455c5e446a1e8c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733620.0,460052.0,808320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f518c9e7958db0b7dcf336491525e9399edb47e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B574792.0,374744.0,810400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22448183592431f1a6b409ce46648f646397c1b8fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724776.0,370232.0,1025400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228866387080aaf1a4998f60aa4c3d1cd3d2a95bfc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624088.0,387824.0,892280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22100b4716cb0694f3c3b4051c9d06003a3b21fc17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671880.0,442992.0,930080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279d31acee76b27656205a37f958eb63875c8f365%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715224.0,432856.0,955320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ee04a5bf62d667cd315f5aa2a5137a1d7b4887e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665512.0,424104.0,867200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223db839e7f0e75cd0d2c7943ca006aa3113242b35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657400.0,448896.0,837000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7cc6783bc8b2d58635c86333c3bf0357ce5722f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B591264.0,411928.0,925040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223bb6fa4cec1ed1cd0079507bc906d3a112157730%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707960.0,389696.0,903760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cbe6952f5bab49a50bc9b1e6223d0393bf8c4954%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642336.0,402136.0,820920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224951b1c46d4eff867b7d25cfa00f40e90e92db5f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660400.0,456728.0,898160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c60273288cde9ae4f91f1b6b104c1e1b95cbed68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710080.0,441568.0,935840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222f5b1cadae5635973d940539d08e1ef8cf0660d3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645728.0,411992.0,906080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ea77bc609eb4ea09f29aa08a93f649ef6399afa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707816.0,432172.0,882800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab6ada8ce871cf6cd614ceed387c2c9c1f7fd62c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673312.0,506216.0,979200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22260cc1a4a123862088b49e066cb9fe90c4fa0d49%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744488.0,441312.0,908640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a868c4a2d5918dc8c4cf4d68f560de772f4d1c49%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665168.0,457376.0,912640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3ba483987b09e351e1c2a511cc8ef78263b2a1f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672368.0,456568.0,941920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257bb08cc6ddaa7c25b1fb640593963e71d5b0a2f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711664.0,432952.0,947880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f2a49b3c069dc6e1dddcd6a817f14e43c433fef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666744.0,416080.0,956400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255a9cfdbd3767a28f1b821653f41363b5445ee85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618032.0,412904.0,921480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225240abd8a6976aa0fee7421722d6e5c246ca0b0b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709240.0,487584.0,839440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228bfef8dd1f04717770b75fd5199ade8efbc039c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699256.0,435936.0,886480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22636ab266e09a9da1b986c76dd54101bfa571bc0f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673284.0,498912.0,977040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6c7138cf0819964eeff94ad10874a0f23cf6dd0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727544.0,459816.0,811400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7d233ea63361c7e6c0e3eb8c3eb4bbb1ed7620f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684912.0,407088.0,843640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22082eec51c1c3af447e354e6ee931f8074e80469e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716864.0,444656.0,999920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22536d4601525d06c22621ed11e291b7036d85adf5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613248.0,415704.0,792960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249925841372f7a9431f855c768034e120b71345b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715004.0,479440.0,848880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206f88ac9ae437f005e1c25ae0b375088e8e99372%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689108.0,470964.0,879120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22571b66eb5d6011b18a7cef5097559eb640cfd665%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666216.0,447504.0,895520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225910ce28170805146a46d79f227423b374442d42%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717248.0,445368.0,1001320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c088b0a548ab05867a403fd642ef7190e0700bbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719304.0,365520.0,1010600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2eeb05d9571a570f489bbefb9a6a7c744a5ca31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689632.0,467864.0,950720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2283b0642d02057d5082d2f8ee292d8f45d14aa5bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676672.0,376272.0,812160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224801dbbc06418d8223a057441793dd80531e591a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689880.0,438776.0,909920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dce77e59914468d86ba0f41a9add3e9747a37605%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674912.0,473488.0,960120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22840c2dd7de61d79c9e956cfbf4d768d9ac42257c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703504.0,369808.0,985440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a0f31a6d4ecb2ebc1a614f928f4ba57c19b3bf87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600656.0,419848.0,937600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f57754db7321fe5961336e4b3e0a5ac08d3b5196%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615048.0,363432.0,890040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210ab2223fbd8000aa6ecb9aaa327bba6457c89bd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713304.0,439832.0,873960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0934c4ee31dc380f21a2f071cce113307a56696%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674400.0,506184.0,979160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3112863ecef3693dbccdea7cd8afafbd508480c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660552.0,448800.0,863240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f0f94d5cf6e98d3b1b24fb46796f9a5889990740%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682304.0,421664.0,902160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226ed0d75ce5e9c044f7e7b69d53f3de2e0f93c8c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684888.0,481944.0,872880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227040299d209c5d124a12698ffb92d730c90921a6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683264.0,418616.0,902560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f40e4dac5b6ad3210bf0fabb872ab029d7a2effb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B753320.0,437464.0,882360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d85e7e844cb0149377d7e9258e68aac70392255b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687832.0,406384.0,908480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa03ca99067a2fcfce54a6422ed65edf9fe5ae25%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676096.0,378552.0,815840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233b8a37b7573a2a994be86dbe34dee1770f0eac9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637280.0,474040.0,874480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222eabc0ec63d9ede9700cf4af6433fda5fb5b9cb3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732448.0,466880.0,800800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2281ad316528f43de4c11b3c8b55e6cf197c6b01f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699368.0,435480.0,927720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202a80ae4ab68d3f1c4c652fba392fd587eb03e6f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716304.0,365784.0,1009000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c17d6a6f732081e1964eb8c42c6515f8862c481%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762048.0,447616.0,889520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2262842e5a1d267fdc025456b60187e40ec8523098%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707760.0,444616.0,878280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c7a8c76d76156dfd2c5a6d20d124bc460a8afc9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676600.0,440592.0,898440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e99a229550d5d245872e128a991b2e5a6f53802%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676128.0,414576.0,896240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf1b7d3a0e8a519f7abe27047bb278c6a97b0829%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654432.0,411120.0,945920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc0887fed3a00f1099e65680e73f39f9218a0579%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652708.0,420300.0,919040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1babf8176d78f0e456fba6e0c182c655babc68c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B557704.0,392592.0,810600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200d702c1c296b55942a89abca15ee1da539625f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648448.0,453704.0,915720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4263d6d700e1bf96a2983ede5198808d5957cc0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B784336.0,453280.0,881920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c53778e03815c815cb45a36d69711e108a7b701d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742144.0,425352.0,963400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0de77176a649888a27f38dcba64de3fe874169e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B789528.0,352056.0,940480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc5d173f2d7d9e59ebd678c25c076513ce749b66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612640.0,369720.0,983160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201b08a88cc70a38f067c9dc8d72b9e724f587a18%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677504.0,392536.0,835880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2268c3628c144ff01c95e84b75de3419349ce99146%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704328.0,453208.0,897720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22101110236665da513e1bda35967605af12936e69%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760272.0,359792.0,920080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e716382b66c0656c64f688845e60c7d0f09b9877%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693336.0,403416.0,895640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22866bafafe4e7458d8fc8a92375b7fd8dbf95d969%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734424.0,395248.0,944720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc364bbbb000b6e20aa3fe2fa6c7ae644a7da92e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654712.0,422656.0,920440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee19b90f0cfb3d704661dc0b1579f8e59602d426%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644040.0,407076.0,891240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ebf67914e51a7ad2bf29a020847625d0d83a8a99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667904.0,527208.0,863360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c73babcc3451a100b669c731804c5bd8e02b083%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672504.0,396648.0,1008960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa936b3d8a142643aec144d72a463d56f8892fec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710412.0,459532.0,898960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc9dacd80da1a42070948f02de87ece71924ca90%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690064.0,464992.0,884280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b2d61ab0d57b49a5dd6e3053a7c306bd0dc085a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B810544.0,331848.0,1002520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e692bb7bf24e20faede531471a04c927368ad08d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737120.0,383392.0,892120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22672f508f2b2758cd5e54e13ec6f1d2a6507ef047%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715728.0,447488.0,856880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220cd12a04c1d3a93b6f876012c6dc974b35cfc07e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633424.0,408496.0,825920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227508c96bf8d05618775afc6264d62c3891f922b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B593480.0,418388.0,941080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22840d378076aee7926532f17639f1484bbee14ff9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699944.0,380000.0,959600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2243ddd8c9e86c5e7477940078186fcdf9e4e24119%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708960.0,366056.0,1030160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d3ecfffd27ee3aa6cfbc77657b9f88af48b7fbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678872.0,392824.0,838240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fcec6169e45ae94c99f262b89563b760cafc400%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649432.0,422056.0,916320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22798c24b1e727dc92b4d91d96a9be6a5435fa861f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664408.0,445896.0,845760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22138f453c1f761dba7bdd7109871e82d2f8251dc5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661200.0,449184.0,864360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ae02c24b11883265b54c0f3b9b4f2cd2645f0d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702640.0,374088.0,977720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd3c30f07290b93be9f5d307541746805fcba669%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682528.0,453664.0,927800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f2fb385d352daa51e712c745dbbb154b62beb4ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654160.0,413320.0,896560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ae2024b59e6c2c578d766253029ac523f72730f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656672.0,412776.0,888960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca058f00c551bca0b412dcff9d1a0679f3280123%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722080.0,454192.0,839240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c999dbeee90010573fb35ad3096d53c46d1c2430%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714244.0,425832.0,874560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f92dd525661bed637ba784b26c52b384efa7a459%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683248.0,485496.0,870360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ae527b2bcb5a4701fafed5506f19e0da4288be5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663448.0,416152.0,950640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af107b9d04a77272533803dc0e899152e24f52dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711656.0,431600.0,946560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b4075fd5f845c2c3c69aaafd6c3df0d57249673%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614496.0,416376.0,791440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22254f3bcfe9acbe65c01772fb50d2195d313d4d2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675288.0,397656.0,844480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6d6cfe4cd7bf717b619d7f7894e8a64ca8ea24a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704768.0,451792.0,899000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3a529a5a747fda0b87cd3ce5864d28df73f392d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722612.0,440140.0,890520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222f544f0bc665aca2d949b026e436bcead50ef856%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634416.0,400808.0,893400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22833363c80d622e33af15c76aad84cace693541aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702112.0,433592.0,935840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c44841243229befff3f47d253423f3cbfd862eaa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662584.0,417880.0,940600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22787ac9d484de03e0cb8c48b95161cc73454f74c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711008.0,442680.0,878440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f230a5092a0cbb8a1b8b3fe9647b51aeb3d0c987%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680540.0,409148.0,846080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cae15bffc48124ade41faaa925f57a5834e57334%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713928.0,471520.0,856760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201339c198caa0d7cb2188760181d13e454bbed07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716520.0,458928.0,966480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c3a642387b1dc2b32259513074e64f173a7568c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714560.0,467792.0,861520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d93f3617e98ae789530400b6a377d52984142805%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698496.0,446264.0,898600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f98810c6500002dbc02fc0cc94dc77004245940%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B792096.0,452448.0,878560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a536e4858dba6e10baef467460aa594a73ee87f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686336.0,409264.0,836040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e234e7bfa76312b85c2ecded96b82ab13f276d7f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623024.0,510056.0,899480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0695b99c200c3cd9e3fd68e084b92b4749a890e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B758488.0,361992.0,936880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c2d71b128f6650efe41ff5941940a1ec8632a37%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713984.0,471576.0,855240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200d6cb9788fc956ff42eed1353038237fa2fb68c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761928.0,358992.0,918640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c78d2325bf34162d72a584601d985bb2043aedeb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694128.0,408568.0,823880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210aa490c2c68a6baecf5dd5fed77142c0f321ea8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651816.0,449928.0,913840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de0d5bf4fb315d67b481c86d560740e80ac21d70%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595072.0,471544.0,860000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231906a34ec6c3c9afb4a52b05f5581424a059d91%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B813184.0,332896.0,1003640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223c9a736ac373db9a18471f28585cee4dc0559cf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704224.0,438728.0,917360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228655532f9be6135968614e203493392504301c4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727472.0,459304.0,812200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223bef2bc262ef3e3081dc2c3de6e334eb795e6438%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662692.0,461288.0,943080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221723c159f544b6d3cb2381b1ce24f1149444c102%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636496.0,462304.0,930080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee433c18b6b5037b3fd1d7f8e12792085c1209f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668608.0,446056.0,896440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8836707333157430475a4f49422fbcfddb33b87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709288.0,488136.0,838200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22740f17d206a5e5f19f5e1fa0959a8529af25ad93%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B579264.0,391600.0,814160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f71cd1f2a65849b38f34f01400e1eeb985bbfb9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719304.0,465152.0,972880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22371299514e6bc4815a25ca36613f68d2cddf3fd7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719248.0,468664.0,974520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c3c2b33b35b0f4509d622e9e4f77c2f861ece8b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645220.0,458644.0,893040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a649efb2ccf7451eef4bc855bed6bf5361f1f98%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716200.0,444368.0,1000080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d078769fc11c156fd36fd0e3d91c77ee686318a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715576.0,382432.0,902880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228296370060fea65f478afb76e5cc656fc6e8ee60%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754928.0,361352.0,934760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22750c3d49aeda8547ad256ffbbc6eb558c2fc1e49%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703496.0,438784.0,916840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ecd0e25bfba3b6041a58cea8ffff581a549a3a3f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713744.0,425472.0,872600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9616c22b19cf45b32d8b3944d2872c482871920%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673464.0,450896.0,937120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224dd7d577dc1363056b744ea85bbea7bb99fc9cd2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713824.0,484440.0,843160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d6b1b825b92599262966b5bcbb9fd8d31c2b858%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684288.0,399848.0,1040800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d722f9a273635865e348a8938fae1d62dedb662f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658600.0,468280.0,850560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22212394fbe2c72ba06a2483dba3a0f97595060249%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690296.0,467664.0,882000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221cf8640a123520a47a84b02bcb5ed69d2464936a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724172.0,417136.0,867000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220559bf81777a289a8e64255ac20bf629baf804ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674360.0,446552.0,873880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2246d205094302c2baa3387dedab1715556d69c2cf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719152.0,484624.0,990360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3e7e4f946e305b505de03dac5fe133e67b4d9a1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683472.0,400456.0,1041120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2222a5be86e437f7d926597a4041c4d7d172a56f7e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724920.0,518760.0,906120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295b7cd929db1fd1ab451c5fe4fb8eaa0b2ce7558%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654664.0,451408.0,861880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222152b50bb906fe67dd95ec33256a8d962ea2107c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627592.0,392528.0,894280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f048d93bcb324f7436c0529f7bc30f81334f3875%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B773168.0,360000.0,957520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8de07195a3edf7ef4f23be2d707e8e566b08bef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737608.0,441008.0,889360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7a9c26787add740f04e9da01a910cfeb0469ecd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634888.0,460240.0,885160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b9c90840455f1c33cb810752f262afd3acf685d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664384.0,417184.0,951720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bbdf8b8c99eb6fd8d7672fe15eaea64c5f391b28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695888.0,408048.0,821960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223332fdb44d0b47711f35c5bb1259922deb1aef8c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726236.0,520908.0,907840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e009171d356180f8797822ccae05bbb528d800e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665016.0,402008.0,910200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255fa7294d53b63ad868824ab18a025ade142a78d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710536.0,394464.0,863480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d94f01b8d4122c975cf6c85676b077ca431a6c04%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722632.0,367992.0,1020120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7ccf332a3f614e014f93fded35ab0b234a9ab94%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637360.0,494304.0,899640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b491c9603cd0fe625cc864d0fa6e13d2eac3a0e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719300.0,441688.0,913000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a570803908bf3115b580f817ba783eaed8b34fb2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666432.0,422192.0,934880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228220fada68423145bc9201d9b380f98e4e74dd2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667600.0,421544.0,930960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22521905fdf6f6395e544389004c19264bab215fc7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658592.0,461280.0,892120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2aaa1990a8dfb944511e45af3b93f58a5780fd8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606928.0,480152.0,944360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22339c0d0162de60426310a6eb53b78a6e0f722651%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664032.0,415840.0,952520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22312ed7bde211f25460e21eaccb2448aafad87d74%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738040.0,468664.0,819600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c26b06863313757ef3559f1efb57a4e1e049a5b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666280.0,456928.0,865320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e638efc25c4d39d0025feb9605c5e89d3a62cbea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642864.0,459044.0,892240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22641d4661f1ab261b5ded99ab4cfebb638a1008e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740016.0,424024.0,961440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a0f061a6e7c1462883792bb41eb0baa22ac7ad4f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B802112.0,340520.0,990000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232d85b5456509d203e20f4d79f3d2a5d3561e3c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673680.0,401520.0,851560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c95533dad31851cd9fdd44f3916bbb000d409485%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737568.0,468112.0,820160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22632b032a0cca8582611929a5ae7c4506d1c39d7e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725832.0,381408.0,912160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c931838dec4826d0a3b42f0d4d50fac1e2d6f5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608584.0,479024.0,943000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2212be950d9294320333d0a1eb5d1d470950609aaf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725960.0,442376.0,890800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22901687570fcd5e511e7fa4ae9120e8beaae1a0f3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626928.0,354304.0,1008960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f16a8d5b5f3c9dc355e934cc4aea63316743bd7e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736176.0,467252.0,822000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226789507502ef5c9dc32ca0df9f1eb68fa4695cd9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701928.0,372464.0,982760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bbf14594856edbe95f55c2d0e3893047ca6ac662%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B759856.0,363184.0,922000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e19dc50456e8933d16b2e3b5344573a06d0e65d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750960.0,419048.0,963000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224168fa1a07e1b968d2c68a7ccaf647ba562d49dd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B774880.0,356800.0,941680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d5deccd7be19e7d9f2790c9ab0ff5f98096e15b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631348.0,391576.0,961040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203187f648234ed00ab72520a04d343cf0474ecee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675616.0,479176.0,962120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224c227ab85f37f12116c432f94bcd1c6e7252b124%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745696.0,438584.0,888520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e4715120e602ded5d989ec11dfd7c939c34e457c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607880.0,479632.0,943600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b48108d4905ac1971cb35cdc22cd39aeb43523ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719848.0,472640.0,981040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296074b8c66303a2375f5b744dcccf24e5ac462e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754152.0,398128.0,957760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22265fe3b8491a91c621a7ab1bad6ec9b153474b31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639248.0,459680.0,923800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228aeaa258d64d142ab6151aff15bbbe0bb484b1d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670132.0,407280.0,946040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3b0ee9e9641b6f2d6080aed8175d47a9395f234%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660376.0,467104.0,854440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d58fa017a02e9d4be94f7ebd45adb5f0e468b60f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722888.0,456136.0,825400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22165042469b052665777146d26716483787380969%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664672.0,419016.0,937320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247f62139ff4e59d89ba01ce89e71ee82a993ae02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665528.0,444376.0,848280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22865c0a2bca96ee59f8d0ed52e25dbe5361d8609f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B574728.0,390304.0,816040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f60b428b480205f5b6c0ac32f8258570917ea8c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715096.0,439152.0,869440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e711b41f9992ff708d1abf615f3f3810f99a2bd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745104.0,414552.0,830720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224dfc4f79bfb5f7619fe3a5e4e69557fd0db9df98%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736920.0,467392.0,821000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266355d46f04c0a2aabac8023e75c2a43c5d5002b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701888.0,393496.0,928880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229bac9239adcf7d9778a8d57af0b2828aa51b49fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607568.0,416216.0,929760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e4ff92700151c93fca42178d761164984c57e19%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687652.0,410468.0,833560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7bb9c9148cc5605197008c34990afbe8cb6d4fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715120.0,439680.0,871120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290f0eecce9495dd288012c7bcc7140169aab7283%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684704.0,391752.0,900040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22156426c58e9f94ae1e4a67f94f3476dab30970cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626184.0,410256.0,810640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22862a5453d10e5c1508cc6c8b0f1bf3180ae42620%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664992.0,416424.0,945680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226dca483ffdffddc77523d5d8cae39fec724be51b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623816.0,387536.0,968880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff2c01cc2e6804da9e4435bfb4088d9533897c23%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697080.0,392424.0,928600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22212ab95f9439d885960a1e0ea9e18c6a55213490%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679276.0,407884.0,856880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e4f1e94614e5e2c1002c60e425cb760343da7889%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664200.0,415104.0,943000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2218df7a76f357f4f62efdb944447985c60d442bde%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663772.0,445192.0,850520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5cb470ab3d0bd8026bb26f14f57d17b545932ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752360.0,365192.0,928920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2284364fea616b96c5b5aee2f759b8907f72c82924%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723832.0,392440.0,933920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22778b5fae5ade17e070d6922c94d2119c6faec15f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665520.0,416416.0,955760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205adc833b8f45af967dcd4cafd1a7670784dc0f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641392.0,407832.0,827960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f481183c0a802e44e3330d30bf88233b64ea4a6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626272.0,386280.0,968760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2283e0000775ff60ec131787009127d7b82633580a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742752.0,384376.0,889640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22490f3f3a5a09783b075ed6c5e15fcd1eeb81003c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B800168.0,346056.0,983600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d32018b3bda80d8ca05247ad79aef0d1fdf3cc41%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B759744.0,449024.0,890120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2268de2fcab28f6cd6e83255b075cc4b24e5abce89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B568608.0,355848.0,983360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228194b469b39646055985a13b56594d8449d98e54%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683232.0,438584.0,901840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ba6887efbf29d0f5eb70119719e2ec344db2756%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665740.0,404300.0,981360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f711c69aecf11636ec65e3479b5543964a5c659a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717616.0,440688.0,864040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ffc103ddb1c0d418cdfffe1b33d93dae14dcf29d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685448.0,441420.0,907440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ad5f470fd2ad6ee0ece117c73517ef254fa8ffc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738912.0,441080.0,910080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d2e49626066d611160643753aae773fed1e8bc1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703368.0,375248.0,978160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c91bd5a86d78114b022e15a89144b361c5103ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710480.0,445008.0,941080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22157b531abfbf0e7d3d9f5debb5fb104da7a56da7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626776.0,480184.0,873440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b452d4eb98ebd18ce7624f98654e95615d686c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687528.0,473512.0,878080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b3aae305bb26e8dcbb2f4bb729be27ca267ecc5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655304.0,465764.0,883800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d28c96a295b841d84343f1d738ad8d79916f7c3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708944.0,393992.0,865720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2245a0be758469c34d01d8eff9ff6fa6da5c31da9f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708024.0,441992.0,934760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7f2eeff854b8288f892d99545dd57a5a45a607c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B800760.0,339928.0,989560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c20340ba91aa10fd1301704500cd5a86905c446c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765040.0,356284.0,936800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222f98c1d57049251e5c576c94442eaa3bdc844ccb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665528.0,443072.0,849520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b33462af3772cebf099f88df4f4c9276022a3225%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680344.0,383824.0,1072200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22041ece9949dd566943b90685146e66db38588444%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749024.0,417160.0,821560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c4ec94e9e5de30bba948bf13b652d6e1f2c4062%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761904.0,434880.0,883280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220c29767dfe997c17bdf2ad44911e978b14ba4a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709072.0,394176.0,866240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224165514dad07966c2de47827ceeef0d03588ed4e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684144.0,481120.0,874920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22396d091b6e41cebde6e5241758540b29c7372d50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684384.0,439856.0,903880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b5efcc72812dbe69524c6dd0ff1f2b6f769c670%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687736.0,391864.0,899360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277cd350e6cf325aab564283a50e89db70a2ab6da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760024.0,363024.0,942280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229be45990f289c98707108d735581e246123efc13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701680.0,374848.0,978120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227b8da1881aadaa039b9c14118da972ea145afa2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710120.0,435080.0,955400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a6131ff977c606b80dcde4ca83a4630e29420b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747672.0,418068.0,829040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8257fc3d971c19f1d64cb2916865a38caa2e7b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711184.0,430472.0,938640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267723315a6f0ad7e6fe7c460763f41e8073a156c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622464.0,415272.0,915120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290ab56c2d924892d5ad0c33253dbdaf4119b6b6f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738336.0,371384.0,921560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227db0fee1c2c2aec853c8b3c8dcf6067dd08a9cc4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626376.0,469600.0,937200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226338faf60f9e4e013da1fccbefc100f07745a26f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B785968.0,353400.0,940200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228501df4d8f195876c163dcc7e73d412114979031%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641264.0,406992.0,828320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226eaa959c97124aa9f8f6396743dcabe22751103b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745744.0,415312.0,835440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22756062b3772b185ac4acd21991d4f65aef127510%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728304.0,440888.0,892200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229fa95ba69f970e0deb7a956ae6729aab36274838%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722384.0,365288.0,1017840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22337645214ebb0b2409abc77d06f6a0684b038278%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653296.0,448552.0,831000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295ec845bfe9dcb4e61a385b0e13512e4860b2dcf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669928.0,406520.0,947240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225d97c9c6d07c9c0a066aed597faab062c82e096%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715320.0,476496.0,854080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222810b1311c86dd760e605394bf4362fb46202b78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750136.0,416856.0,822800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22078a1cc92c04b9079f8a8d9986bfc02f8f8b952d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674648.0,409128.0,864440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227be93a435a166ec4f7d4fda17504dc339cc36319%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710464.0,450680.0,873360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ba062705f82cfbbde35a5e52216e49c7007ecc5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658472.0,412488.0,847920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22607cc482f8e54ed4490b8c28369cd2594f462170%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699456.0,376896.0,963360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e1075f5194805c62f596ce70210722ddef7a1cb2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661544.0,447800.0,932040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228953737a3680084ae7e6a6256193152ba5325f3e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695240.0,469376.0,914240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22609f2112bf87c12b0058352686f082ec85ebe3ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664888.0,400176.0,994120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220bf7d7bf73dae4854c3b634914270cd4c85794d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622616.0,459528.0,875000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226734b08c92ea5a06bee54a68ce421544f4411e6b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734576.0,441968.0,909520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f9a183ce69158c8a937b029f227c98ff7173b1f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640248.0,474088.0,874280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2208e2d9663256a3b521e31a94418d9b1ef16c4f23%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732968.0,354112.0,1058040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f8b9857f8f307ce1daa6a0713bc9034887a7738%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675376.0,408744.0,862320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf07800bbadba175f94bc2e6e71d89e09f3a820f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698376.0,386904.0,942520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d6a9755313b73bc2e20e681695824b57ae7fd2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707488.0,367016.0,908560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3d1801837979c7e7b07f554da8db064b931cde9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679552.0,408640.0,904080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e1996ea6d4fea225ccdb617f2cab71694678e714%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744272.0,443232.0,904560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c916b3d7d7ab4d887c2f6d2e14675c8dd1767122%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689560.0,478024.0,964280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2237abfc6640b1fe6f092b9f388247c3f2ff8176d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674016.0,400256.0,962840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22699b08369f79186caea0ad26fdcc615dabda3227%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617264.0,372984.0,894600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c6807858bd277360178fe3f3ec1fb677e46c2894%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668676.0,439252.0,862960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22151c9704b74f3ea2c82d886b772c9fe904aa308e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B782088.0,355880.0,965520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226559b2c4e71a4448e9e7ce2e56298229ad90e25%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664776.0,401064.0,995960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a665c71790b07badcda72e168df6662ebd9146e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712416.0,472052.0,857760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273429020fa41176f1800fb75aa989faa7ed655f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689700.0,458952.0,887840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb58e59528c6ec5e632e983ea647f6d706eae2bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B757136.0,362448.0,922360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22740594139a3edcab145b54cdfe4fc3e3696587ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616672.0,414904.0,922200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e1a8af12c7b143361cb419198edabf177ec46981%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668000.0,413512.0,939520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ebbf92977ea0c2b33b3bbbaeb11e697f765feecc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666040.0,455496.0,865520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b7fb186c3832b6921fb5dfaf4b87186986d68e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673080.0,487800.0,970120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22373011bcba698cf54571b65785ca7471bf0252ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B578184.0,355992.0,984960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229194df0c370731f4bcf8e15ff490317d707da150%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630176.0,468664.0,935600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225794bf62602456c71467aac8917f5747961670ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744344.0,442640.0,902400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241bf193bad6f184f70a32941d3b76126264c8cd1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687872.0,471192.0,878280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22139f47fe024f06a58663f0c32f24462f77f968de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707112.0,368576.0,906680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b63b0a8b490fcdc8c941a5be61bc8deef5453a58%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675984.0,417232.0,894840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0e634e50ef0d3af215ca84cf0de4eb0727192c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730104.0,439344.0,910040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb42a2c7db78451ce09e85ab9c616188fc463cbf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713936.0,439888.0,871920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223cfdd66da458d4395a3826fa704f3cde8eeee738%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683720.0,455800.0,927720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c482f64803e4c2e26371aa4b36621c1a6b41f676%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655024.0,451240.0,835120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228d716a843eed7dab8a03b4bdae7b9b4cfd7ecf50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630528.0,479612.0,871800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22145145fed834fd546b1c0e17ce3c3bc8782b3f74%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667076.0,410836.0,862360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6ed47f95e29e3c8d1b30d6ad9794f4ecd63f81c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658796.0,466728.0,852080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d73ec96a4eca93533a5d77099e388f08a33b84d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672848.0,469680.0,958400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed96edea81fdd28bd3ea967ebfc3f94bc60909b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714416.0,444168.0,990760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224585e54dd2953562c7f3c8d11f89bbd8e3ddec2f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B794040.0,347400.0,981840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223377f27cdd12ad856891be62d0d4d5ee96c6bc04%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675376.0,435928.0,881720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d4594cecae5963f0984b76bd6d9454f4a35a77b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B560272.0,393040.0,812280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fcd0a3f875ece545d275293e3eec39d8dcf9a043%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636736.0,461928.0,925960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ed17ea382e9e57c31e66a55e798fa0eb8965b88%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723912.0,382144.0,910080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22764412774ed680e1db2f9bb170ac07b15f2cb9d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718600.0,445752.0,872320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c725c2c47e273e49307cba61856e55124c417c80%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B751456.0,419928.0,963200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224cf213707f0b20423d247f1502e4293982ca8c20%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668552.0,439264.0,861360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221edf5793b225183f36a03a7d91704d45739b9ff6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719688.0,366664.0,1029520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22307d5f9ad1df203d8622c89c6e3a5ef4e9b4a038%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654904.0,477416.0,902320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256ae95b99afbce4290cf8dd525e4832aaba48a85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737368.0,440384.0,910400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8b81a248f01e44ed2146fe701803a8ee61a245a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611864.0,368640.0,987160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225479a8ec438310853675ef926ea57bb18dca4b3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668768.0,404276.0,951000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3e3f66586f1d9bf3de3d25a629d643b2fa2a80e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673160.0,466776.0,951000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b94f490195c4d051131010ca883b7d16c4287e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684336.0,454032.0,929800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa0ad28878099ccd4b5a81a5943f2015d5075dd2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668896.0,401880.0,909640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0dded3053b9fcd58af1a6e9d8159cad041307b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663256.0,454864.0,901960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22303885b62df53e050116213bc94b3d3e22af7be4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631536.0,504672.0,898640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22771df48aa88747ac9b9ab4ac8cc1bb61dcbef036%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721944.0,448064.0,862600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225cdcacbcb418273bd40d8fa3162e38353ff8c7e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664896.0,461388.0,897440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e156c3d972d21f1bf6bc37e535575d4b20dd0b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725280.0,456528.0,814920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b91fb66cdd72619129bb19b4aa93aa9f8e7b457%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668688.0,417544.0,937880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203216b0c98d76091c4e62719d622b7cd5e1aceac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661344.0,411592.0,853760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ee1d66476fbf19c2c080c29ac9fe6bb7adc0f15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688824.0,464828.0,885880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fdd5095ee04fd9177b1cf7cb832e17a33be4e491%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715032.0,444120.0,990760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225394852a35729074883f365a78ad0e23cc92518a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621264.0,414688.0,802280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e187cd3ed2fc014e65fac0301be8bb5799101075%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725376.0,456360.0,815800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cbfb4963e37188efe65ff40922196c316df252ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B759400.0,361240.0,922560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ddc0bed4cff4be9c6fb7555960fc00d6ad7b618%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647968.0,457224.0,930280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2275f92ca19bdfa4229072401a1e1ec170052c0b0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714152.0,444472.0,987600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271ba3d1a4380018407a70ac64eebb93c9052e230%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651576.0,421400.0,917960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22181cc8679398105643d28429c799701ecef7533f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670916.0,445104.0,896280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc8c6b0914baa17cc3b55c90fab41e03c6e2a117%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716624.0,440128.0,914960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8a9543f1cd66972f3fc1a08140694c0485c2e23%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707520.0,431576.0,881440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254fb28a0d6f2d59a5559807a1999b335e43c983c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618284.0,512856.0,900000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2287d928a8721bef4936962a7121fcdab0b8fd04ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713248.0,463856.0,862840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228873d841c8f5d3256f9411c41aed7261be684b4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714192.0,465196.0,862160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d9c9fba628789bbf83afeaf08a837fbd50286eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637480.0,462280.0,887800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0a1c678b92f3054da40d547fb4870f3d41df607%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689884.0,431976.0,904560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ec73592d0529b01c4d8d2498d57909d1b72b060%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624480.0,508896.0,900880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22416e74f27185028c4eb36c6837e328b09cc2cdda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673624.0,461708.0,945680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226168d27f70b0cc328a49e3ebc572b8a232b1d4a8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671672.0,452368.0,911720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22516a7011772e08420d202437c49d42d1c14bd018%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670744.0,488976.0,883040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c726ffe070f45f468dffe281a6886d314e88595f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702440.0,434360.0,934280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c68f77efcdcc924a1f954e9cd52ae4fe719eb087%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717312.0,382704.0,901360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228132fdc19251078831ffabc59c65de0d67fced8f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621696.0,406824.0,820000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292d8961f77ccdd6d30a9055c83a4019ef93b8845%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637488.0,463872.0,927560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229828740bcd5a78454693c277c4efb232870b4f2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713568.0,483192.0,845040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2291e5071a37b5b23dd179c7448fe89a8e201f83d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678232.0,382208.0,821880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265ce851f39239ace2ce5daaa73b4659263a0d6ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723936.0,454672.0,835560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220145c6e5aaa20244e4089731b5afa58f1b49d854%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713128.0,482240.0,846000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e1146bda64cbdc9e3476f7d55ebd08179f87f6f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646464.0,414312.0,835400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260450264d79f2281a8ab0f6d5426cf4aa4839b0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668232.0,529040.0,863960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227fae20d69f2b5de659dea8fb09cc13aca00c7e9f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733320.0,461000.0,836120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c1e63f18e649b9fbc025c0288d5b494b6b96582%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684136.0,433016.0,901480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8cf376b8aa14a5d78122013185bab615e869e17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625000.0,407336.0,820360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221018f65029afb42b91cf5621d5981d056fc14a3f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678872.0,500548.0,867520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22611a587248f8424f7edcd8b1bdf5f80e91bbd99a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707024.0,397152.0,876000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d15ca706b231282b0c3c3b56a4034efc21aaf4ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670432.0,452480.0,874200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22157ab3eba4142a80820247e88ac0e456e9b643ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712904.0,387616.0,906160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e53eff1e48023b2216091f60af20563b460626b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671720.0,442688.0,868840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b6a007eb36afff418833d825806e391d876310ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608632.0,523744.0,897440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2d2410c5f279f150d55e0a81b76d9248680b02d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712432.0,471800.0,857720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9e38b73ac625623e2d14729282c3aac6960a091%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685104.0,480824.0,975200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce793a6452c9e4b56df6d77431c66ddf8da13151%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659848.0,458688.0,894400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab6784a99e1f61dc48b44c4a6fd979f4343c7632%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728280.0,377936.0,912840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e872ab82b3b195cc8d033cb026018030285fa43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666344.0,455848.0,865840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220125cae2fe7ba3cb20f0e82266baccc3a725e1a5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702080.0,450112.0,894680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e640be1e9b8048eb6f4d7d8ad1163806d8df9316%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B759904.0,448144.0,889720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9eb92e7ffa0e942bcebdedd02c02a0a8db325bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684756.0,438184.0,910520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22071bae8a138b0fd91e4508be5f3be2cebbe96bc1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713280.0,448176.0,879160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6d507805bd85b5cf5aec078d64eacda255e35db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719108.0,476780.0,904280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ab16e0f4c640881ea3bb25c6d4621e85d7f38c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B786480.0,355392.0,973800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ae1150ce130b4e54faffca94c0699fa43b3f6d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675312.0,431568.0,875160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7da0c3e1aea2f01d225d468bbfa334e7cc2eee7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636472.0,400000.0,956640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed291034b47b132adba2d2e3d525559878c1b923%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702464.0,400904.0,884680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2c75365432f602b5be1ef7d635074a2381e4eb8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733064.0,459744.0,836600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d885057581c553cd0222dcddf0c6c9917fea1547%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679360.0,383016.0,1077800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224edf88c98164b55559890b6b433c65f5a5dd998f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672536.0,452744.0,937920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea4503daca6ccd5665d04828eb95128f628fce8c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668480.0,453000.0,911920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220dba0dc48535ab06dd7e926b99ac3c39399a3667%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654160.0,453728.0,894360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22633c9e53b90efb1a053b51ab906ec0ed11ff145b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669548.0,423548.0,928800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f385f98603626f50829cfd80711e3f801587ba98%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707736.0,440272.0,926120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223489eaf9514889bbfae185b3e80ce2a092c53bdf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673752.0,450696.0,875000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210ae5c5426b570b1167b29d73707d7c00eb9765e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717768.0,493544.0,1004520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227846783c390c7a28f4929a59723cb221925912d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664280.0,446920.0,901200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207d76825f79c5ee001bda7e48f653805b2bd22f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641180.0,486512.0,901920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240d0ee260d0eed1690d0e413795ec80645ae06eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B791896.0,452648.0,880200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cecafccdd5dadec742524a360349dd6bc59ace5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722756.0,381208.0,909600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4c9cbf88b794f00a1a5bc9e86c55c724d0fdd4d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B746592.0,382376.0,886280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228062e3ae9bb0389794fcad0b1816e8dd8d42d5ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714260.0,431516.0,953640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2281c690deb092c71d48cfe4ffb41f200dfeb3cca9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725680.0,391136.0,936560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220debe8aca697933692401ca70079a5604b1e0078%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709344.0,451616.0,877120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f53f5743287725ac7c5af94153b2c635301ea58%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625016.0,482944.0,872080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf52876ec47fc4f9472b947423a4973f222ca2b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729008.0,376552.0,913640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224138724376033924c91c370430c7fa619e7283cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742328.0,439768.0,887880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a0b636dd693a193d8c00e5aef2a07af75d00e45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752312.0,419744.0,966480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fcf28a7a9be7caec041da5f0c5dba7dcc4d2c95f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673648.0,427392.0,923160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22652e410c9bbc9fbacc1e1de16ede0a4608714e52%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680712.0,450944.0,916320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c954a78c69be7f3ff1ebb84e6f9aad863969847a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703432.0,443568.0,881040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22310ccc14284283560d60b0decd585abdb9e6d881%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676936.0,449832.0,912400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221b1d11a48db29b36fd75f0070497923c12c7d70%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671072.0,407656.0,861520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228afb797ed6e8fbbb9924d62237af6fea5c55bb02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671152.0,417488.0,888920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22466713eeb2cfdd3e921350d47058aac2f62b65e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684504.0,444784.0,909360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ba4628054616b3bcdf462baf614f7d2ec73cf32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689360.0,431324.0,904720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c6d757e6e633ce0713b3f31e369f4d46e0e3e9d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655960.0,423904.0,920920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22862091e3545506d4fd1cd385031ff9440627f196%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665548.0,537652.0,860840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f808730aeb8e5cf61c41a4a60a1e418241f2e9a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695952.0,390132.0,931600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227772b661606a8cbfe0710cb411d9a43ccc3d27d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677288.0,409344.0,859080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ef825d2ee646fb3b3a1d2ace1c180cf6e50e4203%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659904.0,462800.0,945040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2224567b04e3e1f54506c222293f61c381b09b4a41%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740632.0,468896.0,818640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229375d202db8515d83b3ceae839c71229aa099d1b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671848.0,401808.0,957240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7544595f349c93a7f07b2b9714385d4c747c721%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666704.0,414328.0,959120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b90be897c826d9e1e497e599c3b71e641da5488%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694656.0,402016.0,902200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223a41c4de59506f6d7dd0bc37afbcdc4fec3d656a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677864.0,407568.0,896680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227392aedf8705f504c8f86404248d94f421593d1c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621360.0,380560.0,975480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0a1a403ce50564f7ba51c80d8b18144afed5ed2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703080.0,372016.0,984560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dd88e52cee2ebcadf9b0b7b82310a0f95ce8a6a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653640.0,412360.0,889040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cbb2f27c706f77b0ee963e384d5a291a343e5ca8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688968.0,473192.0,878760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3b63ebdb09a10ca74f7519eed47f992752a0b9b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664520.0,415760.0,889800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7ab2aeaed5a13a2139b5cff1f64a1e7336424a2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715976.0,421288.0,871320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22954cd2691acd087202da35ed432ab7b4f16aa464%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B803616.0,351352.0,936680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f5845c53850607450a0d5a3972129c1155e5b90%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703496.0,450584.0,891680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e4bf012eddfc0efda54f19c2c6e15cb6660f42c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B735920.0,442288.0,889800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22644a4c4b287ef11986276ab2459991f3b566a196%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648192.0,391312.0,917520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b57dbd1b23b41cb7ebdafba0b40b424d9a33972b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661952.0,456520.0,899640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ab66f11db20190ef9083b3e01682b13402ec070%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675556.0,471216.0,959600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2101462aeafb763ab8d2c9ab6cb7018aaac741b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662800.0,409008.0,856000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d19f906639da9d6d9945cb9439c53ce345e208c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650808.0,455912.0,930360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22617eaa2bb4bf13aa5dc88dece5c5cbc74ccaa2fa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715728.0,440456.0,978480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2230843a92410bfd11ad6c058bc10bdc80a890b80b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713200.0,386888.0,905760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ebb32a5862023ccafce728287fdb141761dec80e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690760.0,466744.0,952640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220032b0c5d6282b7f955f56dd97081d18bcab9704%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666792.0,458072.0,942080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225323853176363bcd7e585bd69a0e615b2e90eac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693112.0,403896.0,896120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a2f733dda228c0c128fc8661e55e43239f2af66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644576.0,446920.0,826440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdaff113bc1f0a70b18bbfef29d7b8f9853e6a80%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595944.0,415584.0,920880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2275ffc53bc96044bc21e9757912fb6830e485f390%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750560.0,422104.0,975080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a8abf200c4330138f48e98690952a541f7cf478d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625360.0,406768.0,820560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227adf5039b5d7bbc20532131f1ba989c0eac48ca2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646512.0,414512.0,838960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220153a3ec0ceb3ac577e7b7ad4442d833ebec9659%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714128.0,393712.0,930640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22664c45e738188fe587d88824fcfce90a9e1b7e03%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B598552.0,413856.0,921560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260e9f55a0202c6a99b2095635a25d0505a62319a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B569056.0,354696.0,984200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d6388fbef14bf930ddaa04fb172f9713c146931%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682992.0,482744.0,982520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22572741360bacebef8ce041d52cfd96b8dc219315%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700712.0,383432.0,950480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225214b0c4f84cff086ea252774edc087bbad53517%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613968.0,435024.0,768160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22599989d83dfea3d32fc95acc232441f2f0adc11d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748392.0,419232.0,971120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265cf1f37a45602e711d67d1a2661e6f4f349362f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634176.0,419960.0,912880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b90e3604d737266d0b9251aaf5534bae9ac29749%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720872.0,470672.0,976760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3a450ff9d43876f487e9f468b8f7e7d7f16e308%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712200.0,432800.0,946840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eaa2af74da3b1c4eae9d8de1e6260e7a78f0a850%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674536.0,507384.0,866320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222f47c2fb1199b9f639bc4f0685b8a1d9cce6d529%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748528.0,446744.0,899400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b052ea80eefc954da1b01b79c33753dd86d0ca9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616376.0,514200.0,899120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd7a2d7ce6e75a71e26b37e5a61859213ba53ce3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728976.0,442440.0,890200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e88a31a4163c7a134defe37fc35bf9358f1977a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739800.0,471232.0,815720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c03b788b4df80cd85958fd4a75f9a6107a019e38%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631944.0,413008.0,910560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d78c87c29c6acd4fe2388950e72150f92d1d1f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663408.0,423712.0,862040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8e656bb4bdf2a8eb1cc26b7963519436e3ca5a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668280.0,475832.0,892600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228383efe6b39671c8655e70ab147f0b4b58e9db3f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619600.0,512376.0,900080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223a8e23fdd463811409277625f28936b0edaa09eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709568.0,428920.0,879840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0b6b2751f532b85a2386e45f73d00bc0a98aca6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702456.0,379404.0,901120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e51399712ff038f9d074931c4e384fe97cb9bda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718376.0,461504.0,972800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242be78b1a7cccb54884e36f2ea9aa643c06a2f0b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712576.0,436128.0,888760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8be33d3572c12fa1b2eb287c098a84019e2f1f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648024.0,482544.0,902520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e45b05794af429f054ddb0f551bada9b99dc789%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683696.0,455608.0,924520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f18cbc21823e3df89238af6cbb95902d692c8de0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726488.0,439768.0,911600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b92e46c35250f01954a53ff8aee50f0cda36c150%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688432.0,394408.0,979800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b46edd92d86bc8d8605b6ec40347b3996c2c3774%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673816.0,413360.0,873920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff38313f7c98886e6710f19263ac55910237fe89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663772.0,419548.0,939320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2250d7d9384ce076a81c179cc81651bf78a6df85c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698432.0,381240.0,959160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22527ee0dbcd9786da69ce0ea06bb08c2358dc6b5f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673480.0,448736.0,888480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0567c2419c6bda24419f143ae2c6446428c0cc2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731180.0,440640.0,912120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de9c676aeec2b13cba3117e9ca5c1da59a1cdee9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725368.0,381976.0,895520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a678ffc894f42892f9e04ce32774b77f65b6521b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728620.0,492908.0,905680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206dbfe7dd7d7e3a598f780cf9ffc752f3974e2bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681960.0,455896.0,932840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf53b8450f72bc1da1f6b2909281f9422f501649%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708536.0,428080.0,879440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221f35b0c80cb97612d114533a69f80f7e1e252d4b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668560.0,474984.0,892080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22756f47e522a45eb79a8c8526acad3f7822463afc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655480.0,467776.0,909600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff673f8d428f2fc6d531292073f9f012e2a7c742%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B599752.0,414512.0,919720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233e736e82f64ae50b6a2a12eac3bb0c8266c5d3f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674264.0,414384.0,880680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a79c991f3130006967f3a090fb730e69be83da5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647284.0,458620.0,931000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0f1bbc0d5b51abe238a4c476050fc52269796ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713776.0,441560.0,978400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ca580fa104b6730dcadf33ada07141d3e4de3ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709412.0,448164.0,882720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279b51fcd9e97ae053664a37ff85a0320cb808d46%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646304.0,413216.0,837240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22116b4077cf926d08e48b15310700758bab9e99b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664888.0,446928.0,930520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf3b99605338d5b9ae86e36abcdc0ee24df09ee4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638704.0,467600.0,934160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220349025dee3026f9d332823d636711a10f0e8032%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672064.0,515424.0,868000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22442982bc3debc145e8cabd5870a1f024e941de61%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749896.0,438416.0,885640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ec1366693f0d9e0899f03061d06b69416d71657%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690192.0,469604.0,881400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0db72b4b2eeaa69b6ba29c324eb6d50a043a35a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635720.0,442368.0,817800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a95abc20e9e0803114d26e46677a3f83fc3d9fe7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684624.0,484000.0,982840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e1e833065ab43a1a8029e1e4c7b752d8e12c640e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671808.0,439792.0,865000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22240bfd6fce6033d491625b87de5bfe95edf66fec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640344.0,445344.0,821080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2262922a485e6dfec848a73dac84ae0270b0b5874c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716464.0,384816.0,902000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226ec1df03b895bccc74c4cd422c481a9f27e92c82%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748312.0,420760.0,968960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a8337825b003563227ff5aad19c7a54ddc4b387c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636624.0,395928.0,816600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254f79da7cb1df30e1d7e72c13d677d661c68e4ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727728.0,415512.0,858400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc1a763b98313a1e4619b647df14653d5ee50428%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763728.0,354792.0,916360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d04d1697a37b8cdbd853694407e94de1892b8f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615468.0,420192.0,785360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b700f9fdf9d7199afc3d23676613a93119e5c87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674096.0,410096.0,865640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af863c8faf72c194f9300afb46ba89680ea20d66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718880.0,481952.0,986640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f04edc3a19a864df071678cc642dae9b056d351%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670152.0,424340.0,929480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f08aa82c56444396493a9bfe596cea7fa7866492%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B735392.0,380856.0,893200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228d255688d946b0e1b18ae211a0a2cc20a723f63b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684128.0,482992.0,985120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2263be3ff8cdaa15cb3095349dfddb719c8afd1b02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704408.0,366416.0,1035560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22315807a55b785a653378766ffe8e1a0b63398858%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681744.0,491868.0,870120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22136b8578ee6dfdcb6db226b061fe71611be340fa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733668.0,441524.0,890240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b21d6a331053ec259b8432cce70b93a3fdf90c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633416.0,499248.0,900120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e9de72a1d77e3c0f2ecaf3dae2ba13a1c9f122f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720224.0,419312.0,866640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c8e71994644c502b1f763e062ec61390c1c33dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670728.0,480624.0,889520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d68ca6f9a586749aa18c67c4741f7ba6c9b2595f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700032.0,380592.0,964280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222604cd4d548b9fadb2d2dedc452bc7618c73b112%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739260.0,470408.0,812800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221444df441060861fce3bf4187c0a010e8a7c519e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697584.0,408832.0,821320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222185ee19fcfa05e2b8672ad9c3f1cb3a27f161e1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652200.0,463656.0,883040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc0cebecc04fd94f66ceef2752bb6eaf5780b002%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656680.0,413472.0,888840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225906d80c1b78df96453da97315b48fa3bbd5b29d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745352.0,396600.0,952640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a06327e962ede5c905b7427494af3de0a791d46b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675528.0,415912.0,881920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22444f624d9ff6aa8f80b5808298ffac2687ba2d1f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701920.0,452528.0,897720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a289a86d27d8821a615f1e34f50c22b5283f464f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654984.0,415640.0,894800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225744ab8ffedc821c3fe86e175e70915fc567790%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685736.0,481208.0,980080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221943b6b1413bd94d7ca540cbef67703d43adaeb1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688872.0,439376.0,901240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223cf99fe7d3f28e246ee3b52ed7029a790cca1172%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655216.0,412496.0,888120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dab24c085ad3ca166450ebc0f5f8b9dda5d4463f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748360.0,442904.0,900360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca908834296e55ba67067bfd22f5a7ea706bce7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656152.0,412176.0,942960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ae1fe00016060d49d7eaf5380a71cfe8a9e8e01%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770464.0,357040.0,940640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22963d0305fb436ab68873e8e87b513dd9c9990879%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620688.0,405552.0,819560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e8c04ce8d6bd464d0c99514756bbc9c287c0dc43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696392.0,390408.0,929280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dbf71bd7ebcb2f5270edd59b5853178dd073ac1d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B775504.0,357816.0,960520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce23f43fbf0f11bbb782e420bbec962e25c6649e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674896.0,479736.0,965400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202177f29bc60e43fe41bb58b8b8a28b8e3553240%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693176.0,354712.0,1056160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220086488877ec3fed07a788fe4654b34bcf051c16%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729584.0,504400.0,909000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b33091dd02e18f4ad0afdaf5e0c9d508ecc6dcc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726904.0,422920.0,946320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2287f8ec699f8ae5e4b1473c548c46757fac7ed7ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717304.0,382472.0,901280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc594ea4dc720d0064ab93944acc2c4e317f8fdf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712184.0,435368.0,961440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7fbca7e5fde6f898232cc11c8562f90f3b77059%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679888.0,408584.0,855120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22756d3d36bd28472ebaca31d2e2bb6729cc50b50b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628376.0,390712.0,961240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2219c5bc5bca54148057e06e8aebb19e40fe81ee64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671712.0,399576.0,960480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0f8f9fb5706cd28267043045c5595b265a61620%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669176.0,409016.0,861960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1792b7c271e781fc67de16f6e3d314b1660b487%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745468.0,423208.0,965720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9f30e62238b488d1befe786f397ffbbc5611f35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665252.0,462612.0,897320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22620d358cc16aaa643c61b965915e14074d3e0636%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695392.0,358576.0,1047960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a304cff6e722a2daa023b7671b79ce4184b0f3f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609832.0,413760.0,928920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f3f46dc1d4bae02cfbaa33a3bc6351e3b1cb3ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650984.0,455544.0,933040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b69e5054323e27bc46384cdc4b616224509a349%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669840.0,453592.0,868120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22324e3802b4a14ef3695e70eb41c4bbd5903b144c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B809248.0,334752.0,999520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e161cf73d02707dd109b72404756e86766670bde%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703224.0,449688.0,894280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea7e25a45bf6df1eb7aa85428bb58af39eb3a744%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623896.0,382680.0,975880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e1b71644a4f66770a8263b519b5dba34fb1e158%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672440.0,403112.0,852680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222fa4e8ccf3b55a02749cbebda0dddb4691e1b34e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612864.0,436928.0,764480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2263bd04bb7c1992607d4c3454a26a2cd23aa4ae13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B594304.0,365032.0,976600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296b4a45ebbca11dee195054c35b1602273fde5e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666288.0,530024.0,863520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22745487bea42383bd57875d11f247efb7ca689bc7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667200.0,403488.0,979880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221a46d9236295fd42a029b14882426d9e4033a30f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704016.0,370992.0,985960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c92439ba0748ec1a9db1cf935e2693a91718131%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636000.0,443808.0,818520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b68aaf0f1065597f8efb37d477126214dbc8d1e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691920.0,386744.0,898360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad6749afeac280c383a0589f55d9ac485f265d7b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705144.0,434080.0,936840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224cd258d0cdac0bb96ae4b43e52b5ce0ed28d7ec5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712720.0,466456.0,861680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22efd5a1f498492be8403f7e5c875f5e542a8bc403%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707320.0,372208.0,991680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af053aa2522472b658fa048c0fa6d4cce610c95b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B582280.0,359648.0,982080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222664e7065863caaf7d09f15caeaa5ad117782eed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643408.0,459264.0,889560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2733e132871cc4c54aec910516db5d1ff210feb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712168.0,482632.0,845760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a99b78ee92c76aed06af0831d83d6a047db31072%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688580.0,473944.0,874920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f97622ab685063a5ce786d95de8e090362be8130%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728688.0,458656.0,837800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce4f5792363272c7bd1f9ff6253ffb0029ed0736%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752592.0,420744.0,966680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc6a2832744642b9bdb1f73b65294953244d7640%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712824.0,440336.0,973720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba4079fc0b8b7404a68beeab67dff1bff2c0637e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739384.0,398496.0,949960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22648ef9b986e06377262d9c0f557e360f47d828c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B589304.0,425040.0,947640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b62c307c9a8d1ff73670bdcb643bfd278603ed79%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714808.0,464524.0,898120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290e2bbced083dbb4d7de64fa4cc2eb7784d3b673%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627560.0,506056.0,899560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2204ca49f8ae23220a4db3fc616ed2be857194539c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639768.0,421288.0,914280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2228983305ba9b0f3640c3bc673cf1e0b7120d8c11%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615520.0,414704.0,794720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f142ec9ad517c21b318aa125882aea545069d993%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762992.0,359240.0,936040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e219b6a348d9194ff66f98b029a313261dc045a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604048.0,421840.0,908960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b7ab573757e155fb8205be373003aa1aaa95f02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631064.0,392456.0,813320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207fcd2819d2d396240b2802105c08ebbaf796758%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642328.0,455656.0,916200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb8afcf37815a7f2e6cd3e52e349e49ba319c4ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736080.0,422080.0,954200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222336ee2657e0f027c7639000b33ae26904f6a858%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715816.0,441064.0,979320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ef6390ec7fd5371ddf0bef50fbd0c2b4c34b36e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734592.0,441536.0,890920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ffc66c47a0d94bd40c6a6e3c1cc905614e80d5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675600.0,448392.0,888920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272df32f1e5de8ce1affacb38b0203edb07f20d35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740896.0,412720.0,842560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b91aaec67b54dee51ce1eaff81f4dae06f922cc4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721308.0,446348.0,865680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240e5f97fc79114fdaa6f2a76baeca423e1a42ffd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662136.0,447040.0,905280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c9a71510063ea5e96c0e9e0fa6f289dda0be8a62%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645768.0,455320.0,916000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fef33102bf4cb1ee7d7d9941da05e0c83bac2109%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687072.0,479184.0,975760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f3194bfccf857c69a00af91ab7b4d2598b8fd58%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696536.0,392312.0,930840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229bc92174e6844cf90a3dcb4a1e8ed4e474de2b0a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662304.0,455896.0,900880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce27de272c117fd49fa6ee7ad4a9005547e18ead%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595328.0,365208.0,977440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222914dc523dc10f2eb118530df949c7fa9ab0e6b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669148.0,406132.0,951680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b5c69e1f1eb9844a2738f7d053504fc9c0b09e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645184.0,413864.0,906440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b9dd1d812e0f63e60faf574abb58f6245a7299f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B560672.0,351112.0,987640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296a7da3131a58205307021b4f95559c47320a440%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716056.0,444616.0,876760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e21f0f292795dc28ce513cd422a198a2dc01cdf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B596728.0,470328.0,859960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb2e209def50dedd3d802afc544fa2ee4d8ddb5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676256.0,481272.0,966320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247ced1e5533b472e9a1c094ffc954465d758cb7e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612976.0,413984.0,924360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7a03d091a4ec583973ccde8ebe47682a455df76%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654192.0,423696.0,920960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22064bd09d5885c9937a88585b69a4b97cbb964f09%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708064.0,435424.0,887480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e1cbd8713ddff4223dd4447822a0bf697fae429a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685388.0,447672.0,909360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1e467af004d90ab9c9bf82ea1771bcc5f4eb621%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B598348.0,398020.0,814720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e5cd2c8065ba53d0bb8a8f8f0db642c2fca58629%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667488.0,453624.0,903560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d22e4befba4a4be82e29c71fdb78e5ee4888f210%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692984.0,397144.0,922520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a38c86717ce4b0c98c0c305bd79ef2f4e2f78c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729188.0,500380.0,907800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b555ccb05e555b7960964781d4f1262320fd3d2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762896.0,434096.0,882120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225fb3fe14f1e590eed490888775d7f9620d13cb91%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725384.0,450120.0,859680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d55dde66b08304236cbde9dcfc662994aea6f36%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B562776.0,393608.0,814280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22800bcc701725d6c0ad83b8d9f82364d4088d258d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612576.0,368744.0,983800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aedb71580a34a65c80f4bacbef13620fe7773f10%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674336.0,450720.0,938040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226edbc567eb2297dadc8a0610f9cef5e85bc16beb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645984.0,415448.0,835000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22468b5b21348f5a855381ef1f5792ddaa07b70a98%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728688.0,506608.0,907640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229dba138f7949de02d38a8600b888b29c959fcd94%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688272.0,456024.0,890000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e727d42fd090a18101eddfa7d499adf67b69afa1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631168.0,435360.0,812440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22012def951a7db47c561a4704586e7fedede520ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683744.0,454432.0,923320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220923960cfc6af9b0b96b6cbb00c1b3b8a49c996c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630032.0,436304.0,811240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220bbe6554cbcb1c3e3eb6308749f9e96568eaac78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745128.0,415788.0,827720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ec5f8fd21dce93375e1020ed7d97d5d4ac1ecf7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668472.0,448408.0,867160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed5c7bf8421cf56aa218f50225301895fe7c47a6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673344.0,508544.0,868120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22165a7450ba33079a0da40c83e26f92dbdf3f915c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621144.0,377928.0,894560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22541b2349126ef7ac718b74dc4223fe9bc1c545cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674568.0,431144.0,873920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f2081180b7dc2159b6a0e52da4f60caf044ab83c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648184.0,408456.0,891200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249b11ac41cb48c3fe9cfe89434db2d5f6281927f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619904.0,421112.0,912080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226767eb6cdfd9bec10ff862fcdf4243986e6caa94%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616600.0,459840.0,870880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290d5342daa0e78d543615a5003c4cbf4fa9ca961%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683696.0,407064.0,842640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226dfba7bb072f10dc93b87ce307c91c2f59a2328%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728324.0,458688.0,843040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277a22e2d6fd7c2863df4b20ebcd9c01667d914bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717448.0,427600.0,943760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227261ca324515d50debcf415493211e79f83ada6a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641872.0,407904.0,952400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ba8cc69fdba6e7a60232b0b26aed69a0822bdbb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631144.0,420448.0,911480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22007b96485abf4cd95bfd9e8f0958f8501772e472%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717984.0,458512.0,964000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22966e8bdb893afd3ca1bba051a5a41da9c244faef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639336.0,459400.0,925000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223244570cc969312b79cbc3053e34e6eb7f03774d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668552.0,446728.0,865880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a04873ee7a2559f587ae226a6c0f181173521ec3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745952.0,368056.0,924000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285a757b22d6175107526ee2becd86beef309dd02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714480.0,454176.0,956760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3e98e69d80ab8a194342f499dded4ee03ab432c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619416.0,372216.0,893240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d2a9bf869556cadba3436ff70fa5bad678bf23f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748128.0,397640.0,953160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ad873fa12a1281182369d83fc18da4b4902a0ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695384.0,355600.0,1055360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2264e32c8388b99ca79f7b1f84ce8daf0f358f1a85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635808.0,397352.0,816640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254eaefabe1cd56042548b3a8e0f7dd7a4ac43256%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661984.0,457128.0,898160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b2ca95432cf6b758a8100f55d03ab608a02498d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B552128.0,393720.0,810320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22647911089b496d0a161134700856463c5ddc9df2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710088.0,434072.0,944480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258fb9a259bf160bd48e71f7f5ab6a063a643ea28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678312.0,399192.0,967040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c160a16905304dcbae683b405efd927cd929f7d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658792.0,415704.0,941200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2261b75b9ad57d128157055ef47df29bc68004316d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648072.0,454264.0,915000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2269230c162eb18e46fbd6f15e34211bcef02335fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663112.0,446888.0,903000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d58760cd2975d0a46725c6995bf91c4dbd35a1dd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721136.0,440448.0,912680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227df257a07ca015680be25ccc2d1758227976a5e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685024.0,480344.0,973360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224396b1b197eea603bd59e4e039bdb168e42a9d45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649720.0,411248.0,904720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e71994d3d757bffe7a794a5a0e5fd5f6a85eea0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675800.0,512528.0,981760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267b3f53f1c99a1f733a2d4a7f2f2fbcb711d7954%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659464.0,461496.0,945040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b90f4c4ac2737ed971f19ef328f63afb82352a3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668064.0,411600.0,943360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210cc4bf24bcff1d5d4f055402cc9010caf3235b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696704.0,436440.0,917520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e8058c953e79c99e194deb1bba419b1777f0b035%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728504.0,356392.0,1050760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2224027ba70d5631818cb1b0df806e11d13666ecf0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614040.0,435312.0,766920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297f76a591a2e45a00ed8b54c0449f1cc09cee386%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B759844.0,400156.0,959760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a48b32194391eae9b0519af0b8875c18e0ea7c5c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630984.0,469672.0,937480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c1581c967575b9d0ef0616a2c3c39165c8215bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714584.0,446616.0,987720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22322e9c1857c9c302969ea15c118cced17f321e3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693496.0,355496.0,1057400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b2f13d4d474a8f5a3f7300f6a5a407680624fb5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744216.0,383216.0,887400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b4aa8e03aca1af7e7c2b7957923aeaced7ccfa95%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625488.0,389712.0,966680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229111c28ff799f2d57867f5ad168347d9ce366153%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669112.0,522400.0,863800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1d22e0452d8d0b4afe079a820ef99090118e7bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724428.0,453804.0,838360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2239dc89ce9ca93969966ecb56339514341a662ccc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657384.0,469548.0,906400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22087107587bae95803f3db474eebf9438d48409bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681720.0,421064.0,901600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f2e026c94d58439ed1dc91658732209ef807a2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611272.0,520232.0,899720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2243b35dfb6a2ccc43334e63e0f02057e28c87efea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745592.0,411976.0,835800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b9a94358a6f6d19422f26f07ebaf2e620e5f3d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722460.0,480312.0,901760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221835b88b5ffa3237dcdf74bc99879e27c2d1e2c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699456.0,381552.0,954000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce187cee58a1be919c1048ffea283ff0ac273993%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630736.0,419416.0,913520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0e7e9ac39f0713f6b310a29ae74047058e05d47%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697272.0,379976.0,901000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220db14b7f4295b28beb437878fa0bc3f57bf1c43e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625128.0,462080.0,875440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aab7f0d86d77e85af5dcdb815f53efca443d3e15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692040.0,471704.0,956760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221738f55d445ae131146bf7cedd2319a94d5f8b7a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619216.0,421408.0,910640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22401730d9b5e8c9ca0373e99ed1e07d1a25cd905a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720096.0,366416.0,1028760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22951e2c7f541b39fd032ddde0f8f91f84cab9d916%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B547240.0,347544.0,990360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d220468802be1265509ed09b2e6435471345d85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756472.0,363576.0,937640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ec4d6d4a364591ea71be99902730b7c5724b3dfc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683396.0,486144.0,870120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a39d9cbbf0b136c0043ef40ec75d3bf0c0fc75db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706592.0,439320.0,919960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a9f052bee994fbf109da8d1503bcb4a6347fbed2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639592.0,475160.0,946200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290ccf7e15fd1a1a8d4fe731dc3a34eaa41d7e453%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672472.0,440008.0,866280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cda3097fed6907cca1206c35ce16acad15eabc3c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673536.0,448384.0,888560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227037dce4b359bbb7f33598db9de530824b5fd587%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748608.0,366888.0,924200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2264c43531e438db44cb8c7e632a6eb0583f3408b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648648.0,409920.0,833840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210f856ddb5043ca92f3bdae9a2f7abe534a4e42a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698360.0,438464.0,887720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc7000ced5ca3ff340ce9dd5932d0f3423c9ee57%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643720.0,408448.0,953160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a2b20d6cb73eb8617cb7c227bcd363eab06e261%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675088.0,413776.0,875120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2270ee24890501129df98a29357128313483aaabf0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727304.0,484936.0,903400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc3be836d2736b4ae5d72fe3517f53315c42a832%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671216.0,519352.0,865680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222bd45819729d0b7b589a7ee4dbf6467f8c1ee80b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720744.0,480104.0,903520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229268dd601c984f01dfeb35988b27dcd71494ab7c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633952.0,412968.0,909760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2281142f63a69bedde775e09422f52ed61f6925329%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676288.0,397440.0,847640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210e7491a99b1307c93a711931f7be13339250af0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656512.0,463720.0,885280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a020e9d470bd3bf0bed9ee5da16b6ae8db8ff75%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654336.0,452024.0,860520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228bad984490182ee5fe58107682f4af3925614208%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595640.0,418688.0,941600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f84038660795bd2758f3538b0f4aa67e898721f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B591752.0,413568.0,924280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22971414ff10100d42f322887a3000675cffc7c656%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639736.0,460280.0,885400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279d96520860f78ac1f7f3a6f641bc49b56bf3574%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658000.0,413392.0,888480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229dacd54ea2297d46f1db54cddb4cb57555aeb48b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738320.0,424704.0,960920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b50a531f3e074e6a2bd209604713c6bd07bacbe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642616.0,485880.0,901600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2263d2f5e33d942398b7c8894d67d42e8ae97ddf36%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B598560.0,415776.0,920480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22699ba8d91cc94f9f6322178bdb4e970b5220a7ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726104.0,431160.0,958920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ae5ced6cf57c02c76ae235d4e44cd4d197aa38f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639288.0,404232.0,951960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f2eaf7cb4248edc13f2bc7b190a8519ef330650e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664808.0,468648.0,896560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224437238084bea05a721c971cec3c754e2b256f3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664840.0,409768.0,860920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae2bcf8955b67863c5675cb13c758a053344a021%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600744.0,416288.0,914720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a82663657e72d798ce623bc65848693f27e9b848%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683992.0,481608.0,984080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c016a44aaa773da70599026548d83ffc041ea828%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673992.0,499784.0,975000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fd2f1990caaa6ac2cf516d246a76b49dfaf2c98%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643184.0,421376.0,913200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a54d9e6d74ba64b0731e3431409bb2c0a8a823a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712088.0,427704.0,876560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac9c607e6203cc1d1db83939b494b3014fa974cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767304.0,360792.0,951040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d81b46d9008d7cbdc8fe977d9ebad744aa37285%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717280.0,487824.0,995000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2244c7167e2f971b4a54e58a09bdca1b38417992e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687512.0,407424.0,838560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de6180c9909c092a53b8478f5b761d0d28d7a49f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707656.0,440392.0,916480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b4c62c81910c66309642e9bcc16332db4f1f6b9c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712240.0,449128.0,881800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220389d0406055e3f30786aceb05d2f68ade78c5a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732200.0,392752.0,942000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22893a1bfd210c1fedd7e76341cc0f46ca8df04060%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720896.0,425000.0,945480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a9740eaa3caed6edde88c7a8cd2aff344077ca7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720904.0,367824.0,1029840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229fe659cdb584346fe39c6959eabb75456f861ba9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621096.0,460440.0,872240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228bce12f3514d7f27d8aa082bef7cb27c69b66f84%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B839184.0,329676.0,1034000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b2d03eaee6faa4f1ba94c21fba753715b107141%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664852.0,458696.0,943760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f176bb721e6b857739c0641696bc3286f78a50cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722160.0,423880.0,944640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ceb7c5508b3459fbd1d20357c17486f889bf5b12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638968.0,401944.0,819320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb97cec9f8ac24bf320b263bd7c4d61472edf836%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675312.0,504328.0,979680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a0562c7532a270e5bd2eea960982b3617c5e6914%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653448.0,452080.0,932280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1dca85c9bd81648521bdcfead7f089baf1b073a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765840.0,359392.0,937360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5006b140857a3cfed923d7f23283e4b618724da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671392.0,409348.0,866840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222f3db1f8e3c3f5492c2829d3f94985124c7bccd7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750736.0,364952.0,925520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225350417d8358d2ec45222fec480da98ab14fcef9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713368.0,447352.0,948160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd6639b095ce5b301c17bb95657121766a56b349%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616320.0,370872.0,892400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22348b46740f724fa8ec3d17b300f489cc5c5b1a14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718448.0,460736.0,972640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c89f62b643dcc5a72ddf510b1469e2f62539c1c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727080.0,517344.0,907160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b17f17a494a0ba1cfd1332ef91cc24f42a9a0739%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756112.0,363328.0,937760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3752ea7bb21198bd45cc7de5b48cf7fb725bd99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622840.0,384784.0,973720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226289a3093431174af3caec18cea794de988bdf13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674200.0,448288.0,935160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a231887a991e25ab53dc6c2ad17f543c5cc1cab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682416.0,399496.0,898600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22918549bb2ea774039f4fe8c06eacad7ca5874c49%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628024.0,391192.0,963040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5f985028b863f877b8574171fce794336f522a8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710952.0,359120.0,912120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2218f331cef068c48f0e77d25b7c14aadd947eb3e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712000.0,433592.0,948640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a901a645211011d07d611ddecae0e7d9f61c4a1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619364.0,416568.0,802040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22441e409c0a4f03155b62c823fa8b4aa8991b127c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B565460.0,392428.0,814240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224ef7edaa8fd564fb97b228af16dc34a1e312c3f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633784.0,388560.0,927720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223191bad7e4cdda31a4ec7ff6723b71eaa51ccd21%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752144.0,362744.0,930040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2289378f9d61d01ce1ef719a72e9c72d98bfb6ae4f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677024.0,415152.0,895440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235833adbf0a02c9c95ce05c335837166523d97cf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708360.0,442288.0,936280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225271f5d3fa6da5fc889e7d2113b7d2ca64795779%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675920.0,418560.0,889880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226041fe68e0d63f01080d10d842f0498649bd45de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688808.0,462912.0,946400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22128555c9e38b6b6323baa3c9700662a9bdbd0ffd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722412.0,365612.0,1014560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255be3ef8e80de49eb67437709bc22567e3546ec2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603320.0,422184.0,909440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22231e49b06b305a45950c9fbb237003c2ca3b97b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631728.0,409016.0,823680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a31584db25410662584b27d33b6c4d43e6885f91%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706424.0,372448.0,904800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f24c515a5dfcb4bca9b0c681f05e316c1628922%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700048.0,383032.0,956800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a2dfc4a5968e9a7a77db4d833a55bc9e9c8a1e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630992.0,394544.0,959960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22448bcb9efbf22bd3feef406fdec4faefb50f2ce4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658296.0,462440.0,886040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253507a3b4f6997901d1931a8bdf932534cda9ec5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B746392.0,395864.0,953040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d079a5ccca51212ec6ac7fab1b5e34543698f9e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720720.0,472328.0,977240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227119ce36ac6c066319d8e9719823170f6f8b40b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B773816.0,449976.0,882560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae9feda8923f85b05f91492488f6e94a90c42ce2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705408.0,366728.0,1034880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22885da2ed3fa2574c0d40950811a210c3ec103558%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627640.0,419520.0,913920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f33891b9532610f42adb1b0c9f9e617cb1396bd7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727112.0,380312.0,897200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c9c889406c1af0c692537558cef03ada1bae17f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629704.0,398552.0,894960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dfb13dfd5e432137460b96800ec80a418def4b3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748832.0,417232.0,825720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224522239a25a9a6242f84c61f33db44b4aeedcadc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686536.0,438140.0,900720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab28486b559b13ed83d92db6f6273298a515c0fb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654200.0,454472.0,932800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f7f89581cab3f4c648a76343c2453843fc83683%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614256.0,369904.0,979880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228384b919110d17f17e75dd81bacf79ddd324d53b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713224.0,440672.0,970560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ac442d82445677b6ba8f0e709686094dbaf802b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737264.0,424952.0,954760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a5a507424a81147dcc7494925149c9e490cf116%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671304.0,445672.0,867880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee32a29b68ebf51debfc0221de0309f0f288917c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716336.0,437344.0,886960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221da6516813d7240ca1b28086ae049a3affa06959%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699864.0,383200.0,953400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b97bc50353c4c45267eb0515d329a640c003dea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B584280.0,361000.0,979800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225502547676365168d1f2c23f1f00cb1168de8cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636044.0,403244.0,893680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203084f839693b91094834ea5a5a8a215482ce1aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651096.0,409328.0,837680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f8ffa69d12b2c1e0cb7bf8207386fcaa147d05d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662624.0,448864.0,893560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a3d36b79bd4e25cb45b6d7d29ff8a5efd542e02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671176.0,442656.0,894280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e5147eb30fb5a3c433b8fadc1bd3460d3c29ae4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687104.0,429416.0,905080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3e362d05024030ca42d8f46af2a0efccccd0a92%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622408.0,407864.0,818840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de83db090cb4a09ff8331814fb4c400b3d2149c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674896.0,468056.0,955920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22219181d3c535cfd22508413c098069e673939da5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673064.0,461032.0,945520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222dcd186514eac0f9b228c85d9cb47f9a486087b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665728.0,444776.0,850960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a43238cef6474322019b0d6e8cb805bba8e068c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712880.0,448232.0,880600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ca10177c2510dd47354371624607390d23c6f6d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726340.0,430708.0,960120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea77bde05095b64986833e6fca698039550b450a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B587928.0,363312.0,980480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b9da9d3659ebd4873ac9298b89941d585711f11f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713672.0,444584.0,944160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221be6a6201525a6db4eaeb38a2ce1dfc969848f42%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682616.0,431688.0,907720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2248d7b4bf565de6cd7b41e28d8770a30b2fb18b9f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B830120.0,333096.0,935040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22623e635ea8bba12fd11a0354d8d1e69ad9d9de73%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669104.0,457248.0,940920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22161df62b1fbfda4fbe8061d486d0cb2cc217298b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615956.0,364340.0,891800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c02fbdaacda8bf037f9114ba0044ef9f8b3a387%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669772.0,446688.0,867200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fdd82743f636538ff0c6e1cdb7f893844ddde85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631504.0,459672.0,880280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e8123ddb3fa50ec39b6907a985a2872fee92208%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715024.0,430488.0,954840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f0975eee8c86c828987771471c25118361dd20fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632520.0,502128.0,898800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b14ab4c7aac4fbd6c406b5065546b9bf2efff06%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717608.0,445280.0,1001840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225507e86d9cd7573a4c10a4e96b77e3e28ac176b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635808.0,401384.0,891760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227bcd48036503cf89022a78c40fe4d104321202f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623920.0,414736.0,913520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22966032601de229d0b9fffdbf8ee49a1c12749f12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630152.0,458584.0,880360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa77656305fcd6e40e66d5c358fe58ba3c2ca2c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613768.0,418572.0,786360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22772419645bd08162e9478bff40d616d8b8421701%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715848.0,441264.0,866320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ded6aca8c55115b798e7702f98fd1623125bdee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690576.0,468048.0,951480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a39e12b1feef08705d093a65ca9dfde6ee1e589c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664720.0,446616.0,900760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3b49649a419c71ffbc4e747c5779fd4c868df47%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679816.0,407688.0,853200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf084fd6da9dbdf1cf1dfd1c7aeb10b555cd77ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736472.0,466144.0,824360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2268a0cc4c14a1cdd46d849757dcf430a73733ad1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734872.0,440824.0,889160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ce7498b7216f9412e6a9dbb0f53c9ccb7319532%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664032.0,458632.0,943120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c83e2087eeddbf745d98aac8460e9849d041973e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683968.0,407632.0,843080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2646f9eeb902e008daf2f8e6d02f7918e565e32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713288.0,445880.0,875880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228da4aaa58908aca05b6c4033b5ad15bb3693037f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713512.0,449480.0,948880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d385b1238c76a5a93a29b124a9002a93e53d09f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680952.0,433808.0,912280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e64531a3f8675ed0b59a8b76036b14905399c77%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711560.0,427496.0,877840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298cab6ee736010876200f7967fb023311485ae3c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616208.0,417656.0,788000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223423b355193192d3d67d9ba59d2f255da9efd2c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726832.0,416144.0,860280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fbeed30bbc2b3fb003aa8585f737a32bd2599e67%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713040.0,386288.0,903160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a0e977c33358f160f40f98a971659b333cc557b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668264.0,371912.0,796240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a18d6a50215571777b7dda3cff10992d81416abd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673064.0,418496.0,888520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22708783790d3732d8736a303f9869a46a285f7c26%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636032.0,399912.0,818280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9714b1a268ba2416d627f17089b9307d30843b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675384.0,394856.0,842880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223315886480da6b61b226b212c21df234b95fdfa0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720228.0,364164.0,1016560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2236be3aad669edbcf1a0d14bbc31ddf8bb56e25b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B592152.0,363612.0,977440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c2e25fed5c7925c94bac4e2c48c40d74058193d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670032.0,372568.0,798360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22014ff7a0dd722a5e6e3e9070513e0a5b91c69fe6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699928.0,386608.0,948880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cd81ff7a69f1f7a628c7c61507fff4f716f1c84e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621152.0,381544.0,894040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22968b2407038eb434105f8bc00ea29b9114bebf9a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747384.0,418024.0,823280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2236fbdfe5852edd45bf4c84ea00c9f93e58bc91c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683784.0,407200.0,843160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220572716cbb7323e3a3383112a2db72ef56a3b8f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669680.0,454528.0,939360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed2e189d0351ac9998240126f470c08997aaa12d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672600.0,490784.0,879720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b05decf7421599658d584282fbff90a92385e537%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701416.0,451648.0,898000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b3a91552cc5220f018b6057cf66de76016ef473%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694552.0,399264.0,921000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22418b4f308abf2199c0371bb0cda3a231c7e6400b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738632.0,413776.0,848920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b6eea12fca62694d79b97c98936d5b316fdf0ce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714920.0,450576.0,953720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2269cc056ce919d98c653472121c7c40c2cdb3e250%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B598312.0,419736.0,939320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dad864bff3801a51478b502daf38bc24dc4398b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733424.0,440528.0,910320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222253922f1725588195986f02c696286e80c61782%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672400.0,426696.0,924640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220932b27ae23a338dd36aad76da225fe12a581aea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732648.0,352656.0,1056840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225aed7166b1b2f24c911342d7784f88fc9c70d4dd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710920.0,365896.0,1028480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b6ed10e18d3efd2772903c4dd681dfdf0e0cd93c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705768.0,438616.0,919880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d4713630d04958effce43369cbeab11f612f04ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707192.0,439816.0,932960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220bb596679c9a8bb385625f7ef1c0ea6255f21a89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733240.0,423536.0,950720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea7edf73b5eff182cdef5910b5ea8229f310222a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640744.0,407960.0,953840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227aa49d62852000bf2a6fcfcd4ced26e348ddf81a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711368.0,450600.0,881840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22001832c06e1d17afdccf29103085e9e6d2ca66fa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683176.0,486448.0,870600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229adb80983880a6c3dd239f413893e43f10407082%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631368.0,501320.0,898920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277c658468180098fe53ac01a7f64d18d87cf7822%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627552.0,388816.0,966080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ccf63e0ab801d8010fab1a97655cee832862472f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B602292.0,421296.0,909840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd068e92c0f814f473ac7c918fd58d311971e898%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714556.0,436252.0,961320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22800f504a1916fc5f34301dbe4b3884b55edad330%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720432.0,381568.0,901040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2b16f4d56c158324bea2dce7f1e799471be7262%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708928.0,436184.0,950080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228319e35f26a1c131ef2713d3ff084efff17517d2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656784.0,470608.0,908560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f60731b2341d8a87d20fb846dc4a81a742251d0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607724.0,415068.0,913400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4517197691f235a4c088f876cb6bac8baa4d31b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630608.0,466992.0,936520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a86391d1e97a5a5cb705617354b2ae1c19662fa1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685048.0,412676.0,902440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2e7628695973b6557d80eec31db21affe27d3fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688484.0,469208.0,879880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b13734ac9464530535fa393dfd379b37cae3b8e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643640.0,460056.0,930720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3167842404ed10ef1afd0bc94cbc846421e59e1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624088.0,482064.0,872480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b530f67851df0f707dfa797d3e1b828ad8aa92a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717336.0,459352.0,968960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c423e2188aed6a0fbb30873f68254e17998d8902%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647224.0,453840.0,917080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22540fc4a1677839a058b55726149ae53be8f58582%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620532.0,360340.0,1001480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225417989cded8fdf3f27ed3dbc0e685e0b576d333%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754976.0,438816.0,882680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a8cdd6d597bd987ad1843dcd28593bb07abd8ec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625856.0,407160.0,821960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f2f7d05e2bf5fdd1eb071aae29236847cecd381%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697472.0,404408.0,889000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff32d40a6a077cc3fd1fdc605e48036a4c1cee19%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713608.0,357072.0,912720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fab84c107eb6ce3623d4eee5928eaec7e86052e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715296.0,453496.0,956680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220d8d5a9fda8529d8104b5afb9d62fa16dec38f73%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745624.0,421856.0,968240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2204d208888248ff9dbe61b57f0fc0d166115dcc95%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674664.0,464840.0,951920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221675f4172c6c720d9dfe3e2b2374a3807964a7b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712256.0,434568.0,960000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233777803bce3e6c2bf9d2728cf50b4bdccf3c8d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665376.0,421824.0,936000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e17d3d58b75c7f29d3f0b40c3d770b7e7fc22b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687596.0,407188.0,902120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260805890f5676dd9fd4d26f3ac46ab5dd9714afc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674796.0,445364.0,878640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22456787dea742190fd25bae24a641e2b4a7e7dec3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642112.0,464808.0,934720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7424d0bdbbc9929abcad9ed56b1b3d47caffe02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729656.0,374456.0,913800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2243aedfb838772095751d1905d8ceef1c136d1618%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677544.0,376240.0,810920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229763874e5298bfdac6052f958d2063b29930e55f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638664.0,387536.0,926080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249fc21c039c9b26f7ba7c8c674b2109a7962b2a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672392.0,446720.0,892320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dfb9e3aa952555852c0e7cc892ca810544be59ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669960.0,483664.0,889360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22212f066906605864b78be6ff1d11835113b1d18b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613984.0,420320.0,785360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a16a70cfb362735b962e3975d885acc74b54eed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B801960.0,339760.0,988880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1d6d8ff0be31d3319b1c13bd1b850e8258f8dda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713208.0,366416.0,1003880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2215bd415dfb359579641fb5fc4cc299797b67c208%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700744.0,364000.0,1038800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c98b09a349efd1e5ccd6b4d46dc0e08ca6585325%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612120.0,414336.0,925600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22638669696b2d614c8c026ba7355820e823a35164%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703544.0,375728.0,902560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226855d021f9061b4d642bdd68d9de92137115d05e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711968.0,437296.0,961680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0b45eadf7c0cf550b20a0fbbf403e48a36cfea1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B589600.0,474160.0,855720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc051b47ba4d29a2a0594d1ed932c84c0ca38b21%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668344.0,446552.0,894920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228eccb064ba59215f995acdcb76edbfd4cefee256%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637128.0,401352.0,818040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c80b8dbdc8b06ec53a3f1d25be2c0e4317cbfa4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670408.0,446376.0,868400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0a6e731789700c60ff22acf611bb8f49181f77b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678504.0,448624.0,911560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e5a1e9dce4c6df29837e6632067de18009ce1641%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663552.0,459480.0,912800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202d0ef5d72c21f425f2d45af5469747a57779481%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B820248.0,326304.0,1012280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e066945f2d969bf9004e0004a4626f541875d3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659440.0,415448.0,890400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22906a03411dd35a0d54652e58212899f4caa469dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670016.0,490836.0,879200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e65309e7a3937eae3662e64e8a96456b6dc8099%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710056.0,458392.0,898200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227cf515bb81ba89db49773c7b74fd650da6e93941%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715176.0,444696.0,985320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255e8f346561f38e410e4ebb53a4e09ed56e3ff3b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745912.0,440192.0,885880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22309aa5751131e4e98240e2aaee18ece3fe16d7ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635960.0,402312.0,955960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221a27863fe80acf6edb7b1b98062133e680e23ab4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B569156.0,392816.0,813720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22818a37b74d353e4efe69a8799911c2180436b841%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729880.0,496304.0,905960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e9fc7facb04048f0c5663a8a39ad4422773ce88%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728264.0,453512.0,851920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0fa057ed8b679e863a2dffd183eabd46d12a077%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645088.0,420416.0,914880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22927f4d830e47ce57418b315d77c545bb3e0e30b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672696.0,441496.0,889400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22751f90e0b9c45ab8d280222cc9778bcf6a8934e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B779064.0,443472.0,885000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22904ea87886b502a33de277067349b2dac7da7a82%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B577240.0,374960.0,810360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2283f603b6ca8eb11a3ec590dd5c5863906dc027ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719368.0,440320.0,889040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dce099a1ca9d8b0475ec46abbe26db6aaa67d266%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687592.0,472888.0,876480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d09f08a47254960744598168adedd7ef281dad50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654288.0,450360.0,834120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ced5496eeffd8352c02b67985c0663b48428ce4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707128.0,435196.0,885640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1463bd20f9d4504563720c54a509e3434107bb6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663096.0,400360.0,913120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb1aa13c8d7af1a4fe64c8c466e79fec3db057c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682192.0,451992.0,919960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22902271c2010965ace07971380cf9494a2144caf0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631808.0,466704.0,934240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cee9c5c33a316f4c958e306c5d9ada9db903a5a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617592.0,373048.0,892720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22531a169d3cd1756d625ac4b2d4f96c59d4a9838c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644664.0,389760.0,920560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2239c5a3fae890d74c3f584ffe93938fe44191e57f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B764928.0,363632.0,949040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249f3fdaa4370499eed6a26f94cc449a43dccc50a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648488.0,467088.0,882800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266933326100888935f90c7e9a41077a72d766f3f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687416.0,406728.0,906240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2284514dfa0d1844c5eb0f1dbedfab8cb6a010a408%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613572.0,369720.0,980920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22260ed2c3a644580f319892d6de505f1f0ca93235%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B607436.0,404568.0,812840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2284ad187a4c6d9676e82e65ec36a762ce5b1608ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695168.0,437792.0,916960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d515c4c9554688016b34afe94f1687268663222d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614120.0,433664.0,771600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf9080e791d59748f98f8f6ae79740d123c64037%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677032.0,405092.0,898840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fcda4156511885ba82b163e6c429ae3ee21452c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722248.0,365792.0,1019360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225112499ffc1ab7c6d1a7491e13974e5f1015ea4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669432.0,476712.0,891240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f024ed0b97aec6ee54e70c10840bf801c332115%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643232.0,460160.0,931920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282c55354d6cea734c2139eadf84996a9e5ea0218%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643896.0,411768.0,907320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22757b7c661f7c14849ec249286dec278e0bee923f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638092.0,412464.0,904840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f8ab3addd837369b6a8c02f78e2183cc560a9b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645960.0,470792.0,878640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22662af9d1ee8a0b9b55e6747db31fc55363a0d381%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685224.0,481008.0,986880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224caac8eacf8ba7c68864842932611d4e8e63b097%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675032.0,464832.0,947960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae810e2e627f6b1ff058c88868cc12870f3b1c32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715904.0,489208.0,995800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205aaf12c927811d80c7dcb3150c74cccd983700d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707016.0,431736.0,882200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292cf0ecd7ad110c0119f50ec77eeafb18620a500%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640616.0,458864.0,921320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295513e5cd74f1bd61cfd5305d6750fb29e144db5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674976.0,466936.0,957360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e344f3f328dc2fbf1f5b92e1f64ffada7a38c9ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664136.0,415272.0,949360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f30320e98ccff60167dcb986106d1ba2c7ecdeb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669304.0,428296.0,923920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1896ca2d5d95b5035d61783aefac2ef2fcd97c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672088.0,450704.0,875400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2275795eb42e6223d3d646a559b21551342cb3d5e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661968.0,410808.0,851880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ec4dd11258f28a72a74ab51e889ca5e081462f3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670392.0,442176.0,927960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2234c1e6f34083c38c4d73170d3696890fcff4e1cf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669936.0,405976.0,950520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e23c4630646dc4868e62f11b7e95e1f3ba5aaf31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754816.0,447000.0,894360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22138c3375a63484ff8e06e6ab1f6367521e35a488%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677632.0,406968.0,905040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b8fee60e1734ca66e0654b078841eee5a044c7c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697968.0,435384.0,922800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c5fe6815761f9805675b2d1086ca34af4496e73e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647888.0,412600.0,904680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2222469e172674d6a11bf1e42383ecb8343d267b76%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668400.0,453904.0,912160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278994d2582f34d2e4cce161e078ca9441dac937d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652272.0,414800.0,894920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f56e6520b3e6e36bb310cbdea31d515bc7bc26f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B782784.0,354744.0,969160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba53d50e0d14f24799417a2d65f28aca434f92cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652496.0,421776.0,853360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3020da4c55f65b3154fdf1ba6ab2150fc38db95%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638184.0,459600.0,886680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e65a9e1e75c70f9af6e06a7a64a8db0ab57aa76%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718456.0,446864.0,1002120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c1bc804ff346334acec30d609d4e61cd82524f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662772.0,448720.0,864440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8ca465e4722bce9d10a49e9eb6b7269a2b8c978%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657032.0,450032.0,895600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e09fc42973a2cb2b89507b283abac124f47f5ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658352.0,460872.0,891000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d270b4479da7534145e8897bcad29039bf70528f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737704.0,414456.0,849920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2229a6f1604c020cf763959532e6258cb748f77c86%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719632.0,383712.0,910920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8a51764214c21281ba8f79a51528c7efcb14fca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674584.0,486472.0,969440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22215b417beb88062f2fa56003efd047f62aa51afd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666264.0,445416.0,848120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f514723d4977e19e22996dc5fafc4f0b2c03628f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646896.0,391512.0,918320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220524df96ce9b2d9ea47ec6f43f4d6a74b1f0a7e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693944.0,404800.0,897760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a45cc2f39386b5915543e5e8ce501c16bbc92a32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712584.0,429232.0,876920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e06d5e0750eff4c59290c316c921cdc4ef4c62f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671712.0,400248.0,960440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22713704a0ce84e95dc5c1a057a2f61af152b62ae5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689616.0,468088.0,951920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228033334a34db410d10bd7df01baac4244c05e474%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690560.0,462288.0,945800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc100832515b1866ded6ecf2a1e1580e7e02608d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687384.0,408736.0,837160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b713afb0740b0311be1a0118cc44d972a7df0b9d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658552.0,413296.0,847040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2251543509bded378bb5c80d4481632c1c41aa8b95%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752776.0,363304.0,930720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e2a48c91fbfbbc7f31ce667880edd112ca3be10%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715296.0,366440.0,1026960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d941a6f49103c9f456582925b10d6a32e15819a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673460.0,454092.0,940920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278a22a0db4e68e3093353204334657fe07719682%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717216.0,460488.0,968240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8f01e7b1f711b1c724a43a05436ade2478f369b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B746984.0,368040.0,925400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3d5d5558c77f92e4428cf286592336e435d2db0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640696.0,457088.0,916240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db126cc5062bfaa01d77493e4f33617a6ce54feb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650616.0,421864.0,917480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241b64a137e363a3cf2cc07ab970b948bb75e36e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614816.0,414912.0,793640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267f8306648f325dc6e8dc9740c1368bdebcb9529%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635840.0,463640.0,931600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a8734246769a6d713fd4e63b728d09c5337a5f43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626392.0,410128.0,813120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f5bfc4a5296c46236b4ff948fa008b5ef9d2706%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595308.0,397368.0,814960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223645bca5ed13eb1dc3863517eef690ae4060ef70%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717488.0,488840.0,997240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228df23ca215ed1aa4f7669976627ef7dfc96040df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696976.0,384568.0,898960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22734ba728cd8fc13b6a9f25d468ca9bd6e0a9cb34%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B810576.0,345536.0,935840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eef4c469a3423428ae047ef5ec3936d227b636f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703144.0,443240.0,882400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee26e4b4e3ddde0910571cd88d53b63637aad5e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657464.0,452904.0,932000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22be60fbd41ae9ae1e43a4feb418a732ed93f91fe0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738896.0,421688.0,954920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c513adadecca5b12d60b33f413dbcb2ab3704a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662056.0,415928.0,940640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6f599e90f07428f73d6ea53ae190a7abf78a2bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716744.0,440640.0,918160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e7a970bc80a6738d9741e6afeaefc721ee876efd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621152.0,512584.0,900280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2269d97966f48a9a0e5907e00791da1be4790d819c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679792.0,388472.0,833680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c9b5cfe6d1407adf645eecc2906fda59fdc4ad3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B605048.0,418080.0,930720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1eb1da91e214219ab8160fe3725f599a27c7678%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629380.0,506304.0,900160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c251d1f293fee9d1861ee004410e4656a120658%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B586672.0,424344.0,910840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e1762e16aaefc3ef10f50a32da07f9625a9c8e67%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634176.0,460832.0,883680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223cee461623cde5a996b44c88420a2cc17d3669bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726624.0,488328.0,902800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad7a01f208d7c761bec98a534018e89548ddba48%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671024.0,411496.0,866040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf25f9b664402dcd193d97f7ae00869a5bbf9beb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633496.0,399472.0,893800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22557a65da287af5d7138a51819784dcc886ee0222%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B808368.0,345112.0,934520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2245a2b21caca69d6cfe7a397c4b81d565b4598fa1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694920.0,404136.0,897880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285ee31eca6e23b7a22513ecd1e66bb4f9c00132b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697120.0,399944.0,901760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b4707cdcf2be82017b91c27cc33a0bec8df5d52a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696484.0,359868.0,1045560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228673dbe563faff15ba2ece2501d4b31f0a7500f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713272.0,461520.0,867920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c2429ad242faf6dcb6f67140428344ab6196873%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683336.0,453488.0,931120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22137ec5adf9ea6729a9f4ab059f5e3bfedb70d7ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696104.0,390424.0,929960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221029b6b0d3ddf748ae57449d0bd501ccf24c920%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624936.0,385600.0,970880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220fdf51c338fdabd488cf6785c5c3695f01a26b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623560.0,387368.0,893280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22156543f65773372daf131a6c61e44443e9b0a269%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710384.0,434568.0,954040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2222d03fae266309300b7c35d945f081948f2a6235%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616584.0,425864.0,779440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241987d1b9cedff311d36bd38ec025648708efc8e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716056.0,364248.0,1008920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221f0e8f4cf1b9c055933569cd6d9b38056480713d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725256.0,422096.0,947080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298f00c717229940cfa539f36b2cb0ce1a5c93456%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739496.0,441848.0,910240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ddaf7294c100ac7e773eb7d07949ec7bda01c748%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B598432.0,397136.0,814160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22425188c4ee6c7826cd046b34dd56e4ac29e7d7ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684176.0,455192.0,928000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c3dfbd402d73df649afc0213a55471a387502ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B585232.0,423296.0,912520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a52168522b806a150845f460a0464d840d2419ec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706560.0,442248.0,926640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c94f0d4966e746956b2bcc101c95d92b091d534%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B788752.0,452536.0,880000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2286b1d64551fcf38eee208eecce6a306ab9a5641f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722976.0,447776.0,864000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e95d13d98985ec032d280277041e2fb87ff46ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690656.0,456568.0,887320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd4b4ad5ed5c98f000f8095ba784475a0627fe54%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653712.0,420464.0,853720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297aa065363463028c219ca4242bf18524966be6c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715024.0,463256.0,897840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d8b935a7ca5a01b90d2dc799f0e3f5de4788302%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719992.0,479288.0,987240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240c65506f73611836d17ea221a2c0daded4c9b4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637568.0,462224.0,927440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2224eb664cb15b93932d354411593581ed45cc2729%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724140.0,424188.0,944440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a403fa4b1792dddfc9c09fcd668276b3e0bb7a8e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721056.0,447544.0,865800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220078584aaa29872063c5d6a2cd8e83c9bb441aca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701208.0,364992.0,1038720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c2a45766edd33fccab3cdda92114b78055597163%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683908.0,395748.0,899080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b17ebb2826874f7019ed232148db2111b7886865%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733928.0,412768.0,855320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2215ed322198deaa1e33a2f5a1bed3bbc08e982936%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654432.0,413168.0,844640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222bb40215ac61f6899567ac52ba46512d7e08e2bd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760928.0,362488.0,923000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ec634ca3c9a91e6a1bb5e06f6e288cca73e28590%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684968.0,479472.0,874080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273872ba7ccc1870b8c05db17489661745fdadf4b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701552.0,435432.0,933440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d1e531dc9936d5ec4bec34ad22587f4522872de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727360.0,391288.0,936280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2284d5e64b36cf7899dc511477ed0ff98e85726790%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686248.0,392100.0,900120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220b66a00bcc221bb77dcd6e691ead6ad90c1ba32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675368.0,473504.0,961600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2294243c1ebf1bb6d1f5cab371b652c38b0d0578a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614672.0,435480.0,770320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c529a4c57778bf395ca349c7ddccadccdb859bbe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625208.0,392080.0,808400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2289112ff1301c61f6a320418683325874399aa612%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676264.0,410200.0,897800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0ca60e3dbdacfa28f71743b1b2eb5e735134cd7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673528.0,439568.0,925720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a65a32073a261c0d43d5ae305dcff45d472df9e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B803080.0,456160.0,880560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8d82dae56a437c3c1c07eb6eb26d41f6ca1b874%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666968.0,364256.0,788880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257a9f0ed64a82ffc8f31c5f95afba5ffb2612fce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B558744.0,393624.0,812600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285101f1ce90bccb8e7d829ecbaa48ba1ac81b2ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672984.0,453904.0,939440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228398b1d3452ebacee729269fa9d3ca60bd1bde75%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669440.0,404600.0,908160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22893d1e782614498bf99bca613acc884bb3d17f66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651848.0,419280.0,848640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292a1da28871595375207c70af2071635fd7352e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741512.0,469184.0,817920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2287871d2d6ba7b8d923916da063669eff9bf236f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732792.0,464680.0,831800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22adf99b2222070e56f70e0d1b4894a5e63c22ad61%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676144.0,406312.0,905680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c64b3bc9f90e19fdb5f764828baa88cddf88b06f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726120.0,363352.0,1040120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e95387cbff2d2165392f5e479ba91b16feb6cc6f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697016.0,404544.0,889640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297144ad56c987a4a973d2072f725704c88376047%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600508.0,417688.0,917360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240075d0fc25330cfb021900b69cb8186a1c5c32e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686392.0,475440.0,876280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e776ecb4a6dcdaf562120497ff7f7b3678d6cd6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642000.0,454704.0,917840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3d7a775f7048143956ee1a21bbea235048a969d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619840.0,392176.0,804160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22100e2584f24a62b0d44e9ff90e179a1e84582503%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681840.0,432480.0,903560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22157af812e10ec3112ac932e20c0de9c72b9c3799%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687504.0,433108.0,901640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295521437a1e00b8977cd56a0d66ef1ffd23c4d8c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686272.0,428424.0,905000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2803826cb3011af31a5969845895bbc1c5fda28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646776.0,411944.0,906800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226145b04cb818db0fe5a8e81a6bcd56a58dc9d5a2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663288.0,461312.0,942640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2820427d24f5799144dbd212808dc486b48523c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678816.0,446844.0,874680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265d5dd2108a2ebcb6fdbadeb694eee1473162586%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B801808.0,455304.0,879280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222491054f565f51ead242ebadb8be58ad97d09df1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662856.0,448040.0,905600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a6dc9a3e1aefd8abfc6a3e1e822b8b624d153b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606160.0,415904.0,914400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa99f8973196449762b461752ecc0f1ca7ad3b5f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642880.0,408656.0,951800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e7685adb039a55a53f1851d516ce9ddc11de01ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703536.0,432424.0,884600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ecdb99c41c36b9568572f819fe99d97e705e3fa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642632.0,457424.0,852520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2204ef04e622d355249a56f4a0b61a4efdbf4cf066%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700808.0,448912.0,896120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233a13e2a7d9f7c65462396093106c48d3010007f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726336.0,448688.0,860040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3780339509271c81d38a7c6d0ebd401947700df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B753856.0,419816.0,966960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bfbaef45be128cffc4a686cd34c9b6e8c9cf1c05%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672344.0,449384.0,938240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290e072a76eba0d1a84a4e9436797300d05101c66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B735960.0,465208.0,831600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3203a70cd884323c65ed06df8b47398ceab43e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668960.0,486304.0,887120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8c07fb83ca80b969c555a341cb28bb8f87914dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646816.0,453240.0,916360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235c221bc7cd3cd6c016efdab10b6794aee9dce01%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661808.0,417352.0,889960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd6816f2c7475dea4f380936e81f2a81b2d30e9a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726496.0,362576.0,1044040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272d872094a9e6eecc290202e7cb339c03a415973%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637744.0,412608.0,906400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce7bd688f381098eb9b5d4c3535834742a63bdfe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672224.0,465424.0,951840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d19fa759c1f7a8e710dbe358fb80b2e875d6e0e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615528.0,433936.0,771680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22767f9d98cc7416b2a1452cbd746c35298e35ab13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674440.0,506752.0,865560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad6074019c524b7146a46b17ccdcad94ee25e8b8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639744.0,419808.0,912200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2229561d1f48ac79a51aa46b16dc9a402836b3efdd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626896.0,461664.0,877320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228679e94b066dce135057afa097b62bad1f4c3e43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666856.0,409976.0,863880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bae5ba898c56d2fb9476f69b9c844a161e1d2af4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664656.0,457100.0,901240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22082a49980c8380e446bc7a36ab75d417423a4057%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741696.0,422352.0,957880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fc68cf919b65ee415fae9aaa3a7746947d5739b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674888.0,407968.0,863560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b15064e7995147f19df41d23afa673f8854025f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706456.0,448600.0,879440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22152625a78efeb1b50c2902979dc89b7195eb5185%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630816.0,436560.0,810320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22576f3ef847f8179d9eaed23ee90213faf0d5c476%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672096.0,406328.0,907560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d4931ecacdb876dcc02c196d1e74d77409725a0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734080.0,373904.0,919200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b0c282503983daae27e46422ccf8cea003c6aeb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713440.0,350720.0,911640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cab9e0e4b6167310fdedff87d2891b7a2279f3b8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606824.0,401136.0,813480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231fb6a8f61284ad7a07e8a526a23371c8433dd4d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701384.0,435024.0,936520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221259ea03587008a7749abd239ec0df10ca52c339%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700016.0,434936.0,928080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220416f69d37854439adba33b13a99290314f5f4e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727768.0,439336.0,912720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed33aee36ce691c9b1bfdfc5fd8d3b02583e7239%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611440.0,405720.0,813640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a697872f0b6fd0958784387df58145f7682cdcaf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742048.0,442320.0,908280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228781ce6e1b11aa93a0ffaa6107502e5bdac89808%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604960.0,466432.0,868720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a25b30eb3573f112b25eb242caf3c65827ae447f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743304.0,411712.0,841160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232abf10062d98ea8f63a5d152b66cc54af6686d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626896.0,387392.0,968240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce2532f7f67296bd4330775874521fbe344b799c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B574744.0,356528.0,985400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22866baf495e717c9d0ed665f8b342ed2b9f3c3e4e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743688.0,442804.0,904600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e8dad3a467a4f669fdf22ef131a4cc3ece289f4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702696.0,376036.0,901600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225466e8896ff5b02c8d3814aa387979f4b84dcd05%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727552.0,528320.0,909320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22edb5e50ac4781b14089deda21b8271e21a49ac9e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713736.0,435560.0,887120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc0f7c22cb40e293e55a2103cb7dedfa26b7bbdf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621944.0,461248.0,874280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22edb81a167ed24605d59e29388875cd80e161a125%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719640.0,364288.0,1011440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2246ec57db68e90d023318f4400292f6002a06d8be%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B759880.0,449392.0,889440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290c8c701bf5ef398ec2397d9fcb4b98705891dd4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665264.0,447284.0,894360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267b2b224d0d4868f5a550c3a953c657dde825deb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673512.0,501520.0,978480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a4db181240ad37e1da4fdb2a5a8a0960892c787%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672328.0,485744.0,970800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222734fd84e1555e91ac433f9d1ca24799f28f235d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729456.0,415632.0,856640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee65b50f2a3209787c88c6076f324a75584dae34%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654488.0,465288.0,945840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228d0706ae655b9c292b4ea6b75cdd7bd4bbd8d346%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B576776.0,375368.0,810880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296932e0c1aee34584f7fa233f3cb2806a3738394%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644840.0,448280.0,825760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb23783abec03612c5fec3af6e38f30ee08ecaa5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756464.0,363040.0,939760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22449ea59fb672f22b9ac6aefd1fe47a8dde82c3a8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646864.0,470584.0,878000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ac243f8bb406f5977ecc0a875bb8952d4420633%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687856.0,433056.0,909320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2251d5814e5e063d26db0f8a2d4482123c626cb07a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622640.0,414960.0,913960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9cd64c09b231d80da7243fbc2d41525259de65f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737368.0,441884.0,909840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e5f59395e9754c575b023fab491992de6db8a660%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670008.0,401512.0,954520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22afc7efdb67335934bd5b72483074c5a1f9e00574%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695384.0,356496.0,1055120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2259a8fc842f7352f2d257e21ced8a3f76cbb92773%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729928.0,423640.0,950000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab5aa6c16bb50a43a0491b7afa6da6e74391f917%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709400.0,360784.0,911000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235f10336f3186604279e1f12d1787dfca81f4724%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639784.0,471024.0,940560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228cefe6c37976b7ca0f6243847571a04f0118ecb2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679088.0,449928.0,914640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f1d9fb099ee74baafdb800ecf86243f9703ce2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706100.0,447812.0,878800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22be247598e43781cf63c9b4b43b5793916229a170%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615512.0,417520.0,791320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fb77aef7e7e0904b659cac2d1f95237082f8d45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700920.0,435896.0,929440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2214a51a2070bf05d5ede09ea45aa5d78e5a5f04ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625056.0,409360.0,811760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ff27ab3cade7807754f269eb0d4530e5747e9ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684228.0,425680.0,902600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f149109b32726d1f0cbad75df1138c75ed5daf6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B746184.0,444864.0,900600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221492b6568a628c27a0da35d7017c877d8baec26a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639472.0,462320.0,887320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f09e6eb18d0b0f2a8c2ed76ec8c632784c71d21a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670296.0,453712.0,939280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2624a4286fad506b23dbce96f8728206362cf30%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727712.0,454688.0,850920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f1867c20d33fdce6c50f7942cda6d41eefb533d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631304.0,407784.0,822560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22951731ee96e75531a3c445ee2b9b117a435b594a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676024.0,415952.0,881720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e747cc5c1b576d893909086bbffe5f58739fa55d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670904.0,408072.0,947440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b089795276de6b21893166fa0199daea15361b3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619752.0,372480.0,977880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299d70a70805150c05dcf9c6a9234fb9c9e1be1f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724104.0,457112.0,824600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d615992f44413b147092bcd84936ce5fd74afc42%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728072.0,490592.0,904920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22afae90152a27103158a8434f68f769302980cc78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691080.0,401624.0,916160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb1d2bd595d20c8253401dc966d67b50576a7277%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626632.0,421184.0,912600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e7b668786b6f450498c9952746825740b5b696e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661088.0,422104.0,862040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8693ad3cdc995d5c95f6a2fc83f93e572147323%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627160.0,391800.0,893000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22108584638409eaa883576f36bee709f0fd4dc7f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635896.0,406984.0,825440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228323903698450c1c8a163b527f0948614e0b166d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B766856.0,361968.0,951640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2276a031ae68ade351ea1cfe83f1965856b5a85a38%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691440.0,467264.0,949720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e9c358c5082711cc14fe3281ad7b72f199d60d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638808.0,402208.0,820560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22164ccb2961c87a82793c716cc8dd8b73de5ed0c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672152.0,400992.0,852120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226ae1274b141763caa900c2a208c531aa858a0a2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701656.0,376608.0,968960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a3c6d6c41a51a98bdf37d3fde305d9aed269800%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684168.0,394992.0,899200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22be5ef7dc31a0b6611d7b652110ebb69550bc3ce4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648688.0,392024.0,916480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22026e25b23e8a771c91348c12f8b5480b160892a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717228.0,420496.0,870600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22867ad9461f26a85abab0e5f42e948e3a90e53bd6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683540.0,443776.0,908600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223c4f1e74937917ccefd1f7a78781d095709fd97%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600072.0,468448.0,862840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22165b4b3181faf49ee6e7f6e2f9b6fd5ff0409d90%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643976.0,446864.0,824520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22320a7448ace9eb4a22a3b2eded707f7eed50ff02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654368.0,448672.0,836080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba162416cb7bd3b2db05e2a9e5d716d641b91ea2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670524.0,442140.0,928240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b95fb72a0a1317119fdb44227e58b6e71f1316e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724376.0,417824.0,864520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22231308da3d3bd382fa8677f4588fcc137bd1fedd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726368.0,517168.0,909080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227020813599a8d911992e63cfec47b503b03452b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669056.0,519528.0,865680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a9ca89c6d180f7cb5f4514f993d8858adedc2c99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674520.0,497560.0,976320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c5daf218f58b3336483e9078117198fdc86cdc0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677032.0,413452.0,896600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d965cb391ad22ca757d1db4997b506b2b0a410e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731688.0,430588.0,959720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220622915fd72167c1b49b7e67477a974b1f94a5d3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683320.0,456192.0,933080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224208b570eaea11ea0032a06a32f5e69d6bd6ddd5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742872.0,421608.0,959440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22668b21e08266b42233e9082cb4b65511de6102e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710384.0,457072.0,869400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6e0bad367c194210c9829449a6050ce3a1a9bfd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649024.0,410880.0,837280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22150e9e155c2f8426064716009da26df06879a3e1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720112.0,446780.0,868040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22923704c27df813b8823f3e4d03a9b6bd600963b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713136.0,429504.0,941720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c6951350722de960ac96b93242c324e00ea07e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686648.0,407576.0,844240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22761fdb2c00788de339b2380e72edc47240e39236%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699408.0,393096.0,926480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22858df529fc5f62afc22be972e22f0afd143e98f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B572024.0,372964.0,811800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2289243e500c3295ee785e99aa37fb2814a9a48449%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714384.0,446376.0,877080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b348533a77ee905353401bf6ac4b059e6d8751b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683352.0,439096.0,903520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c2d5451c3898a6d8be666b8bc8ec25397fa01960%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675056.0,452976.0,940280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a22785fc0ab5f6a3948cdd9df2713023e7a49a6f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700776.0,396088.0,903200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cba908e6a9983e0bd1999437f979d32e3073527a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B587960.0,472096.0,855080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2204f0850263f365014a86e33efa501d0e8881de55%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686952.0,432056.0,902000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22315f2c69e60c90c49d7272a2fd9a68992f650702%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655996.0,450672.0,911680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2293d6dc82235aca27915090d75c19b862aa5ef46b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692712.0,404144.0,901440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22946f70db16e4dc900212f0066469815ea65a382e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648568.0,412168.0,902360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22753b5dadf27beb5cd0cd0e3ba6c7107d37cad454%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702208.0,393464.0,928080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c996f22256106eda910eaedd0940df5ca865553e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762296.0,401136.0,959360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233f850e3c11fe970b6bd8ff12e1644b9d3c772b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719160.0,472640.0,902720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224beebc316e32cc478cb0ebf28e38ecdd3618a2da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712592.0,462992.0,865240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f39671fb1005b6baad6900920b75cab0c51393e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752360.0,416932.0,819480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d99f34c6bcc9a92246e2493b1951246311bb255c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674760.0,407496.0,905280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7852032a82e90ed3a75c5b438ef4721bc1b6a5c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651128.0,479880.0,901280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22155dab356abcde64e07a62d8214ce553ec7c89e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722184.0,438568.0,890120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ad47616a6659d9d4bd362ac73b46b8a01b27a64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683012.0,431536.0,902600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff6faa2b078fdc9d6d5789b25a6b24ecf2676bd1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689960.0,467352.0,881840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227573bc4075e9182363eed6af67a56f32f5b1e50e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B561664.0,351320.0,987520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22972692555ded47bdbfe690c060acac9bcc3c1f66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682376.0,453720.0,923520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221be15ce99dc1bdaf093c8657beb5d9e3c90fc3d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727240.0,379928.0,913840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e62ef76856df429b90219bc75a12df5c72f9af81%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760104.0,447920.0,888160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c09da5cadc64dba7876dc2fbb2a2f886df6e99c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715192.0,387784.0,906240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22880bf724563ab6b1bc986bf5086b5783c5d6771f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641200.0,488732.0,901680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c815a6a5e57861fd831b1e0f98a31f29051f8f45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727328.0,528728.0,911200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2245f98596cd2f5eec9f9368bc86f5394954c210e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611488.0,464288.0,871160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cdf50f4fa8384409da0dcd00d232536796c363d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668324.0,471720.0,894320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2229c00eac6c1670ba6b05cfbbbafed99c0adf30c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694472.0,409760.0,824200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdd5eddb47280fbf93c70c0158153476f78355e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669320.0,403776.0,950560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d8ec3efa212a8d6d4671318c510a38cf69f8376%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707968.0,440760.0,929800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2263518681b8ac7eab8658f879e0382814b0c71b0a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636296.0,389224.0,924080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f735c4a6231f138c60021007931c250808b1aab9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720484.0,477148.0,985160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22650de4e40550a13e2f9ee3983534725b5f860d12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716732.0,443536.0,999840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ccba54eae16fb9eb1ad093ec25cdcefa07eb1021%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707520.0,367248.0,910600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b56844e85ca63ea981fe536a10a9b76cca86c81%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688208.0,392320.0,981680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c0c6d2a865552afb75b412998cd15580c862d6a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760240.0,363072.0,943000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2b2e23fa8c939ed46e070cff7e9397473f7d493%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625880.0,408240.0,813600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2250cde8d8815ace3d2355f001d836e731c5e786c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661224.0,461928.0,912760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ae8cf5697e7619fd5c89117d81a8620ca69584b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662952.0,399896.0,911800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ab7ac8d9409b2b5d8481762d1685dbb4154719b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B580364.0,422016.0,913040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22377a7458f24bb9153bc5c7cf2e5bae371f91ca10%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666608.0,421856.0,936280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b029db867f92584e874e70f0f5eea60ca628c14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632280.0,413688.0,908920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac38f481527e12d6d68d341dc622dc3bee0c2c55%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659184.0,462344.0,886880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c783bd4a28f40b5d96f3b0e39883561e657c5257%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683136.0,421000.0,902760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254243c8761e8b9c0df7c2a57c554132fe81974f3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715104.0,383784.0,908040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b3d9fb5eef31db6b4367b4abf08b73b80c7fd01%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635536.0,441504.0,818520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba47c1f42d63e4f357d63b8aaefb9280f07bfbf7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625760.0,388312.0,965200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273d62d7c7a5a1e8f346e0ea8930e9b1caf0f8618%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674768.0,416156.0,882840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274a96a560f6b868a7e965180edc0fa6ca5f979b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711192.0,440392.0,917240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226bea6ee00a54b89eb7628320e4ea1306c8c1bd15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675088.0,414752.0,879400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22960e8e97beedd1c293c7f24b0ba71a52e40ec556%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745000.0,383280.0,886400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224863cb42af72768be79e16ee847795a91c5dc2f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732152.0,463376.0,805600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22172fe1ec5251fafec6a7c33ca0727e825b0c8152%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736792.0,371056.0,919920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dffb87450a46a83491185870274a6457e6f393a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658744.0,448024.0,907400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fdd73c5a1e46c04ffdec6b84c4665d9c50f0e87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707712.0,436208.0,948520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e5010f800c12c1512c79eb883e1b261b41b3b11%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674336.0,379064.0,1085800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dcdacb3e67cd8d1cd95fd8f0350edbfd4f6c9916%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660504.0,414164.0,891280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228296432aa343e68d5d4b5c0aabb847e7a7d367b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650600.0,417952.0,843920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b69af4c0d4081cdfc4b2deece315c23039486395%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B774288.0,435872.0,879040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf67f3a708c5eb02145a6b8dadfb485a516e1bc8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704856.0,451640.0,890640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1b9eb99a0b9263297c831d24c142206f1717943%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736944.0,467688.0,823160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ffb19c6c1ff2b7493642dfaac9037599bf06ace8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745032.0,414160.0,833480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217d0f89a351a8ca462d4d1481df3df39915f545b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616368.0,426704.0,776160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6f5ba1773606697662303273cffb9878b308319%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677408.0,380784.0,1083240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2238f9bd4768e10b0a09a15262cee9408dfa1accb7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657448.0,466160.0,908600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a91aacaa6f390cd783387c1d6c0e99ad7a2529aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716796.0,437948.0,868480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b1c88d60facd3fcb104b657d2783ef192672ed05%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B789896.0,350600.0,977560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fe5781ef3d6a71f716365c7d7c685a94ab94096%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635368.0,396240.0,959280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222f386ebda81460947548b590fc4be802a31b1263%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680032.0,448040.0,877360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22085cdabb026c4c502c16b220106eda2680971444%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714536.0,432296.0,952760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22419403db89649d7772cab28d826980de9911ee08%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724768.0,379040.0,911640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257826d7d8feab2d7a080105dba3c56f40da7f3c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703544.0,371224.0,989720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdbece1ed0a31878079db4b027e136975804e4c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667072.0,416752.0,887640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201dec9495159099a87ede415af39972decdeb078%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689376.0,459304.0,888520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231fcc103565531f92149c99bf320edc5e782e34e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B801544.0,455872.0,879080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a13a5d14cf3786b058c0ccc6910e86734c9f06ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731600.0,460828.0,808200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2286c5f83349e15f3886289684ac3add5ff7b87201%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680624.0,433664.0,913080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222744668df44363cc369f43326c01d59a5cd52111%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674248.0,412880.0,876560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298d16d1e6aac9709851113d5b848a8247037292b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648816.0,450040.0,828040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f857e7f6a533faf53414d73af47fa0d5199370eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700296.0,364960.0,1038640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b6c4ad89b67c87fa2837a83fefc0a61a0804891%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642408.0,472432.0,875360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225118020e866f2ae63bcd5ba8c71404e3d7af6adc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637400.0,400280.0,957000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224612a3d31b74cb2c8e5f753f250510ab57b67bf1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670544.0,453424.0,940120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f620ace5532ac473a6c8de3e8d86e37c806878d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652224.0,410416.0,839480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225df4b63135376264f4a1ff632ccb75c03fd50fbc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675104.0,475216.0,962120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299bc74474b3feac83e440dac8ced8616b5b9fb56%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741744.0,439464.0,888440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2293b4cbf16aad5aa5128168dd32c7a0d6f56dc147%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B560152.0,351008.0,988320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2286118b0de2f49a177e479df0f54731d284ca6aa8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686380.0,431172.0,902360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7d469e6cb4bf20afc71154a817e84228b903083%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B558568.0,350464.0,987800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f2aed012a3323936265e045ab5484bf751bc779%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715016.0,452800.0,955280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220cfc1425655abddce92a7133f434ea6323af4ce2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713816.0,451368.0,953960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6608c69a909cf84f8958f8af1b246ddf3634734%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682336.0,419928.0,902200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2214d33f927b84ddf812e9c3cd571ac3d2b7d1c7f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722272.0,364520.0,1015960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228271c7ba13cdc436b0b16812e7c31e838dab75df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622536.0,381600.0,974880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221cb6ed84ffca15e652c8f61834cc638cc4cb3433%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625312.0,408888.0,820360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22397082a581b8be6ec5d57e8dcd81fdb0fc43f04d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705360.0,432576.0,936960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256c326c9d17676edc1f66e2a6dd1090324a3b044%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676520.0,377712.0,817440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226389f3f46f16439de4dd500aa04ab8be3e980183%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716336.0,441512.0,978440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b050287b38584faae7e7826ce7444c0153dbe8dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719772.0,476508.0,902000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22659f7c947b160989a2ffa3247651252ad55423ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691256.0,440768.0,899640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22726874877f8a4bd86841386db23fa63d2927f224%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745912.0,421456.0,967520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224959437dff36419dec3e8ebfbea8695239e95e2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674048.0,449576.0,881800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf033d9463077648a2a7c1b60b0da1bd20c9642d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708648.0,441840.0,933920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aebb002cdbffe1d5bef1b032aa6a832a7ddbc64e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658184.0,450552.0,862920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241b45434f5cea5c91fd161dd5f25a836db8376d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702096.0,435128.0,886960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf68b7c23df8bc0d1bc1abb8cdcadaf18fae14d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B772952.0,434600.0,880520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3a66507609597548637d06066854424c5fd7517%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670568.0,410768.0,867680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298ee3518ee850281848dc5f4b47461682c3ba980%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720840.0,438328.0,890360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c18bdf09fecc65380c9ef7eb5fe7aff99872527c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663092.0,421940.0,864240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22789cd8c432f3c1670d3f1699db66a9283cef09b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673296.0,437504.0,927440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22097946ad5088f4ad83436b93ddfc470de9fd60e1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716632.0,488824.0,998240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222229dc0bcb869ec51d343cf7d76338afb7146a2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727064.0,416432.0,857880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223646ffe74515239a4e265b2d7d441305c304abdf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743744.0,444256.0,906520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274e0cd01d6d6318f7b9d2a7fe14ae8bc27ad03bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745680.0,423200.0,966080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cafa870410b7ceadde81d3774d0fcb7df81b8612%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B746496.0,419864.0,970080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e73d8e1ea5e649af6fc73c9f5490372f73c97a8b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674816.0,490168.0,972200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2289ed28f58e58ef6a2029264cd78a372fe3371295%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626552.0,505540.0,901480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224ca416715e9d2bc847d9728472084af89e2734ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672968.0,437424.0,926600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221825496fb475e50fb8b3c24e7bfde2097c0e2b3f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682336.0,431776.0,903040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7dedeaf6e62e21f54075553bbe792044543d576%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711968.0,444904.0,940560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d99d5145afc0bd559217087ea9b29e094baf9c25%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601432.0,419672.0,937480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dedf2f75fe1d610fad9f4faa8c89bc9db4bf001d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733008.0,344232.0,1066640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fbfe934ab7ecb9f3e0e2e3c04199963e96cda4c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642104.0,457656.0,890800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223bef27980f9841fe64023abac56a48c17ff02b58%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616724.0,419808.0,911360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22961f4dc72f2504d6206415d47092b8f522d6fd97%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697152.0,361904.0,1042960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c2c3f2ca8302fa40a947321f604ba6038ef2483%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715168.0,422400.0,871000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b623fcbdfc93e8b02caea744f840d5b794aa5b68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667096.0,446248.0,898120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22329da716adfd7458f738b72f21067c87ba6783d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701376.0,363784.0,1038120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b7f636356b16aecab5885b3ec83c13a8abc649c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664696.0,425088.0,866600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201cf837d7dccba2ce98af7b5038a587b026b26b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713520.0,366056.0,1004120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c6a0bd11f32b2dfe700f4be94df2a6f92aea273%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708936.0,394864.0,860520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ba345846e21fd3597a93345f67a737ce61576ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710000.0,445016.0,939480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22601b90dba6a5c1f69f56c3aec65698c883690c81%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622480.0,411352.0,806800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227ad1f6a64fe3d85a59494acd5387dad878938ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649224.0,454396.0,857840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf86803e8f17223e5db298672117acefd6d592e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678912.0,448112.0,876800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4308ec11555e7b5b36e1dbe44b75f51f8e3daef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706640.0,439280.0,923080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a67883c6cfa90eaa2ca3711a8edb7a9b8a9af2b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699120.0,379464.0,964640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22567c869cfe1ce800275c94ecda138c93ca4ba70d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777600.0,436056.0,879920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc5c551859dbaf4a1827d6071e74336a50732790%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727216.0,439152.0,911840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201dff4d54b2de4500c49669f2b109892e9f3a918%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654144.0,413096.0,896120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2215b868dc2e10042b850b2e4bf5d8343cfe65585c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606604.0,417256.0,928960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232fc831468dc0d7b7440fb02c3e5fe014d34c104%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711536.0,435848.0,888960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e09dc9f506cc926a7a825ad4b5c135f99e7125b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673144.0,437072.0,926120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf5edde6f4d5b76eca40b29e66872b527f0df3ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721984.0,465512.0,974200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223de8e8ae754a24a26239b0f228a934f7dd624c85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631600.0,394248.0,960280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282c57830fa7a08fd3934949911179d4b88837502%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700600.0,816792.0,960400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221fdfbedacc29564e18d9d728ca8141fb25112996%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645688.0,415784.0,830600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225eebf32e212209423468fbea9d2d947176ff5aa5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726744.0,440472.0,890440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211f30e78eb94d13f026df504c909a14993af141b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687360.0,480704.0,968520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240f188dee9d1e5a7a195757c0b6d429a4e26096c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664208.0,446264.0,931400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224639a89565b6dc7bbf42d52e2f6c32971e3391bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687868.0,409112.0,840360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad4059b2a4af0be53fdc4a8f0f1ab2bc85f3d868%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638864.0,403488.0,890960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ef4d16ea7c1825270218fe99a6510cd4dd811c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748696.0,366312.0,923160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bbeaf156ed132bd5c822de7dfb488d414b9bc18d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628904.0,390120.0,965280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271028894b14b99bb260e110b4108d3fe11620e07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730560.0,355072.0,1055720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bff8869dadfedf81ddc1ebbf2a8eaf34c0321545%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712588.0,425748.0,874080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22266eff0b07102f22084fcd441acdfefa56e4ee81%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708040.0,439680.0,931320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0416de8fb349efadab541988565ae9eb16718c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603488.0,466160.0,867720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224af5fa566fc194809b52737eb84079eb64f1110f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B599320.0,418568.0,939240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222673a6f0dbd4786de9f7d7c5ee8814b312f73ece%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704784.0,395144.0,902960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5a3a20d200300afd3db5f5a54fa7ed8ffe4401d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702584.0,436312.0,887120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fcdc3fe9718a744f3ab4c93f73dfb962655bd73f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612136.0,422312.0,910960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227520e61bcff1c559af4ffe1c6b2abd536d5592bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712664.0,442288.0,876240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fdce76d6d686e3f85d63ab90fc15969a364d765e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760696.0,361504.0,943320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e82bb52437f44780efafde68d4ccdfb2d8ccb4d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720760.0,475592.0,982440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b8bdb1cedc134055ba81cfd23906e83cd0fc0ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595912.0,414256.0,921520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229bf016f294d877d04141cb177e3eeb53275f7c0a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725032.0,523800.0,907320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dbf5a770194e591425d55daca0560d1b1f06d60f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B768120.0,401736.0,961080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0c55c32ffb5160d7692d491a5331bd99552d6c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624744.0,416888.0,910200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225701dea26bffaa2a51b3fcbe5b647b426c66b9c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663840.0,415136.0,950400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224854c08a2505427612a8f84625e0230395323435%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626360.0,389280.0,894120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228625cf7e231dd961f8e3c3eb155f83ac6a8c7193%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700584.0,380248.0,961000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265cbb8b791d7126ee6936ce24bb00ef17a843ac1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B576184.0,377496.0,808480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227225990de9f82337cf6c9ea068c60706c4aa80ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621872.0,419200.0,912240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b521fcdc87bceba5d8f8b1936f8216d7c796765%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B592656.0,395264.0,815360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d77719b465f58225825942c15bce95df30329160%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673128.0,467280.0,952360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a77bfc822c3925691a707475ddcf4a24b584fd6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B790952.0,451680.0,879120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8f9375e7351941d758ae6e17729a7eeb2cf95c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670688.0,403544.0,953400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ea40eecd245551e9894131024e5aed162b9305d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648184.0,414904.0,834520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ddfb795b4be3ac9100d51c3c59ac7868b6069af7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665816.0,446280.0,844440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d288b4bc32bb5ab5bca1280d1a359f4a679774e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B780592.0,354776.0,939760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2218f650d0b5abbb72ff49160f551480fd98ac4996%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626376.0,394056.0,894680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22139bc26fcb5168c59625b2e0e27245ce538c242a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686648.0,431288.0,908680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f24019e71eb9b85a87c9761237b27217bd6cbc3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B792480.0,449872.0,879640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257ce5a00c10ea5c002c0bb8770ce3e0eb9a1e6e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740192.0,412568.0,843760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e7711d76ed76856a4b9bd796ad379bea3b3ab63%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638376.0,459640.0,886360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223101b93a3454f67effbaf26c2482d92b5ae0bcea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672200.0,510232.0,865960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295c51362c5547f871ea924d43d5bcbfe88579f42%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670344.0,374684.0,799120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22205b16c7361a712fe1c8c294ad008159b77881f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666952.0,451376.0,905440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2216f56423b43557f818c1624fccf0da55d4ceba83%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689640.0,462656.0,945840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da530051a489170f74ab0212eb9f47ab8cce7b6e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716936.0,439648.0,917640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b81fb3cef06727437e2e37598f4778777a39f42d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B795080.0,451912.0,879280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253f83af7594995d0fb223fb9a3ef507a3e34c116%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673896.0,413384.0,872680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22268ef4259e125a56b091f8612174d2cb04ead766%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689704.0,438912.0,902480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221459a4efd2a8e52102d86ed000b97199f9b0b128%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714700.0,439048.0,869520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22303525469cfa5ef552bd3287bc8ab6c59e1f1806%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600496.0,421312.0,910040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22be977869405f2089f72bb1d47474742a8f5f4455%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680992.0,450520.0,917280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2208891ac68b0e80b699199ac2b9d7d80d26ad02a5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B606200.0,389712.0,789040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c67c31c5729f06e57e31de2516cd4a86f6010a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616872.0,431328.0,773840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256878b2b48aa52041f0c72d6415b4757e4bc9613%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637560.0,403368.0,953960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa6a520669dcca5a2289a22eb0462ac55ee7396e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665456.0,441536.0,857120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2245282e623cc62a1cb1d2d6e26d083a87ad00b92c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708864.0,390816.0,903160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fd783079b2dd6ad22a12da4142d7b062e166637%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689688.0,393952.0,981600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0c3d7b7426fe0c90bde1942946ff0ac0e0f0da7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626720.0,391608.0,808280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22444282c0fbbdfab216d60417ac7028e511b860e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622512.0,375432.0,978760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273324689d7086f8b833b6036923ba2cabfb66c31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654688.0,412400.0,944120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c7d6aa9837484ba7358fa0db8769345a0d7a9ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694800.0,411336.0,825320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e35c5fba139d66fcb1b6abd226846972e89c1155%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672824.0,449104.0,935400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba4503bab2524fa707de972813842291ce6a93e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674712.0,448808.0,882200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225ec8ac5313ebaed0a4ef392827a94a3e41e8986%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722824.0,473624.0,981440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22413d58715e41ce56e7363dafd8e01182debe25dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609192.0,420348.0,911640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ecc2c3cf0bd67aa1d6bb128915889a322140df1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638632.0,460168.0,887800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da3b2ea53416625bf30f6ad74a7a672ce866893b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691736.0,404076.0,899880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2234432d1c25729fa3f23e0f07626b5df260f103ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690560.0,467984.0,952280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f7c5ee464978278044e9f9caa6831615f436fb0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644960.0,467000.0,948800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b29eceede81f486aa39a9c26a1e5a9c813b1608%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643528.0,470372.0,946800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267be1fc04e151fc3a550ef5378393ed39831ae1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604508.0,418292.0,933240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22773ff2b907d038de819e7f73f5b56a1a1a9aa63a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713936.0,395256.0,931120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22156bf2b536c75ab9e980112b12d677e8c0be5bf6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683112.0,457864.0,938920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f58b0241617a4cfbb54796195b5d830cb9b1934e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645768.0,467968.0,947600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe60a26de1fdc862c00a16b24c142cf4a50b5aa1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743880.0,369648.0,924080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226953805aec8678a22069ecd3ca057e294295bbcb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667664.0,425968.0,868280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b3774d6831ce2a72d843ac5325c7726c5e6fba1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696392.0,381992.0,898640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260b9256ec33e67da9ef34dcfe15d1e2aafc4540a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642320.0,457992.0,889680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260ea75e96713c1ecc2b35dfe0b8acdfc6b6ae88e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658136.0,451896.0,931640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f83d62e5b7a333e276ee6b19874df6e69c86bd7c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674704.0,437584.0,926680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a1cb604c5d62a9e78dd8eccc42ada30a08bcf65%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716896.0,432904.0,955440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cadd205d4cdce475b2d4dc88734b59b68b27fbc2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706248.0,370072.0,992480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c12e5ea783eea0a5d0c0fddddceea1ed45b46370%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673712.0,471368.0,958720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b18ea0cb993af5a858da13f8c94a993a4f585b7b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696876.0,440192.0,888880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22242993ae898cf8601253dc12e58e4b87009926fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725008.0,370760.0,1028440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e08b2599ab5aff900a52bf31376fc250208e5b8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752528.0,438816.0,885160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e16e77d560e03d2d1996677370bd3806d35a8b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707720.0,441224.0,932280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c9a0692816a89e1411711fd1d64b83b5dd788f0e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667952.0,440024.0,858120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277c29706bf0027db78a0904258960db76c8341e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B581424.0,423008.0,913280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242d434595d9b9ba385f44b96f3cd9e92a0d4e465%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707096.0,439504.0,921680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a2605efc1e24d4a371d5ada2b6e1cec13eb8ff8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644880.0,454800.0,855240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e42feb6c1402d20016606ebbe923621db0cf284c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655480.0,448752.0,910320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c61d7cb0d08aea25cc6dd3cdeff634c5dffe8756%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669176.0,477664.0,891080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226630f0c39d68c46367e02151f61d8f7900b1c5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717312.0,421864.0,870400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253720cd18cf93635724a161b532dc13786156fc7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715000.0,438184.0,963240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f349c392fc4856917e817c992d8bda994daa8e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715632.0,444072.0,1000160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22386ad8ed802dbbfa1fe6cf973934cecc9d29e116%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638628.0,491476.0,899440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db2cc43ee44bd1ae07572326a53d98440a05fc5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603024.0,419720.0,936440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c73a56f28dd4881c3c8de86a8093278c404bc06f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B766464.0,362364.0,951280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b4da66e11ddd46059d11bcadaf62485c28ec906%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B659920.0,416332.0,891880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c1814a4739ede14f37cc1a5af9c8fb13df461e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638408.0,465904.0,936520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22052e14edf815839875a920ec7f00cba1dae32374%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672464.0,442944.0,931560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6925928b6994cfe51aea0580f1b6d187ec267d2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B594168.0,421272.0,910000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22458958aba20f1f0abf540af53bad68c525e7b492%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629096.0,468728.0,935440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222276f38266e57ed993dc407f28dae365e7526240%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647696.0,410384.0,949760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8dc6d4c0244b527140199838b3fdc93c9e1d01f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B549336.0,395656.0,810200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e19a4be06ce8f43c2ffc3d5597dd1804de69aae6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656176.0,468536.0,908680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227eb6d472e794920f62facbbd403e6d02cb450a2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724712.0,380224.0,910680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257df36ca4cc2756eb855b0d9d401c9a3113fe96a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694784.0,394840.0,927760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226422310b2ff4ad866afcac1229a6769c52415d5c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697828.0,445740.0,898280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229636fa7dee030248a070cbcf1aa6b26e47356d2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620808.0,459592.0,874320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c6137f68b3be0b0e8a603d04c6a700180a7019b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689424.0,441512.0,883640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221f1fbbed39cfdfe111b3b300a1e3b3ce295b2826%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B753280.0,399264.0,957600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221a73fe6aefa41d726b944952ca9c44ac792720f3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665552.0,461992.0,898160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228fb911ae76380e123ac1956ea8206fc5fe99c629%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704400.0,371000.0,990280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2250847fbf2c1b398113842862e96a76f578ca4caa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730856.0,355088.0,1054720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207891ae5e65de91a8d51a6cd02b46ed34f2b78a8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B771184.0,357856.0,939480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22609bfc2a87f2d327b9625b78edb1d32b8ea6e5b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748384.0,416716.0,827920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225693bbc0a2f731734fc07eccf8cd8ccfba5b6de5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673104.0,414768.0,876840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22966e01b275c257f495c2e3a9be0e7cb4c0d6ae89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678536.0,379400.0,819160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22385b7e917d829aa9e5cd5b1fa871f26d09190a70%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693040.0,398448.0,922400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221bc6285ac631b7d8e20720b074c031a1578ca239%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716640.0,443104.0,985560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249d8e29880a7d54eea9eed8a5f769710b1175e3b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675712.0,449352.0,885240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2276f4a71fdcd8b52203f8fa5b3215a1c18b573f5e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684816.0,457176.0,933840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226aa435dcf31c00bdebd50399ccb812098b81a480%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638272.0,466128.0,933800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b94d3677d0cf3829c96b7b84d85433f0fdd7e657%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676216.0,392920.0,836760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22686d4d3c10f6c0b334ccf4062c1ae4db7e835183%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630560.0,458752.0,882560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220778165e43f015db88383ee400532c4e6e26e0e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645904.0,472600.0,876240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b7603b68dab8daf3db145137f84dd31a492903d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B776248.0,356584.0,961040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2230ade7fa7c1a53d784b9e3572531d92d0ebf71b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619784.0,406048.0,816920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225038abe313949205cfd1482907318de86c13ec76%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B571104.0,354848.0,984600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3d5d2914e99019b069b4ed0b5620f85b2208717%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699312.0,437184.0,931440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22039fdc14b9f8b21ce2f4f2f19b014f8f514a4afe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687072.0,431848.0,908800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22921cdb99ae269179f12933863ad3a12c74abd44c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670520.0,489208.0,884280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f3bfbabb5d5ecb1fe0a23b4cdae7752709ccd1a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707616.0,363256.0,910240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4e3b6a32301f1fa61388f14b8e609738e6eca55%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674704.0,400712.0,848440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e526b87266454a26dd9e12b849d5096eecb211d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705544.0,393768.0,928160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d828410beb218e99708b261a6ac65e99c35d326%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675164.0,438020.0,924800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf012af4b52ac99773600b06fc40d8ba11da80b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699168.0,364480.0,1040080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fdff048c7d573ce770323ce7452473cfe80f1f88%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650496.0,411040.0,949200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231aa6ea093b93402b89f89b9cdbd66a27d63e452%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647736.0,459416.0,891800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2cf5b2898692d17cb146a430792a02ccf1ea026%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716712.0,454152.0,956880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e2ef8facb23920df4e3267adf3240e16f9b72ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670988.0,452532.0,875760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226232f1fba36ac9fab1ee0e6016c6528611efc587%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669808.0,403712.0,953760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298c85a72c0f4ffb58222a2ffff0a9a4488c20b97%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625296.0,390800.0,808120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a1b204df14c7921976945b1f044262cde0857b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748416.0,437728.0,887680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2219c611cc67e3de9ad0756b336adea4f5631fc0f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713384.0,440968.0,872280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22201becb305c334af8dc9b6feb3054104d750c647%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721136.0,477104.0,986520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225218fd9e30faf251c47b3f0703e6fe402073014b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730944.0,355112.0,1055160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db4221795cde3f7608b1add05cc984f1d87447c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657608.0,467024.0,909040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a8d86336afbe1c7c711e4e52ac015c296f8f52fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747600.0,417080.0,825240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2248e2d6866f4c2ff8dc9aca44337b71e717cb3b31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720872.0,438888.0,889880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa95c4c76d6f30eddd1750af7c4fa619292a0840%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647256.0,407404.0,890800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295c2f6700ede9231e8ae995ee3c8d1ecbad5d6ab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712600.0,456576.0,870880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22946c1e09a2ef19aa9830b43ce29fbfaa04cfa074%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694320.0,397728.0,921880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22033883377427add4ff1359d6ba726784ae6a6a0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718688.0,490096.0,1002000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257c6769a3c5a6c6b268678a17250ed42becfbd9f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663560.0,410736.0,858480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c63756b844157bdc712fdc3f83f9651e9c0896cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711648.0,458832.0,897520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c5c28a708dbbaf73e0f81f4bc906224166c8588%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675176.0,470088.0,957120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229733ec93acbfdd853731eca117378708a221e687%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706712.0,371608.0,903320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e96e41a0bb0a7441cb4f56bfe121333dfcb9965b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621168.0,382712.0,894040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a904422729f216f070a1f7f612d72d06c28e8810%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644388.0,421528.0,913720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225bead6d209688276d1ab74e2f32d1e68676372e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635992.0,461536.0,883880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220564f39e6a33cdc08206ba73bf8c830a9666b04d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729656.0,498384.0,906040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e4b5140b608e8d40149a41c708f5291433b315db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618860.0,406968.0,816880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2238646eace692fc51cc934ec56a674401b771a494%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632260.0,400996.0,893080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2a9fb10d0d46b2dab3aec5788b8051060cc4f8d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683872.0,424432.0,902240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3c3ae3cc70c00cac5342f95e0088471b9f8ddbe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650544.0,394808.0,917800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f2231401f8c54e58d5c1157dd9f3d6cdea8b5aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658712.0,447960.0,909640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258b68537c5f1ec1d2d65b044ff9459c3b84b5aed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646192.0,391096.0,918640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226b7b7c4793028a1d8451afa48bf6a37a6130215%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711104.0,393472.0,863640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b3256882500a1c4830695dc53597284bffce06e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675856.0,444712.0,876360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d66eed4e8254ce48de3acb1985b4f7fdcd6df7f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709152.0,436064.0,886160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22731d9f3915e5c8b4a869955fae74b699f3a88a1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B570016.0,393456.0,814080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2230dad8aa3f712fc44c2a8b0adcac7f3521b26af2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700712.0,379088.0,964960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb7cd46957129a261ed5b90cf03c64c413383333%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702912.0,443984.0,883440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22977095e136ee33dc2082bffdc7044b4e80446622%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653416.0,451184.0,861600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fc066a8d01acc22b33ae01e4ba698e8e5c968070%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711728.0,447984.0,881520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221c8bcfa73a160e4041dd1e0f2003d37068bd2ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716728.0,489040.0,997720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c2ccc3af52c0243383704de6b527f7a5f2c48386%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645848.0,414848.0,836880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7128a7da69e827ca29b3209ac0bd89ad9ca5491%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719272.0,460888.0,971120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2287ed056d0d462947d7776b5e5ddee3f583b7a292%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665820.0,449152.0,866200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247055bd56f18f75476a5e62aa57f204c50568116%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726456.0,362824.0,1041440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223565f948ae3ecb8ecc3232a2f3e4a9ead4393925%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669816.0,483160.0,888480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a90a3120bb00f9739d906caa221fefc3a4b9a28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673704.0,412976.0,871520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225596acd3688d92c32b76a1fea475fb8f3068b3a5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685576.0,477400.0,873160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207059f32111f55f5dbfe3d0ce2eef342b10860be%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673928.0,450928.0,911920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22615ba4b2f13a9b68c8c9f1ce50b49144c3f43f91%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748092.0,418320.0,824200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a11ae585670625bf85d726e05e12c932e099ffd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722408.0,365368.0,1017920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c964edd1024c0397dc9454bafa8f2ac9e7165d55%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672536.0,487840.0,972920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22466a355bcb22174538c54d8cf31a1b411eb28a36%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664432.0,416160.0,942280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a8a7624017ccf646c427763109c9668a02ddd4da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749040.0,418136.0,819600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22195816c3aebe8ee764e1824b10132b10f90ee6a2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739664.0,411544.0,843600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22546882de93037b8441365f54829b0dfaf3fa182d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641792.0,407704.0,954280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d147e0fc3817b2bdbb89649cca7a7ded1d129063%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B794984.0,352256.0,938960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2289339eea8ffba4a508047925d66126ad4398954e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700576.0,394776.0,902200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e673772ff19fa67f5df6caafe84b31a02233d52d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600384.0,396928.0,815320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f530782e7af7721118271380275cd0a38751e58%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712472.0,349408.0,910920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f60f1333f5ae5a1731b86032cb77160e3e1f14a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708416.0,434952.0,947480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a7e9fea54a9291754d1e2ba4e74e3e360898a7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648488.0,415160.0,843080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b932c357e1126d0d397bc30ded4d304eb8484ddd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712280.0,445952.0,944960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2219147f0855c4ad1aaf53de34f6c30045d81724ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715832.0,386152.0,908400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c20d7f8b95b0049ba719f96fc720f1c2244ccdc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B815984.0,342080.0,934600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b97eff9f591055fcb61bea54529cf52a000f31f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614216.0,365800.0,993680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c5c507882ab864f2884f6fd1583876701702019%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647768.0,407512.0,833280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1f465de32df319029c5c99fdc867d54c0d0ff8c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676128.0,446888.0,879320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279ec64adff4845f64c2807a4e95e9fcf24db8de7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638288.0,461444.0,926320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22667376f87d708156ecaf26150a8598e85039f81a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697432.0,362128.0,1042240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1408bcf97cf89bbc579b2066981b8f76fc6d3b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727696.0,389708.0,939640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22478988386d5598e05b787504a0da9058b4c4ae8f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604680.0,465800.0,866760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221262e9eb972f2a9303fbf9cdbd5ceef20af234e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B755600.0,446696.0,896880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c164882100eaed474279977e8021a1f32314af2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617944.0,405896.0,816480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f417aa3b3cf630c9f9bcf1eb248d5d00fc326e11%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B559924.0,393244.0,812040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224001f8c643f85bde6e69d14ba8b37a14685757e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622992.0,357352.0,1004840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e479a676ed988284f2a8b5e86b0f9a6cdfb4f68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658256.0,413616.0,849240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22237ea1bd714c5a45913578e0be9f760548608e61%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633552.0,466680.0,934080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f9708a43cdb8576d4bdac3aef070765fabe46507%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648560.0,406864.0,889800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ade52f9195976779f0ce5f2a4311ce22b84e8a3e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613224.0,369696.0,983360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a8387e52303711f178cbda31046d4242afefd255%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637840.0,407888.0,825720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c35096334c2c6acd19e2d9151f7d740e152f159%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684392.0,396528.0,974480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d390f3c6baf97df96b3b3d51bbc795c3d7551c6b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B827184.0,336944.0,934360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296e493783a82850d0606c13aed1d418b95719940%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B751624.0,364872.0,930920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227cdbedc6ed817b410fea62dcd6db8650d5140e31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633260.0,393272.0,959600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca344dbe9c360cedd3d6615a3e8140a85f57d860%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705128.0,435816.0,885600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285c164267cc71d7fc5be8dd7387b0ce4ae81ec59%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754984.0,438104.0,883000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9c1ecc8128d0d9da2ae7e61a8e9c58b724d83a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B780808.0,451464.0,881240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2287deb4018cb4b20bec7b6ad55c5952ec0bc16850%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667752.0,411528.0,965480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b11efe4aa02114db36dcbd6f6228a366a05bd386%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708928.0,444184.0,878880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1f6a733c501b623056b70e7d2618ea13286936c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720416.0,418840.0,868000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22700ad093e1fe77de2e2fbebfad8986a5c900f77f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B590588.0,422896.0,947080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b6e065a5fa78b5c2201f07e1f3cad51f1b6da5ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662712.0,456912.0,900080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240b0c27279cbace13354cee7e7de7e1ab87224a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739376.0,384040.0,889840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e32b31ca652b1db76e280bcac7a28c50fc5db4d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637160.0,461452.0,927320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297c856577b7b743ebc7228bf710108a810608ecf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677664.0,418336.0,890560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22037d95aabfdb113b3c25f19cd34d807403a6430b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649104.0,454960.0,855840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dec2d7b606c25085a9aaafbb9fb887d3ca756f78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635072.0,496768.0,901880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227de197d32ae99d346a18a2521f437f1bd34d07ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719756.0,444744.0,866680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b353455c2dfd4a1a5810258e46db0bbb37a0182e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700916.0,438880.0,915840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f879b1d6d71ed53eed99b0dce971042a5d111f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668480.0,426776.0,927600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d61327d703c82f6be393ee43e9625c9b2cbd9bd6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643720.0,408536.0,830960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a62fa813d6ff77734cf848286a1841c2bd48ab46%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716096.0,428224.0,942640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22258dcd9f6767d7d705a80a536f9468b16447d797%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721136.0,420024.0,865840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22232afc0db9b27e77e07faf1e81330ad76bd55ec0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682308.0,438208.0,904560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221a91dc5c479e1cb1bb9e4e29bdc5bde57d107c1b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711720.0,447624.0,948600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a326b7dd5337cb35eefe6d4c0f07087a5ee093da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692112.0,391904.0,985680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee3c35a5cef040e88830bd15c89402f9bbb3c331%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696056.0,437552.0,915040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d43433d1285b3195463a02e70981c6fc98070435%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705912.0,369456.0,995480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cd37141c8ad2d28e1f97799af069f5339cda7518%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716832.0,443488.0,998360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22591664d615fc728893073d306d908d2723267736%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667616.0,527928.0,864000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2239b5ab160fde714861dff1af4d90ba704784e6bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770816.0,401472.0,963640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228596012198d51cd1adc4ce546a5433947a896cbb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639232.0,408400.0,828400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221a66969d7bb6a2e431f2e8baa98a693a02192f5c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B806328.0,459880.0,880920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8a5cd80d4f2914dbcf18d046699886f94143d43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777476.0,437792.0,882680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22787ed7c45c72ce9b9e664c6aaf93060bed6ed818%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690464.0,405328.0,900560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b47c93b1cdbd4bf8768d77748f67e3bedfcdb901%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682264.0,396544.0,972840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1f78238866bea5d3b8dee58e32b0fbf234f5c3f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684496.0,407512.0,842600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22abfc3f3103e952e5cf78a497ed108f024f785591%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622292.0,374500.0,977120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2228572d53638b85bc219866656e592ef449b44ed4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683616.0,407552.0,843400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2239124882fa88d622ae0d49a12ad47d6be2fc0172%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674288.0,435296.0,880960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223cff47c4e0f70a7cdf587fff96bc16d086c2a788%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667768.0,452732.0,904560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3096423c1b8b8a24a723c425587db8ad93729b3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701944.0,433688.0,935720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233c0cd54c42c414527ab45de1c043e2cc11a7646%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661296.0,446120.0,905400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db63236d9278099cb6b6db7b49f670cd3fafeae1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609308.0,415420.0,926040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221299d9a96f5f5fda614a766604dfe9f87b9371f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683184.0,444328.0,880080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221745d5d852933d6905f64d3ef3e4e04bfb7fb825%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732224.0,423208.0,951640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0e7b42d745e74adaedbfe2cf9302af2930598df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676040.0,503272.0,866360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22845b82a6310d1188d093e45c4c9028a116d3541a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671312.0,401944.0,852280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fc2ab72b056e5e40374894da43b268b63906e503%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770904.0,434120.0,881840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225da6fd8354a9c66695e49e5426fd349e6481189c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687704.0,455856.0,911800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d76707ad50521fc823874a0408076fb5b7b4c26e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633464.0,498608.0,899280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292bdf647773c61bb07ab2377690f46e17cea6a30%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676528.0,380968.0,1083640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2269d744e4a12b61296bca4c0fb68011ff386702b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703112.0,451832.0,891880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222da11942101d08c2003d1f724b3bd4f69ea1d879%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668344.0,409920.0,965560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225dad4bbb19ae52f5ce685f54763cf13b05b862f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632408.0,399980.0,894520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223eda50bb60831b4c3b04c98befa2898c31959c3e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673912.0,500824.0,977360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c6e8ed7eb5369ac244a7861ae388876682f04501%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B816696.0,341368.0,935360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225fd6accc0657c67b7bfdb827acef5479821399ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725632.0,425696.0,946080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221df58a3479a39ea67ba13d7dd3de90f163b54d22%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770096.0,434816.0,882240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227069f03642dcf83e0947972be297df2faf35570b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B587816.0,362200.0,979480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0ca7b83d1cf5733d6d1f44d3f17b9364c876f6d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B580184.0,385120.0,812160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b2b3f0fb3046d20e508acedafc4922896b64f7f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B782784.0,356792.0,967400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a07acfdc18b43dae13f4f0bf3c707c4d15fa3013%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667296.0,415376.0,959200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227bda9567c35084252fe3094fb1dcdd80644ae4c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616432.0,424336.0,780840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f29c1063cdc1e53cdbad7e9edd7d0304233bcfb7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743360.0,413120.0,838200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220053e5e6581225daca03fff625933373b0af42c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664688.0,451664.0,864280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220824763ceeeef9a5d9eb9639db92f687bb2763ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718912.0,441112.0,916160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c972b84554f388165a7c563630df90f0751656d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667008.0,410512.0,967800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed763ed7756abf404cb52ac52519a1fa4eb7860d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668728.0,411216.0,941120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ca03ff22427f25bdd8de80e66b3d7f104c6a2e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653344.0,395272.0,915320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d230bf24cd8cd2d1e714f668a21150255f07513b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B807808.0,460208.0,881920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d5cc8c88f269ae22d7bb53173a9c9b680e43e07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615948.0,366272.0,890640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c7bf17dc1651a19f8c9a803c339a73a27e637a64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720376.0,467456.0,975000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22763fd77ff1df0fb7c6a56ab7d1fcc6480c6417fb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650828.0,409700.0,890760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8fe1f9312b0c3c3af1a1cf8a8a8098b5a3843f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632280.0,474184.0,875760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256248cadaa897f2cdd778103d3e9a137a749ffdc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723272.0,431552.0,958960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220d58e8da970d15b48c18d0f3c3b42749f38770b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668696.0,410688.0,965120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223de0f504c673aeb0d17b56e77b3981a4bb3fdaaa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738188.0,442436.0,888600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c69598148ad12b745a424ea388c1fa09c2e4236%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672216.0,406328.0,859120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235d7cbc54bf10625f724b29f60db932762a50c48%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675192.0,409648.0,855720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253502d915250cbd7f4432fbd054d2c7cdd2c0210%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671232.0,377976.0,1088600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e8c53bf5b720a01da76ef457ca8af606d2afffd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667448.0,415896.0,939640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221157a161626a9d7f86c6b1beb60295cb64dda1c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690776.0,437440.0,905320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce553ed41f7ce575ce276bc8a4de6c5ff63112c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749112.0,446184.0,897720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b14796088ef0a97e6e0601c2a2c32b507e7a2641%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654080.0,412640.0,841760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227900caf6e6bc01a086404a38f2af0bce61443072%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692064.0,439736.0,888480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229aea0e714703bb1c9e2cf1fa34a4ac02ba960be5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713176.0,367160.0,1027920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227bffd9eed177f5f4275a424214bca101d75315af%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B592272.0,419656.0,941840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a361374275943e6c0bb3accd3602429add4ed27%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694176.0,410952.0,826600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255eac93549e0c69a14b58af86d1c1c2f03a611b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724376.0,441384.0,912280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff781c006087dc360a81b6371314b89ccf521f2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656512.0,451432.0,862480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22466b334f59165ec0c8265a2f648b517e995076c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754232.0,448456.0,895240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eceadab3495b86e43728784b347c1b6acfadd55f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649776.0,410016.0,839640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b7f34e19ebcc828b5dfed3dea2884b6cb1054a50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717496.0,426624.0,942280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231bb7ee574b22c89320413dbe9d9bd912fbadcd2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712312.0,440512.0,917600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e779f183459b4ecb1cd64aa39c56f64b858e0c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667184.0,418728.0,936520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22697e6b1d089c31fb7c2df93a0db0a7df64b64a68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660896.0,399388.0,914440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200dec4d2ff0f5059b85a541278f5dff8fa7ffa8b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739528.0,442296.0,907760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22922a4280e5c754c21095b2b9a8e663e7cec2ef35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639792.0,474312.0,874200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2246ac1cea118e1cc2123f89036806f298ac6253a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726584.0,458880.0,811080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221f4fbb7d756e719137832c44ed165a924e2009eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684296.0,428592.0,906040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229152128a6909ef4c35e27ecc3acfcef7af0b4635%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693064.0,402600.0,900760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f982b180ec0b8cdedc1c22fad8111225f51cd85c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B592244.0,393800.0,815240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22028a51be5a9a685027267ec71dee178fa7eec087%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719248.0,426652.0,942760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d178336d84e775dec9275d5704224c873372e52%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730920.0,464192.0,804480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b92d6ddd0eae26837a819e9f028afa544ff8ba90%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674912.0,409472.0,862520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227429c1d8f51aa54189ac1da23fac6e147a4c657d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727128.0,487744.0,903640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22597a2be49f74c68db111a10bebb928ee875c11f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653840.0,411248.0,943720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b247e0f7eaf02205183c2666e3ec26275d2263f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644800.0,408560.0,949640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d81d26b58fa833d5ffd7d7902a13607eea36c610%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639660.0,458628.0,890800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e8a20af4c4746e321b9b9b63ff0af6a48e5d9c2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684528.0,488368.0,869960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22929b72f23cee4e59610bbea8b08ef73118920d96%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681704.0,437216.0,905920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2293d009b60a972c35bebbedc1df729b528e4a8d6e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693072.0,399160.0,920320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282bcafd6a55f853500004b9a34436f0b1facb0a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622408.0,460672.0,874280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22634eccad616e9dcf714ad388a341e1a56e2471d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B836552.0,331256.0,935560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d8f819e4b03f3431e98041d16e9d118cf17fe11%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664960.0,446072.0,900520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a01af43f7c1de5bf4971fb93018de8c7a63ae24%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661288.0,448576.0,837960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f90a6f6d2bc516314bffb4e3d0a75afd67531acb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729468.0,505396.0,907560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b1d5c4f7d99c40e764950ef07235a7f743419ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660152.0,459368.0,892800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fcf08f53dcfb6fad9c57577bf8fc45a508eaae7a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684168.0,455920.0,930400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22541d889ee2126559cbb27ce55afd2bca6c2371c4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671208.0,517024.0,866800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22069a37475f083939168315a7768177662cc2f7d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724352.0,450744.0,857640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b288b67ec84366f13d15fc4d09b97a0c24551c22%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649104.0,452712.0,858720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc6dfdf832565df658e7f102d8c434cc0271fe3b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698008.0,397856.0,901160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f0a4db40dce2ce7403f71e7cdf340f5f273d5cb9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616088.0,432896.0,772880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279e22bd0fe568ed670bed9ec5fc8f71e27ecd9a6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673904.0,415344.0,880600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221327683fbbaa225629d6c62bd748ccb3ccb52934%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631728.0,439080.0,813200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22662adeb8acead60390750d00b1e5bc0b6efb00a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713048.0,447000.0,877400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226602d386d1c640a4edeeb1ae3b284f4fe8ac06b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658824.0,463112.0,886360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e493d596affd3b4cdb01e149454991d9255c857%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B610960.0,420824.0,909680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22546dbfb10f1e5cd495e1e52c2463d5905f91d4c2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667356.0,472872.0,893800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b175ebebe18b6c52f2ca06ee512a2492b971e60c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708576.0,396616.0,871040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22270bb2805932588b448643868a17912891b0a7a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689588.0,458816.0,889240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292af19100998b2b2a17eedf04a3e6e65995a33e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633616.0,458864.0,882440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22885650bb2100cb39e4b0635b3ba137bbe6358635%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654920.0,412152.0,846160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b6136fe2f9b744f242ee07ce1a9f02ceeaca7fb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690696.0,474536.0,958920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22385b1bf10911ead925679a0ad4f384c95e29035a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648324.0,470016.0,879440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c7fec6141d46ba7f42f8045519a416f70bf82cf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707888.0,369344.0,993520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ec14dd34bcecdd2dd102db530474144f00d43ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694400.0,395472.0,922560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac377da4c4ea8c576887d2b827cf49aaec161b19%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688752.0,470600.0,880520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a9d4646d9838fafbc6380490a1b958face7c273%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710760.0,441048.0,919760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eaf5d10c29699ff65766db4f88360a30fed1d10d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657864.0,410792.0,848040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed5e95ea2ed5f1337573f87cd132e88d2635be04%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731208.0,440920.0,909480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2234ba75b4a5403347517f90e4f6c2817037954d18%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723668.0,380092.0,909640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b2d395045be30fbc92460997dcc3366ad571ff0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665640.0,447672.0,895520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0616126cf7a720e02141f9197f9f5ccc454e79a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719856.0,484536.0,990440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c04195bbcb9c5cbe6fd230a5c5a2d5af1fbf917%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595496.0,420296.0,940160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210215f6a9d5f7b4dfbe92dc9ab63a2fcd9750f82%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670828.0,399080.0,960320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c1031e48e21ff6633185aee12d2849807f27eb8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B818792.0,341816.0,934440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f5280539d7c8c62736f9c744672658b914431aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616336.0,461608.0,871720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3188089a43893b82cc8546bb1650cee3404791a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698664.0,382352.0,954520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227aaa999b15ba9f132b84d73ff7c4806a3a95eda0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691424.0,403144.0,914320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ffaf9477a6a0cf86a4750ce6abd72177a8891edd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690248.0,477224.0,962200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2280577854e665aa07eabef60898af002f68c3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717372.0,458772.0,962000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22233f291c20f700b3cb73ab1eeeed35b9fd56245e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690720.0,454888.0,890000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229200f2774265ed6e8d65da264e2bdc84e2404905%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672736.0,440992.0,893760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22910826f761597a69e194fd921510ea6d448ed9f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662216.0,411504.0,853360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a87c18abd2778248e1623b752e1bf4b8c1d52bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666984.0,523704.0,864160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da1e367a149bb411d7d453abfe89677dce40322c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672876.0,507720.0,980320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22967fdef35f5ef176cf1467a1cd6294abf8b310b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663216.0,411496.0,856720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233ab355c470ea1c4a4b0dd758982c980232f39cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733936.0,461520.0,835920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22faab10f5794903c92a37626f8f210a9556e4cda7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714256.0,445232.0,990800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210397f797df86219bee0ef2f0c788d0335f8ca89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713432.0,440704.0,973720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b76b8aee0078e9ec842c4f309518874946ccde26%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666848.0,458128.0,943040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22133c91456af59f624998307c0c31d16b50572508%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716064.0,438280.0,887600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb765c4b0e293b35d54ff3d8874d265596bd37eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675504.0,448448.0,885160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223414c78b1774a668831f6f400f2f1a39b0a6214%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639976.0,460744.0,889400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e9d3a89378cb96db71baefacf8c9b3945cbaee2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B772512.0,358680.0,956600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5c501d489d0dd85bf15e9ca47179b53386b8c51%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682200.0,430584.0,903920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d7b4672199981f83e9dd1d03130b0aabac51c94%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670416.0,401232.0,955520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e545106432873b8bae4452d2fc8715e49a9c1f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613552.0,434216.0,767840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22488d1c348470fc98e31d64ec6848fc967fe2ac5e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B589080.0,394400.0,815400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d8b5bda048a5b791bd87176d2addf979d79ac14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672800.0,444360.0,933040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22134c778458cc8b76d18e9074a93a90a486b86848%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724040.0,442312.0,890880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2286c08de2d0efe8b8cd8f7d64d1f6adccffb6ce9e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624000.0,415164.0,910760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bed2cb1bc3a56c9687561276627e5064ef40149f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638672.0,460992.0,922320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228cbcb9e0a2628b0349070d611aac8f08c2baa4da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666720.0,440712.0,857840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c10d72a907a1a939f6e7c16af7a335496638e309%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712632.0,427056.0,875960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d938d5adea0d6afbfaaa4fa349e58515db8c7d50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690656.0,432920.0,905440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7576ecce4a9cbff361972eadcf56a73445a2396%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703192.0,375144.0,973160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2244775aaf3da3d4ed232e915c702135264bf86b94%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631964.0,409380.0,823560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f62fbd12dad367b2f440cf3bd001ce6c64864cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639456.0,408616.0,827600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c49f2fc9916e5e28713f1f7f26e9b9004544d95%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672088.0,451540.0,911280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa84d590de5445983997ee4df685d1e41ca0e5b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651272.0,408872.0,891120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240d8cb06de12aee3b191b0ab1c53184910726d14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664688.0,399024.0,914040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22737f420104ba90d43fa6ed1493ea0ff75f220d60%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665328.0,457024.0,900240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221f5362823a5ca3f3956a8db898031acf445d5e2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709436.0,448288.0,882280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8c8956e7a773be589f7e43105208d2540028b0f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661576.0,416096.0,888880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ddc03aef584d971610b0928ec3c8a11011d1f527%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663672.0,416728.0,889840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc17a5786451ef9ad35b437d41e9736e275a4f98%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665000.0,445984.0,843680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f9215a0241b2dc4b5c7c24da66605c9e8141c47%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713568.0,366776.0,1027960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253beac9ae79802c89594312ef42bcc58a9be32e1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B746520.0,421296.0,969240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c44afc220354e94ec0ed47c975deb2a5637b480a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674792.0,483344.0,968200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e7d2cdfe981d3a3fcc38b9508f284c365af66e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B599392.0,415320.0,919560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ec98b7187efb9e19af255148e8409ed71e921a9b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747280.0,416304.0,827000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f0f2efcbc79388eb31588f733b81ade91bddd5c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689188.0,431204.0,906240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1aeeffb7040f0dfca3ab2e6918756e8d4280996%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641008.0,408172.0,829320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2286beee05c1fcf2437a4b10756c1b02417058a994%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700136.0,435912.0,885880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229dd57271b2cf1c3af573c71993e6ac9ce8679fad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739152.0,411728.0,848520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3b4e6cf279bf58e260bf42b1c9bc0a96a5fabd7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675228.0,418400.0,889400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249a2fa77acae1575af661c8df47ab559ae724797%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B809648.0,334096.0,1000640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220430c24480684955f7fd8eb4b356b90de4d5cfe0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705180.0,370316.0,988120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22632039b33c78e066a4e08e68dd6363afff6191f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718032.0,463216.0,971760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22585b8bb145fe14c4ba4b91534bdaf40782e781c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B774264.0,353928.0,939880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdb73a6a8c5f437439e4af3f7a40c70995e516c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B557304.0,350768.0,988400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8dce34e970e5a3fbe2792dd3a6a3ecdbed4547f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731600.0,458296.0,839400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bcafc58284f4045f9417f1bd1eb90942aacabfde%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727080.0,415592.0,863000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5cb5af7651260dcba64858845eb45659df63f9a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668828.0,485644.0,885560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ae26423ece8b49081f5d6c54cb4dbfd9694aeb6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682640.0,454768.0,926160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2c27759c39a1d348a6fe25f0a2ebb89b7fc3cea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641808.0,408128.0,951320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b1a54060f4eeccc5ede5a1f11890a33f65e589cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747272.0,437016.0,885680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202575a3629ca8480af628385068d170f2c464c40%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669888.0,451488.0,908400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253041beac225e14cdb498ef05dc8662bdd79a9aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639208.0,461232.0,926680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2244e5854c5f961886d0b941b4d84f7fa557111b38%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637592.0,401240.0,956040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285548a8f5e39bff1778c9d7e774c1834289ab920%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B772064.0,451032.0,881640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225dd3badd3a676413dcb48666261ce539d1cfc18b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673376.0,438672.0,924560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2714d01c05a11a45f98e93e9adf35f4170703ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702656.0,376496.0,974600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221f6366b421a747e8a811e4532bf5d0e0c62eba83%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675308.0,477828.0,964280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221df008de268b71798d77637cb3fb3650816bf3d0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717888.0,472816.0,900720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ffe70f5190195985319616f52ab6af01c73829a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B582160.0,389800.0,814280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226ddc424321ab8613189f4abe8da81aa382098f97%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655456.0,465080.0,946360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257d3664d8bc924ced62e434ef67810e5daef73a3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627392.0,416136.0,912080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2209f5575476caeb0fe42d8d2f99a1f14a963d73c9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691968.0,441400.0,887240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb882faeaa5365a72a1974d2289d66ab28a3d220%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640896.0,459112.0,888760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a780f5a689a393cd231945550eda46529f7ed513%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713400.0,431224.0,950840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c5297244660f0db20e62044adc2b0ed9a86dabf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648768.0,465432.0,946680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223cd1f871389b01a85f1b617049759c5168be9f65%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675912.0,508680.0,981560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e16b5fe46e631157f0de94a8726d4a19a25127b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721408.0,471592.0,978280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271006773cd159c58fb9172ec35c60cb30049931f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B570528.0,355144.0,985040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f702e18092a9d64ce5f2e1d9c6b03950edb551e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653164.0,450448.0,912680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e709bad03a1febd7fe5a6998ec001f379758d81e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B791136.0,353408.0,938840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb5d261b62d9f4e74516497117583bc87bf9f503%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656144.0,420808.0,859280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe2429944ff69b4bfc375f125efea26de14158ce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677296.0,512696.0,982640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232d4ed440639a172cae9bf8c4d1736c80d37e6ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652688.0,419096.0,848360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2243c404dd6a1fa50ed722fcaf99dec58a75922b53%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645944.0,414664.0,836360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22826752198389ff984d8d44310d1a911982b210ce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680464.0,397144.0,969960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22775eda8d729b80c17f3b8e9f060720e811f59434%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677200.0,407800.0,861360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cda9c0b99ff836e6e341301f3f97549a48c0a00b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706536.0,456280.0,898080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dd51cb3820c1c5a81168492e7b4c14dac4663181%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740392.0,425696.0,962760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf6a0607437b4af44db13729aa38a7f6a6f1fef9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671784.0,440776.0,893240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a01f9ab78c01716723025a420825a33f4fed145%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672040.0,441264.0,928600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af7440a4ca2ff479febc4e0ec0ccd923d3748f59%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715520.0,437880.0,963960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292250b57e1721b4576ccd0df3a4a8c05817342d3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673536.0,482160.0,968520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d99efc2b34b7d4dd5e074446118095d3a7152a17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674728.0,373080.0,808720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22718a1c07c1582bb939f2ad8d65a21f3b3e288c31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667328.0,418352.0,938440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7a363008f9feae4eae976fca20055981efbc3fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719336.0,474344.0,902960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d76c0ad88f1fe32a582a71b23a494dd4647d5cd4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733768.0,348304.0,1065040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0324cfc847ecb7f29e6a0acafdf2f11476fb05e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640088.0,469632.0,937400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f73412ab847cae39c0de2e0bc006ce19c38f65db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B773424.0,434608.0,879920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22047b24725728287912fbc163467792575bd25f0b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719600.0,492104.0,1005280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22339a393ca8219dd1ffe8f25bd198f2ce3b428ef9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686240.0,430308.0,902720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260af5684dcc6f5bc90628cf3c2437e03fc23b47b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701840.0,437088.0,935480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e06a690d18bab186bb2fe5b39db1cc2840185225%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B579224.0,380880.0,810240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229bcabb672ece1cd326d8094e44ac6736fed3edbf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709008.0,368448.0,909960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bbb5f2645a963b6d84986b20ad8cb6430644776a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703312.0,374256.0,902440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d632bdc256a3d2780046691be7d7b6464bbe817%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671872.0,429824.0,871400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d58c98e55c191aa328e36f101003a48c4b3a176%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640008.0,409536.0,828360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b628bafa0c418d8aaaa9e85c780d8a70ec4f297c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685728.0,440720.0,909280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206628cbcaa46a4826dd9f0370aff547d76b01ce2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712480.0,434848.0,888640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266bb0a7618065a432e9391c5a4c8b84567266e89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645904.0,456736.0,893920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad17282a4fb922c706ae2d80bcac6dbab8e10317%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620360.0,512984.0,898680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2269005dd806e7c0d630528c3767eea769c80a421c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642928.0,407784.0,951520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267c90481e8def6f27c178a04e1005d18f6147d4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689888.0,403728.0,909360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e41d04aa7dff84818a8420345c8d4071354eb7da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732588.0,442692.0,889400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22479bbd9d9c9bda952aae88f1b097a02f5e60c7a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641736.0,460240.0,849000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e06cd35c99da7feff37817db9f37059e368197e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645376.0,472280.0,878720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2246f56c3537a7ba833e578f93e52cdd27d7260e1c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699072.0,382592.0,898680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224776567b9d035b72b396f03605564030adec5c92%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645416.0,420800.0,914240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b28ed443a75f53e807a331b2abfc0bf0cc7d2ed7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717784.0,391664.0,934360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221da5a4865c61299e280a185f541e33db8f164af7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666656.0,446200.0,929720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d4bcb1376b3e0626e680c3d96c41a0afdd0954ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667288.0,410888.0,966560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d14aaf50f49465be9970f430dbac8bf4252c2cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673596.0,442784.0,869960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271eadcf6784f2de915f69237e65f3024118b5f6f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723840.0,392864.0,935760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207731e7610e073e0d9475a4b1b109ecbae610c38%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609184.0,360080.0,891440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299d21966fd38718467bcfb3421e02ae2e6c2137f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B802072.0,338712.0,994560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae3fb5e1eb47f3f3ed22e0f031ff8fb1465e6000%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633168.0,460336.0,881320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c1e64a390dfe90a3fa9bec77e89985ba29ec43f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712056.0,353616.0,914080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2283c36caaa1b66236950fa7f1a8af5ff0f72470e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679216.0,431736.0,917040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253605e10a571a2e7d9541b99d393711989112e25%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614572.0,364684.0,890080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206b92a969b2bc5c84bbbfb3d33e8a5dd3596e3b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664600.0,449944.0,864880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207d6d7311939689adae294853b81ce17caaa9569%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630864.0,408464.0,822920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228b8552a534ac1d66d3dd1898e7152a5c087da891%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727904.0,459104.0,842440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22beed9af2b6f6fbcb25388ccc2d9248d96c99525a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671148.0,427968.0,871600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22318845c1d168f5550932c9982883b757e78404d0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677892.0,407784.0,857600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2262bd615e21a73cee74e84ac5ff57f87118f33e86%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687096.0,474768.0,875480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd6f8800da6f93e5ecbce231f95d21a035859da4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681048.0,434488.0,912040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f452ee44703a18d60454a45cbcc8df1a423d7ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729324.0,513892.0,908000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba39392cf66187530c5ef360ff3c60363b53469d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650488.0,452696.0,916240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22005d6f15ea1c359a55c4466d0e5f633f749add31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703608.0,372048.0,981200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22465528fa85309cdd430c5ca9ad50563dc3a4d536%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666680.0,364144.0,788160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2237d44de65b23693c8b6f51f5f3687a81ece256d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693992.0,389980.0,986160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22465db509d4dda6cf89fa2278c737418b2edd5f1e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B576396.0,391400.0,815880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225fa33d621ebaa77663f9e41d957cfb48b1a2801c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684192.0,441232.0,907560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb77b20f605c57ca62667677a5e91934f15d6bc5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721000.0,475136.0,984920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ef2e2992945d084293bb613f3151430baf6a81f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B793232.0,346944.0,980080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2229eb45619a1a0651aaf4cb3e6be60b32ae1926f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680708.0,387440.0,834160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277034fed0c11571425b1d4ffc8173516c38d4514%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725648.0,365824.0,1038040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295ee6ea1db39c602f67895e335afde6e528f068c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680296.0,401424.0,900320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a7a9272175a2432f49f25e59a3054fce738c50f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705744.0,439712.0,922600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22347a2e045d28f7061c7c3d432541c9da722f67f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655752.0,454328.0,932840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253b890008acfda80fd8a840820c12d7591239583%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B820480.0,324112.0,1011600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221146090134318f4d2f84247765a6fe21ea5e4bdd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706752.0,365552.0,1032640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5267e6279ed828938f29ea3b749191868e89448%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690988.0,404028.0,900960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299e88e9b60c644ef3ab9976b9baa77320ba2bf54%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716856.0,438504.0,887760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b23a32f051b091289e74dd3935afc3d0532d2a3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672728.0,446200.0,931600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221cd9fa0318c0262f048b8a81e571e88d032b6643%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685888.0,479496.0,968520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2250e75c890018ed05daf8edcc3cfe17950d0212db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709000.0,435840.0,945160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab176f4be299c0dc9cd39b2830e1568a465430a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689816.0,400656.0,914960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2294d53a86ecd921879014a5f4d6af788e730edbcb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652336.0,418672.0,847680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5663c60e03f7007fed48f4f3e1385c4f4df4f8e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658264.0,414880.0,891080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22366fec5d8f9eaf0aa7f17b449fd54c6f93657af9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698440.0,442672.0,886640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22471fad79fa82fdc735b0597af76dbafa53f9cf32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724232.0,448304.0,858520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278ba1570124e7f951a387ecafe7a25d20988b019%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666216.0,473048.0,893640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22566a2fdbde71b7a0601788b0232c86b51b112c67%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687544.0,477232.0,874800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6cb8a58ad68085bb598bf5b3c0c76d3ccecfc99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703852.0,435968.0,939960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229513520b1828d057ef0d86fde7836f74c622a2e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645288.0,454104.0,916520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da7a597090c92d077c631d32bfeb2f863955525e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635456.0,413408.0,908600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b9b1ae4e03f0cda7b10651256e05ed69f0d81335%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736944.0,372920.0,919600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22302decb63485c4022f903be7a37c8a025efbb1c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652392.0,451376.0,912960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22df298442052627c47cee2a245010dba2a52b0ba2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716916.0,429532.0,956200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf9dafd0ffb1a7d099ddc28ec15da618e98783c2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647432.0,455928.0,931640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea63fb3e0dc177ec0138f66cafae482af210201e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673360.0,375576.0,801920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207756bd689d39f3c84f164178bfbb963060b9fad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641304.0,405776.0,954120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b117d2852b1d08ffd3cfd5d81ff981459699512a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712848.0,385548.0,904760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222df95020c1d2e49dfd42c2ed3296d67e23f4565c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622592.0,483720.0,871720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e2880f326bb7fee9f1e053683de6bb07d6f6c72%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612368.0,412984.0,924560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220d5c274e4d27cf68641e4e5a454f4306d0bfb6ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670600.0,423040.0,928040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f317f918211595cc0deb0539df47d878fea4d527%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706824.0,392956.0,929240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b5f96cbbda8d7e1c72a978dc78f983c5bd95ab6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632336.0,465752.0,935600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223eb79e7a88f7ebf280020672ebb35d8198b1ee77%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706600.0,373352.0,903000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2294ab4caa6b5c1bd8b66ddc83d0e534d95e86c368%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B584248.0,422328.0,913720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f73d96365c3c8ff92ebcd1366be8dff9a03f0476%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624984.0,356884.0,1006000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201cc04712bc781628f72b67143263d9d04bf0395%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676976.0,394324.0,841720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ef9cd878af5eb3aaf58015764a42b917edd2bbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672748.0,450720.0,912400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222de3f5810fd5667ee581a4c1470a66eca3b44eeb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676904.0,432896.0,877840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206d57244c6586e0c2fff17ee7e40d3bf1ff7a9d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696216.0,394568.0,924280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b251139af545ad253ed35763889c52fb8b58718%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B618856.0,370424.0,977640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228112bec60f6d67a2cb5fb525b96b2c6ca9f9724a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683880.0,395280.0,975800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203fb4db2ef6ce96da59dabe029207c9f0c556c8b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663000.0,419192.0,940360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b5803268761f3905b19df8131263aec5bd3c880e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657296.0,464512.0,909080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227ba70c4c4bcb831437f19a206e011328c22aa3f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B769904.0,434984.0,882480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e5c6b548de92553190aa680d7b0f860af389a68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714056.0,440272.0,964640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db3c07c895fe5866aed5387738e05a3eaa401ff2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644016.0,461504.0,933320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285a3113e4c790fa8dc9eae951b636b283b8566dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713232.0,447224.0,944200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2212e568f08f6b6dd65e39210abda2c1bf316ba547%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640408.0,407544.0,829640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22229b510eda2b8860176705b74d4ce51cb3649722%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729848.0,457744.0,839680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab26ae4227b33028bd7bb08eb547c1b7442947d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595184.0,421528.0,911320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f89d05e6aa4d103a376d9a006eadadbfb6a1d8e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714856.0,437696.0,887320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1383e66b50e6f1cee33cb166bb07e432244c7d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680584.0,397104.0,970720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292319568214d7b0935cdf3d6e0f4bb578bc0ba3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626724.0,408472.0,814400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297c0a296d74fae2c2cd6c42abc6115178ff6b543%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669168.0,454996.0,941680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226cc09d9e700a3db0b217d81c648d4570f083ddb4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B825088.0,337184.0,935680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e4d45b276851f85061ad37392fc73fe31c8fb15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637936.0,402104.0,891440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a404e1b76b512409e3b9a6656685c22b00c1ee68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631608.0,409240.0,822640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7f88583bd87054bf9f37d277aa91b9491d49223%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B789544.0,348808.0,980000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227a8621ee0321dcb1459ab1cf110853610d00a463%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763392.0,358720.0,936800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e44ab3c8b1d48cbd37bc152f67ced850ddbf9154%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705392.0,369632.0,988520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240a440c5a11fdecdc078574f0bcfc9d6b82a5e37%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690008.0,438856.0,904560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a36fbe9786ac80ed6eeccac343a2a7a335e025b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675600.0,474360.0,961360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cdb6ad5c56bdde2e9e73071a7176679f751e3138%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677248.0,396232.0,845120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca65dc98d63416303a408dc9bd673cde39fde1ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681304.0,447088.0,877160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201553932e811587817133894d639097743fbe868%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681704.0,399808.0,898440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a73a7c992970eac6fd25251d3a92a8fe93e8be92%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645648.0,416136.0,830840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223986fdf428899f79affa8a5c9b872bd9e5433876%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672312.0,400824.0,854560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220bc60c8b5bbc053127a20b033154ddc2014a23ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664184.0,443488.0,854400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d11c2b58e8daee663fdcb187405b1f4c709e066b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B805640.0,458564.0,881760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de669b12ce0d1887167f223a3ab6acc7536bc3bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715440.0,427264.0,942640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225fd302140fad38e5b8262423886a5c31b40b8de4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673088.0,399336.0,963360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0e86e256de4e938ca6cf9d5cd4aefb0220be7fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B735308.0,464724.0,830960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221205df2706abd62bff8da04a0fe35d98de93436f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706544.0,362664.0,912480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d74d85c41bd80f5c4ed772692704c0676a15a6a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657048.0,415088.0,892480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b5fdd3e84bff5e0bfb5b272cf790e9666832b847%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730192.0,393216.0,941120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2264ebb7016c13363c1c175f86ceae3b8911ef7a54%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693896.0,396968.0,924400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22887abdc01cd1d7fbdf07aeaf21f418aec43ab3a5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719592.0,467416.0,974800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223bf7db37e7cd60e48aaa30bc2aebefcaa2242e6f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612272.0,418808.0,913120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fbbee341d4ec1c73ace70778250c27d1f1e67d87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B592040.0,413040.0,923200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dd06f490511943049df59e43ba98b4be526a23eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677192.0,521672.0,989160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222aceda184d71a2bc99a1a00fb6c10026c22e62ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664352.0,419600.0,936160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217c72b0f5ecbc0eac23b2d4c18752e497cfd79fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667968.0,367480.0,792600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223feeab938a2a004e6ef9ab42af5abb65feec6777%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661640.0,415592.0,889120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eaf04ab3a2ffb8315475fd8b2bde4dbe30f3f5f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B784976.0,451264.0,880480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b2c377c79d4d599e30d681e9b7b9feb694061eea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695152.0,388272.0,933840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298b914cf682682ff5418e5eca71c52bae309e21d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621544.0,379540.0,977320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e6bc1b99fb1f933dfe7b11f32014e1b67020062%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604080.0,525248.0,899160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222fb336d5e7dc7a8fb5c8bf4aee00cbe0b9e3277f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B823336.0,338376.0,935760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d9f3b5aeea6715539d121a44b8bbe64e82294155%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721032.0,485152.0,990920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203a43c5a134c0fa2e4b5bb237bc1161ed49ecdfb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B576888.0,391968.0,814120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e19daf513fe41cdde5cd99e09379cff22385de82%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711768.0,387856.0,904560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22133c997a5fbcee11c8951b0cc47d3a86fe87e73e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656896.0,463992.0,885760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1a7c1da0b7a40cc158b9b5445f89728ccac8ff2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674296.0,465736.0,948000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6e5ca4475eaf8052e75a316d3599ba29f6c8123%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711320.0,351464.0,912120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a0e173564586d1ca157592c571b8b9db46d517c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B751808.0,363320.0,925320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2263eb54940dc8dbfe7eacc4b249e6154ac41a12e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726192.0,450864.0,858520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2294912b2c9980eb56543a3168591f51745d11aaca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713824.0,447224.0,878400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22285f8ffdb6a15a802ba38cc0b8ef1cbdfe1d43c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728344.0,530344.0,911400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d12dae64eb21fa3a87d12af9e2107485eaacf2f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748352.0,420232.0,972760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e8679bcef27964f85ab2f787aae7d7c76666df8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734808.0,394776.0,944200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bbc9a3541879b8e36ac3a58e5c0e2961f3f5104e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703584.0,443168.0,880320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b9fd280b481900b7220f8cb9b5f8ed243846488a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674248.0,444664.0,871240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e107b63de2fadedf959641d75cff56ad04d9fd8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747008.0,439992.0,886640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2262760e78d7fb1950f3cc4fe2b17c92317afbd793%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699320.0,434364.0,931240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277f56420bf4e9d8376e5264dfeb5d4e7f1728427%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623008.0,412032.0,807440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22439fbf78dffc3ba7f7a7b11c40651e9b24940033%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686120.0,460016.0,943800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e2c38b11f26092db7c298b79b30f0e252fadc92%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702192.0,371320.0,983400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7b211c1bc4dd7d664b765abe13223657be3b888%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689576.0,477720.0,961720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229921e62eb25a42561923e72887653a2e3b1025ac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673512.0,473144.0,959120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdef22fde1defabfb193c2905b81d0b4ddb6c053%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674312.0,448648.0,884520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223742cdc0d2edde593e8f480a2a893c3545d52cff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749592.0,422104.0,973240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dbc0abc021797da38a24cd2373c71f467f504c37%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674672.0,409696.0,866800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b5b7d7a19f4aa01c3404ef33d38374ed22e3e765%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707496.0,452784.0,886040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f526e8efc504b1a74954cf6f584377ee39de0ff4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650704.0,454800.0,932320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22458eb67dea203a868ed78c55ae64fe7958e6528f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703996.0,436376.0,941440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22103d5e18a61ecdaea59508f7c42426d734fc6768%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726848.0,529352.0,909960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b58671cf8e0186c165958e0b609e6517d7c77ff2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657848.0,465160.0,910080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220dc0203baf40922c69c5a0b3f030012d97bd6990%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641384.0,402872.0,892000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8edc10c566933ae1eb7d3778f15d6c37662709e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683152.0,444544.0,878920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb803b13ff8a130914fe8f4dbe709f60833ca777%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684912.0,458016.0,938120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d419644b75720bbd6810b6cc5c0d6fffd4a6f54%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705048.0,434664.0,885720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e9e802030d83c6a279610d854f76e9077dde11e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637944.0,407600.0,828720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2b72e31490f4fd0fbcb5cd3042df2de1e327b9d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652392.0,420376.0,850800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1d57ec1eb92aba5181d51e173f8d290f29f46a2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725188.0,370136.0,1025960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22683bce5357d4d0191afda2eb98dd06c70655657d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B818288.0,340112.0,936480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cd9f5a8d536f57061dbd716956c0378a13b25035%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715876.0,436092.0,888160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22910e8415c3a1fc75d8b1760e84830a861e0d5422%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B610468.0,393236.0,796680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221a7acc959682f001b7cdbf2d9b8884fe28ad6f3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614120.0,405552.0,814720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c48102e86ea4521bd5aa90dee5a7851e1bae39a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B776480.0,356104.0,939560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22080c08953b3b2cbedfb7a477a4baf29c6eb79219%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673936.0,503344.0,978960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3ad849e4a07b90cd6b527c0c559b47cb03eede4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B778576.0,443064.0,884080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fa0c50283262f7405c506719f0e63adda30d7d3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B596944.0,396272.0,814680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273a051f7ddd3b0ca3d56bdb7696c473c3a5aeaa0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725008.0,519648.0,905880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e367c58423b0bb517f60fd8540ed544cc728a4ed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667944.0,454272.0,902560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dee27d2a3d810e4998ea896dc57bb50ab56dbb54%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B772744.0,358512.0,956640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba24111eadb0e1adc2262b62a6ec16b9d6f3ae4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673000.0,442160.0,930200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22872ef1b146905fcc0ec906bebb83a8b51255cdef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722548.0,392152.0,935080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235adf947a7e697ab3c695d25c5bf3fafa16d109f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763656.0,358648.0,918800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f56757e15ed71f6097ff269979f4299731de31c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608264.0,392152.0,794760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1d9829d651ecca88369d59c74ee36bb4424d690%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651488.0,466288.0,883440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2244c5902da913a64699c015cda9cdd78a4294a0b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726144.0,362672.0,1043360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b0405f2e30a41f538fff7ecc789d329d7f1315f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750392.0,419320.0,821280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221dc017eea0890a5a4fd0a73e0bf835f023910c9d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681484.0,406984.0,847520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217a650e49308f760caafa8cebdf586f13d67f666%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668152.0,415768.0,889160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242cbb95b79d1d220f10b27a6446f3b8d22410060%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707680.0,439624.0,916720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0117a392374cd8c7946bda64a9fedbbc7832b2e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727408.0,417568.0,860080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249a6c46b545f05dd52871fb694321573880f1aff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727408.0,494544.0,904600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221698b448eb90b36cbc4bf2f9462f95ceba5802e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640432.0,403592.0,892480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb9918f0317eeb64264e9127e917ff573a8da3f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663888.0,459632.0,942280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f956a8fd552b08d34061f8ac03e09f37def9ece9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B831928.0,329552.0,1024920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bae505a217f9e575f8743e0d4af429e1a089c6f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687272.0,409192.0,903240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210585e073256fe1a3a8f33810b276d8c9a15d009%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636040.0,395464.0,815280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee69409a22794189d1ba9fc3cc2f0ebd6ae8eefa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B595760.0,472792.0,860360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b124a87f127cece86b280a00fdf8c7f31a63b87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707280.0,434360.0,887320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225d74960bd6a77beee6d7c13e3172e703f50913cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658144.0,416608.0,941600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d64c3c3721a57e161a7531dc91baebc8d8a823a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654008.0,419144.0,851120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278894b1facf91942c3fe7acf383a71debcb9c0e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641828.0,473192.0,876320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a8b5766e1ef862cf41cef7281ef10d731ebd19e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683544.0,442792.0,880360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211b8bd3025490c259c78ce7051edd7f88cae22ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731960.0,441832.0,910120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22edf6f82ad2e9c505cfa86dfbe553656da9501ec3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663544.0,416200.0,946080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22565430c54c3b6670468a4fc685b6125e045506f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645384.0,412632.0,907480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc63e4135a807a3c9acea260da1b742502fb1e15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709876.0,441332.0,938040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3d55637b1b2aa5da55a631d37e87a23e1cfeaab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677776.0,398328.0,966760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0c790a68f75da80760417d3a06e242cc6fbdd04%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681768.0,433768.0,907800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eae33469895ff1a26f096da966121420190acc66%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B544376.0,346352.0,992320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c365f76aa6bfe44469c159004b6bb7968109738f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629424.0,392672.0,811120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f43aeebd275b0a73c5d41da9920e7f98f940882%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692136.0,409168.0,827320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217a555c33a2b8c8b0004dc16b88926463fb4a8b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B821288.0,324600.0,1011400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222649218824fedf516e1f780e825192b2e290a371%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668000.0,441556.0,861680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229379a57ccc65a99d3e255756feef8dd98c05068a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756704.0,362184.0,924520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240f7e7c02bf0e31b613ab6a95d65b4bea294e27f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707376.0,443816.0,881560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f409b2efd739093342a90ccd3d1fc86c5d213819%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657752.0,459344.0,893840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1ec59a76cd06876a9e2eb0d43ef22b2eb232cf8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B835248.0,330648.0,934160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a9cefd6491e427e1673ba9b24dc79cb81f8e2b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629616.0,420252.0,912960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aa6f8b0396399d26508e83d502af8321f4d6b33a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676168.0,515120.0,984040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267ff4add7a795fb0306eb1642b72d942842ef22d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693168.0,438168.0,914320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22468819cd447d8045e0bfcfd5b583ad9d114d9154%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679112.0,407784.0,853200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d40c0a0df9884cc97640602ec7534ea4ca406b03%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627608.0,409432.0,812600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2261b54594f380451a958ba29f96faa69919069e25%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708168.0,450968.0,884680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cd70e79e3922203420dde9f19107b8901882b2ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727772.0,453572.0,852800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f0c4b26b6f96b9ee039dd53f6aea5bbc38d319d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674552.0,461048.0,944240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2207bab26105eefbe8de42912f267ef885dc8e0d46%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665140.0,467560.0,895400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c3b856c7f676de2ca233bca03b957d5613f0ec3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715584.0,465476.0,899960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d47341e259c0d1208ad56cfa36fecc72390ec5f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729856.0,357616.0,1051920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2237f1ea41faced9c7cce83518b6519508b71dc91c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760168.0,436776.0,882120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211b33fffbe83f1b90a8236564633b99df824a22e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743848.0,423040.0,965280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a4383c185a64dc1fef17815c6b3e99bce507dff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B576400.0,374088.0,811960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bbe61889ee839d4c7af20a5965635128196d2e7a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720840.0,446232.0,867360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff93391b884e4fde079f862551f5c8703fe64246%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716744.0,455496.0,959920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2201169f06da5ddec267e0b8d82e5ccda4e5aa5b10%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706176.0,368000.0,992840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2296ec95cd092299dde446050370fd195f7e718f22%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744952.0,440592.0,888080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22933aa2fa5b00f060cdba5c0a0fda429994dbbf9c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672048.0,467584.0,955240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d5984d197e18fe8663fc8e3f754e8cf6d37f397%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716376.0,472472.0,902360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222746a385a4224ffbb2aa8f0d244b8a124ed907a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777336.0,354312.0,939840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ded03cf3f87f86b7b51cd8de5bc287b0766adba4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B602392.0,528584.0,896480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223376f85d503baf5a1be710c1fdb6bab3652aa297%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727752.0,452040.0,852520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cfb6964a3c2af1b90187f784a34d11aca7f5960f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649720.0,467848.0,880640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278d862fc6e63292480b86edcc8e33f50d5751da0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681136.0,435376.0,903600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2278624cbe2d5b8632f56475b24ed127b81ec09351%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647424.0,410280.0,832640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224eee8a8e9fad6b9e1e74844684b9ed52f0bdb1a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642584.0,459096.0,889960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a42692eae6571b5774c0ad99e1b051e385adf573%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B585652.0,424776.0,912120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22365f42e555cc734ec996505e7cd6bc046dfe462a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652292.0,411720.0,841320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf52b3aeda6b6a9de68b79bb3c9e6258fc44eaca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715808.0,458296.0,963840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223465b91a4a1cf8b2de3aa77a5e31095a33697451%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677168.0,433848.0,919960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c286d4691d3a25c1925a403f20bc6fddcdb767dd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B789320.0,451432.0,879920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22efaeb9bfebf85a7710aa46cc5cacf365d6594851%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655408.0,448768.0,913240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d339cdad53ecaadb1a20ab8a93fe545384a822d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B601760.0,398808.0,814600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224606ee4a2ede73c485bafd223bcb605996446448%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624624.0,483400.0,871880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a50d16d165ae217bce02f4d6ee6c080b99d0ce73%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617864.0,426464.0,779920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2244e787b3958405430cded8bb676ca686b75fa8bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674344.0,437240.0,926600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22233471e1df860cf6ebc0eda9f66674c2ebeb8fca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649688.0,410736.0,946960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227af66eb1b37784467c06865eebe09b28d4edfb22%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712264.0,431480.0,941080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222a6ae369864cc55965f61e8f161562824eb2d1ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B583280.0,392176.0,816560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ec636a22a537c43f38acdbd271762d5994314cd8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B774992.0,435560.0,880880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d590d2ef7e8138851b6c3c3fff038ef12c80463%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724400.0,369192.0,1029160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe6283f2dadcb5f070355f6240bddb8447913ea2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717984.0,490488.0,1001280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2212d410bcab63171881db8990f601e8be33a7cee0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686960.0,437592.0,900480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe789de6819250ef8544b96565995a5e7a5be0ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650808.0,412144.0,945520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221145d15e60a8bbcf0e8577a0768bdf2b33f80c58%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681904.0,444944.0,909880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e441f2ae1001e4ddbd5786431f7e2ebe9cc23e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B769728.0,434352.0,881360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223d596a05950723029a8e45a3ed72f51e6bd9534%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761720.0,360224.0,920680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d009a8295de55f893014f4f7186ffe9e16a5e01%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638144.0,473792.0,875640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22849b61bc152e8519feb03f5d9b349d269807ece8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674568.0,458096.0,945040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa886573b424d99e18e674ce00e08fa2cf1c1a6e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675728.0,429792.0,873280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6ed75b21ba9f8ecc2e1eaf7c46980b950a4161b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679464.0,409536.0,849640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa5ea2d61f73f9d9414951136edfdc07e2653680%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694336.0,390112.0,932160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4fef739ed99c3e2f8dd4e32eebcf21a7447369a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729416.0,440520.0,912120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e12c2e413ceea265f0cded258b3ad84c8de5766c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695600.0,394072.0,923760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221231c36ed3834e5b1ad932e8b86f92736c3d8676%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749856.0,367280.0,925560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c0beae3b38f780e78533e735f25163797a8921c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660444.0,460272.0,893480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228cbf8cf06b5757a525e675f88265f9bd2a7757f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684560.0,480048.0,873120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200a13bf254e66970047f8fc6bb1827768dd47dd4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650080.0,412824.0,902160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b72e0a032d0e9559f26d6401d3cb443da1a28b2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630552.0,406544.0,821400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22baf3a2a1fd7844faabb612833ad82079d4c82bff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686852.0,429488.0,903480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b851baa69f3daeecfc9c4234575b3f3b920ded8c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622736.0,416680.0,914200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d7e505d53d9ff0d0ec57145923343f09d23fbf0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750384.0,367144.0,925680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2df2dc3aa8999cdd68c207c6e3772bd11ecc13c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620088.0,379600.0,895080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3491e98773c87ae4c080715b4b67176272f8c78%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657016.0,412488.0,847360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210c60b4b6a101232086b4b970ced35523a68aaf7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620624.0,416400.0,915360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c09271cd44fca87b9443e44d84e67aec9f6d57aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656336.0,470368.0,906560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227af3f84cc22ed9829583deafcf2c4534b6cca998%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670464.0,491760.0,880480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a2852714fcfad84d6ac947bea36ddc92c4920ac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B566752.0,352516.0,986080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222c4e90683b1519953778ad94a6da04c797459854%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627560.0,389488.0,963120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2291381753767b0fb38d9a6efce02628b8f3080759%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752512.0,438248.0,884120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd4fdbd09b6ad8de6c2de4087ae11063adb32d35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745616.0,382704.0,885640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242f065cbe45de402abfeeb7f5ca497a2ed7c5044%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641560.0,455256.0,917200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c54fb673989da00427806720b744ae6398baa958%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667584.0,446860.0,896080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225534f5c6748cebb72f3cc2d621b8271c62bceed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711520.0,441656.0,874760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3560582b720492fc90d2cec8e0b2b925d219ae1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657080.0,416144.0,892880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e391659d63121918ff8f4eb48d966372c58eb20%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709352.0,453224.0,871880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a969fe45c410dad45265537c0c6c6aad71a9bea4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726632.0,378536.0,912480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d720fe4f51cc3acccd9408e8af5e13e98d827e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724752.0,369000.0,1028600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac6431539761ee77f31f95c6c0f3440b1fab48f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672880.0,400472.0,851600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de5a0e498e2f5065fcb53f796e108c815a053630%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734412.0,465368.0,831600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229947dd03860cac33d6502dddf7fabd9fb03afec3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708648.0,358808.0,913320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226f6e3891aa439849ff2c52c30f57986668e23ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691968.0,408680.0,831080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227bfea43e168554c6f541ae87fe5646e62dfde20a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613316.0,519632.0,899280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bba273c140c5c0110ce173c1024297c493353555%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B746952.0,382248.0,887160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22921072bba1d4dc6bc03872610aeed81a6fcde248%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651704.0,412792.0,839800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22111202f5142603d97670d7d61da03fcc19959fcb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648952.0,416344.0,843680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2213d595008964f4ddf273acbfe9bd6d76b5db850d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623472.0,357904.0,1004560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221f2638ca7d08a15d09462799193acdf86e766672%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686408.0,394488.0,978240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22514a5f83cea607de70039b5a8d039d6a18d895b5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613632.0,464256.0,871960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b5479b0111edc5b1ccb7d593a7889c86bc05a2e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666392.0,410568.0,861360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220719adfb42315d4cd6b3c215967441cb84e1ac0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720296.0,477200.0,987160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277bc76423d75d41231adbf0b0103716793ffc402%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749080.0,438248.0,884320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223873b446b961757a18b9f10e4f92cc5f12f82f0a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B590716.0,392960.0,817040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d0420356c9910d03edca2b808abad84267a91d9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B570936.0,371940.0,810200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a06e51387d4f3b6019f14c0e464fa7b2c54513b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B820224.0,337848.0,935680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fbf4205dd92e91e46412890c4021310a0227293%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611376.0,521276.0,897920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e8c496cbb539775fe566be6e5d83af451b4c7a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B600456.0,421512.0,911040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bfa2f88df4f2cceb90933862bb6479f156e146c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669488.0,428600.0,869800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2267ef562cba9bb8ed7b52e4132a6424eb273cbb2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673472.0,467952.0,955120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22254bc2dee2d2f69b4f972496a5688637d0dfea32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696736.0,440848.0,887640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226227dbad92431d302c6072b8f56a4684b63e6a25%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604208.0,466904.0,866720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ebc197a9daa7abe4e448364bdcc46144a07743fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644368.0,420136.0,913360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279d9ab0b1350b0a5214667eba59fef07756177e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B572384.0,372896.0,810520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b75067b9b7aeacfccbed9643b6e673a7779a9f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B552920.0,350400.0,988880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221afd8e51c5f4072eef4397804bc0d7a2e2b2fce4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641592.0,412432.0,908680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260ee6fa22260336b14ceef4e407f7e029872e43d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682688.0,407840.0,842760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e6688888c2df0b7574cd5cc70b8df6e37ea9102%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641384.0,489968.0,901120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da431ba4318706f1d767d4abf3a972820d22cb54%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641240.0,405512.0,954720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22260fdbad16056ac24b94791fa893da4a8b4dd711%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625544.0,390704.0,810600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2243801397788c4159686b41339989b42e052bc7df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713648.0,447912.0,949560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253400c7f8990afa33fb6bfe1697c68070f753ac7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667952.0,422288.0,931200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f65951c9f928158d3d309322c758c5977290581b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645720.0,391200.0,919440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e47d583759f25b044c3a6937c42cc5a1eb71000%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705216.0,398792.0,876440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2216dd4b5b19f45454fc5f4839074903940327823b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683596.0,482924.0,980160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2270d2569fcf094a4bf86283104c8ccb7918db6928%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760992.0,436256.0,881320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2244735cec26b3e456da200a7e82e7ef014146418e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626712.0,408912.0,819560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235e2f25bf857ecf5f58863a9585c629680138ac3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608784.0,390040.0,792840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211cc583372c6bceb791bd310c8abca876cd2ff2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B725488.0,430680.0,958960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2228f36219f7ae18835d422a57a74c1464f4651276%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608728.0,392760.0,795440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e2aad4316dd063f1ebbdf89aa3f59149564da495%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681356.0,453164.0,921680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221cf1ac6f9af4701820c912d4d352237893048914%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B805392.0,336920.0,997280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cbe0d3562ee21f45d2eaf41aeba04548ff095b9f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721476.0,463976.0,974440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d479d718e62a7b357b42d0f5d42de8626349794%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678992.0,497568.0,868800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274eb58e720ee15ed1257a0a59b3fd51856fdbcf0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673264.0,466088.0,951600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22abc4d365bba492d32bcd47ab4542acb33288a6bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675184.0,482640.0,968320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe8bd8db62b569ce74a9e7b09df0f1afe538f800%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B572600.0,372680.0,810880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c13d3192f1f60b94f659f412452d5ae54fd44546%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639056.0,404544.0,953440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22329fc522265bf505651f2bea069cf904e7854c8f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641872.0,472184.0,948240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d1d6432384487c8337f73d553b5bb894b569d65%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716528.0,490696.0,999120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c29bba81cb70ce9effe07f2c121dd54329d15bb7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703272.0,376184.0,975920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235366fdaef96cf5ed2a0f5275c5c96bde593dfbc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678216.0,418216.0,894840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d5ac5ba806ededde6fef606440a172ad5f565b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B608728.0,359824.0,892560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5a37c73373567ef08dbc77bb2cbe4713f9fe064%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631928.0,408064.0,824280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e243cabe220740555e999a4a49ae5892009160f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680400.0,388840.0,834400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227fb7ffe622a84fecf42482c898ae026625ed4151%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698168.0,380944.0,956880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a0070f4b3d7b008c33b8a94a3421000099a0a662%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700824.0,375704.0,970960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c04d4c78f35952c8c682fb228ac50bc5d7781ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620360.0,413792.0,916080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b9075ad104b9a95e932b1911bfce2b93edd4994%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679040.0,496136.0,867440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224c4f9f4ca9dbe109ce09dadd2ba59b5905bafb4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658464.0,461808.0,888600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2252ff5fcc8740f25768658ddad263be45b0918fb0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736752.0,374864.0,920320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e94635fbe7b875e366079d48a4d1a6ed6a30092%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614360.0,415560.0,790480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226cfdbd8c03363dcceb9be635491539e2e701250%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703072.0,393744.0,929200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f95c6c0458acc0859c308bbb3ddb1e2925ade1e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675784.0,475968.0,962240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1555c7613513f22c00e68963040ef6e12bb194f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723568.0,381848.0,911280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22772f00735038ded8360dde32f71a8561e66449bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664088.0,409168.0,857800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc6b75f2b935418f2618aabb9c181c9f87bd0555%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640680.0,403584.0,891040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22823104a2400c16dbb525632b095b25f85a71af68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702720.0,375136.0,974360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220820447e08d881381eb8d92df2f83665068c94e8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685096.0,394600.0,900200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c5b8148f33ce1de2886c3839e30c52e6ae59629%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B591696.0,396248.0,814600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dcf0d7c603177702a2fb045df193170d05e0d0c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669152.0,451008.0,907480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f78611edeb583868be1f1ab20ef3ca904ba18093%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625376.0,421536.0,911640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc096b38935e4423c7bf86d6e2739250f3e13cfd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699344.0,381112.0,957880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299e14070a5966011634ee1ce4b6112595c18eb64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B775952.0,355480.0,941920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdd199b631efc478c38447c7344de15803710888%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707064.0,371600.0,906840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265484f30ae9099255b42f4419368a6c7f37091ad%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B801064.0,343272.0,988640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22535ac7f95d78964cb58aa93cb26fe1d5f3bf3d55%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712056.0,455984.0,868520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226527889c3278b5e3029dc6d92ed5f0b54cd611ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641104.0,402520.0,821840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2255f47bc08b1d9ea6b01c0ab7bf38f187d449c28d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658720.0,461956.0,943200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae26cfa897b48990fc2efb09ca821ba060ebb70b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666648.0,445080.0,847480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b6dbf71a7300145637c3808a1bd2e1447ce79bd2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700848.0,434216.0,930560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22528546066ffa556e3bd8bee7b1345d7fe28b39c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700800.0,378504.0,961240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e130622394eba04398d495053478e40053015997%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B602640.0,418896.0,934120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220261e2d60f6942c32599e7371f0341884a44d4b2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664184.0,448048.0,894000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22307e5ba2c0b389a6014b5c60b324c945a9f09c1c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690728.0,464304.0,948120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3648fc2d66804a8fcd76460dbef6b5499f213cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750032.0,420576.0,975440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d4e02e4749cbd5a2a18a2660d42d3210d1c3d2a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706760.0,446232.0,877640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223b385f80bdab220fa138e2d6ea4c87f211800082%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B596064.0,415096.0,921720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a46b7ec5ec6474a6597751296d3fc9ab5e9d4e6c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B822152.0,337784.0,936000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228978a4266378e970a35c690bad141dd80bdabad7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682700.0,429600.0,906000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224a3691beb5f2e7511c32ab65ce55e4fd67540009%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717824.0,444480.0,873160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3f29d24f4974676e450ed054fa7de8decda156c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718128.0,437808.0,888120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1cc5010ca1c1a7dbd4997650084a28dddb95457%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B792536.0,452400.0,881240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c66a180baa7ec31ed78f1fdf0430b49f968252da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677544.0,382128.0,822120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223c42a954f479f52e38766e0f65884d07a0733277%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B786864.0,352800.0,939880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a887edb8809a62f5bdff3b4a60e073415deec3a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716032.0,443632.0,979120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d2389bae8ff48636ae1845008bda5eaa230c6f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639240.0,475416.0,946320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223614548c77a000bded07278187b9cd5aaace5a13%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640672.0,401504.0,820160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3396570721e352b545944474ed20a4673922857%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668200.0,410472.0,966800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a7cabebc2ead01a01298813fe58c355a4ac9d8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685144.0,482728.0,986440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f0a72952113483f9aa382e52504cba2214bae318%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B581228.0,390864.0,815480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f0fd61e6f76528d3c55d6b954c9ba248b3bbc092%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633416.0,406880.0,824600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ece089b770c5070737ce95925a3076ffb724e7e0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634456.0,472168.0,875480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cbd0e97ccb128ad1cb2e04b34bd192879309a646%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678936.0,387664.0,828920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2238544f0b9bebbf3003e79222cf6be15bcb78f00e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652128.0,450296.0,915240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22577e6dae1cddd76649f513d5a38a390efe0f35ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674128.0,375008.0,806000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226830f337f7ab2bef60bb7a88aeed46f75d7ad292%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684824.0,406496.0,841640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b83e91eb791ffce7ad03e54a9bb0a3967b726c5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720480.0,367936.0,1028320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a7d6ea8eac1d0e53c39be51dadb10894e00a7805%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717508.0,385200.0,908760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22871f8c2ccea4b32c7f7b81b6fb984e6d3adc1c9f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693196.0,441552.0,899840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea062ad00ddbd7bb9ca4e1395ed7e6e7149baf57%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B792608.0,348728.0,979600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e002ba0268bc09a1a6d873877cc99ecf3ec942e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672736.0,412792.0,871720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274e3578200c2388596c0269103b3207e9f858969%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717720.0,444704.0,871720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22edba1b05e4eeeef0f30b5536b18802513d4728fb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720192.0,431640.0,956720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227c86ee868e69f9e4ea33714bc97f0a4c71b83b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721776.0,442128.0,913640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22215bd849c293f2b68007c68e64d4704fc7429a46%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B604448.0,416464.0,915360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bcd8c4da6d2e83cec44fc6a384289af9a7efd840%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673720.0,407944.0,864600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22218d296b595bf3c9b14dbc58e897403726f19455%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B653336.0,454128.0,893800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b132d187da22440dfb3882787c53036292901533%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756640.0,362196.0,934800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e39b9550a104b5e3fac2a0de18c05c471d9ef626%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715672.0,444464.0,995440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7b9e398036f2a56dcab3b53e334ea160eed16f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691664.0,456296.0,888360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a55f78bf5548bf44612bb43ff0dce2167a1f042%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634288.0,400232.0,957560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229d9287d2e1d1a9ae6b0d07ee10e4c58ec0495185%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646432.0,448120.0,827800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee46dda3c8d2678f5d479e7646c4ba1471838405%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710680.0,454736.0,872800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225094bac0aec05dc390f7aaa8ce44b0aa689b6edd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633080.0,466216.0,933520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3a5e5239248328f47ffa4920e3abd2782de57ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727736.0,358576.0,1047400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f1a7a0265e32c368fc552b1937b556a1b836b9ce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675512.0,393792.0,840040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b0068e8b0b24e1400ff22ec08dc2e04ec3ffa6c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612792.0,436824.0,764200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c6a101b93f107b7114ef7e711aa0a0aa4f01d3a8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673360.0,446472.0,933800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290b53bc4c25f7fd16793f677cdf8216216206213%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624664.0,460920.0,877440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a51ea2037181689f536f3df88c7d4930a9c4eb5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708088.0,443448.0,877480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4548428d87cb21d7f9be0c6e0122bf904caf0e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763648.0,401416.0,960360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2236f87d2cf86385975d194864aba83c068bb231c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684472.0,437972.0,900920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227958c00a24094183e43020246db9593772841056%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673760.0,445280.0,870080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5f0df1c344261872a4bd71a409c1c716a172f17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B580792.0,386800.0,811880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e61d0330855e4f5e54df9506663fa1dd174b9d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B785856.0,353088.0,939280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205fa4a568548e941f3ac47f4c72f40f3e743f32a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B555872.0,393008.0,812040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dce4436039958fba5491a0040aba9cc3a3d7ea08%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696168.0,389016.0,938120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb4e9bef7ebe7e57d8fcd3f936ac548b464b73ec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654952.0,413320.0,844040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22746b65aa650586c3caa5e05d0f892c9fd7c1f390%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677552.0,515744.0,984440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2225e4b93cc8716bad1105ea5284976a29831627c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665960.0,401424.0,909880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221928024b6c130a3fe114e0a58ace42f13453f02e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707112.0,369112.0,991720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e1dce054f24ba73c1077973851e5f525e2960a2e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703400.0,434040.0,935280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d835407b705d973149ff3488ebf2e5e17f3f6296%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629016.0,407624.0,821160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e88f35d78b8509a503800c5e3735419d6ee0f57%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628464.0,415368.0,910160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3e8424c4f3899d66b578e35e5bfd20d8b104e9a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713728.0,448952.0,951160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bee27730009b303a39e3d6751da835731f654935%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777328.0,438784.0,882520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac8b21fa35f10770d62ebdcb2510767ba3d6b3aa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721192.0,469744.0,974960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d3e26543b1c565947cf994aef607c64f8d73b94%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B752632.0,437504.0,883480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22241e13185397524b09ada24ba0763fd94f3bfa69%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B597992.0,470576.0,863320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e2e31b65ff2684d076aa95b30e966fd0c1ae298%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B783472.0,454176.0,881360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254ab1b221ee45ee748aefc421d70297207b0a5fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624028.0,482048.0,872280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277d032a7eb7914b4f073f65266eb5ec64c1a676e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665144.0,445056.0,852560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f33e1b0a82ace95730c8c67d7de5ec3d1816b95%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750248.0,418608.0,821760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b4ac9c7cc133844bd4987cd1bb3d8647214bdc4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654664.0,468640.0,908520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222cf046fd533637ce988e430dc30fc3fd0a333ab6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642456.0,447624.0,824120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2252a083960af46519d724d2260b48d10bbcd4ecd6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684328.0,439928.0,909400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d833d3327bb82cd05e1bcc5b9c7d8d2acbc3ddb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B789448.0,453344.0,880440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e45d3405999f2be713c2a32d7fc3df407f75fbc1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714896.0,423816.0,872000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f80129d76688b6c5d6dd3f6ffc1ac38b467a2816%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710620.0,436832.0,888440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d17a6d4bc3e292b44f1ec01323cc4adc62b6753e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723168.0,417720.0,865040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff20d9fd1bc02148a77e42cb35c78c6da6c954fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667320.0,456808.0,943040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7e3a7a478135980df9fc25f4c318a5d02365136%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670912.0,440800.0,888120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22174c63e3527dc0f535eef3b0b5495b07eeb1b698%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721640.0,381096.0,909200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d27ef0175e3a32c9c2c7481543733a8124a2e03%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665144.0,425032.0,922280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226796ab092ffd221203808d7efd847c9ff510e0d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750920.0,419536.0,964280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d9a8c7c45721081921f6f1f515d8515608769bd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704696.0,371008.0,988400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a1076c4c37cc0f9416296ecd5da264a99cdc088%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661392.0,410824.0,853440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0b01646ad5f35f72fbc428423b156afd6d54ca6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669888.0,409484.0,864400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f45290e1c30472f239d9de706c916391ac39359%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609976.0,417072.0,926560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d64008421359d1644a9d824a2c86077534e0c9fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721168.0,439568.0,892080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22206999af43f02ac4e4cbd2c0660cf2a2796e7262%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690872.0,387200.0,900720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f61c224c1618bacaf46c86731ec2bad8e734af0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730264.0,430288.0,960080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c21562cf8b4c2357e83913418743fb53a478a50f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718192.0,461816.0,970440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a404146d9baa0311d3c7484d56fdb9da48b26637%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667184.0,441424.0,856320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e58aa3a9539e5877b39c10815dae2e980c27ffab%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689908.0,408208.0,833920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223251bbe9e4069ecd3c4bad4e9d4fd730ed715294%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715260.0,365052.0,1007480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22700d3828c2285a47259dd412c0bc6c63e5725273%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726528.0,362984.0,1045520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f6259827ce564dcbc502183be4de377796faf77%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B792544.0,453296.0,879720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a1b9a295bf0fd67dea72b380cc2d601792e00a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B801544.0,350256.0,936640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256d8f0abd1c3fc6dbb2cf5629a59d8156ed2698d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678944.0,388896.0,830960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b0e08003baa10991d8942df3c5599b3715fb553%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684168.0,483808.0,871040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a439960cdf87d6876f9f1d61004965a3bb8d3e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729104.0,509128.0,909200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299a8bf361317d3c73a4ba69c93387a236efab43a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675544.0,399672.0,847960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227098a28ee7e23c9b449fb9307c4e3b7c2fb0a8f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613736.0,365376.0,990360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f6a48d177dd5f3457741dfd957c4050ca110b05%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673120.0,443728.0,930920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d77281578fb56c756f4af517168eee9d1e2031dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657584.0,450056.0,930960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22684b74dd988baf7dc75a03b569fd0dea8b014066%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706928.0,450376.0,889320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228d6b6cb7bde9de12f46e3c96b4c8a70855d5be48%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691944.0,410184.0,831960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e97294c924025fb967ad99a700d74d4a5c0c2e43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678096.0,449376.0,875840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6884763e432e89063d858ffe7b48a94a98e2e5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661588.0,447068.0,929960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b4437879b4d9e4a62917c71e44caeb9c788a3825%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727520.0,416432.0,862400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22251352b27055d8d5d5c5eba7bfaf8948cfd67cd5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718536.0,384328.0,899640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b24db3072a036cd851332ab3dd73e366c5a726d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687072.0,461952.0,943840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b02eb4ea1e9bc0713772ee49f6bc2cab6cbbc025%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662980.0,445344.0,902640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22efed8a42d212812418e1b29cb38ea1eadf1d6def%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654952.0,411864.0,842960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf64c733b48deb11127c80807a205ebd4ee466ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642328.0,462320.0,934120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225cc27c7c70e9a9bbc469eb94f3681f7e25b9af26%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636688.0,421472.0,913640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f9f9303eb2fb4a9b81d67384cefd99203a175bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720132.0,463628.0,972680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2262e6313cf40b3df96c89fa5a6f59e92909949071%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711528.0,393504.0,866160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222d4733e3edb7c157a2f20e035d09c6a69c30d622%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721708.0,381824.0,910240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22334236f2f5d547351d63ae41cbafacbe3e94c75d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717008.0,457320.0,965240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228fc4c56b47dfc588a98c82bab74f98327556b5ec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B784480.0,356808.0,970200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232234be9b3a36e3bd160d60cabf9be0f79fdb4b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681320.0,396304.0,971720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226a7be742d5b1930b80142edc71eae68ee199c809%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B582000.0,387328.0,812720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c6d7acfa59eff9dc85dd74a7070680859dbd0db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679724.0,448080.0,912280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b28754d9a2cb0d96624229fe3c3c2f5996759e5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697312.0,407856.0,821200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0a8ac1c6afee8ab25ea96af7d1412f9058ee046%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724064.0,369412.0,1023040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b70938eea1575b4b292d0329ce7bbb6615c4a7e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685776.0,481624.0,985840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba7edcc0323ecc3f187979f76926c3520ab804da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B605840.0,368312.0,977960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226214d1cdf136dde1229ae8e43bf5d233eb8d54f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729880.0,507688.0,909400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b386a84b663dbdac4988696d00a69784d22e73c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681576.0,385548.0,832080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22acfde3cf58a114724733c056d0ba7c82ab10c454%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724020.0,483168.0,902200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253927d5b1ce8245b14419701bf3abc4ca7865e2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619056.0,415288.0,920120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221dee62ddc44a1cf880c57605dbaea1b2ad9786f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663344.0,460824.0,913280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206e754359f2fc094d012adb0e81bdb43babf3f9e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709168.0,450280.0,884200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2256b7d1e6f7b451c7293254d8f24d427847d33fce%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628152.0,407408.0,817440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c1c04b21f2e4e58eeaee18233fb78e9b1f6071a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B627704.0,415712.0,908840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0e5d8d8c6e670c39e7ad0b8c6869b9468a530dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719036.0,382396.0,900000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b50752f0ce99f33fded4d1e9e683bdccc7e17a6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763888.0,358984.0,937880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2288abad796bc7a347a9792a7c50198d0d4a355382%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B812552.0,343496.0,936000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cd87455631cbc86ddc3dbb2e64e5a848c5730856%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B558952.0,393968.0,813200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c27db187cd0dbcf335434dddfff2f9ecc1dd200d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680440.0,498816.0,865880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229fe8b2fee2b9c8d6d2ba5e7c57971a5cb843bb31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B586856.0,391240.0,817640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2286a870df638a57d59d04c90dc594694f64585e7d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673632.0,483400.0,968440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223eb93b157e78b1e6625fad5961dd051b7de83ac8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B609712.0,371112.0,978400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292ffdf72c04a7f996d15772a1bad826ae9224a28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665144.0,535176.0,860200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226cd3b6884d500a388805440e96af6d84c7b957e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667756.0,425596.0,868080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202d3efcd7b05afb1b74135080e2a4756cd38e52c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B823336.0,336744.0,936200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2271bcf4371b0ec880b6132b18a0164590f2201db6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616600.0,518072.0,897280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a0f8ff43bc7ae18a0ba5eff8eb6be21dd05b9e69%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B768112.0,361976.0,951720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2273a886c67042e00c872bb3034a1ae55e0e3af7fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693304.0,411480.0,827400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22656de34641f75e11c7c923820a467df7aeb06cae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685896.0,442952.0,881920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a01b12b9bcf2db3b6007e2caa31cdfa05b403407%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719680.0,438792.0,890080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225106803a745a5f5ff51901f437d1748b25b4dd31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720624.0,391744.0,934320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ef2d6dbdd0b878e627dd22941ca56294de7438c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715288.0,445028.0,875000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22513675958ddc20216b156794725459d7fc819b60%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689688.0,441648.0,884280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f383debde9f2eee7c1fa008faa126ddf50f4ce92%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647896.0,454760.0,856480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff0915f14fb502d0ba25c270ac67aea15bbdd003%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670824.0,490840.0,882200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3d2f767f721434480755fb8d107af61908d9050%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763276.0,448648.0,888160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224373a4951d0f170b1f8321578f86e52d529abe43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667824.0,369032.0,793320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221ba7b4600466e11b9e0b441af313367d806fc332%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666424.0,470976.0,895360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a98dbc8e2c001b32f03f0a443d4f809ff939345%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B636808.0,460512.0,927520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22041e97c90e6f7080fbe63f1efd9c9f35ee771239%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624496.0,384464.0,972680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2287886b887ca7c2c3db3ca3fee23cc504722e48d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716960.0,458576.0,961360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b265f5a464a4245a13b16426088fdc62e1d03438%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666024.0,441936.0,855760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22078ab3175510a82fb9ec19372b0213a6732f26a5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B602984.0,365192.0,977480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227b7ba98a6f98d1abb78bb6cd4d33c1d515ddc385%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711672.0,435080.0,885720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222f02609bf7d20d53a16b79543ee2cd0145e3c37a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707200.0,440256.0,922240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee7d7c971a795330d4e16b751de715c42571fea8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B758440.0,361376.0,935160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223bc154711d5eac22394f7614860f2bb21e668126%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673632.0,437496.0,926480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277495a6a2708ea3e9fa5a3eea15932e2dbd89e9a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701920.0,444920.0,883120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227cca7d4e8c0d14ed5f7504eb14faaa8bf49c9728%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673344.0,402976.0,856520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b8f84f14fff2e90dd2bc803438fdfc55dea4498%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651488.0,455672.0,894280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2270941e97193d848288d33a012a1d09440afaa888%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673296.0,451688.0,937800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22843e81a8634e25aefb7a91b815f9cff49f264abc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623752.0,409448.0,820120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f34fb06286d175ac05926246fab65cf16a8b1a0b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717352.0,459280.0,966520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc27da246b106672bbea8817fed64c779a4f48c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643592.0,389280.0,921160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227dbfbbbd99a3b22e29a68f8e7754f27cb553c46d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712784.0,388288.0,906640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229836912fc2201b7f8688db9257ca03a49802a860%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763808.0,362360.0,947240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b06a4ffb078759e51df97419a274b4cfdf879a87%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649368.0,410056.0,948160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f11cb29ba30842419feda77ab74769378c34d5f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665128.0,420384.0,936760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22166388051af83ac83ca1cdba4cf2795f0c33c001%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654608.0,394120.0,915160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22633f86a48accacf693ec20036a347ca4c4ad449f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634000.0,414208.0,910360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b0e14e89b47e923f2a27cb264c0d3044a4329a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713720.0,446048.0,942400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224953c2578fe51e9902b94a16e948515fef2817c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625320.0,394064.0,807400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb725f593aa0419983f9ae7abb0ff39e675dd4eb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670536.0,399592.0,959080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221cfbe7b075926709ffd1afbe9a8cf893aa6ef78e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716440.0,439840.0,914560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf70ba6b896d6cffc090af205f85e016ce005782%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637008.0,397680.0,818800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eb555288bab66365b4f2f92f33ad6b289aee2d30%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686064.0,461280.0,943080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22729a8221b2833fd20db486bf3a1ffa352db77a2a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620376.0,419872.0,912000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22392dd2012595dbdb3efbaa6753305e6e1c805e3a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635240.0,461112.0,928920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dfe05cc892f38b9031169ed5ecb79d94108e1cf8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B602736.0,416432.0,914920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab2abad79202c09e985dc887bf58ae9888caf954%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B799128.0,352552.0,938560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247f54f074c7320e9cd637de57766956f800da7a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672928.0,446576.0,871400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225722f94cc956eb50df13c92ff2c91e36cde05ca5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B597696.0,365252.0,977480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d81c5414b00c5b7559a6750188adacb9286efba1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649064.0,421100.0,916120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f3535082d068737a9592b1811e7d373b9241728%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645488.0,409280.0,952160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22151fda3ec0b5f5b2d4686ec71c537179d8b60143%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629728.0,460008.0,879280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227d031de45cb6750cbcf616309882cafd5cbde99e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679936.0,409152.0,850440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e10d85fa47308005b4fc31245ec697156594e5df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664248.0,410128.0,858320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e662bd439f7321d963c515a1966218b521b33269%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674848.0,407344.0,860680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22110a9ac386854940b1db5746de71be1ee4ff20ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658520.0,461904.0,891600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22af3940451864561027f28e1fd1b3dabe02dcad33%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715072.0,365624.0,1027480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22588652cc7c2d07f3c58ec37ffd4dd0474ad3474c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669024.0,422728.0,929920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2270aa6eeb66937748773d74c483b769eb658acda1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719964.0,461704.0,971600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22493bd840ab4dafb50aaf17a9120358267231748f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747416.0,381816.0,885680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2258f1233cc1e9301cc2d945b38474fd54e5b8e90a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705488.0,391568.0,904000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22abd087249fdd6de04b12cc2eb6ec728bae7f187f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745664.0,441216.0,887480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22308135416a4ba324cbceba4eb5aa35f932c50347%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684620.0,438416.0,901160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8e522827527f03991ca8e472e889ac20df22556%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672400.0,400552.0,961400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22971aeaa5f4795aa2582e14e93a988d7fe1d4da43%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674268.0,473124.0,961200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222143e9155f0896c1e7fa73eb9e45f63134aecc01%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671632.0,441448.0,891040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c9db7ba604fd84d19b8dbb996669d91e2c9a5f80%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634224.0,465872.0,935400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226dc4bc94177737d3370ecc6226c47b7ed981c84%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674196.0,444720.0,931800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2678266f0c303e833b190e7f27a368abf84a8b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673512.0,410248.0,864840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cabedb7bac68846461bd64b1d6b201f5d3d48a58%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700400.0,384144.0,946560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227826cefa2d67a6a834f15bd510777ca7803b839%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671992.0,398984.0,960240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223fab2b8c77c4eaef88f08688776f8ad1c145468%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716648.0,464864.0,900360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242ae11eab087fa6862d9c03743529d9cb3587e51%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651548.0,420208.0,916600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22585b498636e3d17eac3ba72f6ce62e0932cc3e0f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672408.0,409688.0,868080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2299e411498b162158534597b77346e4430703f2f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635456.0,414352.0,907680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de6cb22e32bd5bc8f353b17683f006bc0a00ab73%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720080.0,470216.0,975200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe8db9d379fd79b48760dc886f18136f1253647d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658512.0,457728.0,894760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22235d38c23ec6aa94b91fb53a4d6a973aa82de776%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676608.0,506336.0,865840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223a453fd3881e5a2d41885795474060881bbbd1c2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649880.0,409016.0,890200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225e4d5db7a19ecb56609925b46cc110030e82fce3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714424.0,440448.0,970880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297df3b3170937ff153a61f3cf455dce5e6c98410%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B759648.0,438048.0,882680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229780bef38876ebc92bd5e4931354b7beb53d6b12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672008.0,440032.0,888720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7318e7d01e0ab4acd0481d4bb295f7893baa114%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697768.0,359792.0,1043240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2238dc3dbe42e2e414e8c080b53a12a3f20d7c0265%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719944.0,445168.0,1002920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272f7fcd99d65e5305bb7356135e07e683243c3df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706584.0,443104.0,881520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8a35aeec4530fe5b6cfff8a3a3b9b88ca1e3c94%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669824.0,418144.0,887800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c181add90aa3c57bf7fbec7d1d6e4b96fa3c2f74%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734048.0,372440.0,919720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d94a64f3bdde9deb28504b542603da0713763eeb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676224.0,436120.0,922960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c0acbb8c8937103f3d3130495b5399b5e8355ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723304.0,379872.0,898640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221266abc748b76cdb5e1e736781280ddf6324b0e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765184.0,432984.0,881800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22113b11f453ca97262b4360f3ef2ad7074df7f7f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B570048.0,393248.0,812680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f5b72b7f4021d8b0ece3c7bbc0546e5e19994f95%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B587560.0,363904.0,979240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ec16ab739641fced2d18041536983bd20d38ecc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628056.0,459624.0,879680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f86f5e37c1ff3ebb739a01eb73f28bc8dd0a210a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731144.0,357888.0,1049560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8f84e86ecedf1790ca41b2833f676c476d75d9e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741128.0,414152.0,845520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc1dd9ff61451fa6e8a514932d00b8dc21eea7bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716368.0,366128.0,1005840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22057caa440f4cb3a0292795ca6ec6fe7e44caa232%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669608.0,406872.0,948800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2209664d952e00f125106a5a5ac6a4b43d69c769f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681520.0,450872.0,920080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22396335035c68a0f32ef4c4ea35496f6b508a2403%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716776.0,440232.0,871640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2218b525ce3943fedb09dc60758ad0162ab675d699%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696296.0,359384.0,1044120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f70db222eeccbf97a37c76b43d9d6b7fa984bd7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687268.0,481724.0,973680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aaca9490b4069e3d75a04c86b5b7a5f7e298c9e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614160.0,463520.0,872120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b9eb5317bbe5cdfc8431fcf92fe7e7d6a445ba4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644352.0,461840.0,934360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aec5883d69c6347f99587f10f6a0143d4d8d418f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642096.0,459656.0,889560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ba1ed450cb82776f88df44449c5a871504e822d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708936.0,360048.0,912520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2212ad7525c28b604af1505734711a2d9b8b590a05%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637952.0,444608.0,820520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a265b22ac4fca4774c0fe800104a936e35b8a37a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644432.0,458640.0,931600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c60b8205966298f2a09ef8231d69b03933381e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715072.0,441800.0,984000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2208789ddbb7ff2ee079463bd5d4217570f88f8869%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709572.0,436412.0,952000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ef1d89a6a264ffecd77290679fa52016bba7a56%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670464.0,450680.0,907640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e89cdf8868c02afa09c23e501ac8d1992b4cdd8c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693800.0,401572.0,900760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2236f1c54653e15f564747f369f5221b1cd68289d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674336.0,413816.0,881120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3c0c00998f79053f62dd55bbf4b0cdc9716c777%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699376.0,375152.0,970400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ede8b04608451899e91a8b325b28bf7e1b8bd570%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748080.0,444064.0,899720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dd73b18b81b35143f85c051a62a3a354ba7f5d77%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615248.0,460496.0,870720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226116703c96a8f9bdb77d196ac40344d1b31059e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700296.0,394240.0,928280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c49828af3f712521ce27e4f6d81267abafa7dc2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703696.0,434852.0,886000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224aaac7227cfb39dba6981e55ac88514076bc8cef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714416.0,462136.0,898600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22102ef6bbe1c9d517ea7813c45b887b4e17397e3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B779800.0,353784.0,939160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad966120e538179ab8cdb6193469a53ea375d752%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B586412.0,474148.0,853600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d76cf2d40f572fa345ba80be938d729f304cc5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673936.0,434624.0,880320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229405b9384e02d7cba411ed858f22c7253a389d4f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711472.0,444568.0,939400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c572c24579dc6ced5e5b589e22cfc5fad897757%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712584.0,444792.0,941440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229a6fd0f6fb7ab7af00756ab95206cc340e92cda9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726136.0,514840.0,909120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223934f213060d3493b24491ffb13e69bb4ee4bc0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673128.0,497464.0,973360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2239383d4fd0dfcdab9a56bf05c4b9e536d32ff36c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615160.0,363560.0,993560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22103f97f8495ca64cab9f9fdfe4fcbbb3768b6618%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680952.0,490184.0,869680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2216ad39d310f5a0bb945cdd017584e3825f5ab7a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640504.0,457904.0,919560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ca21f087e5949a08920cd87627130c9fb5ee1b8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623824.0,383700.0,893160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f61d63fdd7959ebb592ae55c710ce0df038e332%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673168.0,443176.0,932960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2284deb05ff357e9a7ea3b50a89e258d28dc1f9c9b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710352.0,435000.0,957880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d79c735630ff96d98f33480df8105fcfe3bf3d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713264.0,447576.0,878640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b867d30796d6c424d79d345c1a0f2af3c49c2a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634676.0,441940.0,816960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22237ec8ec7593524328f8517377554475b576271c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690720.0,408928.0,834560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b67b8bde2c76eb9c0e922ca28b1bfdd6ba8afdf1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695920.0,388296.0,940920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229892b1b1228f8cfb3d241c2503ff47628d5ae80b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709416.0,449612.0,882680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225274821db0e0db2bd4a8af2b594abe6ad3674950%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732952.0,352232.0,1059000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ca326a8f78e8f83787cfb8074d85e8e99e1a94a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634320.0,463928.0,931960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c8726436f65c650e63a99d20694206cca33660da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666944.0,470952.0,895560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fc563b80b6a8d6022694d61565d58d1ab79232e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640256.0,460000.0,889480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d55a34da553a1c37f759cae642447fe1bfbd6f2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696320.0,404744.0,892880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e947e86aa4c3d37adca6b801dd94144c670c638a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721208.0,445040.0,865920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf6bc6077bca92a848beb0ad2fbf0121646c5908%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B614408.0,406344.0,815000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2257f4309cffe6c9c0e40fd218721c0cbe4eff1ee3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670280.0,412080.0,870640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22484c12c5d3c2e07da0bce54b662bce30d26538e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B836280.0,330936.0,935520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22517604f0cae11921e4d3db874f7a73b9d9c16ae3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632592.0,395136.0,958400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fc10a550e504923cbbc5a1701bc3aa7b223aca12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706296.0,434448.0,937760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2213b66775710970973e8053702bd9bf00aac5e7a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714616.0,435840.0,888600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225af936dc64caac9b5519bfbabe9d1cec70392da1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658336.0,416544.0,941640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2265e8adfe32360082f5ceb066b3f9d9d64aa981f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658544.0,415368.0,943040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6c6ede1611803f299adfdc44d41dab6c7a47be4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714448.0,446480.0,877960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7793749f223eb2d92c8e0c9780d1c5364c214b7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744584.0,423920.0,965400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2286a0987ca1560102e6ec366dd0799c153ddf721b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632600.0,460800.0,881800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2982e3d1c2ccad5b839b9ca71c6e95511e92aee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B786984.0,355072.0,941280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f3c7b1c0054f5dfb688cd3d27ce0707dbe00310%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715472.0,455416.0,959920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203140081e6dd1af17874bdc6eb27c6fc05605256%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719248.0,478400.0,986160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c1cc8a4d6063c7c3c812394222bb58da840594d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686120.0,481280.0,988240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e653b97128a41ef4c9953b079ebc8e181b4b6847%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B710716.0,444060.0,939600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f9642fb1dc94bb710472f089b34f25e31c869ab7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702568.0,376224.0,976640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b9439367717e5557dbff3814b44b62369e2aa23d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673784.0,402392.0,851560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a929f6ca967404af27493cc479518dab19026b1d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715768.0,451432.0,955520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22035461e6364f49d12be950c0e256e2acd28f85e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672536.0,449088.0,937080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a70f78ff01c75b4897c7c04435096335a62c6376%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668492.0,424172.0,868280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd1e8ec020dc00b40fb1a807497ac99e070abf1d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670008.0,410184.0,866480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229f54708226c57103a1259875c8dc0a4607379880%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767592.0,401932.0,962800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb74fd30796778cdcf0ea4da507a38b18d514d33%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709400.0,428400.0,878360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224afeb2ec84a3530412a03b1631bba26930bead97%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736904.0,441272.0,910960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224b882849bcde6e6be345a6c51ced439288c5057c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711712.0,431256.0,951400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221964a7158d3a720b5f2c411e396f553fb6f9716b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716848.0,366960.0,1027400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226017b1cbe38b855aa41ed9e8833a9ecc70050314%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656808.0,416144.0,942440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c2b4a36ecfa3f3a44d06a21c0204376d6d669553%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767592.0,433608.0,880480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b9f5f36d274df92b48dd02aba6e41a2e62dbf453%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674088.0,444248.0,895560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c5b728045919534f047f67069a7524bf9154f18%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715544.0,442656.0,870000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bda608bab81a2ba6bc33de6fe5123ee4917d8549%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688216.0,479264.0,968240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228cbe34c35c20e917a8a6c8cb50e8aa1c102511e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B592352.0,394776.0,814800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9119a61c4abb7ffd13dca90e27a30d86ddd868c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673888.0,410240.0,866720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282b9795941c0a9664c0808951277b2508389d102%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640520.0,459960.0,921440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4c0e726882ad4aedeebb46b0f69c926ea346fc2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705536.0,452600.0,889440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2264bc6ec4e2bd3162aa4ec32600981cc8c4013a14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B780288.0,354144.0,939920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22db5a2b62b411e839e51cb186ab5821d7e06a5a67%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762520.0,360384.0,920720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225b078fd7b80ab60e7fcac6bf6aac962e3a71ac17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669656.0,482520.0,889120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dfbe888e40fa997868335a59f514d81587cda5b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673944.0,478864.0,963600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e78e0e246c8747474ce7c23f171b336de2a9b91a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680016.0,499480.0,868080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2221c66f31b882ae9af28fe366a27d2c12e559dc03%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683340.0,426292.0,904120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d30de979a099561dca6189b43c0f2893b4ea226d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657152.0,397424.0,915440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229624a9398cfcbb0db2f1882c6883835fe409efe9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709000.0,398144.0,848280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d1454258004536f9ac2b7c276eb36b2af46e7542%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705888.0,433784.0,936720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bbbf21a34b7f9c53f19c3454e3dacbe23b6ba3b6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684552.0,406648.0,902480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226426e697f138928fa05de950c0a198b9014a71e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676088.0,450272.0,886320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f34487ff6eb8b13171401af73578ba4686da969%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681668.0,434424.0,907360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224589acac8411704228a4bc6374d526ab6679abc5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B815408.0,330004.0,1006120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226bce19d437364070b8eb42d57ac18ab9f7f28f2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657416.0,449944.0,861640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eef2786ce1bd60e5fde8c56535d80cc30184588a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704056.0,400368.0,883000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b028611cf848921aefefe309b072d2506122607%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707320.0,396632.0,851360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7aa689c10272bf5ee62dd46b56b6f0a678d3a59%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634736.0,459376.0,883320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f34ac1adbf0a0900850ed7e1a490b65a87976584%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B807112.0,347624.0,936840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22547e53043c7804d6fe86291a849002c68aea1747%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620376.0,513480.0,899760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2238bdc5a28e42e57bec9e32deaa1e790eabfa8bba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656164.0,467084.0,909160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b93acfb2bfec7065aef731456052ea6c74399cc1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B831256.0,334424.0,934200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228859ef210e4f32f15bd126f76f45f8aa227fc7b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691024.0,472408.0,959960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223fdc6a21c34879d7713102ae81ecaf9977b23671%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656736.0,413472.0,845760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a676ac17ef409db5b6cc2587a544f5d4ae104981%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737784.0,413528.0,850440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211fad3ff1f2d58a38c879d7399f9a53611d26014%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711504.0,358072.0,913040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f90450ef48da5a79a28a72755c8a43a464b11ae8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B652520.0,476032.0,901920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d32511c243433485ae73f6242e1f29eada97dd8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672904.0,444112.0,933160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa132f2dfb09824c22338e86f8ec99a191a934cf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675816.0,408320.0,862680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222cabc87be4de22fbace28efcf32aaa3aac39211c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B559424.0,352040.0,987440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2251fe22ebbc76fe4abba7d95479763af3833148ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717928.0,491344.0,1002280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229932f420acfef4118e70f569a2b3818fba1ea991%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683760.0,458368.0,940920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b336127319d45bcd1745503a208879dd67f3895%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737912.0,442984.0,910280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ac680b993b84beb88d042346469af3fd0ae7e0e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B629840.0,440564.0,809440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f552a74a8f6d134b1cd28727a6d93b08772f681d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686216.0,479184.0,969840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f57693331d2d8c6984ee3033657b4103911eb76%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720528.0,467664.0,974640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a08fc97500bd8c2265388d14f1db510cc3a4517e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704552.0,452256.0,889920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22944c501794803d4252cb61ddedd143403ad98db5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706032.0,454176.0,899320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3e2752ce130bf5a68a0d20523bbef667e2f8732%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734368.0,352280.0,1062400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22911b50556c0c4a2d288d976b6db989e872fa5aa8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B727184.0,359616.0,1047800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cd07f653d76d06256e4d6e3e97b81a99da638dfe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B598624.0,419464.0,938560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae0bf9558d2f519153c9f92f2395e01ac4342013%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B771928.0,448968.0,882200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ed0d186a0bce736deca5c5079e74548ea2d8b78b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668080.0,440056.0,859720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c1b31b0792d67e8ebf61fb7cf5414d6af3ed9528%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630924.0,473624.0,874160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aebd9c038e72d6d6885f0e71b2c293cf9d64b678%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626640.0,395464.0,894320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2209564d6b527473b7d12464978a91643f46ef5a1f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703880.0,394200.0,928760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225da185c660f571e1cf3c6e42bb9d9c86333c6202%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685920.0,401448.0,1032440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226da04d8ba6c9b4dd5f70cd71bf4d80a97827548f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706960.0,398704.0,852280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229772216c75fa24991fc7e48e12ff1544dd4f435b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B654448.0,411384.0,846520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226e088de5052f6077bc418e1b2363b487d13f4a28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705168.0,394276.0,901960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9288f42860d11d2882191d54126c9ae6b97d90a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722104.0,451880.0,841240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2217e1dc5b25643e852958e53aed1e48415f9dddae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B641048.0,444272.0,822360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d7adb7e8e61e766fb55d2dc6bd9bf05ee4b391a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713528.0,449704.0,951720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22571cd93f9b5e1a4d35623d3b09d33c35552f2e42%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677976.0,519280.0,986600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2260058bf9ab91ae0506caa7f594ecb4f10e9f332d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638080.0,412576.0,905080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c6bbbcd7435bdb8401fbcaedfa3c3f2b826a580c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B616892.0,395112.0,802320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fa0c19ada16c3e2d7bfd2db598332f3892c3dee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738368.0,439760.0,888120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22afd5530e20a3368438a1a772086d7fd363ceea0d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680224.0,420408.0,898720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c4e21eab815adf2ac3ea4edcc93357e72cabc37%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713920.0,441544.0,970120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220f12ca2e4b48403ee1ffbeeaf7f1f6f51aa67867%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716624.0,469096.0,902120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b74b4f9624f13d1c34cffdc210dda8f94affe94b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647080.0,456840.0,932960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e448089d1ea18c7bf21586824f25a15b0b971d0f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671920.0,428688.0,923040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22917bf32b61591484d09b6b557b31a65d4aa4a546%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658816.0,468192.0,851800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2bf09a8d9bdcb584ee25051569e66d13c53df83%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736648.0,395752.0,945360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d13a24263f9bbb43e4b7508c635019b413509d17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B733128.0,440200.0,890600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22997ff495a26191f655dab90e44709192a7b7749a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765656.0,361168.0,949560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2242f5df7ace7de7eace9bfb9c6108125b6fba5f48%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699016.0,378608.0,964400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdb4bfdd57d502c2a6dd3a2fd343949e715b2768%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672752.0,460736.0,944040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5c88aec63ae9b9adf65a069aecb94e304eaa412%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718048.0,426128.0,944840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229ccde56864430fdd56a6973a956820dcdad85d5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B610520.0,417592.0,913040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22189163f7756c66999528a9fd3147aefd1e2d6991%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743448.0,412816.0,840560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0fd56f2a239b793e1e1914c5aa348b38fc364e7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617200.0,368120.0,892160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22025311cdc57bc900f82a6a5f364d2e7ff5b2f92c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674664.0,380112.0,1084640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22954b74a6edf6b09bbe7df4ff64ce9425ffd54aee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762152.0,358024.0,935960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fc9fee6b2b042635847f52d8769d2f2150721be0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701136.0,376184.0,973480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253ace30a57847cf09169f08569e94567d5d9f67e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656560.0,412192.0,844800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d42822c96edc32ba8d5c9e6a8ccae6b3457d6c7c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B651648.0,454168.0,932280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2288ddd2df6e22a7ee1a84d84b68d48cd8c7057734%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715432.0,475296.0,851760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229610f02478f1662beb6f1c92c904dfe6981a78b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621776.0,484720.0,872800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22df6a41107e8425961d2f182ad1ea883849d43e46%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681504.0,390872.0,1055200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2281deb1c6e32ace4a745c531882199089e8f2e55f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685656.0,408752.0,838840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0950df1fdc407257317895a92cf8899d68429bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728400.0,458160.0,840840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22519b8658deab1fe56413f5d7e7e7119bd7987ad9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742048.0,439632.0,887640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7994a1099c2e0d2e8af52d7aeb50a93105191d0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689600.0,447540.0,896080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22187461ee526ce27619a135d45c0c5218d74b1917%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676160.0,430576.0,875040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c0adede4629a7317cbe1a9535117c8babcd774e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688624.0,436776.0,900280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298810908cdba2b8c67dfbfe24afef3e7dc6b1c02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B753080.0,363320.0,925280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e213b4eb47e507ed64b4c125a17dfc3c502478f4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716112.0,459624.0,966040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2234839139d498ca3e3ae3162519498ee67ce813fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B677928.0,396264.0,843840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a1736f70d94498acc772c67697f8f36e4d6f2294%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736488.0,427616.0,960520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a3c30d0ef8a307492285d325126ebc6af12bd641%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638400.0,473248.0,874320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229062169cb0a847c2617ed0cdc4237d2a602eb277%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657848.0,463584.0,943480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8c73926fdb9ae406fdbf71ecddb6b1f1bf384c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672768.0,511256.0,868200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22676adda9bd2d84b75180e8f4a95e9961c1560999%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705464.0,375296.0,901080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d505b54caed71c86bba93ae6e02c8c6311b9928e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732944.0,429808.0,958600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a81fa3ff50a3959a2192eff3a5bcffbb25ae425%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732032.0,375292.0,915640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb9b36cc2ad635ac35daf7628d914556aa1a2f9a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676448.0,393416.0,840480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b48e06a59c6e75ea7d478ca0d99c5241ccb379a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B712232.0,432528.0,949080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fb7764a85ce34ce9538a15e5b2fc02fc44792c7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739896.0,410408.0,845600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282c6376c53a1754f77ab4c61e9866f6991a48455%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676708.0,395752.0,844360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22060d6f801698ef48d933c607cbdfbde340899b0a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679336.0,382896.0,824040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab657cd7ad566e5791c450097642db2a97fac6c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728964.0,456780.0,846040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285159750bb2c67622998f4a6b567d0ec1274ca3f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687600.0,479256.0,967600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227df9c72d6b5cb0d3ee8e7582dde4faaae529ac09%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B593968.0,424032.0,909000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22763fce0b69be01b384cc0ca41e07e214b024d266%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646384.0,482200.0,902600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d449c47a4c1797e44ac72393d189777c71173d8f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657744.0,414296.0,942640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4c3ed2266de0196c478df1f0c69c0c1a56faf0a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670424.0,517616.0,865560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e4a429258a23dcf806ba1d5c257d94abbb20888e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684752.0,435400.0,910560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227b6db63a9fa2ab4a8982fb41c570e932abb52389%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688164.0,431528.0,908120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2261d012c3922746741f4a54bbd384c4a826b12485%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670152.0,525072.0,865760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eae8f9ca1e59559c6f0a4f50d308ff08c3a04f42%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625312.0,421776.0,911960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f56422a0f924a4a3d7fbe86c0b1f18921f73da2c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667376.0,472296.0,892560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f123d524a9450fcbde3cabf70141e4d41cb72a83%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682512.0,453840.0,924360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e1aff1865ad65a1291204b0bca54513b601a8a2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688704.0,430632.0,905120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2281f1fc2b685bfb9f72d8551f9123fad62e5705f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724592.0,431336.0,958200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292b374887abf09efab18f87afdae09dfae369c9c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681304.0,492904.0,868160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b54a7ab07bfa50d0198bb2b51af431f1c25cf265%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713728.0,451016.0,953240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ade9d7a47b944b1dc9d7b7eb6ab1968e4020f888%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643848.0,404840.0,825880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ad501bb384d1aedf6fa0360b46b0d33f07db3b2b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632308.0,459680.0,881600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fdcb4e07ebe08ef20565f143f572e1b4c3efe3f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B660216.0,461888.0,912400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228fa5cd5783bb0bb4896fb35d3c9ea74e2772210b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647536.0,455280.0,856160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b5cc44ddc241387a870897a7bd411e9b9563fae4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626808.0,409200.0,815000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220cdbf0d74aac3e33ccb7191e7d5c8e5814e8574d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683816.0,485048.0,870040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2287155ec670953cbd49feb330e1ab635a55e0927c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686680.0,482072.0,987800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b726941a646c1dcd1bde7d2652d5880740038d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716080.0,441032.0,916720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226897cd23addc181c7f3e44f8baf6f58dd84fb0b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718520.0,459912.0,970440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c4bd300dfb83ca92eced8957a2b34640197eb489%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683680.0,439920.0,904840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229224cf4b8a792a0bbf9db49df2e9a6774905bf11%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722344.0,479312.0,903920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2235f8677e2cbe8c088e5603e09eb0b4992d62e22b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714304.0,347960.0,909120.0%5D%7D%5D,%22linkedSegmentationLayer%22:%7B%22segments%22:%22segmentation%22%7D,%22shader%22:%22%5Cn#uicontrol%20vec3%20markerColor%20color(default=%5C%22turquoise%5C%22);%5Cn#uicontrol%20float%20markerSize%20slider(min=0,%20max=20,%20default=5.0);%5Cn%5Cnvoid%20main()%20%7B%5Cn%5Cn%5CnsetPointMarkerSize(markerSize);%5CnsetColor(markerColor);%5Cn%7D%5Cn%22,%22annotationProperties%22:%5B%5D,%22toolBindings%22:%7B%7D,%22name%22:%22inputs%22%7D,%7B%22type%22:%22annotation%22,%22source%22:%5B%7B%22url%22:%22local://annotations%22,%22transform%22:%7B%22outputDimensions%22:%7B%22x%22:%5B1e-09,%22m%22%5D,%22y%22:%5B1e-09,%22m%22%5D,%22z%22:%5B1e-09,%22m%22%5D%7D%7D%7D%5D,%22annotations%22:%5B%7B%22type%22:%22point%22,%22id%22:%224a1cbe364de5a8a950839ac95ba8c8385f4b1c2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689808.0,463944.0,894040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a83f538c46f84af03ff381169120544c0f2e996b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718112.0,481248.0,912840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b5e64b0d789f8e56f01943b47729206d5260dab6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646192.0,526080.0,934040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22008abd9788160cb18fc41eacb96e28d7c9749036%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625732.0,388188.0,966960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e77b53b30a82b20c0e34721360739decaccc25ee%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B787776.0,552192.0,884480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4ddccb742540a4dab5efdcc0c6458f7ebace6f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B574280.0,435176.0,867840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a34c784db829d8cbaa613c93cbc0639d57fa4f5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B589528.0,611264.0,798440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2246679731d64dc42ebdba311d4f935538ddbcc3c2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B585112.0,439960.0,873040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c94213e3b42f5e3e063fa91f9021eb9339720538%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643288.0,525952.0,934280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d6c98d9ce4b4b1807fd6ddfc957f79bff24feacb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700800.0,563496.0,839680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22302ee778c0fd440a5162fb10925511029420d636%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699728.0,548952.0,855320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226c20174ed907047d72bcbc0c58c5db36d9dda287%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B785184.0,605960.0,792920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225a3dd30c54f4a9e5b597adcc8b477094779ea07e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765576.0,424272.0,927240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227e08e6637148638d1511d9890c82e4e2ba2e7efc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697392.0,574112.0,885400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5fb84fad3989213e9ea464bd419c56446970d40%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698752.0,474680.0,877280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206a809acc4785f12f49c1f55cdbeb13ee4054b14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B663768.0,603472.0,818680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222259654d70ff6d0dcf4278f626fb526defd0b561%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740072.0,414448.0,831440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221fa3cfaaa838068bff06d7826ac046bbc432558a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726192.0,379640.0,817680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee47056eec166ddddf98a5453864079f42058906%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736888.0,469008.0,839360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b2a696aba02d1b84ff95319db1bd5e90f9e154d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B815536.0,788088.0,853920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22644c56272c6c2312434cbf207be461a4185272f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B561896.0,427328.0,863440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bba49d1862171ed4fcafa4ccc2c38e5a9fceaa35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743984.0,819400.0,913200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e695d8e4bf4c6fe68885c32e9b4f90542142120%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714216.0,417968.0,810560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290cc4e8579b07fe321e25c39e4419d36702c27ca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739160.0,408896.0,789600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf3635ffb64a0b5804d5055dd187dae92661dcd1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628960.0,600680.0,809720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e85fbcbcc09f6e268f60a6004c08f81f3f412af%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643656.0,592360.0,880040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224fb628ecdb7b9fb4e76bcad89f03c084f8c33a7e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630704.0,482296.0,898440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ef717de87d8e74310109be04a3a37e1e9ffc5d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B593032.0,444900.0,875320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22661fecfe7de9010d60bde64f6778c99b4f54bdef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750824.0,441416.0,946840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279f0f6dc1564c787844a996d629be1bfa227b9ec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B880120.0,807376.0,912480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2268c2fe01709d8e84f2fc3a48a339ce0d37b5e469%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B816336.0,811704.0,888840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229e589c48d91b28e9c6e672577ff0317a45b9abb9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694896.0,480520.0,958000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c890695ae9190d93c41c49fe90296ca4a2a0dc91%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749392.0,523792.0,905400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2245b6f7c81c50b10708d27b19d57e612e4d2935b4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B771240.0,442572.0,970680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ead64fa477059b35490008f33120d5ed3c8020bf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613784.0,458704.0,938600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da41f1e38b372d7fe033c1218a484117da93080a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B743688.0,544512.0,831920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22efc5df41800dc8d40e6e3c1ad4af469469bd7a7b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720552.0,400472.0,959960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a99fdc1dd20ed103f3d8f05da9199d70b6ce7aec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B637816.0,599592.0,879840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ef1d31d0c40373270bada34b3646b744c4af98c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740384.0,463792.0,823520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2298164997c4c509574bb78af3e25dee9431f650c8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720048.0,558696.0,882120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a8c1c2c972d5f0c94f429fd2525d6053d613b8c2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671064.0,660560.0,899200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227db4b18eb953818969fa3ff9f30a30dc45030f29%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675408.0,491832.0,877800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22abdfed41ce63d18a8d58e9d30e6eca5e43ef21e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720128.0,414776.0,796760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22564a58d4992bf1b3eb5b17506e4130cee0f04c2d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702408.0,455488.0,848320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c93804157829480298d7439aea4c8afb17f55766%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732120.0,412824.0,940560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22567968dfedf2882bda5f312bbff5afed61bbb563%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617496.0,472288.0,895600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220ceaa99fcd5c268b72c3ce824c5eab241324389d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B779704.0,404216.0,899280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232df7d08b5ad3bc23e0e6995294c7c76d0a80d96%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648856.0,438528.0,788480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222b276aa891b7cc35a3be650a5da769d63f02d0f3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B868600.0,809056.0,908840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220aba8e784e35156706560edc41cf9351a3375246%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B592848.0,514304.0,948480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22073b0488d4d55661c1eeb898c05cc3dd09587a98%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720976.0,409640.0,826440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223167fd002f547b90541923b20498922c84de4828%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731376.0,389576.0,822120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22babf530f8bce6f29e6364ca440c0abd22e727761%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635144.0,465880.0,908720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2233ff97ff31d646dae63d523ad061d2eb85976468%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B856384.0,802656.0,801120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2209937c449daa0e69fc4b8c613a08f6bda94fad4c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B951688.0,811816.0,911680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227cb9ef8bb259ab5be99c66e25c2a9ec1acda09c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619936.0,474720.0,895560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22602461f53c2d70602ac1be19ef1bb276e1cd94bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B773944.0,581784.0,806880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4803802ea6e273d6b69dc2f522121601483b343%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698664.0,876736.0,1037880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22632b622e0ba7145ca10a575e4577b7dfff67bf85%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770792.0,412824.0,914320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22757c9ded93be3e00282cba6b6da70167f1be8bdd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646824.0,583848.0,879560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224411f46af20677749e380adac65006c3bb4e4782%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645948.0,526048.0,934080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224ef62d9d15b6aff3c64776aa94dc068a2f25fd9b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711888.0,482704.0,1004360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3c96609d14f960712ce4c224db5857b3af007fc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717080.0,516688.0,901520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f81bdddc7d9439274f17232a430fbb8eb5a8c658%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B728976.0,491912.0,884800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22195b087de06746570096e374f25222def6243bf5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680024.0,649464.0,901920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd93d950063af92e3710fd30b2d19ff21ad4730d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696760.0,577040.0,923120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227c560804d55343420880da069b19eb6acebb79e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698248.0,555508.0,850360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227224e79ecf55ed878ef0d26f79907654a36f521%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630208.0,482656.0,898200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2227c29b1f96693d73fc8ec5f7fb6e959c0b12ae0a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633624.0,455160.0,912240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cceceb6f92ba7a06d29ff6172e3313c2423c1bdb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B777176.0,352408.0,962600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c2a5e2a763b38cea22ca7279b659adfef198283e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704784.0,489848.0,879520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223152729502bffb389c78a08b9db1ad61fb669830%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716952.0,481064.0,868680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229fa265a061735ff72bdb9f65a416fd7da602f040%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666096.0,449040.0,811080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4be06be684eb598b3735cbf8bba364241ad3a7a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724072.0,513280.0,986120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221f88b7e8bc265ffe7b2665bb0b80aa3ef171a877%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650896.0,441016.0,792760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2240ad6e72f318a87d693bcc41f4dcbba0ba019726%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B771680.0,576184.0,812360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cefab26186e977bf7f34897f3484b0239be6c1ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693904.0,399216.0,917000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228031affb17800a9e3f4c650d35edd30116cf857e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B775008.0,352736.0,955200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232bcbef15c7a40a47fb0594541d4a5f1c273fd8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740032.0,402560.0,951320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d60473fb44a4021ee465a652e2d62abb51d869c2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B817936.0,389488.0,851240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211218e012ead17d419bdf3c49e48f56874822fc6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709368.0,565384.0,902240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c364f3dcc7de9e42aceaf82ba3272f756410db4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B818696.0,388824.0,852280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228a06b2af2ac16712bfef2af5a71e938795d2a4fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B842272.0,383928.0,831960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2281ab9fe1f2ea5a5f22b835596b9b5d7795830028%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706368.0,430136.0,826800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224d41ebe2878a000a2e1c1dce609106e66c99174c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B740808.0,458784.0,862520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ddc46f5d1449c23178c431a5c5f8bdf86609ab9c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B772176.0,425232.0,747440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e62593a988257493bfe7fb35e8dcf66b48350eaf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668740.0,454356.0,827680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ae9eaf138b16ea9b0ca8f1444fefcd8d7362e7e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B794952.0,398736.0,878040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22edc52cea6090c9f1bcffc77677118b773b2ea7bb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B626088.0,602400.0,808720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221d480589f9d0cb50dc19a859feb117db8bb93946%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621128.0,602508.0,807000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22231d984eeafc4c9034c12666741cf2c96f0cad1b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B589448.0,611352.0,797960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2254e703feaebd58c225b40f3d353bdd0ea8ba4961%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B648224.0,439056.0,788080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223496647aee649caf325561f147c166a9baf36938%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661292.0,682936.0,893160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ea13738156bd31df2fe3904890bfa6d148973006%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717168.0,518232.0,900760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d26ed820a43c30b2214648d31a0f3fe5cd0cfcef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B775760.0,411032.0,906240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223cd2578488a88da7ea6274b8689baf274a34cd50%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719740.0,487084.0,933320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2246b99a27631319fed912327a3f698ee31ac24cb4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646704.0,572760.0,893840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227bfb2eea280c6fad8fa9de8309fe341de1ffd91d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B735552.0,550848.0,851560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229fafac14f43f01f02be66151bcdcb828614e2afc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B769712.0,571288.0,816040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231c57201c9c042d68c30eddf12c38b5266c7de22%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B788608.0,814360.0,885720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b759d23f2d3faeb9e50033e395fdb38be2b599d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B977704.0,816540.0,908840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228e5b36f22e7f88191effd3d908a10eb62598348d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B676624.0,503228.0,918560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229dca4f53c63b537c1566cd54fbd6f800cb189f37%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744016.0,461240.0,815960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2239fb774b302748e03068c565326abb373985fe4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B807704.0,392312.0,856520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc0cf2b0817107f465606c88cf1bde40d24f5181%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633976.0,455456.0,911240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc2b58376522b5aecbaa3ffd5445d2bedea38a9d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638952.0,425696.0,890880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ceb6c3825d7bf99528fce3b618cff56a86a1dbe3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738544.0,404336.0,948240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22622622bf9ed012eaae305b724c57fa89033d6b20%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721264.0,409888.0,826640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22daab82d1d69dc5bc175b3d35f7c1e57e23c00ffb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702432.0,459936.0,863560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2203e2e48caf1a8647adc082bb5329b7d7e6a7f68b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688520.0,607808.0,793920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227b6dcc3707c04da98b2bd501a34a71ee2d5a0bd9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748992.0,381952.0,963080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22175dcb1f7268b56b3754742611ced4b10e7f0fa6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B998488.0,823696.0,902680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f973eedb15350702003af8a7bfc24070cae18be0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646712.0,577848.0,887480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9cc92ce3dbca9d3e33900caf8a3a9c6fcd7e415%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B832328.0,384512.0,838040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22da225d1531fbdbbba1f9cf63b11e6abbe4eadb09%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B630528.0,481280.0,899400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22938a60a0426767e639c3335ea3cf56164f1542d7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688880.0,878360.0,1006800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4b6fc96265d03873ee0e2602e38d9e962b5b4f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696256.0,878136.0,1044560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c662669a157d68d268a5db1099f492dbe5e6cd02%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B634408.0,461088.0,906000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226b88741cbc84e4517810c2a5472a27e0b58adc7c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699976.0,552320.0,851200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220bfe25cdf4c6c30cfa5e443199b21d8b651074c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B772192.0,578480.0,809240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22536f881ef216b74f4f49b19f738640b7c9020bc5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702976.0,568504.0,921320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd6ad38c323c3bf2c5c55b532c67b107e3617ae7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695952.0,471496.0,897880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f42deeaf1f7a5bcda1280547079b61a758d1f90c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B832024.0,384072.0,838080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2283c46f7c1d0c9cc7c20874bdf732118c1b46df69%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B592648.0,444912.0,875600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de9a32b8ded40052fa748e292a59f5dbe65e5aec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738660.0,549540.0,843200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2247808da10dc400fc4cf3d59d39c4d733e7670269%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B801504.0,784848.0,864720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b6f29ec4036b81e1ef873dce8b96ba3a28c1d5b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628272.0,608644.0,879520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226463a7bcd1ea7c1c47d81bccf1698c9b15050e38%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717216.0,493384.0,935200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c0ed4d5d2c0d58ac29bf98a62e4830b935800f89%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B762944.0,530368.0,902760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223eccdd2a41b6e19e7ee81d56d7a54ce4554451a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B713552.0,485488.0,965920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2291be3286214d1ccc25be8ca8d8453b66d39eaf33%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B668552.0,412720.0,941360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eef18e88b9a3040d73151dfd16074f1a9906e0e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670424.0,660408.0,899840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0fe0d5c114404adbb3f7d1482d3a065e42440ac%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B800720.0,395104.0,868120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225ba1ad972c4e263be7f10e02f20be8272293d98b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623236.0,477292.0,897280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22156102054486e40642e94e1c7eca87c5cb66ea3b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B783048.0,439152.0,979600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2243aca021f0e56a6cf4bf4747841b264f7fd7b8db%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669116.0,439984.0,862640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229629f0e297c7ffd1a84e25976ffc0851dc51695d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B567912.0,430340.0,864520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ab5d4fa4607f8fcfcc37c656681b1b85275fdd41%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B887696.0,809136.0,771880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221c5fd3aca45625c2a654a1682f1be4fda9edb1f1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696072.0,471828.0,897400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9b60113a5bcec13db54a9189c707fe753f70ad8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683560.0,519912.0,883640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285adbac7a603305e03664bf906a5836baddc798b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B746568.0,804984.0,909440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2282199133e7d15bf2fd40cbd7feac702c521ef31d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722544.0,443960.0,928120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d2bc28d015ecbba7a4168f613d6d3ae94ff3f4da%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749048.0,523352.0,905360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e76b610cb9c0c7fc2ee7230179a514115de8702%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708232.0,545216.0,913400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ae8a2788f5d313aedba6c6c636bef1b00924297%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B930816.0,805984.0,917080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2228d412cbec77a3968a9c57f99f89c3e0fdfd96f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742224.0,452944.0,858720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bb4056ebe2bc8dfc7f7c4e5e5cc3ec502d020177%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700896.0,464096.0,867480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221649fcc961ec5ea3b1c8b6d8ed6808c0421a5153%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B635240.0,464120.0,908440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae53c3e1668502ae4202143602dc434d582f9940%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672272.0,451016.0,874200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e264adb010772b8748f91741ab509f37af210836%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B794416.0,802424.0,862640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2202127f933eacfe900eb30b3d7724c23a5725e7e9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742016.0,546592.0,838840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f5fb1c825460e7695fdc00223a3184a1b431894b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B590808.0,610328.0,800040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b919142a1e2135d8aa2f03e0c44ab64963049cd6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B574832.0,434760.0,868080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fb4ef56ae3f9adbe0d7842067cefd89dab3ef23d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B831888.0,797712.0,823640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226422b3ebe4dbbe3a9596ce9d67cc110803a8642d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723288.0,431648.0,936760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f44079916784cecb75f45aa1141f9fd96b75f3cd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B826776.0,387264.0,840560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22555e6f39c86af54485c2fd5726a7922ece2f9e9a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B715952.0,565144.0,891720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22632b83e7445f26e9d32da424c8ae98d3ce57b351%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698984.0,596768.0,807120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a2a75c482201d8e8d1ed4214e9500763afd71f0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689184.0,587664.0,850240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22653d4f7838c2007193e09fccf5cf15dd13bfda4f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657184.0,693720.0,887560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fa4ef83858de3c3c9d2ddd02a69ab636fb9d03e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717520.0,486752.0,942440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d02fa35b15b28aed20f179e213d8a481495917f3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719240.0,479776.0,868680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22404148728c43fad628d7e93141b421f8cc4dc2df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B557328.0,426936.0,860880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c12a545dcd1b7d474d560f0921292d6080b61774%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737812.0,472376.0,870200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228aa49a155f82381f1a936b2bd413107be8f7ada2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B557064.0,426368.0,862440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22682b610a2bb704a204a5b5eadb064284a430b9e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699528.0,876592.0,1037720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0c24e6a27c8c199e812f50f1d9d6dc922b8c7e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729496.0,474136.0,938240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a61095f688a23d18138159ea217bef6f128b1818%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B816304.0,811576.0,888560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22202dfbd0c292d8fdb60e1279da545c58541ac9c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B923480.0,806272.0,918080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f3412f6b7478b5c3a3f375091f5682643186291d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696864.0,499872.0,888000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f7153830465ee60682c885b86184fc261314e7f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703864.0,589968.0,815560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e50d1b46dcf712be0606ebbaacc3a638597a5a0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684016.0,403200.0,1027960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2286b2bc71d2b2542a420cd8ce10586c274c655872%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767168.0,430008.0,756240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c00c0604dbe0aa31c046d126683fb9769df5fd8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B852344.0,381176.0,829680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226fccb3eb36c461174ac4fa1fd105be19f8ddcf86%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662400.0,669384.0,898240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf56249bedb7674b1edf51729cc6f463c12509de%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770640.0,412264.0,914520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c11a2995d8924fb4a24dc9c5cffb1d7b36939c26%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744920.0,829364.0,919720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3c501d8af87f5fb13960b5bef48e7f4a147ef4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722608.0,514800.0,979960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22252f890f655f717284938aebe4f989dc94ce9f44%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661320.0,676800.0,895120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227376ac5089293099cab0b5b5e60c0948df2f392f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655992.0,482960.0,914120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e0da66c8d07d02043768dc7ee16ce8199cd41d14%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B831952.0,810488.0,894520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c07b9a4a09532c15df77113a6ae083b20fa844f0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B811308.0,812100.0,885840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22920da7c9cc1471b668a135b46dfa2988438f662e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706528.0,427832.0,824720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2277d80a986dc5d32266c21137db20e45a0d1c8de3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B603248.0,609264.0,803720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223bd780eb55efd0860c9f0ddc8cfcf2ac39504056%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B686184.0,408000.0,825960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ee2fe504f508ed4a907b7583509d3ca2e8980ea3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B852544.0,571152.0,839280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22734a944a4eeef3bb848fd4dc6be6e6fb9c06938e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B749808.0,445600.0,779760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cdd4f8d6e3e871a292dd23cfa528691051c103bc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B788544.0,611280.0,790160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22829e1de137501eab38cf86a13022cf4d78666a3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645320.0,602616.0,813720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf26b27463d64ef38f323b2e38640654ec1dd160%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639032.0,471816.0,909040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dbbcc63c63d8360726240b6614d6f5ddc2a43c3d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B902728.0,805736.0,917760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224e3c64af0870504441ce1a24cc388da0cbef79ba%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707160.0,547064.0,913840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225767277b2d4469c75d8f3800057b77c4c15b4836%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B775280.0,590648.0,801480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223ff6a0c78e3be6d1b7cb4fb0b7e331ecfcd1d3e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742984.0,422184.0,840840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e06951da324be47c4afe7ce03287d144997c8c0c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646620.0,579956.0,886240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22284c43ffc43d344ed09300d87c57639ad3daa3d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B696472.0,471196.0,894480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22df164db5bd1994e68e4f9d5051a3aa018bf7fc4f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729800.0,472384.0,853400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f6fdfdac2b8346e5199778d9f54d4320483dc9d5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625384.0,380888.0,977840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e95a63ffe2ae3291fe03ae3f76223f03cb906e11%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B664304.0,458176.0,912480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2263a562e04a2e098d26a03234fc0e4def03a5655e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692832.0,866256.0,985280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2266df6efb74fe3601a749c713913a1105fbee54bd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703912.0,394048.0,903120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22378606435ecdbe7624e6398afcbce1d7809a3497%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B750448.0,442032.0,947200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bea31c82b2a2272b241be757f414509d9b9ac709%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699192.0,876232.0,1037400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220d7bdcd59b744f7049fd7e18b7cb1a91d26a09b8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B638320.0,442656.0,896160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bf3f85b7015077a2c14e6d1c66114d3127deb1ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B787416.0,413688.0,737680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a69b2ac2545155fcd6492f4d5426ab1af69c85df%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692608.0,603744.0,798800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22545e49f4d484ef115b9fa71bf41a5e6226e3854d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763492.0,554784.0,824240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ecd048dcd36263ddba12351adf12ecffb92c417f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624336.0,619096.0,886200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2205a112b6cbbc340ea6fe3732d40d3bb3265a2692%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B822056.0,792720.0,839920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221258dd825c660ec38ec0e6133db73b753ee4ef5d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617864.0,519376.0,942080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22df4bf081f07920835e065da965631ee76626e186%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670464.0,660312.0,899560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8ebffa429954b68f1cb739ef5805ad62840695f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647384.0,478320.0,911840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22730c6c7a4618341c7dab314cd2bfd963ac7ea60b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690256.0,455456.0,888640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2245543aa97b8f2c9265aae0b0d2c6597bb5478dc4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691144.0,461656.0,1000080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a20461bfdebf8c85b72ef3df4c8b74c669d58eda%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B794960.0,554304.0,881840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d9661e6f6aed586aad67587ffd94f5ed352961c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714240.0,485616.0,957720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff80a8c871955456834cbb642d634483192f56e3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B758120.0,373176.0,967760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b07602cbeacae5f012f75ed0435ffd15699bd36%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658352.0,414648.0,825320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229bb96110c9f82981d7e3a3fe77fa484cfcaee2b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742032.0,412600.0,831440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b1dd356364b97a2b9532da3e8674190203cbb6f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702096.0,569112.0,836800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225cd6198a4d1320944ad4c169c0864045eebfd94f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718912.0,368008.0,819040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c36a2d93ce3f3693f630a0ad2b20616bee3617a7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B726464.0,510520.0,995560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d8f64690b4e7dd48aea705fc5ab8b4b0e9240ec5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693680.0,601912.0,799600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fdcc4e16dd0b22608cd15738c3443e6dabaa260a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631568.0,415832.0,753760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249b72337395c2750b0afc8e1c42c584052d86637%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706144.0,551816.0,915920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2294f768af514bf7b8c5a1d42a3eb52261bf9f9c34%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B679984.0,506864.0,884680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ceb1123b847d48ba975456ff47d2052888287d6f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B741256.0,463832.0,820160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22567e4093ceed9e4ca39538ffe518ad6a2a81de5b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B774532.0,587540.0,803240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22de9424a793d71ea66a710e7d39e24fef3a34e27c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724736.0,454728.0,921000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2291b1bcddb65571f5f073461a9210d02d8590db05%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672808.0,411816.0,831000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2246df9759c10169eafebce975bdedb94399f48afe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B700168.0,552344.0,851760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2292af91b4be422b0a4ff08cda394ad411dc56375a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723920.0,420600.0,795480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22018f9a84e2b2d461385dc4361cc0dd5a45ddb353%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716416.0,427352.0,941560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bc092e6cb06914b23f79df58e5104f521e694808%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748392.0,541432.0,827600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223033033d92e6e8e84cd45f3ec897be19c58a1386%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B774028.0,582068.0,806640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fea6c9f591755acfeb7cd66ed3d0410b32e8c26a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656120.0,446600.0,799680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e1367bdfb9519d14f4ce966c76c40199ecd20803%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724504.0,513704.0,983720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22752201bb80d351b80a68ec5ed01eb8572b513da7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B737792.0,470872.0,869080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220bf787ef7e440f94d90b3b4c56c90986af42ab57%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B742584.0,785432.0,910720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2220f251de024216619a848f308fbd85c7b53c0ee6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B631552.0,415632.0,753440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdd73b6c62cd5a94bc272cf651477a56b13f018d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B844504.0,382544.0,829760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c36f5256291591160d41daff17d97ba41cb0747d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B892080.0,809544.0,769520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b28fa9a507b16840070a7472a64d9ba1f12e142b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B748360.0,448648.0,959800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e6216f4a0952c1d6175ecc2daa9a8869cfa6dd32%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699496.0,447512.0,897440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d85dd0d7ae0c4f0aefbe841e948da656e24c8612%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693528.0,399064.0,918160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fda70efd5fa21ce9560636dfe704a3fe5b09413f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693120.0,877976.0,1050960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227679bd50b352464b2eb03d595058e79c10288c08%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B803112.0,554248.0,877440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229b0b390c4faf0b0d61edddf4ccda1d1768a4070c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701112.0,495208.0,934200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e4a72dd4716b9fa68e42df383ce772107820ed30%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687336.0,537824.0,922080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241bea20298f5413fd1d24f6607c9e558e35f8837%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682656.0,540968.0,916080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bdbcfb7b7d5fd5c4d3b933104c7bb6701a5c63a9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B543696.0,344272.0,994280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e8556854ea7aa9248e30bdee4e75fe0ee7607738%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B891472.0,809360.0,770280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228c0714cce9a38ef20bac4839dc79a707ceca11e5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B623304.0,522824.0,938720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228dcba219766b456836c059024483af582f9e5f21%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640424.0,525620.0,934520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225f9f7e45743ffa64e4500e813d949c2805f13577%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693288.0,475624.0,966360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd04a55cee0bb7f9466e039021667afb175e1c29%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B615904.0,414688.0,796120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5ba4f7cd61e0b6ea937f4a7e81b8a4109d76d67%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B697704.0,488888.0,945400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223b0d49bcfb5f001e2cd1ef44edcf695829e5ef7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B795360.0,553848.0,881280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241fc44c22b55a51a70974d9cd70ff3149a840b23%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B794960.0,554264.0,881320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297ee2c51a6bef54cb703d05784955858716c839c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705736.0,485776.0,989160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2276da8f4ce89d68c3d2d50f9b623e6521b304a901%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B711448.0,497616.0,913080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2297e3ed76aaec30a4f5c503448f82963a5f89ece7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673192.0,554640.0,913800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210704d87f44eea99ca9764c57c288b09c0f9343a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763140.0,356428.0,916240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2214cb5eb1f5848293751c36db3a3acd6fdc65c737%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B702912.0,374656.0,976160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c63fe0a5173f07bc5a3650dc5a400ed1f3370baf%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B620904.0,475112.0,896480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f218b6cb4fda2fe4ef50993d8bf6f14dac318e40%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747096.0,445592.0,782120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2280b4c641bbfe3f5247ca1d05475f07dd0281ceca%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B691444.0,590048.0,921360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2234c08694b32a289cd5039e9b3121c30057f55e4b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B642752.0,489736.0,903880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2204619597f9ecd3fb4bbaa915ba7ef7a339624618%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B1016648.0,823136.0,902600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f17d8161bdee926ae07ca78016355e8bceb2120d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B768720.0,427816.0,753040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225dd48c65ee982ce26a3117bb9bb1fc9e3d178e17%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B1010472.0,823456.0,902400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f273c64d476416e22747a1cf8d23342ba61ae466%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B806008.0,394064.0,860360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220b99d679a68b1d3e3e7fd70a334df668a8b4a711%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736392.0,475296.0,873920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22017dcd0dcbdc6e1d5e7e97797d46d2dda6b3bf68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695752.0,570296.0,874560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2214d8782c36fbf5ff2ff6d9697c3f43a7f3f6c965%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719032.0,435424.0,937200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d4f44e15f30dc90870297ece55e82a73172af4b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707184.0,547760.0,913920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ae6807e27d38e2491f927a12e9cf16c5b72bb4f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693592.0,595500.0,918240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225620f7c1729e9efaa65e1ff37381fd40108867f6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B772472.0,578536.0,809840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249018118bfa0a166375e45e855416e919cef3124%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B625584.0,380552.0,977800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2222c70776d7b2c8d8f3a3ced1bc11fb9587f1df86%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701400.0,582632.0,820560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221aef8cc5f972940fd347ab78bd4f5f467701f421%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B730568.0,548768.0,859480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f6b197bf42c3777a09b73f452413c73baec699ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699152.0,555240.0,848880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22564a89879659910e839f6d5ce2dba5b6e71f69e6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B703696.0,447544.0,842640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a05f37cf8591efcd67f08d58f90418a3f62af193%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621800.0,456728.0,927880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22220fb1340676b0ce797ce83f7abd81dbdcc9c9b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714048.0,529496.0,906680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22961d887538b938a5e97e29f6842c369631f5b3b0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765144.0,557616.0,824160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2274b3917fb0788f63fb4caf51b20e3cc14c49c1f7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716760.0,518144.0,901120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2272c3b5fe4b45b725d6d0001f6a8a8e7bdeb050c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B769128.0,571376.0,816480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b0a03074a0bf8202b50c71c15b9136386693b122%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706008.0,487196.0,878800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a5d0eb881965035efd3cd65c4448639dfdf12835%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B692600.0,882008.0,993600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d3474fb4656330b52fc575de443372cc97e4e43c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714184.0,417560.0,810600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb046d5c4886ab162636214675001d0f612a8587%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B969072.0,814856.0,908320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279b8117dd565f4e2d4bd86c9bbe12ada073d9754%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B861248.0,568064.0,829640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a1b846ca408c681b212045fd576fe22ae3a946d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B785632.0,606392.0,792560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220d56c1b830fc88ab6564d6808b9e32a147a13424%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B779464.0,405224.0,896840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f4f1d74389f3eb3ff8f993f6f12a6473c24da484%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B665960.0,600520.0,823600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3b9b721a06cb0b16f34237f643dee9ad6c5b281%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720464.0,506664.0,896640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e4c271e9ae2189ac66287711012426050382117a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B669720.0,659816.0,899560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228086be746f77e41666232a49437cb45968a9758d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B617200.0,472256.0,895160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e7ccc02ce91527ff8ae2df2ea037802b9df9cc4b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B835824.0,383984.0,835320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223a7ecdc40030766f0c03d11393edb39c6b3ba920%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613032.0,604364.0,805600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221870984b291f21bb0e96df16fa78482300744c15%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672752.0,599340.0,829280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f9c98c27f40862dd72ed2bba3432243219dd7d64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B682880.0,590992.0,836440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b8602137c0427f1457d988d64e0c674dc364d4a4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B658464.0,414528.0,824640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b80491735cc5b856107f844eb23c7a3ff54e6055%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B717520.0,508408.0,920440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b234191ccc687a54b9549d2faeb428a57a919057%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649616.0,437104.0,783800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d262074f66a0b00887cca011178f1b83cdac2ea6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B619352.0,620856.0,896360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2259ebc8be4c3ba6b01ad87430cb94fe9b739570ff%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B764536.0,559344.0,822680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c3f74f940911a9027d29aaa887ef667507285087%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729672.0,422704.0,792800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227c2eb7908f4223c54bf095d544af1acbd8fd043e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657568.0,501196.0,909160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222e2538206be265b27436f91e501fc5635d07f00b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B602408.0,458168.0,949120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f067b04267edac0b47123671663cfabcc51cbb57%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B602668.0,609288.0,803640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c896ec912bf83cd5e79bc6f9e14bdfc4626c1da3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639956.0,602036.0,811760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9b66c199137564406d0856fb41306cfb5881c04%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709016.0,416968.0,815440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6f2c6973fc3edb2992baf6ef413b76dbf909559%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732472.0,485464.0,882400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279f8aef9156810130fa373e23984cc692ee63b30%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B612940.0,415024.0,794960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221acaa99f674881c06651d98f5418c3f1c7a69ff3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687472.0,452664.0,886480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca7bc05664aab32a5677efdbdf7e117816721d75%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704152.0,447464.0,842520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22bd9482915961e66cacfdeffe2bd034cb9df84685%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763048.0,427136.0,935280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ff700213d5527f05d72bc3e4b176304ff186d683%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709476.0,505660.0,919200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2223b86a3582e5bdea90eb04d137edb018764beaed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B655648.0,698184.0,886240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a6db474d54f1c1b73bcd5c5003132e691616e3dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B721120.0,510680.0,899400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2206b65c6402e4d3e58604996889d5b93b775b2859%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B825048.0,810104.0,893480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a8cc8985626c24b52ecdb97c03c10b547f708d6e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B832096.0,565000.0,854400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226aa6c051bf64ccdb281a549659c350a56b48f365%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633488.0,500432.0,900880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f47ea60faff28e3d14cd5852dca3f006c6bcfe5f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B770272.0,414984.0,918960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e3df95536e5c23235663aca02eb7c30396c6fd99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B766968.0,563312.0,820600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22000130f8555105806773e14b4a6749588226bcbd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B739592.0,414376.0,831480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f47d0843e506282409b3a52788476aaeb3de264e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647052.0,481728.0,901120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224f638aa2c77fb2c67a792f9b7bd4aed937e9e033%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675272.0,491944.0,877520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2210e89546d36178c5664272957f1b4820a161a6ec%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706184.0,425824.0,822840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d79c223fd2a3eaaf80b1622a5c061ba02a74af4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688560.0,461656.0,996720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2218e87306a92a9cf35b09e622062dc47910c7c402%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765264.0,557672.0,823360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220c31da610e034c47a950e16ffd293d3a471c5aae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B704056.0,408440.0,816200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f6a104883604640aa88cef3f48d5b685a8ad0326%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B597760.0,609000.0,801520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb190f67f76413c4b9f8f53143d9edb457004fed%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B624560.0,456648.0,920240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22762ee76df0f193de04729a0f18816e142fcd021a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B765584.0,424184.0,930800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c4a0a47023be32bd8bd0600b6a27d36571726c06%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B611824.0,463440.0,887160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fbaa3de51b6bcf826bae7e6a2e47a765d2ab1b4a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B767256.0,361392.0,964840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22463a7a0d6b1d22e04e8799c7a47125094add883d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B736496.0,468504.0,838880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c58743bb362a443008c8e6b613de72e5ad890efd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622080.0,619232.0,888880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2232e5a0e4317d31a9b2835b2a10ee5a15d3ef5af9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B622128.0,619144.0,890360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228786e9e8b368d51b6d6b9d741d95ee8de2e0f78c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B690656.0,475328.0,971520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ef8668ab0cd75cedbd2b9d82e3641a5174144528%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B643192.0,489416.0,903800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220181ab7ac912230d54612b80af142ed406fd95ae%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719680.0,479496.0,868520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fc3e0b7a9e2656ebad9a5b7d0a7e63ee5b6dfd37%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667832.0,661176.0,899400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e9a16266c24412b142901d7c14655b1bfb73bc42%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B775204.0,588060.0,802920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c249235c33b118b15b596b3a58cf8d94fbb93c8d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B647312.0,585928.0,881520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221bc8b2b3b8ab8234af5ee50b9deacfddf979bebe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701892.0,576408.0,826800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c2163d6662bbd297fdc893c8cb7cfb34c63cf3f3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761992.0,430664.0,941000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221bb9b2d1aa3d0e1e46852c9e4d0667d983e12b68%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B754952.0,444152.0,774840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cfc6b64380c68913f1c0721af87c5b77c86cca35%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688016.0,513440.0,918080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ca278a2ce32dcbfd909d1f402aab993fd0c3f537%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694096.0,515200.0,918960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2295b0cdf4d973fbee2810dea37fd7715942fbaae4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B782432.0,598440.0,797360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f8e5f16726f5f5a347c867bbdac821bfd671fe64%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B656176.0,414392.0,824200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22838a71cc858654279accf6ec908b82503a7653d6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B649440.0,479656.0,912960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220a5c0d7e5b50a83d5971f7c5124d6c5171a24f5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B599920.0,517300.0,948840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241988429ffa5950bdd68ac53680c0e780fdf412f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B645680.0,433208.0,774480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227827f345c35277ef1cc0e00e5bc5ef4bd7bb1113%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650752.0,479888.0,913400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22501821efaaf5cc9f3b4db4f503a0741a0ae39934%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B584600.0,440288.0,873160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fe8f491bfc88090b164c6291dacbe5d734fe6cef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B980488.0,816312.0,907320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22562840757f3240cf28af488384d764f74787e97a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B798120.0,794952.0,846360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223175d32574fcc56f182ac9d7f68a736f73aca2c5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B734456.0,441864.0,910560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d547537a868c8eb3d49c35178bb8844f7d6b96a3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B768952.0,419720.0,924080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226f98f48dabd56e233f781aa68a0b333b6a800632%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673600.0,490896.0,971640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%227f26d106db991a1a1eb6e880c4f6da9be202c320%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666160.0,402776.0,985640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e719bc231969dc21f4bac50d678c3c39f310f492%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732112.0,471960.0,849480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a936c78423548734163e830762956e591b53433d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B695632.0,603000.0,800400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cc74b3bd50b071bfc808d9704e12832f54574a9e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675408.0,476576.0,869360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223881fb722e0b9e53ff4861cf4e51aed4c4170ca9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B732736.0,525680.0,905240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22366c69f328c8820a812833316ac69b81d8fd71fb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B556704.0,426448.0,862480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cb9fed985f17db41908f302c84a522ca38fc5906%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B657896.0,485880.0,914560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2231a851683a776d9d35bca9b0c603723216a97d8a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B794640.0,803008.0,862480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279bfaf13e4f90b45beb92f3ddff0c905907c4790%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689688.0,464904.0,986760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2243d77944fe21532236f976963c3a2cf95d2c5720%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B782992.0,598608.0,798000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2281d13759494ef84382f7215fea0be8353adb8c57%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B769416.0,540192.0,895640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22baa9e6c553420624b8e00ee71d15d32db64eab11%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B738624.0,408720.0,789960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0738e6392e9f5beea72f176d2c8b89850b07efa%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B673136.0,411816.0,830880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a28ce143926aa62354f672793286746fd51ecb4b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B646296.0,578336.0,886920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226aaa16eb3b0686147c8f2ce2ece11a85683cfff2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B784520.0,814424.0,888280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d0511d0b916ed928ed9da5df8bd14c2f5adcf57b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B714936.0,485480.0,956280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dc220b1415777d31b49aeed86d584bb69687021f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B632484.0,604624.0,877560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222180cceab67f81c7ac7ca481f0cc821edfd280af%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667496.0,449664.0,814160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220aa4ecb51efb0b1e94f4544edcc6d4c40951c10e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B845224.0,810864.0,898480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221891dac3807fda58d3da7e2f7189f281374167fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688224.0,456368.0,888880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22eaa48b2c169db845e75d787d53024644af46837a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694592.0,479768.0,880600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f5259a121729c0d978eb5c814b707dd3cfea0e8b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B760600.0,369768.0,964880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222ecea799e841e8c353fd2142b0bcf40cf13c0690%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707616.0,409620.0,817080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224cca8e2f8e2a0f7e7f3b3296ad3a3f328a62d0c0%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684512.0,876304.0,998560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e126776ed6072e94c77d5e928deecc0ae127b248%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729696.0,547352.0,857520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2279052052b5a410cb8b9a077fcf71cc3a28da16fe%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B720928.0,504248.0,894520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229784fa22e37b92be078e02176709291afc00c2ea%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718440.0,525024.0,945080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22562704b1275e13a46a60371ba83894e6641c57d4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731680.0,470584.0,935560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229def3a18538bfdb90c18b1573cd199b3d7eea245%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B779888.0,439880.0,977600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22162b1f5fed9ac2b4edd711afd7781b94bc49cf28%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B729516.0,411624.0,792320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c165f1834ba7d62a5926df8c36e2f66b68223c31%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B667968.0,496936.0,918000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2253ca49356bab164f398a92deaaff520e358819b1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B719528.0,406560.0,957320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220af62b73306ca96724a5b0ec32df7d6bc06ae07b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B747376.0,446144.0,785560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228cb3dbcc7a3cb7be99619a538ba6cac96ffa4425%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644400.0,427928.0,767520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c926470c88dc8038587dbe84a110902240fceaef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B613176.0,414752.0,795200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4c38c4398d445a6cb2b635eb2742ef7f9498802%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B698544.0,470016.0,876960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225396fc444b4cb894bce311bc698de45c448adc9a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745736.0,453652.0,798600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22df7a8e04e23fc7f9e25301a21aaf5e22f57430d8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B662824.0,672008.0,897200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dd116853a745e7d9d84283646de0ac4864d3b952%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B666608.0,449080.0,812320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22faaf1eedd3458042e7d63e6df2333e5626671140%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701168.0,582292.0,820520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223e231973635e50349164dddfcc2adc65a77fe699%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B724760.0,497136.0,891600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d5c75a8c161bad42b7be0970d9083a8ea97938f8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B633044.0,484648.0,900760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229c06c5509d3bff5de00d641bf5c76a6f09ebf2dc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701496.0,537184.0,863680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2288a4ac5d3b71fff2ad7fdc08b6a9e125e81486c6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B640656.0,602920.0,812080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22f0b93ef95267ff9f169bdc76f595f7cd97a289e4%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B574768.0,439400.0,872800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22388a82e11ba6db7315860fae9c4b8fc3e90c86ef%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B701160.0,484376.0,905640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220633c73f29063cf8d102d7023fa498368da520e2%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B708248.0,495296.0,914040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220e0d112ec680ab8e6aba6844368581f732680af1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B706232.0,481880.0,997240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228f55b7866b656b7026f5e60cb8864acacebb4af6%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B650736.0,526536.0,932160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ba9fbc6c4b9c9bd961142072795763edc2f33a07%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B678924.0,486804.0,875920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%220223eb57552e111f2859d5cb5ee1746ae29a7a16%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B699080.0,385120.0,948000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cac3b9eafe63ddfc261ee629d3d874b1125f84b9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B818768.0,560024.0,865600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2290cde4022c1c5e2a00dc63608d61514d292996a1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B675088.0,473680.0,868160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dae45bf1734ff368c029adbb0a791a1c39f9c038%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B709104.0,508320.0,921000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22dd535839c72b10cdb18caf3298411965f7d2c9d1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689904.0,467560.0,983040.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2259574e107d0b8a937540fa3ae125dd44d7db676e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B689136.0,907968.0,1008720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b2a3e52c26452b8d01a4ee49e04c1677a639017%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B628312.0,482224.0,898200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221523fdd4480c5c95e2a5f540699b26f7e4106152%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621184.0,521896.0,940360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226ea120d7dad378131b0ba121799023b11f7e1595%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B639904.0,525984.0,934600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229828d2e9adcbdb30a6cbcbef0df8b22d810c69c1%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B888040.0,809112.0,772080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226d4993bdf675460b1e8975f66103d8c08cf910f9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B661848.0,416376.0,940960.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223d93492ed6271abc59f931ac7992ec1ef586cda8%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B716936.0,499584.0,927280.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22aecb3e0cd78d431e26840dd9ce9e37bd9c6da559%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B761044.0,432812.0,943480.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22daf42e34ba2fcfeb482a9ab42e823d4897ccc023%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B693444.0,877660.0,1054720.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2285ca9b0e21aa7f7c6007af9de358ef1011a46270%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B688112.0,462608.0,993800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2226e37bec40848b9e943277eedb66b52013178416%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B763560.0,551504.0,828120.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2249fb83da274ef3fabb181192e84dc14bd4a22567%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B718120.0,485888.0,944760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ebf294ebf9460fe6a58d5a88d536d99abba78f8f%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694408.0,482344.0,956240.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d64487a3a151213b85269fbbc6f14a426ec2fb60%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B771336.0,542784.0,893680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b259d2a22a1d030945383ada04d2d9472f8a259c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B722136.0,556744.0,879360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%225c000d827521ad144bab879e49085181688f2096%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684616.0,589368.0,839920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2200bc75b28b329acaaa6133ed3094a92d18965b1b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B672120.0,457184.0,835880.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224324157b02715888d607d9719c0a5272750c4586%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705152.0,564664.0,920840.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22c6458ae742e3e4897a7ff15be89205d9aa4600cb%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B731904.0,471016.0,848680.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221e906256c5bc74a6e8890eb80e95d0379c14960d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680328.0,410800.0,827920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22d00c77a8cb9c1ea4ca0052a2c073ae4ece7ad03e%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B674384.0,551456.0,916560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%221b6abfb4e2a99e0b4814e36aa1414936d45d1e5a%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B671520.0,457576.0,837920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a4311e585caf88447e724865500b353f5005c56b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B744268.0,408548.0,789320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22cf1cde82c03abc93b8760b4e7fb67b6ff2c620f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B683336.0,590648.0,839000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22ce681b96c91009f869588de72403143c8bc18193%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B684864.0,589144.0,839600.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2261c6d3bfac40ea93ec3ca6ef7b2d90e0d3bceec5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B570096.0,370912.0,810000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22a69ec62edf34f7b5b66260583310294c090afe38%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B723416.0,458824.0,919080.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22843c1612223a6d02bcbe87d490426d3db25dffe9%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B764072.0,443680.0,966400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22114cc29a0e4e1b4992aa1b53a42d037504ffc5a5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B694952.0,486624.0,951200.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222eaa0680c55be663e5bb380ff364756d6e5fba12%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B685144.0,535512.0,925160.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226eb793fe5ac27999ea10dd44a0ba97ef8dc0fa45%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B680016.0,507896.0,885440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22fd8062404508ee913f92fe14e16648785c59413b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B745832.0,449848.0,954400.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%226391bed072bb13e83a4709f8f178eb472ff1e6f5%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B621480.0,406880.0,737560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%224bbeb90489e23d19154ea95cabfcfdb22faa109c%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B670784.0,509440.0,913320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2259fa49bd50b8b75fce43e0ee6cf23f11628e3608%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B687688.0,517248.0,917800.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22b3c2bf933dd7a8cf2734fb79b19ee9e7456df7fd%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B826176.0,563048.0,858520.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%229fc3f408fecedd8c63aa4cbfc8f2ac7e181b670b%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B756280.0,447328.0,960000.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22280242dee14cbb47617d026ddc93c04ae4a2a0c3%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B751248.0,448592.0,959440.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%228ac058404dc8baee571db9ed4cc9a29ea92b196d%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B848488.0,800248.0,809640.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2283d65cba52b5ac4e50ddc7c1173c4e7e4c99fdd7%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B800944.0,784920.0,864920.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%222bc51b6ef190161dc88d48850bc734cf55aecd99%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705240.0,485624.0,989320.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%223f41290a93e8f8545fa0c2b7aa4732acd1de14cc%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B681000.0,384232.0,1068760.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2211b9eece44ebee5a43eaf17686afee40b77f0411%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B705908.0,554796.0,917560.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%22e37e2b5c6512278e66fa0b930fcbc82c812b0e36%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B707992.0,758392.0,914360.0%5D%7D,%7B%22type%22:%22point%22,%22id%22:%2241039b9b3568bd2f3724c070a8b489a43fb57110%22,%22segments%22:%5B%5B%22864691135491912167%22%5D%5D,%22props%22:%5B%5D,%22point%22:%5B644860.0,477784.0,911920.0%5D%7D%5D,%22linkedSegmentationLayer%22:%7B%22segments%22:%22segmentation%22%7D,%22shader%22:%22%5Cn#uicontrol%20vec3%20markerColor%20color(default=%5C%22tomato%5C%22);%5Cn#uicontrol%20float%20markerSize%20slider(min=0,%20max=20,%20default=5.0);%5Cn%5Cnvoid%20main()%20%7B%5Cn%5Cn%5CnsetPointMarkerSize(markerSize);%5CnsetColor(markerColor);%5Cn%7D%5Cn%22,%22annotationProperties%22:%5B%5D,%22toolBindings%22:%7B%7D,%22name%22:%22outputs%22%7D%5D%7D) showing a neuron and its synapses.

### Additional features

NGLui also has additional features such as:

- **Parser**: Parse neuroglancer states to extract information about layers and annotations.
- **SegmentProperties**: Easily build segment property lists from data to make segmentation views more discoverable.
- **SkeletonManager**: Upload skeletons to cloud buckets and push quickly into neuroglancer (requires cloud-volume, see [Installation](#installation)).
- **Shaders**: Support for better default shaders for neuroglancer layers.

## Development

If you want to clone the repository and develop on NGLui, note that it uses [uv](https://astral.sh/blog/uv) for development and packaging, [material for mkdocs](https://squidfunk.github.io/mkdocs-material/) for documentation, and [pre-commit](https://pre-commit.com/) with [ruff](https://docs.astral.sh/ruff/) for code quality checks.
[Poe-the-poet](https://poethepoet.natn.io/index.html) is used to simplify repetitive tasks, and you can run `poe help` to see the available tasks.

## Migration from older versions

If you are migrating from `nglui` v3.x to v4.0.0+, you will need to dramatically update your code.

First and foremost, `nglui` now only works with contemporary versions of neuroglancer, *not* the older Seung-lab version.
If you still need to support the older deployment, do not upgrade.

Please read the new usage documentation!
The main change is that it is now recommended to create states directly where possible, and there are now many more convenience functions.
Instead of making a bunch of layer configs, now you make a `ViewerState` object and directly add layers and their information with functions like `add_image_layer`, `add_segmentation_layer`, and `add_annotation_layer`.
Instead of always mapping annotation rules and data separately, you can now directly add annotation data through functions like `add_points` and then export with functions like `to_url`.
You can still use the old pattern of rendering a state and mapping data with [DataMap](usage/statebuilder.md#mapping-data) objects.
A new "pipeline" pattern makes it more efficient to build complex states in a smaller number of lines of code.
